'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');
const helpers = require('./helpers-c4f9304b.js');
const bem = require('./bem-5d122a5c.js');
const index$1 = require('./index-0650a13c.js');
const index_esm = require('./index.esm-f7817a8f.js');
const utils = require('./utils-21b17270.js');
require('./_commonjsHelpers-bcc1208a.js');

/**
 * lodash 4.0.0 (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright 2012-2016 The Dojo Foundation <http://dojofoundation.org/>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright 2009-2016 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 * Available under MIT license <https://lodash.com/license>
 */

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @type Function
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray = Array.isArray;

var lodash_isarray = isArray;

const Badge = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Define the size of badge. Small is recommended for tabs.
     */
    this.size = '';
    /**
     * Define the alert color for the badge.
     */
    this.color = 'danger';
    /**
     * If `true` the badge is added to the top right corner of the card.
     */
    this.position = '';
  }
  render() {
    return (index.h(index.Host, { class: {
        'bal-badge': true,
        [`bal-badge--has-background-${this.color}`]: true,
        [`bal-badge--has-position-${this.position}`]: this.position !== '',
        [`bal-badge--has-size-${this.size}`]: this.size !== '',
      } }, index.h("span", { class: {
        'bal-badge__label': true,
        'is-hidden': !!this.icon || this.size === 'small',
      } }, index.h("slot", null)), index.h("bal-icon", { class: {
        'bal-badge__icon': true,
        'is-hidden': !this.icon || this.size === 'small',
      }, size: this.size === '' ? 'small' : '', name: this.icon, color: "white" })));
  }
  get el() { return index.getElement(this); }
};

const Checkbox = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balFocus = index.createEvent(this, "balFocus", 7);
    this.balBlur = index.createEvent(this, "balBlur", 7);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.balClick = index.createEvent(this, "balClick", 7);
    this.inputId = `bal-cb-${checkboxIds++}`;
    this.inheritedAttributes = {};
    this.hasFocus = false;
    this.hasLabel = true;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * If `true` the checkbox has no label
     */
    this.labelHidden = false;
    /**
     * If `true` the control is no padding
     */
    this.flat = false;
    /**
     * Defines the layout of the checkbox button
     */
    this.interface = 'checkbox';
    /**
     * A DOMString representing the value of the checkbox. This is not displayed on the
     * client-side, but on the server this is the value given to the data
     * submitted with the checkbox's name.
     */
    this.value = 'on';
    /**
     * If `true`, the checkbox is selected.
     */
    this.checked = false;
    this.initialValue = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true`, the value will not be send with a form submit
     */
    this.hidden = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    this.updateState = () => {
      if (this.group && this.group.control) {
        this.checked = this.group.value.includes(this.value);
      }
    };
    this.onInputFocus = (ev) => formInput_helpers.inputHandleFocus(this, ev);
    this.onInputBlur = (ev) => formInput_helpers.inputHandleBlur(this, ev);
    this.onClick = (ev) => {
      const element = ev.target;
      if (element.href) {
        return;
      }
      if (element.nodeName !== 'INPUT' && !this.disabled && !this.readonly) {
        this.checked = !this.checked;
        this.balChange.emit(this.checked);
        this.balClick.emit(ev);
        ev.preventDefault();
      }
      else {
        formInput_helpers.stopEventBubbling(ev);
      }
    };
  }
  listenOnClick(ev) {
    if ((this.disabled || this.readonly) &&
      ev.target &&
      (ev.target === this.el || helpers.isDescendant(this.el, ev.target))) {
      formInput_helpers.stopEventBubbling(ev);
    }
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      this.checked = this.initialValue;
    }
  }
  connectedCallback() {
    if (this.group) {
      this.updateState();
      this.group.addEventListener('balChange', () => this.updateState());
    }
    this.initialValue = this.checked;
  }
  componentWillLoad() {
    this.inheritedAttributes = helpers.inheritAttributes(this.el, ['aria-label', 'tabindex', 'title']);
  }
  disconnectedCallback() {
    if (this.group) {
      this.group.removeEventListener('balChange', () => this.updateState());
    }
  }
  /**
   * Sets the focus on the checkbox input element.
   */
  async setFocus() {
    formInput_helpers.inputSetFocus(this);
  }
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  async setBlur() {
    formInput_helpers.inputSetBlur(this);
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  get group() {
    return this.el.closest('bal-checkbox-group');
  }
  render() {
    const block = bem.BEM.block('radio-checkbox');
    const inputEl = block.element('input');
    const labelEl = block.element('label');
    const labelTextEl = labelEl.element('text');
    return (index.h(index.Host, Object.assign({ role: "checkbox", "aria-checked": `${this.checked}`, "aria-disabled": this.disabled ? 'true' : null, "aria-hidden": this.disabled ? 'true' : null, "aria-focused": this.hasFocus ? 'true' : null, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('checkbox').class()), block.modifier('select-button').class(this.interface === 'select-button')), block.modifier('switch').class(this.interface === 'switch')), block.modifier('focused').class(this.hasFocus)), block.modifier('invalid').class(this.invalid)), block.modifier('checked').class(this.checked)), block.modifier('flat').class(this.flat)), block.modifier('disabled').class(this.disabled || this.readonly)), onClick: this.onClick, onFocus: this.onInputFocus, onBlur: this.onInputBlur }, this.inheritedAttributes), index.h("input", { class: Object.assign(Object.assign(Object.assign({}, inputEl.class()), inputEl.modifier('select-button').class(this.interface === 'select-button')), { 'data-test-checkbox-input': true }), type: "checkbox", id: this.inputId, name: this.name, value: this.value, checked: this.checked, "aria-checked": `${this.checked}`, disabled: this.disabled || this.hidden, readonly: this.readonly, required: this.required, onFocus: this.onInputFocus, onBlur: this.onInputBlur, ref: inputEl => (this.nativeInput = inputEl) }), index.h("label", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, labelEl.class()), labelEl.modifier('checked').class(this.checked)), labelEl.modifier('switch').class(this.interface === 'switch')), labelEl.modifier('checkbox').class()), { 'data-test-checkbox-label': true }), htmlFor: this.inputId }, index.h("span", { class: Object.assign(Object.assign({}, labelTextEl.class()), labelTextEl.modifier('hidden').class(this.labelHidden)) }, index.h("slot", null)))));
  }
  get el() { return index.getElement(this); }
};
let checkboxIds = 0;

const watchForOptions = (containerEl, tagName, onChange) => {
  /* tslint:disable-next-line */
  if (typeof MutationObserver === 'undefined') {
    return;
  }
  const mutation = new MutationObserver(mutationList => {
    mutationList = mutationList.filter(record => record.target.nodeName === tagName.toUpperCase() || record.target.nodeName === 'bal-select'.toUpperCase());
    if (mutationList.length > 0) {
      onChange(undefined);
    }
  });
  mutation.observe(containerEl, {
    childList: true,
    subtree: true,
    attributes: true,
    characterData: true,
  });
  return mutation;
};

const Select = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.balClick = index.createEvent(this, "balClick", 7);
    this.balInput = index.createEvent(this, "balInput", 7);
    this.balBlur = index.createEvent(this, "balBlur", 7);
    this.balFocus = index.createEvent(this, "balFocus", 7);
    this.balCancel = index.createEvent(this, "balCancel", 7);
    this.balKeyPress = index.createEvent(this, "balKeyPress", 7);
    this.didInit = false;
    this.inputId = `bal-select-${selectIds++}`;
    this.initialValue = [];
    this.hasFocus = false;
    this.inputValue = '';
    this.focusIndex = 0;
    this.isPopoverOpen = false;
    this.options = new Map();
    this.labelToScrollTo = '';
    this.labelToSelectTo = '';
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.filter = 'includes';
    /**
     * The tabindex of the control.
     */
    this.balTabindex = 0;
    /**
     * If `true` multiple option can be selected
     */
    this.multiple = false;
    /**
     * @deprecated  Removes the border of the input.
     */
    this.noBorder = false;
    /**
     * Indicates whether the value of the control can be automatically completed by the browser.
     */
    this.autocomplete = 'off';
    /**
     * @deprecated Enables the slide in animation for the option items.
     */
    this.hasMovement = false;
    /**
     * If `true` the user can search by typing into the input field.
     */
    this.typeahead = false;
    /**
     * If `true` the options are a proposal and the user can also create his
     * own value. Can only be used with the typeahead property.
     */
    this.selectionOptional = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * @deprecated  Set this to `true` when the component is placed on a dark background.
     * Set this to `true` when the component is placed on a dark background.
     */
    this.inverted = false;
    /**
     * Defines the height of the popover list.
     */
    this.scrollable = 250;
    /**
     * Defines if the select is in a loading state.
     */
    this.loading = false;
    /**
     * If `true` the filtering is done outside the component.
     */
    this.remote = false;
    /**
     * Selected option values. Could also be passed as a string, which gets transformed.
     */
    this.value = [];
    this.rawValue = [];
    this.removeValue = (value) => {
      if (!this.disabled) {
        this.rawValue = utils.removeValue(this.rawValue, value);
        if (this.multiple && this.typeahead) {
          this.setFocus();
        }
      }
    };
    /********************************************************
     * EVENT HANDLERS
     ********************************************************/
    this.handleClick = (event) => {
      if (this.disabled || this.readonly) {
        utils.preventDefault(event);
      }
    };
    this.handlePopoverChange = (event) => {
      this.isPopoverOpen = event.detail;
      if (this.isPopoverOpen) {
        this.updateFocus();
      }
      else {
        this.focusIndex = 0;
        if (this.multiple && this.typeahead) {
          this.updateInputValue('');
        }
        this.balBlur.emit();
      }
      event.stopPropagation();
    };
    this.handleInputBlur = (event) => {
      utils.preventDefault(event);
      this.validateAfterBlur();
      this.hasFocus = false;
    };
    this.handleInputFocus = (event) => {
      this.balFocus.emit(event);
      this.hasFocus = true;
    };
    this.handleInputClick = async (event) => {
      var _a, _b, _c;
      formInput_helpers.stopEventBubbling(event);
      if (this.isChipClicked(event)) {
        return;
      }
      if (this.disabled || this.readonly) {
        utils.preventDefault(event);
      }
      else {
        this.focusIndex = 0;
        this.balClick.emit(event);
        if (this.typeahead) {
          await ((_a = this.popoverElement) === null || _a === void 0 ? void 0 : _a.present());
        }
        else {
          if (this.isPopoverOpen) {
            await ((_b = this.popoverElement) === null || _b === void 0 ? void 0 : _b.dismiss());
          }
          else {
            await ((_c = this.popoverElement) === null || _c === void 0 ? void 0 : _c.present());
          }
        }
      }
    };
    this.handleKeyPress = async (event) => {
      if (!this.isPopoverOpen && index_esm.isSpaceKey(event)) {
        utils.preventDefault(event);
        await this.open();
      }
      this.balKeyPress.emit(event);
    };
    this.handleInputChange = (event) => {
      if (!this.disabled && !this.readonly) {
        this.inputValue = event.target.value;
      }
    };
    this.handleInput = async (event) => {
      if (!this.disabled && !this.readonly) {
        this.inputValue = event.target.value;
        if (!this.isPopoverOpen) {
          this.popoverElement.present();
        }
        this.focusIndex = 0;
        this.updateFocus();
        utils.preventDefault(event);
        this.balInput.emit(this.inputValue);
      }
    };
    this.handleOptionMouseEnter = (index) => {
      this.focusIndex = index;
    };
  }
  valueWatcher() {
    this.updateRawValue(false);
  }
  rawValueWatcher(newValue, oldValue, isHuman = true) {
    if (!index_esm.areArraysEqual(newValue, oldValue || [])) {
      this.rawValue = newValue;
      this.syncNativeInput();
      if (this.didInit && isHuman) {
        if (this.multiple) {
          if (index$1.lodash_isnil(this.rawValue)) {
            this.balChange.emit([]);
          }
          else {
            this.balChange.emit([...this.rawValue]);
          }
        }
        else {
          if (index$1.lodash_isnil(this.rawValue) || utils.length(this.rawValue) === 0) {
            this.balChange.emit(undefined);
          }
          else {
            this.balChange.emit(this.rawValue[0]);
          }
        }
      }
    }
  }
  listenOnClick(event) {
    if (this.disabled && event.target && event.target === this.el) {
      utils.preventDefault(event);
    }
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      if (this.resetHandlerTimer) {
        clearTimeout(this.resetHandlerTimer);
      }
      this.resetHandlerTimer = setTimeout(() => {
        this.value = this.initialValue;
        this.updateRawValue(false);
        this.syncNativeInput();
        if (this.nativeSelectEl) {
          const options = Array.from(this.nativeSelectEl.options);
          options.forEach(o => (o.selected = true));
        }
      }, 0);
    }
  }
  async handleKeyDown(event) {
    if (this.isPopoverOpen) {
      if (index_esm.isArrowDownKey(event) || index_esm.isArrowUpKey(event)) {
        utils.preventDefault(event);
        this.navigateWithArrowKey(event);
        this.updateFocus();
      }
      if (index_esm.isEnterKey(event)) {
        utils.preventDefault(event);
        this.selectedFocusedOption();
      }
      if (index_esm.isEscapeKey(event)) {
        this.cancel();
      }
      if (index_esm.isBackspaceKey(event) && this.typeahead && this.multiple) {
        if (this.inputElement.value === '' && utils.length(this.rawValue) > 0) {
          const valuesArray = utils.getValues(this.rawValue);
          this.removeValue(valuesArray[utils.length(this.rawValue) - 1]);
        }
      }
      if (!this.typeahead && event.key.length === 1) {
        this.focusOptionByLabel(event.key);
      }
      if (index_esm.isSpaceKey(event) && !this.typeahead) {
        utils.preventDefault(event);
      }
    }
    else {
      if (this.hasFocus) {
        if (index_esm.isArrowDownKey(event) || index_esm.isArrowUpKey(event)) {
          utils.preventDefault(event);
          await this.open();
        }
        if (!this.typeahead && event.key.length === 1) {
          this.selectOptionByLabel(event.key);
        }
      }
    }
  }
  connectedCallback() {
    const debounceUpdateOptions = helpers.debounce(() => this.updateOptions(), 0);
    this.initialValue = this.value;
    debounceUpdateOptions();
    this.mutationO = watchForOptions(this.el, 'bal-select-option', () => {
      debounceUpdateOptions();
    });
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  async waitForOptionsAndThenUpdateRawValues() {
    clearTimeout(this.waitForOptionsAndThenUpdateRawValuesTimer);
    await helpers.deepReady(this.el);
    const hasOptions = this.options.size > 0;
    if (hasOptions) {
      this.updateRawValue(false);
    }
    else {
      this.waitForOptionsAndThenUpdateRawValuesTimer = setTimeout(() => this.waitForOptionsAndThenUpdateRawValues(), 10);
    }
  }
  componentWillLoad() {
    this.waitForOptionsAndThenUpdateRawValues();
    if (!index$1.lodash_isnil(this.rawValue) && this.options.size > 0 && utils.length(this.rawValue) === 1) {
      const firstOption = this.options.get(this.rawValue[0]);
      if (!index$1.lodash_isnil(firstOption)) {
        this.inputValue = firstOption.label;
      }
    }
  }
  componentDidLoad() {
    this.updateRawValue(false);
    if (!this.multiple) {
      this.inputElement.value = this.inputValue;
    }
    this.didInit = true;
  }
  updateOptions() {
    const optionElements = this.getChildOpts();
    const options = new Map();
    for (let index = 0; index < optionElements.length; index++) {
      const element = optionElements[index];
      options.set(element.value, {
        value: element.value,
        label: element.label,
        disabled: element.disabled,
        id: element.for,
        textContent: element.textContent,
        innerHTML: element.innerHTML,
      });
    }
    if (!this.selectionOptional && Array.isArray(this.rawValue)) {
      for (let index = 0; index < this.rawValue.length; index++) {
        const val = this.rawValue[index];
        if (!options.has(val)) {
          this.rawValue = utils.removeValue(this.rawValue, val);
        }
      }
    }
    this.options = new Map(options);
    if (!this.remote) {
      this.syncNativeInput();
      if (this.didInit) {
        this.validateAfterBlur();
      }
    }
  }
  /**
   * Sets the focus on the input element
   */
  async setFocus() {
    clearTimeout(this.setFocusTimer);
    this.setFocusTimer = setTimeout(() => {
      if (this.inputElement && !this.disabled) {
        this.inputElement.focus();
      }
    });
  }
  /**
   * Sets the focus on the input element
   */
  async getValue() {
    return this.rawValue;
  }
  /**
   * Sets the value to `[]`, the input value to ´''´ and the focus index to ´0´.
   */
  async clear() {
    this.focusIndex = 0;
    if (this.inputElement) {
      this.updateInputValue('');
      this.rawValue = [];
      this.value = this.multiple ? [] : '';
    }
  }
  /**
   * Opens the popover
   */
  async open() {
    if (!this.disabled && !this.readonly && !index$1.lodash_isnil(this.popoverElement)) {
      await this.popoverElement.present();
    }
  }
  /**
   * Closes the popover
   */
  async close() {
    if (!this.disabled && !this.readonly && !index$1.lodash_isnil(this.popoverElement)) {
      this.blurSelect();
    }
  }
  /**
   * Cancel the popover
   */
  async cancel() {
    this.labelToScrollTo = '';
    this.close();
    this.scrollTo(0);
    this.balCancel.emit();
  }
  /**
   * Select option by passed value
   */
  async select(value) {
    const option = this.options.get(value);
    if (!index$1.lodash_isnil(option)) {
      this.optionSelected(option);
    }
  }
  /********************************************************
   * GETTERS
   ********************************************************/
  get optionArray() {
    const options = Array.from(this.options, ([_, value]) => value);
    if (!this.typeahead || this.remote) {
      return options;
    }
    return options.filter(option => this.filter === 'includes'
      ? utils.includes(option.textContent, this.inputValue)
      : utils.startsWith(option.textContent, this.inputValue));
  }
  hasOptions() {
    return this.optionArray.length > 0;
  }
  get inputPlaceholder() {
    if (this.multiple) {
      if (utils.length(this.rawValue) < 1) {
        return this.placeholder;
      }
      return undefined;
    }
    else {
      if (!index$1.lodash_isnil(this.rawValue) && utils.length(this.rawValue) > 0) {
        return undefined;
      }
    }
    return this.placeholder;
  }
  getChildOpts() {
    return Array.from(this.el.querySelectorAll('bal-select-option'));
  }
  getPopoverContent() {
    return this.popoverElement.querySelector('.bal-popover__content__inner');
  }
  updateFocus() {
    if (this.focusIndex < 0) {
      this.focusIndex = 0;
    }
    const visibleOptions = this.optionArray;
    if (visibleOptions.length > 0) {
      if (visibleOptions.length <= this.focusIndex) {
        this.focusIndex = visibleOptions.length - 1;
      }
      const option = visibleOptions[this.focusIndex];
      if (option && option.id) {
        const focusedElement = this.el.querySelector(`button#${option.id}`);
        if (focusedElement) {
          clearTimeout(this.updateFocusTimer);
          this.updateFocusTimer = setTimeout(() => {
            this.scrollToFocusedOption(focusedElement);
          }, 0);
        }
      }
    }
    else {
      this.focusIndex = 0;
    }
  }
  scrollToFocusedOption(focusedElement) {
    if (focusedElement && this.popoverElement) {
      const popoverContentElement = this.getPopoverContent();
      if (popoverContentElement) {
        // up
        const topOfOption = focusedElement.offsetTop;
        const topOfPopoverContent = popoverContentElement.scrollTop;
        if (topOfOption < topOfPopoverContent) {
          popoverContentElement.scrollTop = topOfOption;
        }
        // down
        const bottomOfOption = focusedElement.offsetTop + focusedElement.clientHeight;
        const bottomOfPopoverContent = popoverContentElement.scrollTop + popoverContentElement.clientHeight;
        if (bottomOfOption > bottomOfPopoverContent) {
          popoverContentElement.scrollTop = popoverContentElement.scrollTop + focusedElement.clientHeight;
        }
      }
    }
  }
  scrollTo(scrollTop) {
    const popoverContentElement = this.getPopoverContent();
    if (popoverContentElement) {
      popoverContentElement.scrollTop = scrollTop;
    }
  }
  selectedFocusedOption() {
    const visibleOptions = this.optionArray;
    if (visibleOptions.length > this.focusIndex) {
      const focusedOption = visibleOptions[this.focusIndex];
      this.optionSelected(focusedOption);
    }
  }
  navigateWithArrowKey(event) {
    if (index_esm.isArrowDownKey(event)) {
      this.focusIndex = this.focusIndex + 1;
    }
    else {
      if (index_esm.isArrowUpKey(event)) {
        this.focusIndex = this.focusIndex - 1;
      }
    }
  }
  focusOptionByLabel(key) {
    this.labelToScrollTo = this.labelToScrollTo + key;
    clearTimeout(this.clearScrollToValue);
    this.clearScrollToValue = setTimeout(() => {
      this.scrollToLabel(this.labelToScrollTo);
    }, 600);
  }
  selectOptionByLabel(key) {
    this.labelToSelectTo = this.labelToSelectTo + key;
    clearTimeout(this.clearSelectValue);
    this.clearSelectValue = setTimeout(() => {
      this.selectLabel(this.labelToSelectTo);
      this.labelToSelectTo = '';
    }, 600);
  }
  async selectLabel(label) {
    if (label !== ' ') {
      const option = this.optionArray.find(o => utils.startsWith(o.label || '', label));
      if (!index$1.lodash_isnil(option) && option.id) {
        const optionElement = this.el.querySelector(`button#${option.id}`);
        if (!index$1.lodash_isnil(optionElement)) {
          const index = this.optionArray.indexOf(option);
          this.focusIndex = index;
          this.select(option.value);
        }
      }
      this.labelToScrollTo = '';
    }
  }
  async scrollToLabel(label) {
    if (label !== ' ') {
      const option = this.optionArray.find(o => utils.startsWith(o.label || '', label));
      if (!index$1.lodash_isnil(option) && option.id) {
        const optionElement = this.el.querySelector(`button#${option.id}`);
        if (!index$1.lodash_isnil(optionElement)) {
          const index = this.optionArray.indexOf(option);
          this.focusIndex = index;
          this.scrollTo(optionElement.offsetTop);
        }
      }
      this.labelToScrollTo = '';
    }
  }
  /********************************************************
   * VALUE & FILTER & SELECTION
   ********************************************************/
  updateRawValue(isHuman = true) {
    const oldValue = [...(this.rawValue || [])];
    let newValue = [];
    if (!index$1.lodash_isnil(this.value)) {
      if (lodash_isarray(this.value)) {
        newValue = [...this.value.filter(v => !index$1.lodash_isnil(v))];
      }
      else {
        if (this.value.split('').includes(',')) {
          newValue = [...this.value.split(',').map(v => v.trim())];
        }
        else {
          newValue = [this.value];
        }
      }
    }
    // trigger the raw value change
    this.rawValueWatcher(newValue, oldValue, isHuman);
  }
  blurSelect() {
    this.popoverElement.dismiss();
  }
  optionSelected(selectedOption) {
    const valuesArray = utils.getValues(this.rawValue);
    const isAlreadySelected = valuesArray.some(v => v === selectedOption.value);
    this.updateValue(selectedOption.value, !isAlreadySelected);
    if (!this.multiple) {
      this.blurSelect();
    }
    else {
      if (this.typeahead) {
        this.setFocus();
      }
    }
  }
  updateValue(newValue, isSelected = true) {
    if (this.multiple) {
      if (isSelected) {
        this.rawValue = utils.addValue(this.rawValue, newValue, this.multiple);
      }
      else {
        this.rawValue = utils.removeValue(this.rawValue, newValue);
      }
    }
    else {
      this.rawValue = utils.addValue(this.rawValue, newValue, this.multiple);
      this.updateInputValue(utils.findLabelByValue(this.options, this.rawValue[0]));
    }
  }
  validateAfterBlur() {
    if (this.didInit && !this.multiple) {
      if (this.selectionOptional && this.typeahead) {
        const typedOption = utils.findOptionByLabel(this.options, this.inputElement.value);
        if (typedOption) {
          this.rawValue = [typedOption.value];
        }
        else {
          this.rawValue = [this.inputElement.value];
        }
      }
      else {
        this.rawValue = utils.validateAfterBlur(this.rawValue, this.options, this.inputElement.value);
      }
    }
  }
  updateInputValue(value) {
    if (this.updateInputValueTimer) {
      clearTimeout(this.updateInputValueTimer);
    }
    this.updateInputValueTimer = setTimeout(() => {
      if (!index$1.lodash_isnil(this.inputElement)) {
        this.inputElement.value = value;
        this.inputValue = value;
      }
    }, 0);
  }
  syncNativeInput() {
    if (!this.multiple && !this.remote) {
      if (utils.length(this.rawValue) > 0) {
        const valuesArray = utils.getValues(this.rawValue);
        let label = utils.findLabelByValue(this.options, valuesArray[0]);
        if (!this.multiple && this.typeahead && this.selectionOptional && label === '') {
          label = valuesArray.join(', ');
        }
        this.updateInputValue(label);
      }
    }
  }
  isChipClicked(event) {
    let isChipClicked = false;
    if (this.multiple) {
      const chips = this.selectionEl.querySelectorAll('bal-tag');
      const target = event.target;
      chips.forEach(chip => {
        const isChip = helpers.isDescendant(chip, target) || chip === target;
        if (isChip) {
          isChipClicked = isChip;
        }
      });
    }
    return isChipClicked;
  }
  render() {
    var _a;
    const labelId = this.inputId + '-lbl';
    const label = helpers.findItemLabel(this.el);
    if (label) {
      label.id = labelId;
      label.htmlFor = this.inputId;
    }
    const Chip = (props) => (index.h("bal-tag", { size: "", closable: !this.disabled, disabled: this.disabled, invalid: this.invalid, tabindex: -1, onBalCloseClick: _ => this.removeValue(props.value) }, utils.findLabelByValue(this.options, props.value) || props.value));
    const valuesArray = utils.getValues(this.rawValue);
    const block = bem.BEM.block('select');
    const nativeEl = block.element('native');
    const controlEl = block.element('control');
    const controlIconEl = controlEl.element('icon');
    const controlSelectionsEl = controlEl.element('selections');
    const controlInputEl = controlEl.element('input');
    const popoverContentEl = block.element('popover');
    const popoverContentEmptyEl = popoverContentEl.element('empty');
    const optionEl = block.element('option');
    const optionContentEl = optionEl.element('content');
    const optionContentCheckboxEl = optionContentEl.element('checkbox');
    const optionContentLabelEl = optionContentEl.element('label');
    return (index.h(index.Host, { role: "listbox", onClick: this.handleClick, "aria-disabled": this.disabled ? 'true' : null, "data-value": (_a = this.rawValue) === null || _a === void 0 ? void 0 : _a.map(v => utils.findLabelByValue(this.options, v)).join(','), class: Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('disabled').class(this.disabled || this.readonly)), block.modifier('inverted').class(this.inverted)) }, index.h("select", { class: Object.assign({}, nativeEl.class()), name: this.name, multiple: this.multiple, required: this.required, tabindex: -1, ref: el => (this.nativeSelectEl = el) }, valuesArray.map((value) => (index.h("option", { value: value, selected: true }, value)))), index.h("bal-popover", { onBalChange: this.handlePopoverChange, ref: el => (this.popoverElement = el) }, index.h("div", { "bal-popover-trigger": true, class: Object.assign(Object.assign(Object.assign(Object.assign({}, controlEl.class()), controlEl.modifier('invalid').class(this.invalid)), controlEl.modifier('disabled').class(this.disabled || this.readonly)), controlEl.modifier('focused').class(this.isPopoverOpen)) }, index.h("div", { class: Object.assign(Object.assign({}, controlSelectionsEl.class()), controlSelectionsEl
        .modifier('clickable')
        .class(!this.isPopoverOpen && !this.disabled && !this.readonly)), onClick: this.handleInputClick, ref: el => (this.selectionEl = el) }, valuesArray
      .filter(_ => this.multiple)
      .map((value) => (index.h(Chip, { value: value }))), index.h("input", { type: "text", class: Object.assign(Object.assign({}, controlInputEl.class()), { 'input': true, 'is-inverted': this.inverted, 'is-danger': this.invalid, 'is-disabled': this.disabled || this.readonly, 'is-clickable': !this.isPopoverOpen && !this.disabled && !this.readonly, 'data-test-select-input': true }), autocomplete: this.autocomplete, placeholder: this.inputPlaceholder, readonly: !this.typeahead || this.disabled || this.readonly, contentEditable: this.typeahead, disabled: this.disabled, maxLength: this.maxLength, tabindex: this.balTabindex, onInput: this.handleInput, onClick: this.handleInputClick, onChange: this.handleInputChange, onFocus: this.handleInputFocus, onBlur: this.handleInputBlur, onKeyPress: this.handleKeyPress, ref: el => (this.inputElement = el) })), index.h("bal-icon", { class: Object.assign(Object.assign(Object.assign({}, controlIconEl.class()), controlIconEl.modifier('loading').class(this.loading)), controlIconEl.modifier('clickable').class(!this.disabled && !this.readonly)), name: "caret-down", color: this.disabled || this.readonly ? 'grey-light' : this.invalid ? 'danger' : 'primary', turn: this.isPopoverOpen, onClick: this.handleInputClick })), index.h("bal-popover-content", { class: Object.assign({}, popoverContentEl.class()), scrollable: this.scrollable, spaceless: true, expanded: true }, this.optionArray.map((option, index$1) => (index.h("button", { type: "button", role: "option", id: option.id, "data-value": option.value, "data-label": option.label, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, optionEl.class()), optionEl.modifier('selected').class(valuesArray.includes(option.value))), optionEl.modifier('focused').class(this.focusIndex === index$1)), optionEl.modifier('checkbox').class(this.multiple)), optionEl.modifier('disabled').class(option.disabled === true)), disabled: option.disabled, tabIndex: -1, onMouseEnter: () => this.handleOptionMouseEnter(index$1), onClick: () => this.optionSelected(option) }, index.h("div", { class: Object.assign({}, optionContentEl.class()) }, index.h("span", { class: Object.assign({}, optionContentCheckboxEl.class()), style: { display: this.multiple ? 'flex' : 'none' } }, index.h("bal-checkbox", { checked: valuesArray.includes(option.value), tabindex: -1, hidden: true, flat: true, onBalChange: utils.preventDefault })), index.h("span", { class: Object.assign({}, optionContentLabelEl.class()), innerHTML: option.innerHTML }))))), index.h("div", { class: Object.assign(Object.assign({}, popoverContentEmptyEl.class()), popoverContentEmptyEl
        .modifier('hidden')
        .class(this.noDataLabel === undefined || this.hasOptions() || !this.typeahead || this.selectionOptional)) }, this.noDataLabel)))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["valueWatcher"],
    "rawValue": ["rawValueWatcher"]
  }; }
};
let selectIds = 0;

const SelectOption = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * If `true`, the user cannot interact with the option.
     */
    this.disabled = false;
    /**
     * @internal
     * ID of the option.
     */
    this.for = `bal-selopt-${selectOptionIds++}`;
  }
  render() {
    return (index.h(index.Host, { style: { display: 'none' } }, index.h("slot", null)));
  }
};
let selectOptionIds = 0;

exports.bal_badge = Badge;
exports.bal_checkbox = Checkbox;
exports.bal_select = Select;
exports.bal_select_option = SelectOption;
