'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const _commonjsHelpers = require('./_commonjsHelpers-bcc1208a.js');
const index_esm = require('./index.esm-f7817a8f.js');
const balFileUpload_type = require('./bal-file-upload.type-6182bc54.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');
require('./index-0650a13c.js');

var spec = _commonjsHelpers.createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
var si = { radix: 1e3, unit: ['b', 'kb', 'Mb', 'Gb', 'Tb', 'Pb', 'Eb', 'Zb', 'Yb'] };
var iec = { radix: 1024, unit: ['b', 'Kib', 'Mib', 'Gib', 'Tib', 'Pib', 'Eib', 'Zib', 'Yib'] };
var jedec = { radix: 1024, unit: ['b', 'Kb', 'Mb', 'Gb', 'Tb', 'Pb', 'Eb', 'Zb', 'Yb'] };
exports.SPECS = {
    si: si,
    iec: iec,
    jedec: jedec,
};
//# sourceMappingURL=spec.js.map
});

var lib = _commonjsHelpers.createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * file size
 * @param bytes
 * @param fixed
 * @param spec
 */
function default_1(bytes, fixed, spec$1) {
    if (fixed === void 0) { fixed = 1; }
    bytes = Math.abs(bytes);
    var _a = spec.SPECS[spec$1] || spec.SPECS['jedec'], radix = _a.radix, unit = _a.unit;
    var loop = 0;
    // calculate
    while (bytes >= radix) {
        bytes /= radix;
        ++loop;
    }
    return bytes.toFixed(fixed) + " " + unit[loop];
}
exports.default = default_1;
//# sourceMappingURL=index.js.map
});

const fileSize = /*@__PURE__*/_commonjsHelpers.getDefaultExportFromCjs(lib);

const FileUpload = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.balFilesAddedEmitter = index.createEvent(this, "balFilesAdded", 7);
    this.balFilesRemovedEmitter = index.createEvent(this, "balFilesRemoved", 7);
    this.balClick = index.createEvent(this, "balClick", 7);
    this.balBlur = index.createEvent(this, "balBlur", 7);
    this.balFocus = index.createEvent(this, "balFocus", 7);
    this.balRejectedFileEventEmitter = index.createEvent(this, "balRejectedFile", 7);
    this.uploadId = `bal-upload-${UploadIds++}`;
    this.bundleSize = 0;
    this.isOver = false;
    this.files = [];
    this.hasFocus = false;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.uploadId;
    /**
     * Label of the drop area.
     */
    this.label = 'Choose or drop a file...';
    /**
     * If `true` multiple file upload is possible.
     */
    this.multiple = true;
    /**
     * If `true` below the drop-down area it generates a file list.
     */
    this.hasFileList = true;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * Accepted MIME-Types like `image/png,image/jpeg`.
     */
    this.accept = '';
    /**
     * Input value.
     */
    this.value = [];
    /**
     * If `true` the file upload is disabled and shows a spinner
     */
    this.loading = false;
    this.handleFiles = (files) => {
      if (!this.disabled) {
        const list = [...this.files];
        const filesAdded = [];
        for (let index = 0; index < files.length; index++) {
          const file = files.item(index);
          if (file) {
            const rejectReasons = [];
            if (this.accept && this.accept.split(' ').join('').split(',').indexOf(file.type) === -1) {
              rejectReasons.push(balFileUpload_type.FileUploadRejectionReason.BAD_EXTENSION);
            }
            if (this.maxFileSize && file.size > this.maxFileSize) {
              rejectReasons.push(balFileUpload_type.FileUploadRejectionReason.FILE_TOO_BIG);
            }
            const transactionFileSizeSum = this.files.map(f => f.size).reduce((a, b) => a + b, 0);
            const bundleSize = file.size + transactionFileSizeSum;
            if (this.maxBundleSize && bundleSize > this.maxBundleSize) {
              rejectReasons.push(balFileUpload_type.FileUploadRejectionReason.FILE_SIZE_SUM_TOO_BIG);
            }
            if (this.maxFiles && list.length + 1 > this.maxFiles) {
              rejectReasons.push(balFileUpload_type.FileUploadRejectionReason.TOO_MANY_FILES);
            }
            const duplicatedFiles = list.filter(f => f.size === file.size && f.name === file.name && f.type === file.type);
            if (duplicatedFiles.length > 0) {
              rejectReasons.push(balFileUpload_type.FileUploadRejectionReason.DUPLICATED_FILE);
            }
            if (rejectReasons.length > 0) {
              this.balRejectedFileEventEmitter.emit({
                file: file,
                reasons: rejectReasons,
              });
            }
            else {
              list.push(file);
              filesAdded.push(file);
            }
          }
        }
        if (this.files.length !== list.length) {
          this.files = [...list];
          this.balChange.emit(this.files);
        }
        if (filesAdded.length > 0) {
          this.balFilesAddedEmitter.emit(filesAdded);
        }
        this.setFileList();
      }
    };
    this.onInputChange = () => {
      var _a;
      if ((_a = this.nativeInput) === null || _a === void 0 ? void 0 : _a.files) {
        const files = this.nativeInput.files;
        this.handleFiles(files);
      }
    };
    this.setFileList = () => {
      const fileList = new DataTransfer();
      this.files.forEach(el => fileList.items.add(el));
      this.nativeInput.files = fileList.files;
    };
    this.onInputFocus = (event) => formInput_helpers.inputHandleFocus(this, event);
    this.onInputBlur = (event) => formInput_helpers.inputHandleBlur(this, event);
    this.handleClick = (event) => formInput_helpers.inputHandleHostClick(this, event);
    this.onInputClick = (event) => {
      this.balClick.emit(event);
    };
  }
  onValueChange() {
    if (!index_esm.areArraysEqual(this.files, this.value)) {
      this.files = this.value;
    }
  }
  dragenterHandler() {
    if (!this.disabled && !this.readonly) {
      this.isOver = true;
    }
  }
  dragoverHandler() {
    if (!this.disabled && !this.readonly) {
      this.isOver = true;
    }
  }
  dragleaveHandler() {
    if (!this.disabled && !this.readonly) {
      this.isOver = false;
    }
  }
  dropHandler(event) {
    if (!this.disabled && !this.readonly) {
      this.isOver = false;
      const dataTransfer = event.dataTransfer;
      if (dataTransfer) {
        this.handleFiles(dataTransfer.files);
      }
    }
  }
  componentWillLoad() {
    this.onValueChange();
  }
  componentDidLoad() {
    ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
      this.el.addEventListener(eventName, formInput_helpers.stopEventBubbling, {
        passive: false,
      });
      document.body.addEventListener(eventName, formInput_helpers.stopEventBubbling, {
        passive: false,
      });
    });
  }
  disconnectedCallback() {
    ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
      this.el.removeEventListener(eventName, formInput_helpers.stopEventBubbling, false);
      document.body.removeEventListener(eventName, formInput_helpers.stopEventBubbling, false);
    });
  }
  /**
   * Sets the file list to an empty list
   */
  async clear() {
    this.files = [];
  }
  /**
   * Sets focus on the native `input`. Use this method instead of the global
   * `input.focus()`.
   */
  async setFocus() {
    formInput_helpers.inputSetFocus(this);
  }
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  async setBlur() {
    formInput_helpers.inputSetBlur(this);
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  removeFile(indexToRemove) {
    if (!this.disabled && !this.readonly) {
      const list = [];
      const removedFiles = [];
      for (let index = 0; index < this.files.length; index++) {
        if (index !== indexToRemove) {
          list.push(this.files[index]);
        }
        else {
          removedFiles.push(this.files[index]);
        }
      }
      this.files = [...list];
      this.balChange.emit(this.files);
      this.balFilesRemovedEmitter.emit(removedFiles);
      this.setFileList();
    }
  }
  render() {
    const FileList = () => (index.h("bal-card", { flat: true, class: "mt-4", style: { display: this.files.length ? 'block' : 'none' } }, index.h("bal-list", { disabled: this.disabled || this.loading || this.readonly, border: true, size: "large", class: "p-0" }, this.files.map((file, index$1) => (index.h("bal-list-item", { disabled: this.disabled || this.loading || this.readonly }, index.h("bal-list-item-icon", null, index.h("bal-icon", { name: "document" })), index.h("bal-list-item-content", null, index.h("bal-list-item-title", null, file.name), index.h("bal-list-item-subtitle", null, this.subTitle ? this.subTitle(file) : fileSize(file.size))), index.h("bal-list-item-icon", { right: true, class: {
        'file-remove': true,
        'is-clickable': !this.disabled && !this.readonly,
      }, onClick: () => this.removeFile(index$1) }, index.h("bal-icon", { name: "trash", color: this.disabled || this.loading || this.readonly ? 'grey' : 'danger' }))))))));
    return (index.h(index.Host, { onClick: this.handleClick, class: {
        'bal-file-upload': true,
      } }, index.h("div", { class: {
        'file': true,
        'is-disabled': this.disabled || this.readonly || this.loading,
        'is-danger': this.invalid,
      } }, index.h("label", { class: ['file-label', this.disabled || this.loading || this.readonly ? 'is-disabled' : ''].join(' ') }, index.h("input", { class: "file-input", type: "file", name: this.name, multiple: this.multiple, disabled: this.disabled || this.loading, readonly: this.readonly, required: this.required, accept: this.accept, onClick: this.onInputClick, onChange: this.onInputChange, onFocus: this.onInputFocus, onBlur: this.onInputBlur, ref: el => (this.nativeInput = el) }), this.loading ? (index.h("span", { class: "file-cta" }, index.h("bal-spinner", null))) : (index.h("span", { class: "file-cta" }, index.h("span", { class: "file-icon" }, index.h("bal-icon", { name: "upload", size: "medium", color: this.disabled || this.loading || this.readonly ? 'grey-light' : this.invalid ? 'danger' : 'blue' })), index.h("span", { class: "file-label" }, this.label))))), this.hasFileList ? index.h(FileList, null) : ''));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
};
let UploadIds = 0;

exports.bal_file_upload = FileUpload;
