'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const index$1 = require('./index-e042d4b5.js');
const platform = require('./platform-14f86172.js');
const bem = require('./bem-5d122a5c.js');
const utils = require('./utils-21b17270.js');
const toggleScrollingBody = require('./toggle-scrolling-body-5e1f7be7.js');
require('./index-0650a13c.js');

const Hint = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.bodyScrollBlocker = toggleScrollingBody.BodyScrollBlocker();
    this.isActive = false;
    this.innerCloseLabel = 'Close';
    this.isMobile = platform.isPlatform('mobile');
    /**
     * Disables the close button for tablet and desktop
     */
    this.small = false;
    this.onPopoverChange = (event) => {
      this.isActive = event.detail;
      utils.preventDefault(event);
    };
  }
  async resizeHandler() {
    const isCurrentMobile = platform.isPlatform('mobile');
    if (isCurrentMobile !== this.isMobile) {
      this.isActive = false;
    }
    this.isMobile = isCurrentMobile;
  }
  connectedCallback() {
    index$1.attachComponentToConfig(this);
  }
  disconnectedCallback() {
    index$1.detachComponentToConfig(this);
  }
  componentDidRender() {
    this.updateContent();
  }
  configChanged(state) {
    if (!this.closeLabel) {
      switch (state.language) {
        case 'de':
          this.innerCloseLabel = 'Schliessen';
          break;
        case 'fr':
          this.innerCloseLabel = 'Fermer';
          break;
        case 'it':
          this.innerCloseLabel = 'Chiudere';
          break;
        case 'nl':
          this.innerCloseLabel = 'Sluiten';
          break;
        default:
          this.innerCloseLabel = 'Close';
          break;
      }
    }
  }
  /**
   * Toggles the hint box.
   */
  async toggle() {
    if (this.isActive) {
      this.dismiss();
    }
    else {
      this.present();
    }
  }
  /**
   * Opens the hint box.
   */
  async present() {
    if (this.popoverElement) {
      this.popoverElement.present();
    }
    if (this.isMobile) {
      this.bodyScrollBlocker.block();
    }
    this.isActive = true;
  }
  /**
   * Closes the hint box.
   */
  async dismiss() {
    if (this.popoverElement) {
      this.popoverElement.dismiss();
    }
    if (this.isMobile) {
      this.bodyScrollBlocker.allow();
    }
    this.isActive = false;
  }
  updateContent() {
    if (this.hintContentEl && this.slotWrapperEl) {
      this.hintContentEl.innerHTML = this.slotWrapperEl.innerHTML;
    }
  }
  render() {
    const block = bem.BEM.block('hint');
    const elIcon = block.element('icon');
    const elContent = block.element('content');
    const elButtons = elContent.element('buttons');
    const padding = this.isMobile ? 0 : 8;
    const offsetY = this.isMobile ? 0 : 16;
    const TriggerIcon = () => {
      return (index.h("bal-icon", { class: Object.assign(Object.assign({}, elIcon.class()), { 'data-test-hint-trigger': true }), "bal-popover-trigger": true, "aria-haspopup": "true", role: "button", name: "info-circle", onClick: () => this.toggle() }));
    };
    const HintContent = () => {
      return (index.h("div", { class: Object.assign(Object.assign({}, elContent.class()), { 'data-test-hint-content': true }) }, index.h("div", { ref: el => (this.hintContentEl = el) }), index.h("bal-button-group", { class: Object.assign(Object.assign({}, elButtons.class()), elButtons.modifier('is-hidden-desktop').class(this.small)) }, index.h("bal-button", { class: "data-test-hint-close", color: "info", onClick: () => this.dismiss() }, this.closeLabel ? this.closeLabel : this.innerCloseLabel))));
    };
    const MobileOverlay = () => {
      const elOverlay = block.element('overlay');
      return (index.h("div", { class: Object.assign({}, elOverlay.class()) }, index.h(TriggerIcon, null), index.h("div", { class: Object.assign(Object.assign({}, elOverlay.element('content').class()), elOverlay.element('content').modifier('active').class(this.isActive)) }, index.h(HintContent, null))));
    };
    const Popover = () => {
      return (index.h("div", { class: Object.assign({}, block.element('popover').class()) }, index.h("bal-popover", { hint: true, position: "right", offsetX: 0, offsetY: offsetY, padding: padding, ref: el => (this.popoverElement = el), onBalChange: this.onPopoverChange }, index.h(TriggerIcon, null), index.h("bal-popover-content", { color: "grey" }, index.h(HintContent, null)))));
    };
    const HintElement = this.isMobile ? MobileOverlay : Popover;
    return (index.h(index.Host, { class: Object.assign({}, block.class()) }, index.h(HintElement, null), index.h("div", { ref: el => (this.slotWrapperEl = el), style: { display: 'none' } }, index.h("slot", null))));
  }
  get element() { return index.getElement(this); }
};

const HintText = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    const block = bem.BEM.block('hint');
    const elContent = block.element('content');
    const elText = elContent.element('text');
    const elTextField = elText.element('field');
    return (index.h(index.Host, { class: Object.assign({}, elText.class()) }, index.h("p", { class: Object.assign({}, elTextField.class()) }, index.h("slot", null))));
  }
};

const HintTitle = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    const block = bem.BEM.block('hint');
    const elContent = block.element('content');
    const elTitle = elContent.element('title');
    const elHeading = elTitle.element('heading');
    return (index.h(index.Host, { class: Object.assign({}, elTitle.class()) }, index.h("h3", { class: Object.assign(Object.assign({}, elHeading.class()), { 'title': true, 'is-3': true }) }, index.h("span", null, index.h("slot", null)))));
  }
};

exports.bal_hint = Hint;
exports.bal_hint_text = HintText;
exports.bal_hint_title = HintTitle;
