'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const index$1 = require('./index-0650a13c.js');
const helpers = require('./helpers-c4f9304b.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');
const bem = require('./bem-5d122a5c.js');

const InputSlider = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balInput = index.createEvent(this, "balInput", 7);
    this.balBlur = index.createEvent(this, "balBlur", 7);
    this.balClick = index.createEvent(this, "balClick", 7);
    this.balKeyPress = index.createEvent(this, "balKeyPress", 7);
    this.balFocus = index.createEvent(this, "balFocus", 7);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.inputId = `bal-input-slider-${inputSliderIds++}`;
    this.didInit = false;
    this.hasFocus = false;
    this.initialValue = '';
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * The step size. 0 means no steps.
     */
    this.step = 0;
    /**
     * Min value of the model.
     */
    this.min = 0;
    /**
     * Max value of the model.
     */
    this.max = 100;
    /**
     * The tabindex of the control.
     */
    this.balTabindex = 0;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true`, small ticks for the steps are shown.
     */
    this.hasTicks = false;
    /**
     * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
     */
    this.debounce = 0;
    /**
     * The value of the input.
     */
    this.value = '';
    this.onInput = (ev) => {
      const input = ev.target;
      if (input) {
        this.value = input.value || '';
      }
      this.balInput.emit(this.value);
    };
    this.handleClick = (event) => {
      if (this.disabled || this.readonly) {
        event.preventDefault();
        event.stopPropagation();
      }
    };
    this.onFocus = (ev) => {
      this.hasFocus = true;
      this.balFocus.emit(ev);
    };
    this.onBlur = (ev) => {
      this.hasFocus = false;
      this.balBlur.emit(ev);
      this.balChange.emit(this.value);
    };
    this.onClick = (ev) => {
      if (!this.disabled && !this.readonly) {
        this.balClick.emit(ev);
      }
    };
  }
  debounceChanged() {
    this.balChange = helpers.debounceEvent(this.balChange, this.debounce);
  }
  listenOnClick(ev) {
    if ((this.disabled || this.readonly) && ev.target && ev.target === this.el) {
      formInput_helpers.stopEventBubbling(ev);
    }
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      this.value = this.initialValue;
      clearTimeout(this.resetHandlerTimer);
      this.resetHandlerTimer = setTimeout(() => {
        if (this.nativeInput) {
          this.nativeInput.value = this.initialValue;
        }
      }, 0);
    }
  }
  /**
   * Update the native input element when the value changes
   */
  valueChanged(newValue, oldValue) {
    if (this.didInit && !this.hasFocus && newValue !== oldValue) {
      this.balChange.emit(this.value);
    }
  }
  connectedCallback() {
    this.debounceChanged();
    this.initialValue = this.value;
  }
  componentDidLoad() {
    this.didInit = true;
    if (!index$1.lodash_isnil(this.value) && this.value !== '') {
      this.valueChanged(this.value, undefined);
    }
  }
  /**
   * Sets focus on the native `input` in `bal-input`. Use this method instead of the global
   * `input.focus()`.
   */
  async setFocus() {
    clearTimeout(this.setFocusTimer);
    this.setFocusTimer = setTimeout(() => {
      if (this.nativeInput) {
        this.nativeInput.focus();
      }
    });
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  get numberOfSteps() {
    const max = this.max - this.min;
    if (this.step <= 0 || this.step >= max) {
      return 0;
    }
    return ~~(max / this.step) + 1;
  }
  cssWidth(isUpper = false) {
    const a = this.value === '' ? 0 : this.value;
    const b = (100 / this.max) * a;
    if (!isUpper) {
      return `${100 - b}%`;
    }
    return `${b}%`;
  }
  getNumberOfSteps() {
    const steps = [];
    for (let step = 0; step < this.numberOfSteps; step++) {
      steps.push(step);
    }
    return steps;
  }
  render() {
    const block = bem.BEM.block('input-slider');
    const backgroundEl = block.element('background');
    const backgroundUpperEl = backgroundEl.element('upper');
    const backgroundUpperInnerEl = backgroundUpperEl.element('inner');
    const backgroundLowerEl = backgroundEl.element('lower');
    const backgroundLowerInnerEl = backgroundLowerEl.element('inner');
    const inputEl = block.element('input');
    const inputNativeEl = inputEl.element('native');
    const inputValueEl = inputEl.element('value');
    const inputValueLeftEl = inputValueEl.modifier('left');
    const inputValueRightEl = inputValueEl.modifier('right');
    const stepsEl = block.element('steps');
    const stepsItemEl = stepsEl.element('item');
    return (index.h(index.Host, { class: Object.assign(Object.assign({}, block.class()), block.modifier('disabled').class(this.disabled || this.readonly)), onClick: this.handleClick, "aria-disabled": this.disabled || this.readonly ? 'true' : null }, index.h("div", { class: Object.assign(Object.assign({}, backgroundEl.class()), backgroundEl.modifier('disabled').class(this.disabled || this.readonly)) }, index.h("div", { class: Object.assign({}, backgroundUpperEl.class()), style: {
        width: this.cssWidth(),
      } }, index.h("div", { class: Object.assign({}, backgroundUpperInnerEl.class()) })), index.h("div", { class: Object.assign({}, backgroundLowerEl.class()), style: {
        width: this.cssWidth(true),
      } }, index.h("div", { class: Object.assign({}, backgroundLowerInnerEl.class()) }))), index.h("div", { class: Object.assign({}, inputEl.class()) }, index.h("div", { class: Object.assign(Object.assign({}, inputValueEl.class()), inputValueLeftEl.class()) }), index.h("input", { type: "range", class: Object.assign(Object.assign({}, inputNativeEl.class()), inputNativeEl.modifier('disabled').class(this.disabled || this.readonly)), ref: inputEl => (this.nativeInput = inputEl), id: this.inputId, disabled: this.disabled, readonly: this.readonly, name: this.name, required: this.required, tabIndex: this.balTabindex, step: this.step, min: this.min, max: this.max, value: this.value, onInput: this.onInput, onBlur: this.onBlur, onFocus: this.onFocus, onClick: this.onClick, onKeyPress: e => this.balKeyPress.emit(e) }), index.h("div", { class: Object.assign(Object.assign({}, inputValueEl.class()), inputValueRightEl.class()) })), index.h("div", { class: Object.assign({}, stepsEl.class()), style: { display: this.hasTicks ? 'flex' : 'none' } }, this.getNumberOfSteps().map(step => (index.h("div", { class: Object.assign(Object.assign({}, stepsItemEl.class()), stepsItemEl.modifier('disabled').class(this.disabled || this.readonly)), "data-step-id": step }))))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "debounce": ["debounceChanged"],
    "value": ["valueChanged"]
  }; }
};
let inputSliderIds = 0;

exports.bal_input_slider = InputSlider;
