'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const helpers = require('./helpers-c4f9304b.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');
const index$1 = require('./index-0650a13c.js');
const keys_constant = require('./keys.constant-4c6c8edc.js');
const bem = require('./bem-5d122a5c.js');

/**
 *
 * @param value - input number
 * @output 73/001217/16.9
 * @private
 */
function formatClaim(value) {
  if (!value) {
    return '';
  }
  const newValue = `${value}`.trim();
  const parts = [
    newValue.substring(0, 2),
    newValue.substring(2, 8),
    newValue.substring(8, 10),
    newValue.substring(10, 11),
  ].filter(val => val.length > 0);
  switch (parts.length) {
    case 1:
      return `${value}`;
    case 2:
      return `${parts[0]}/${parts[1]}`;
    case 3:
      return `${parts[0]}/${parts[1]}/${parts[2]}`;
    default:
      return `${parts[0]}/${parts[1]}/${parts[2]}.${parts[3]}`;
  }
}
/**
 *
 * @param value: input number
 * @output 99/1.234.567-1
 * @private
 */
function formatPolicy(value) {
  if (!value) {
    return '';
  }
  let newValue = `${value}`.trim();
  const parts = [newValue.substring(0, 9), newValue.substring(9, 10)].filter(val => val.length > 0);
  newValue = formatOffer(parts[0]);
  return parts[1] ? `${newValue}-${parts[1]}` : newValue;
}
/**
 *
 * @param value: input number
 * @output 98/7.654.321
 * @private
 */
function formatOffer(value) {
  if (!value) {
    return '';
  }
  const newValue = `${value}`.trim();
  const parts = [
    newValue.substring(0, 2),
    newValue.substring(2, 3),
    newValue.substring(3, 6),
    newValue.substring(6, 9),
  ].filter(val => val.length > 0);
  switch (parts.length) {
    case 1:
      return `${newValue}`;
    case 2:
      return `${parts[0]}/${parts[1]}`;
    case 3:
      return `${parts[0]}/${parts[1]}.${parts[2]}`;
    default:
      return `${parts[0]}/${parts[1]}.${parts[2]}.${parts[3]}`;
  }
}
const MAX_LENGTH_CONTRACT_NUMBER = 10;
const MAX_LENGTH_OFFER_NUMBER = 9;
const MAX_LENGTH_CLAIM_NUMBER = 11;

const Input = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balInput = index.createEvent(this, "balInput", 7);
    this.balBlur = index.createEvent(this, "balBlur", 7);
    this.balClick = index.createEvent(this, "balClick", 7);
    this.balKeyPress = index.createEvent(this, "balKeyPress", 7);
    this.balFocus = index.createEvent(this, "balFocus", 7);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.inputId = `bal-input-${InputIds++}`;
    this.inheritedAttributes = {};
    this.inputValue = this.value;
    this.initialValue = this.value || '';
    this.hasFocus = false;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    /**
     * Defines the text align of the input value.
     */
    this.textAlign = 'left';
    /**
     * Defines the type of the input (text, number, email ...).
     */
    this.type = 'text';
    /**
     * Indicates whether and how the text value should be automatically capitalized as it is entered/edited by the user.
     * Available options: `"off"`, `"none"`, `"on"`, `"sentences"`, `"words"`, `"characters"`.
     */
    this.autocapitalize = 'off';
    /**
     * Indicates whether the value of the control can be automatically completed by the browser.
     */
    this.autocomplete = 'off';
    /**
     * Whether auto correction should be enabled when the user is entering/editing the text value.
     */
    this.autocorrect = 'off';
    /**
     * This Boolean attribute lets you specify that a form control should have input focus when the page loads.
     */
    this.autofocus = false;
    /**
     * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
     */
    this.debounce = 0;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true`, the element will have its spelling and grammar checked.
     */
    this.spellcheck = false;
    /**
     * If `true` this component can be placed on dark background
     */
    this.inverted = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true` the input gets a clickable cursor style
     */
    this.clickable = false;
    /**
     * @deprecated
     * If `true` on mobile device the number keypad is active. Use the <bal-number-input> component instead.
     */
    this.numberInput = false;
    /**
     * @internal
     * If `true` the input will get some right padding.
     */
    this.hasIconRight = false;
    /**
     * The value of the input.
     */
    this.value = undefined;
    /**
     * Mask of the input field. It defines what the user can enter and how the format looks like. Currently, only for Switzerland formatted.
     * Formatting for 'contract-number': '99/1.234.567-1'
     * Formatting for 'claim-number': ('73/001217/16.9')
     * Formatting for 'offer-number': ('98/7.654.321')
     */
    this.mask = undefined;
    this.onInput = (ev) => {
      var _a, _b, _c;
      const input = formInput_helpers.getInputTarget(ev);
      const cursorPositionStart = (_a = ev.target) === null || _a === void 0 ? void 0 : _a.selectionStart;
      const cursorPositionEnd = (_b = ev.target) === null || _b === void 0 ? void 0 : _b.selectionEnd;
      if (this.allowedKeyPress && input && !this.mask) {
        const regex = new RegExp('^' + this.allowedKeyPress + '$');
        this.inputValue = input.value = input.value
          .split('')
          .filter(val => regex.test(val))
          .join('');
      }
      if (input) {
        if (input.value) {
          switch (this.mask) {
            case 'contract-number': {
              this.inputValue = input.value.replace(/\D/g, '');
              if (this.inputValue.length > MAX_LENGTH_CONTRACT_NUMBER) {
                this.inputValue = this.inputValue.substring(0, MAX_LENGTH_CONTRACT_NUMBER);
              }
              input.value = formatPolicy(this.inputValue);
              if (cursorPositionStart < this.inputValue.length) {
                input.setSelectionRange(cursorPositionStart, cursorPositionEnd);
              }
              break;
            }
            case 'offer-number': {
              this.inputValue = input.value.replace(/\D/g, '');
              if (this.inputValue.length > MAX_LENGTH_OFFER_NUMBER) {
                this.inputValue = this.inputValue.substring(0, MAX_LENGTH_OFFER_NUMBER);
              }
              input.value = formatOffer(this.inputValue);
              if (cursorPositionStart < this.inputValue.length) {
                input.setSelectionRange(cursorPositionStart, cursorPositionEnd);
              }
              break;
            }
            case 'claim-number': {
              this.inputValue = input.value.replace(/[^\dX]/g, '');
              const inputParts = [
                this.inputValue.substring(0, MAX_LENGTH_CLAIM_NUMBER - 1),
                this.inputValue.substring(MAX_LENGTH_CLAIM_NUMBER - 1, MAX_LENGTH_CLAIM_NUMBER),
                this.inputValue.substring(MAX_LENGTH_CLAIM_NUMBER),
              ].filter(val => val.length > 0);
              switch (inputParts.length) {
                case 1:
                  this.inputValue = `${inputParts[0].replace(/\D/g, '')}`;
                  break;
                case 2:
                  this.inputValue = `${inputParts[0].replace(/\D/g, '')}${inputParts[1]}`;
                  break;
                default:
                  this.inputValue = `${inputParts[0].replace(/\D/g, '')}${inputParts[1]}${(_c = inputParts[2]) === null || _c === void 0 ? void 0 : _c.replace(/\D/g, '')}`;
              }
              if (this.inputValue.length > MAX_LENGTH_CLAIM_NUMBER) {
                this.inputValue = this.inputValue.substring(0, MAX_LENGTH_CLAIM_NUMBER);
              }
              input.value = formatClaim(this.inputValue);
              if (cursorPositionStart < this.inputValue.length) {
                input.setSelectionRange(cursorPositionStart, cursorPositionEnd);
              }
              break;
            }
            default:
              this.inputValue = input.value;
          }
        }
        else {
          this.inputValue = input.value;
        }
      }
      this.balInput.emit(this.inputValue);
    };
    this.onFocus = (event) => formInput_helpers.inputHandleFocus(this, event);
    this.onBlur = (ev) => {
      formInput_helpers.inputHandleBlur(this, ev);
      const input = ev.target;
      if (input) {
        if (this.mask === undefined) {
          input.value = this.getFormattedValue();
        }
        formInput_helpers.inputHandleChange(this);
      }
    };
    this.onKeydown = (event) => {
      if (this.mask !== undefined && !index$1.lodash_isnil(event) && !keys_constant.isCtrlOrCommandKey(event)) {
        if (!(this.getMaskAllowedKeys().includes(event.key) ||
          (this.mask === 'claim-number' &&
            event.key === 'X' &&
            this.inputValue &&
            this.inputValue.length >= MAX_LENGTH_CLAIM_NUMBER - 1))) {
          // do not trigger next event -> on input
          return formInput_helpers.stopEventBubbling(event);
        }
      }
      if (this.allowedKeyPress && !this.mask && !index$1.lodash_isnil(event) && !keys_constant.isCtrlOrCommandKey(event)) {
        const regex = new RegExp('^' + this.allowedKeyPress + '$');
        if (!regex.test(event.key) && ![...keys_constant.ACTION_KEYS].includes(event.key)) {
          return formInput_helpers.stopEventBubbling(event);
        }
      }
    };
    this.onClick = (event) => formInput_helpers.inputHandleClick(this, event);
    this.handleClick = (event) => formInput_helpers.inputHandleHostClick(this, event);
  }
  debounceChanged() {
    this.balChange = helpers.debounceEvent(this.balChange, this.debounce);
  }
  numberInputHandler() {
    if (this.numberInput) {
      console.warn('[DEPRECATED] - Please use the component <bal-number-input> instead');
    }
  }
  decimalHandler() {
    if (this.decimal) {
      console.warn('[DEPRECATED] - Please use the component <bal-number-input> instead');
    }
  }
  listenOnClick(event) {
    formInput_helpers.inputListenOnClick(this, event);
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      formInput_helpers.inputHandleReset(this, this.initialValue, this.resetHandlerTimer);
    }
  }
  connectedCallback() {
    this.debounceChanged();
    this.initialValue = this.value || '';
  }
  componentWillLoad() {
    this.inheritedAttributes = helpers.inheritAttributes(this.el, ['aria-label', 'tabindex', 'title']);
  }
  componentDidLoad() {
    this.inputValue = this.value;
  }
  /**
   * Sets focus on the native `input` in `bal-input`. Use this method instead of the global
   * `input.focus()`.
   */
  async setFocus() {
    formInput_helpers.inputSetFocus(this);
  }
  /**
   * Sets blur on the native `input` in `bal-input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  async setBlur() {
    formInput_helpers.inputSetBlur(this);
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  getRawValue() {
    const value = (this.value || '').toString();
    return value;
  }
  getFormattedValue() {
    const value = this.getRawValue();
    const suffix = this.suffix !== undefined && value !== undefined && value !== '' ? ' ' + this.suffix : '';
    return `${value}${suffix}`;
  }
  getMaskAllowedKeys() {
    return [...keys_constant.NUMBER_KEYS, ...keys_constant.ACTION_KEYS];
  }
  render() {
    /**
     * @deprecated should be removed in the next breaking change release.
     */
    if (this.numberInput) {
      const numberValue = !this.value ? undefined : parseFloat(this.value);
      return (index.h("bal-number-input", { value: numberValue, name: this.name, disabled: this.disabled, readonly: this.readonly, invalid: this.invalid, decimal: this.decimal, suffix: this.suffix, placeholder: this.placeholder, required: this.required, debounce: this.debounce, onBalFocus: e => this.balFocus.emit(e.detail), onBalBlur: e => this.balBlur.emit(e.detail), onBalInput: e => { var _a; return this.balInput.emit((_a = e.detail) === null || _a === void 0 ? void 0 : _a.toString()); }, onBalChange: e => { var _a; return this.balChange.emit((_a = e.detail) === null || _a === void 0 ? void 0 : _a.toString()); }, onBalKeyPress: e => this.balKeyPress.emit(e.detail), onBalClick: e => this.balClick.emit(e.detail) }));
    }
    let value = this.hasFocus ? this.getRawValue() : this.getFormattedValue();
    if (this.mask !== undefined) {
      switch (this.mask) {
        case 'contract-number':
          value = formatPolicy(value);
          break;
        case 'claim-number':
          value = formatClaim(value);
          break;
        case 'offer-number':
          value = formatOffer(value);
      }
    }
    const labelId = this.inputId + '-lbl';
    const label = helpers.findItemLabel(this.el);
    if (label) {
      label.id = labelId;
      label.htmlFor = this.inputId;
    }
    let inputProps = {};
    if (this.pattern) {
      inputProps = { pattern: this.pattern };
    }
    const block = bem.BEM.block('input');
    return (index.h(index.Host, { onClick: this.handleClick, "aria-disabled": this.disabled ? 'true' : null, class: Object.assign({}, block.class()) }, index.h("input", Object.assign({ class: {
        'input': true,
        'data-test-input': true,
        'is-disabled': this.disabled || this.readonly,
        'is-danger': this.invalid,
        'is-inverted': this.inverted,
        'clickable': this.clickable,
        'has-icon-right': this.hasIconRight,
        'has-text-centered': this.textAlign === 'center',
        'has-text-right': this.textAlign === 'right',
      }, ref: inputEl => (this.nativeInput = inputEl), id: this.inputId, "aria-labelledby": labelId, disabled: this.disabled, accept: this.accept, inputMode: this.inputmode, autoCapitalize: this.autocapitalize, autocomplete: this.autocomplete, autocorrect: this.autocorrect, autofocus: this.autofocus, min: this.min, max: this.max, minLength: this.minLength, maxLength: this.maxLength, multiple: this.multiple, name: this.name, placeholder: this.placeholder || '', readonly: this.readonly, required: this.required, spellcheck: this.spellcheck, type: this.type, value: value, onFocus: this.onFocus, onInput: ev => this.onInput(ev), onKeyDown: e => this.onKeydown(e), onBlur: this.onBlur, onClick: this.onClick, onKeyPress: e => this.balKeyPress.emit(e) }, inputProps, this.inheritedAttributes))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "debounce": ["debounceChanged"],
    "numberInput": ["numberInputHandler"],
    "decimal": ["decimalHandler"]
  }; }
};
let InputIds = 0;

exports.bal_input = Input;
