'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const bem = require('./bem-5d122a5c.js');
const helpers = require('./helpers-c4f9304b.js');
const platform = require('./platform-14f86172.js');
require('./bal-file-upload.type-6182bc54.js');
require('./browser-5e81f6ec.js');
require('./bal-snackbar.controller-aeab4a29.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');

const ListItemAccordionBody = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.contentHeight = '0px';
    /**
     * If `true` the body will be open and visible
     */
    this.open = false;
    /**
     * Sets justify-content of the items to start, center, end, or space-between. Default is start.
     */
    this.contentAlignment = 'start';
  }
  async resizeHandler() {
    this.calcContentHeight();
  }
  componentDidRender() {
    setTimeout(() => {
      this.calcContentHeight();
    }, 10);
  }
  async getContentHeight() {
    const inner = this.el.querySelector('bal-list-item-content');
    if (inner) {
      return inner.scrollHeight;
    }
    return 0;
  }
  getAccordionGroupItems() {
    return Array.from(document.body.querySelectorAll('bal-list-item-accordion-body')).filter(accordionBody => accordionBody.accordionGroup === this.accordionGroup);
  }
  setContentHeight(height) {
    this.contentHeight = height + 'px';
    const parent = this.el.closest('.bal-list__item__accordion-body__parent');
    const parentHeight = parent ? parent.scrollHeight : 0;
    const parentIsThereAndIsOpen = parent && parentHeight > 0 && parent.open;
    if (parentIsThereAndIsOpen && this.open) {
      parent.style.maxHeight = parentHeight + height + 'px';
    }
  }
  get areWeInAGroup() {
    return this.accordionGroup !== '' && this.accordionGroup !== undefined;
  }
  async calcContentHeight() {
    let height = await this.getContentHeight();
    if (this.areWeInAGroup) {
      const items = this.getAccordionGroupItems();
      const heights = [];
      for (let index = 0; index < items.length; index++) {
        const element = items[index];
        heights.push(await element.getContentHeight());
      }
      const maxHeight = Math.max(...heights);
      height = maxHeight;
    }
    this.setContentHeight(height);
  }
  render() {
    return (index.h(index.Host, { class: {
        'bal-list__item': true,
        'bal-list__item__accordion-body': true,
        'bal-list__item__accordion-body--open': this.open,
      }, style: { maxHeight: this.open ? this.contentHeight : '0' } }, index.h("bal-list-item-content", { style: {
        minHeight: this.areWeInAGroup ? this.contentHeight : 'inherit',
        height: this.areWeInAGroup ? this.contentHeight : 'inherit',
      }, contentAlignment: this.contentAlignment }, index.h("slot", null))));
  }
  get el() { return index.getElement(this); }
};

const ListItemAccordionHead = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balAccordionChange = index.createEvent(this, "balAccordionChange", 7);
    /**
     * If `true` the list accordion is open
     */
    this.accordionOpen = false;
    /**
     * Icon name string with value 'plus' on default
     */
    this.icon = 'plus';
    this.onClick = () => {
      const listItem = this.getClosestListItem();
      if (listItem) {
        this.accordionOpen = !this.accordionOpen;
        this.balAccordionChange.emit(this.accordionOpen);
      }
    };
  }
  accordionOpenHandler() {
    this.balAccordionChange.emit(this.accordionOpen);
  }
  connectedCallback() {
    this.balAccordionChange.emit(this.accordionOpen);
  }
  getClosestListItem() {
    return this.el.closest('bal-list-item');
  }
  render() {
    return (index.h(index.Host, { class: {
        'bal-list__item': true,
        'bal-list__item__accordion-head': true,
        'bal-list__item__accordion-head--open': this.accordionOpen,
      }, onClick: this.onClick }, index.h("slot", null), index.h("bal-list-item-icon", { right: true }, index.h("bal-icon", { class: "bal-list__item__accordion-head__icon", name: this.icon, size: "small", turn: this.accordionOpen }))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "accordionOpen": ["accordionOpenHandler"]
  }; }
};

const NavigationMain = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * aria label for main navigation bar
     */
    this.ariaLabelMain = '';
  }
  render() {
    const mainEl = bem.BEM.block('nav').element('main');
    return (index.h(index.Host, { class: Object.assign({}, mainEl.class()) }, index.h("nav", { role: "navigation", "aria-label": this.ariaLabelMain }, index.h("slot", { name: "main-head" })), index.h("slot", { name: "main-body" })));
  }
};

const NavigationMainBody = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    const mainBodyEl = bem.BEM.block('nav').element('main').element('body');
    return (index.h(index.Host, { class: Object.assign({}, mainBodyEl.class()) }, index.h("slot", null)));
  }
};

const NavigationMainHead = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    const mainHeadEl = bem.BEM.block('nav').element('main').element('head');
    return (index.h(index.Host, { class: Object.assign({}, mainHeadEl.class()) }, index.h("slot", null)));
  }
};

const NavigationMenu = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.target = '_self';
    this.elements = [];
  }
  render() {
    const navMenuEl = bem.BEM.block('nav').element('menu');
    return (index.h(index.Host, { class: Object.assign({}, navMenuEl.class()) }, this.linkHref && this.linkName && (index.h("div", { class: Object.assign({}, navMenuEl.element('link').class()) }, index.h("a", { href: this.linkHref, target: this.target }, this.linkName, " \u279E"))), this.elements && (index.h("div", { style: { overflow: 'hidden' } }, index.h("div", { class: Object.assign({ 'columns is-multiline': true }, navMenuEl.element('wrapper').class()) }, this.elements.some(subLevel => subLevel.color === 'white') && (index.h("div", { class: {
        'bal-nav__menu__white-list__wrapper column is-full is-6-desktop is-two-thirds-widescreen': true,
      } }, index.h("div", { class: Object.assign({}, navMenuEl.element('white-list').class()) }, this.elements
      .filter(subLevel => subLevel.color === 'white')
      .map(block => {
      var _a;
      return (block && (index.h("bal-navigation-menu-list", { headline: block.label, href: block.link, target: block.target }, index.h("div", { slot: "links" }, (_a = block.subLevels) === null || _a === void 0 ? void 0 : _a.map(item => (index.h("bal-navigation-menu-list-item", { href: item.link, target: item.target }, item.label)))))));
    })))), this.elements.some(subLevel => subLevel.color === 'grey') && (index.h("div", { class: Object.assign({ 'column is-full is-6-desktop is-one-third-widescreen': true }, navMenuEl.element('grey-list').class()) }, this.elements
      .filter(subLevel => subLevel.color === 'grey')
      .map(block => {
      var _a;
      return (index.h("bal-navigation-menu-list", { headline: block.label, href: block.link, color: block.color, target: block.target }, index.h("div", { slot: "links" }, (_a = block.subLevels) === null || _a === void 0 ? void 0 : _a.map(item => (index.h("bal-navigation-menu-list-item", { href: item.link, target: item.target }, item.label))))));
    }))))))));
  }
};

const NavigationMeta = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * aria label for meta navigation bar
     */
    this.ariaLabelMeta = '';
  }
  render() {
    const metaEl = bem.BEM.block('nav').element('meta');
    return (index.h(index.Host, { class: Object.assign({}, metaEl.class()) }, index.h("nav", { class: "container", role: "navigation", "aria-label": this.ariaLabelMeta }, index.h("slot", null))));
  }
};

const NavigationMetaEnd = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    const metaEndEl = bem.BEM.block('nav').element('meta').element('end');
    return (index.h(index.Host, { class: Object.assign({}, metaEndEl.class()) }, index.h("slot", null)));
  }
};

const NavigationMetaStart = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    const metaStartEl = bem.BEM.block('nav').element('meta').element('start');
    return (index.h(index.Host, { class: Object.assign({}, metaStartEl.class()) }, index.h("slot", null)));
  }
};

const TabItem$1 = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balNavigate = index.createEvent(this, "balNavigate", 7);
    this.isActive = false;
    /**
     * Tells if this route is active and overrides the bal-tabs value property.
     */
    this.active = false;
    /**
     * This is the key of the tab.
     */
    this.value = '';
    /**
     * Label for the tab.
     */
    this.label = '';
    /**
     * Link to path.
     */
    this.href = '';
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    /**
     * If `true` a small red bubble is added to the tab.
     */
    this.bubble = false;
    /**
     * If `true` the tab is disabled.
     */
    this.disabled = false;
    /**
     * If `true` the step is marked as done.
     */
    this.done = false;
    /**
     * If `true` the step is hidden.
     */
    this.hidden = false;
    /**
     * If `true` the step is marked as failed.
     */
    this.failed = false;
    /**
     * Tell's if the linking is done by a router.
     */
    this.prevent = false;
    /**
     * Tab icon not available for the steps.
     */
    this.icon = undefined;
  }
  /**
   * Options of the tab like label, value etc.
   */
  async getOptions() {
    return this.options;
  }
  /**
   * Sets the tab active.
   */
  async setActive(active) {
    this.isActive = active;
  }
  get options() {
    return {
      value: this.value,
      icon: this.icon,
      label: this.label,
      href: this.href,
      target: this.target,
      active: this.active,
      disabled: this.disabled,
      done: this.done,
      hidden: this.hidden,
      failed: this.failed,
      bubble: this.bubble,
      passed: false,
      prevent: this.prevent,
      navigate: this.balNavigate,
    };
  }
  render() {
    return (index.h(index.Host, { class: {
        'bal-tabs-item': true,
        'bal-tabs-item--active': this.isActive,
      } }, index.h("slot", null)));
  }
  get el() { return index.getElement(this); }
};

const watchForTabs = (containerEl, tagName, onChange) => {
  /* tslint:disable-next-line */
  if (typeof MutationObserver === 'undefined') {
    return;
  }
  const mutation = new MutationObserver(mutationList => {
    mutationList = mutationList.filter(record => record.target.nodeName === tagName.toUpperCase() || record.target.nodeName === 'bal-tabs'.toUpperCase());
    if (mutationList.length > 0) {
      onChange(undefined);
    }
  });
  mutation.observe(containerEl, {
    childList: true,
    subtree: true,
    attributes: true,
    characterData: true,
  });
  return mutation;
};

const buttonEl = bem.BEM.block('tabs').element('tabs').element('item').element('button');
const TabItem = ({ icon, expanded, disabled, href, target, label, vertical, iconPosition, bubble, active, context, inverted, onSelectTab, }) => {
  const cssClasses = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, buttonEl.class()), buttonEl.modifier(`context-${context}`).class()), buttonEl.modifier('vertical').class(vertical == true)), buttonEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), buttonEl.modifier('vertical-on-tablet').class(vertical === 'tablet')), buttonEl.modifier('fullwidth').class(expanded)), buttonEl.modifier('disabled').class(disabled)), buttonEl.modifier('inverted').class(inverted)), buttonEl.modifier('active').class(active)), buttonEl.modifier(`icon-${iconPosition}`).class(true)), buttonEl.modifier('icon').class(icon !== undefined));
  let hrefAttribute = {
    href: 'javascript:;',
  };
  if (href) {
    hrefAttribute = {
      href,
      target,
    };
  }
  const bubbleString = bubble === true || bubble === false ? '' : bubble;
  const labelString = label;
  return (index.h("a", Object.assign({ class: cssClasses }, hrefAttribute, { "aria-disabled": `${disabled}`, "aria-current": "page", onClick: e => onSelectTab(e) }),
    index.h("bal-icon", { class: Object.assign({}, buttonEl.element('icon').class()), name: icon, size: "small", turn: active, style: { display: icon ? 'flex' : 'none' } }),
    index.h("span", null,
      labelString,
      index.h("bal-badge", { position: "tabs", size: bubbleString === '' ? 'small' : '', style: { display: bubble ? 'flex' : 'none' } }, bubbleString))));
};

const tabsEl = bem.BEM.block('tabs').element('tabs');
const tabItemEl = tabsEl.element('item');
const TabList = ({ value, expanded, border, float, tabs, spaceless, onSelectTab, isReady, iconPosition, lineWidth, lineOffsetLeft, lineHeight, lineOffsetTop, vertical, selectOnMobile, context, inverted, }) => {
  if (platform.isPlatform('mobile') && selectOnMobile) {
    const onChange = (event) => {
      const selectedTabs = tabs.filter(tab => tab.value === event.detail);
      if (selectedTabs.length > 0) {
        onSelectTab(event, selectedTabs[0]);
      }
    };
    return (index.h("bal-select", { value: value, onBalChange: event => onChange(event) }, tabs.map(tab => (index.h("bal-select-option", { label: tab.label, value: tab.value }, tab.label)))));
  }
  return (index.h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, tabsEl.class()), tabsEl.modifier(`float-${float}`).class()), tabsEl.modifier('vertical').class(vertical === true)), tabsEl.modifier('spaceless').class(spaceless && !vertical)), tabsEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), tabsEl.modifier('vertical-on-tablet').class(vertical === 'tablet')) },
    index.h("ul", null, tabs.map((tab, index$1) => (index.h("li", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, tabItemEl.class()), tabItemEl.modifier('active').class(tab.value === value)), tabItemEl.modifier('disabled').class(tab.disabled)), tabItemEl.modifier('hidden').class(tab.hidden)), tabItemEl.modifier('fullwidth').class(expanded)), tabItemEl.modifier('spaceless').class(spaceless && !vertical)), tabItemEl.modifier('vertical').class(vertical === true)), tabItemEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), tabItemEl.modifier('vertical-on-tablet').class(vertical === 'tablet')), { 'data-test-tab-item': true }), "data-label": tab.label, "data-value": tab.value, "data-index": index$1 },
      index.h(TabItem, { icon: tab.icon, active: tab.value === value, inverted: inverted, context: context, vertical: vertical, expanded: expanded, iconPosition: iconPosition, disabled: tab.disabled, href: tab.href, target: tab.target, label: tab.label, bubble: tab.bubble, onSelectTab: e => onSelectTab(e, tab) }))))),
    index.h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign({}, tabsEl.element('border').class()), tabsEl
        .element('border')
        .modifier('vertical')
        .class(vertical === true)), tabsEl
        .element('border')
        .modifier('vertical-on-mobile')
        .class(vertical === 'mobile')), tabsEl
        .element('border')
        .modifier('vertical-on-tablet')
        .class(vertical === 'tablet')), style: { display: border ? 'block' : 'none' } }),
    index.h(TabLine, { context: context, vertical: vertical, lineOffsetLeft: lineOffsetLeft, lineWidth: lineWidth, lineOffsetTop: lineOffsetTop, lineHeight: lineHeight, inverted: inverted, isReady: isReady })));
};
const TabLine = ({ vertical, isReady, lineWidth, lineOffsetLeft, lineHeight, lineOffsetTop, inverted, context, }) => {
  const tabLineEl = tabsEl.element('line');
  let style = {};
  const isMobile = platform.isPlatform('mobile');
  const isTablet = platform.isPlatform('tablet');
  const isNavbarTablet = context === 'navbar' && (isMobile || isTablet);
  const isVertical = vertical === true;
  const isVerticalMobile = isMobile && (vertical === 'mobile' || vertical === 'tablet');
  const isVerticalTablet = (isMobile || isTablet) && vertical === 'tablet';
  if (isVertical || isVerticalMobile || isVerticalTablet || isNavbarTablet) {
    style = {
      top: `${lineOffsetTop || 0}px`,
      height: `${lineHeight || 0}px`,
    };
  }
  else {
    style = {
      left: `${lineOffsetLeft || 0}px`,
      width: `${lineWidth || 0}px`,
    };
  }
  return (index.h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, tabLineEl.class()), tabLineEl.modifier('ready').class(isReady)), tabLineEl.modifier(`context-${context}`).class()), tabLineEl.modifier('inverted').class(inverted)), tabLineEl.modifier('vertical').class(vertical === true)), tabLineEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), tabLineEl.modifier('vertical-on-tablet').class(vertical === 'tablet')), style: style }));
};

const stepsEl = bem.BEM.block('tabs').element('steps');
const stepItemEl = stepsEl.element('item');
const stepItemButtonEl = stepItemEl.element('button');
const stepItemButtonIndexEl = stepItemButtonEl.element('index');
const stepItemButtonIndexLabelEl = stepItemButtonIndexEl.element('label');
const stepItemButtonLabelEl = stepItemButtonEl.element('label');
const StepList = ({ value, float, clickable, tabs, onSelectTab }) => {
  let hasPassed = true;
  let index$1 = 0;
  tabs = tabs
    .map(tab => (Object.assign(Object.assign({}, tab), { active: tab.value === value })))
    .map(tab => {
    if (tab.active) {
      hasPassed = false;
    }
    if (!tab.hidden) {
      index$1 = index$1 + 1;
    }
    return Object.assign(Object.assign({}, tab), { passed: hasPassed, index: index$1 });
  });
  return (index.h("ul", { class: Object.assign(Object.assign({}, stepsEl.class()), stepsEl.modifier(`float-${float}`).class()) }, tabs.map(tab => (index.h("li", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemEl.class()), stepItemEl.modifier('hidden').class(tab.hidden)), stepItemEl.modifier('active').class(tab.active)), stepItemEl.modifier('passed').class(tab.passed)), stepItemEl.modifier('disabled').class(tab.disabled)), stepItemEl.modifier('done').class(tab.done)), stepItemEl.modifier('failed').class(tab.failed)), stepItemEl.modifier('clickable').class(clickable && !tab.disabled)), { 'data-test-tab-item': true }), "data-label": tab.label, "data-value": tab.value, "data-index": index$1 },
    index.h("a", { class: Object.assign(Object.assign(Object.assign({}, stepItemButtonEl.class()), stepItemButtonEl.modifier('disabled').class(tab.disabled)), stepItemButtonEl.modifier('clickable').class(clickable && !tab.disabled)), onClick: (event) => onSelectTab(event, tab) },
      index.h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemButtonIndexEl.class()), stepItemButtonIndexEl.modifier('done').class(tab.done)), stepItemButtonIndexEl.modifier('active').class(tab.active)), stepItemButtonIndexEl.modifier('failed').class(tab.failed)), stepItemButtonIndexEl.modifier('disabled').class(tab.disabled)) },
        index.h("bal-icon", { class: Object.assign({}, stepItemButtonIndexEl.element('icon').class()), style: { display: tab.done ? 'block' : 'none' }, size: platform.isPlatform('mobile') ? 'small' : '', color: "white", name: "check" }),
        index.h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemButtonIndexLabelEl.class()), stepItemButtonIndexLabelEl.modifier('failed').class(tab.failed)), stepItemButtonIndexLabelEl.modifier('active').class(tab.active)), stepItemButtonIndexLabelEl.modifier('disabled').class(tab.disabled)), style: { display: !tab.done ? 'block' : 'none' } }, tab.failed ? '!' : tab.index)),
      index.h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemButtonLabelEl.class()), stepItemButtonLabelEl.modifier('done').class(tab.done)), stepItemButtonLabelEl.modifier('active').class(tab.active)), stepItemButtonLabelEl.modifier('failed').class(tab.failed)), stepItemButtonLabelEl.modifier('disabled').class(tab.disabled)) }, tab.label)))))));
};

const Tabs = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.didInit = false;
    this.tabsOptions = [];
    this.lineWidth = 0;
    this.lineOffsetLeft = 0;
    this.lineHeight = 0;
    this.lineOffsetTop = 0;
    this.isReady = false;
    this.platform = ['mobile'];
    /**
     * Defines the layout of the tabs.
     */
    this.interface = 'tabs';
    /**
     * Defines the layout of the tabs.
     */
    this.iconPosition = 'horizontal';
    /**
     * Defines the layout of the tabs. Right only works from the breakpoint
     * high-definition and beyond.
     */
    this.float = 'left';
    /**
     * If `true` the field expands over the whole width.
     */
    this.expanded = false;
    /**
     * If `true` the tabs container does not have a padding left or right.
     */
    this.spaceless = false;
    /**
     * If `true` the field expands over the whole width.
     */
    this.inverted = false;
    /**
     * If `true` the tabs is a block element and uses 100% of the width
     */
    this.fullwidth = false;
    /**
     * If `true` the tabs or steps can be clicked.
     */
    this.clickable = true;
    /**
     * If `true` a light border is shown for the tabs.
     */
    this.border = false;
    /**
     * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
     */
    this.debounce = 0;
    /**
     * If `true` tabs are align vertically.
     */
    this.vertical = false;
    /**
     * The col size of the tabs on vertical mode.
     */
    this.verticalColSize = 'one-third';
    /**
     * If `true` the tabs are shown as a select component on mobile
     */
    this.selectOnMobile = false;
    this.value = undefined;
  }
  debounceChanged() {
    this.balChange = helpers.debounceEvent(this.balChange, this.debounce);
  }
  async valueChanged(newValue, oldValue) {
    this.tabs.forEach(t => t.setActive(t.value === this.value));
    if (this.didInit && newValue !== oldValue) {
      this.isReady = true;
    }
  }
  async resizeHandler() {
    this.platform = platform.getPlatforms();
    this.moveLine(this.getTargetElement(this.value));
  }
  async popoverHandler() {
    this.platform = platform.getPlatforms();
    this.moveLine(this.getTargetElement(this.value));
  }
  connectedCallback() {
    this.platform = platform.getPlatforms();
    this.debounceChanged();
    this.updateTabs();
    this.mutationO = watchForTabs(this.el, 'bal-tab-item', () => {
      this.updateTabs();
    });
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  componentDidLoad() {
    this.didInit = true;
    let value = this.value;
    if ((value === undefined || value === '') && this.interface !== 'navigation') {
      const availableTabs = this.tabsOptions.filter(t => !t.disabled);
      if (availableTabs.length > 0) {
        value = availableTabs[0].value;
      }
    }
    this.value = value;
    this.valueChanged(value, this.value);
  }
  componentDidRender() {
    this.moveLine(this.getTargetElement(this.value));
  }
  /**
   * Go to tab with the given value
   */
  async select(tab) {
    this.value = tab.value;
  }
  /**
   * @internal
   * Rerenders the line to mark the active tab.
   */
  async renderLine() {
    this.moveLine(this.getTargetElement(this.value), 100);
  }
  get tabs() {
    return Array.from(this.el.querySelectorAll('bal-tab-item'));
  }
  async updateTabs() {
    try {
      await Promise.all(this.tabs.map(value => value.getOptions())).then(tabsOptions => {
        this.tabsOptions = tabsOptions;
      });
      const activeTabs = this.tabsOptions.filter(t => t.active);
      if (activeTabs.length > 0) {
        const firstActiveTab = activeTabs[0];
        this.value = firstActiveTab.value;
      }
    }
    catch (e) {
      console.warn('[WARN] - Could not read tab options');
    }
  }
  async onSelectTab(event, tab) {
    if (tab.prevent || tab.disabled || !this.clickable) {
      formInput_helpers.stopEventBubbling(event);
    }
    if (!tab.disabled) {
      tab.navigate.emit(event);
      if (this.clickable) {
        let value = tab.value;
        if (this.interface === 'navigation' && value === this.value) {
          value = '';
        }
        if (value !== this.value) {
          this.balChange.emit(value);
          await this.select(tab);
        }
      }
    }
  }
  parseVertical() {
    if (this.vertical === 'true' || this.vertical === '') {
      return true;
    }
    if (this.vertical === 'false' || this.vertical === undefined) {
      return false;
    }
    return this.vertical;
  }
  moveLine(element, timeout = 0) {
    if (this.timeoutTimer) {
      clearTimeout(this.timeoutTimer);
    }
    this.timeoutTimer = setTimeout(() => {
      if (this.interface !== 'steps' && this.interface !== 'o-steps') {
        if (element) {
          let paddingLeft = 0;
          let paddingRight = 0;
          const listElement = element.closest('li');
          if (listElement) {
            paddingLeft = parseInt(window
              .getComputedStyle(listElement.firstChild)
              .getPropertyValue('padding-left')
              .slice(0, -2), 10);
            paddingRight = parseInt(window
              .getComputedStyle(listElement.firstChild)
              .getPropertyValue('padding-right')
              .slice(0, -2), 10);
          }
          const isMobile = platform.isPlatform('mobile');
          const isTablet = platform.isPlatform('tablet');
          const isVertical = this.parseVertical() === true;
          const isNavbarTablet = this.interface === 'navbar' && (isMobile || isTablet);
          const isVerticalMobile = isMobile && (this.vertical === 'mobile' || this.vertical === 'tablet');
          const isVerticalTablet = (isMobile || isTablet) && this.vertical === 'tablet';
          if (isVertical || isVerticalMobile || isVerticalTablet || isNavbarTablet) {
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.clientHeight) !== undefined) {
              this.lineHeight = listElement.clientHeight - 8;
            }
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.offsetTop) !== undefined) {
              this.lineOffsetTop = listElement.offsetTop + 4;
            }
          }
          else {
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.clientWidth) !== undefined) {
              this.lineWidth = listElement.clientWidth - (this.expanded ? 0 : paddingLeft + paddingRight);
            }
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.offsetLeft) !== undefined) {
              this.lineOffsetLeft = listElement.offsetLeft + (this.expanded ? 0 : paddingLeft);
            }
          }
        }
        else {
          this.lineWidth = 0;
        }
      }
    }, timeout);
  }
  getTargetElement(value) {
    const elements = Array.from(this.el.querySelectorAll('.data-test-tab-item'));
    return elements.filter(element => element.getAttribute('data-value') == value)[0];
  }
  isTabActive(tab) {
    return tab.value === this.value;
  }
  render() {
    const block = bem.BEM.block('tabs');
    const isSteps = this.interface === 'steps' || this.interface === 'o-steps';
    const Tabs = isSteps ? StepList : TabList;
    const isMobile = platform.isPlatform('mobile');
    const isTablet = platform.isPlatform('tablet');
    const isPropVertical = this.parseVertical() === true;
    const isVerticalMobile = isMobile && (this.vertical === 'mobile' || this.vertical === 'tablet');
    const isVerticalTablet = (isMobile || isTablet) && this.vertical === 'tablet';
    const isVertical = isPropVertical || isVerticalMobile || isVerticalTablet;
    return (index.h(index.Host, { class: Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(`context-${this.interface}`).class()), block.modifier('vertical').class(this.parseVertical() === true)), block.modifier('fullwidth').class(this.expanded || this.fullwidth || isSteps)), "data-value": this.tabsOptions
        .filter(t => this.isTabActive(t))
        .map(t => t.value)
        .join(','), "data-label": this.tabsOptions
        .filter(t => this.isTabActive(t))
        .map(t => t.label)
        .join(',') }, index.h("div", { class: {
        'columns is-multiline': this.interface !== 'meta' && this.interface !== 'navigation',
      } }, index.h("div", { class: {
        'column': this.interface !== 'meta' && this.interface !== 'navigation',
        'is-full': !isVertical,
        [`is-${this.verticalColSize}`]: isVertical,
        'bal-tabs__col-items': true,
        'bal-tabs__col-items--vertical': isVertical,
      } }, index.h(Tabs, { value: this.value, context: this.interface, inverted: this.inverted, spaceless: this.spaceless, tabs: this.tabsOptions, border: this.border, float: this.float, expanded: this.expanded, clickable: this.clickable, isReady: this.isReady, iconPosition: this.iconPosition, onSelectTab: (e, t) => this.onSelectTab(e, t), lineWidth: this.lineWidth, lineOffsetLeft: this.lineOffsetLeft, lineHeight: this.lineHeight, lineOffsetTop: this.lineOffsetTop, vertical: this.interface === 'navbar' ? 'tablet' : this.parseVertical(), selectOnMobile: this.selectOnMobile })), index.h("div", { class: {
        'column': this.interface !== 'meta' && this.interface !== 'navigation',
        'is-full': !isVertical,
        'bal-tabs__col-content': true,
        'bal-tabs__col-content--vertical': isVertical,
        'bal-tabs__col-content--full': this.verticalColSize === 'full',
      } }, index.h("slot", null)))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "debounce": ["debounceChanged"],
    "value": ["valueChanged"]
  }; }
};

exports.bal_list_item_accordion_body = ListItemAccordionBody;
exports.bal_list_item_accordion_head = ListItemAccordionHead;
exports.bal_navigation_main = NavigationMain;
exports.bal_navigation_main_body = NavigationMainBody;
exports.bal_navigation_main_head = NavigationMainHead;
exports.bal_navigation_menu = NavigationMenu;
exports.bal_navigation_meta = NavigationMeta;
exports.bal_navigation_meta_end = NavigationMetaEnd;
exports.bal_navigation_meta_start = NavigationMetaStart;
exports.bal_tab_item = TabItem$1;
exports.bal_tabs = Tabs;
