'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const bem = require('./bem-5d122a5c.js');

const NavbarBrand = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balNavigate = index.createEvent(this, "balNavigate", 7);
    this.isMenuActive = false;
    /**
     * Link target
     */
    this.linkTarget = '_blank';
    /**
     * @deprecated Use interface on bal-navbar instead.
     * If `true` the navbar does not have a mobil version. Only shows logo and an app title.
     */
    this.simple = false;
    /**
     * @internal
     * Defines the type of navbar. App is used for almost every web applications
     * like the portal app. For our sales funnel we recommend to use the simple navbar.
     * Meta and main are used for the website.
     */
    this.interface = 'app';
  }
  componentWillLoad() {
    if (window.matchMedia) {
      window.matchMedia('(min-width: 960px)').addEventListener('change', this.resetIsMenuActive.bind(this));
    }
  }
  async resetIsMenuActive(ev) {
    if (ev.matches && !this.simple) {
      this.toggle(false);
    }
  }
  async toggle(isMenuActive) {
    this.isMenuActive = isMenuActive;
    const navbar = this.el.closest('bal-navbar');
    if (navbar) {
      const navbarMenuElement = navbar.querySelector('bal-navbar-menu');
      if (navbarMenuElement && !this.simple) {
        await navbarMenuElement.toggle(this.isMenuActive);
      }
    }
  }
  async onClick() {
    this.toggle(!this.isMenuActive);
  }
  render() {
    const navbarBrandEl = bem.BEM.block('navbar').element('brand');
    const logoTemplate = this.logo ? (index.h("img", { class: Object.assign({}, navbarBrandEl.element('logo').class()), src: this.logo, alt: "" })) : (index.h("bal-logo", { animated: true, color: 'white' }));
    return (index.h(index.Host, { class: Object.assign(Object.assign({}, navbarBrandEl.class()), navbarBrandEl.modifier(`context-${this.interface}`).class()) }, this.href ? (index.h("a", { href: this.href, target: this.linkTarget, onClick: (event) => this.balNavigate.emit(event) }, logoTemplate)) : (logoTemplate), index.h("span", { class: Object.assign({}, navbarBrandEl.element('title').class()) }, index.h("slot", null)), index.h("bal-button", { class: Object.assign(Object.assign({}, navbarBrandEl.element('burger').class()), { 'is-hidden': this.interface === 'simple' }), color: "light", inverted: true, square: true, icon: this.isMenuActive ? 'close' : 'menu-bars', onClick: () => this.onClick() })));
  }
  get el() { return index.getElement(this); }
};

exports.bal_navbar_brand = NavbarBrand;
