'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');
const bem = require('./bem-5d122a5c.js');
const toggleScrollingBody = require('./toggle-scrolling-body-5e1f7be7.js');

const NavigationPopover = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.isActive = false;
    /**
     * Defines the label of the button
     */
    this.label = '';
    /**
     * Turns the trigger button to inverted style.
     */
    this.inverted = false;
    /**
     * If `true` a backdrop is added
     */
    this.backdrop = false;
    /**
     * Defines the size of the button
     */
    this.size = '';
    /**
     * Color style of the button when the popover is closed.
     */
    this.inactiveColor = 'light';
    /**
     * Color style of the button when the popover is open.
     */
    this.activeColor = 'primary';
    /**
     * If 'false', the closing button is not displayed
     */
    this.closable = true;
    /**
     * Defines border-radius of popover content.
     */
    this.contentRadius = 'normal';
    /**
     * Define the position of the popover content.
     */
    this.position = 'bottom-start';
    /**
     * Define the max width of the popover content.
     */
    this.contentWidth = 0;
    /**
     * Define the min width of the popover content.
     */
    this.contentMinWidth = 0;
    /**
     * Define the offset of the popover content.
     */
    this.offsetY = 0;
    /**
     * If `true` the width of the buttons is limited
     */
    this.square = false;
    /**
     * If `true` the popover does not have the shadow
     */
    this.contentNoShadow = false;
    /**
     * If `true` the content has a min width of 100%.
     */
    this.contentExpanded = false;
    /**
     * If `true` a little arrow is added, which points to the trigger element
     */
    this.arrow = false;
    /**
     * If `true` its content will have a divider line on top
     */
    this.mobileTop = false;
    this.toggle = (event) => {
      formInput_helpers.stopEventBubbling(event);
      this.clearTimeouts();
      if (!this.isActive) {
        toggleScrollingBody.disableSmoothScrolling();
        this.scrollToTopTimer = setTimeout(() => {
          window.scrollTo(0, 0);
        }, 0);
      }
      this.setActiveTimer = setTimeout(() => {
        toggleScrollingBody.enableSmoothScrolling();
        this.isActive = !this.isActive;
      }, 100);
    };
  }
  clearTimeouts() {
    if (this.scrollToTopTimer) {
      clearTimeout(this.scrollToTopTimer);
    }
    if (this.setActiveTimer) {
      clearTimeout(this.setActiveTimer);
    }
  }
  render() {
    const navPopoverEl = bem.BEM.block('nav').element('popover');
    return (index.h(index.Host, { class: Object.assign(Object.assign({}, navPopoverEl.class()), { control: true }) }, index.h("bal-popover", { value: this.isActive, onBalChange: event => (this.isActive = event.detail), arrow: this.arrow, backdrop: this.backdrop, position: this.position, offsetY: this.offsetY, "mobile-top": this.mobileTop }, index.h("bal-button", { "bal-popover-trigger": true, icon: this.icon, size: this.size, inverted: this.inverted, color: this.isActive ? this.activeColor : this.inactiveColor, square: this.square, onClick: this.toggle, "aria-haspopup": "true", class: `bal-navigation-popover__button bal-navigation-popover__button-${this.isActive ? this.activeColor : this.inactiveColor}` }, this.label), index.h("bal-popover-content", { radius: this.contentRadius, "content-width": this.contentWidth, "content-min-width": this.contentMinWidth, "no-shadow": this.contentNoShadow, expanded: this.contentExpanded, "mobile-top": this.mobileTop }, (this.closable || this.heading) && (index.h("div", { class: Object.assign({}, navPopoverEl.element('head').class()) }, this.heading && (index.h("bal-heading", { space: "none", level: "h4" }, this.heading)), this.closable && index.h("bal-close", { onClick: () => (this.isActive = !this.isActive) }))), index.h("slot", null)))));
  }
};

exports.bal_navigation_popover = NavigationPopover;
