'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const level_utils = require('./level.utils-3d220835.js');
const bem = require('./bem-5d122a5c.js');
const platform = require('./platform-14f86172.js');
const browser = require('./browser-5e81f6ec.js');
const toggleScrollingBody = require('./toggle-scrolling-body-5e1f7be7.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');

const Navigation = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.previousY = 0;
    this.bodyScrollBlocker = toggleScrollingBody.BodyScrollBlocker();
    this.mainMobileHeight = '';
    this.isMetaHidden = false;
    this.levels = [];
    this.selectedMetaIndex = 0;
    this.selectedMainIndex = 0;
    this.isMainBodyOpen = false;
    this.selectedMetaValue = '';
    this.selectedMainValue = '';
    this.isTouch = platform.isPlatform('touch');
    /**
     * Defines if the animation should be active
     */
    this.logoAnimated = true;
    /**
     * Path to the logo-image
     */
    this.logoPath = '/';
    /**
     * Aria label for the meta-navigation-wrapper
     */
    this.ariaLabelMeta = '';
    /**
     * Aria label for the main-navigation-wrapper
     */
    this.ariaLabelMain = '';
    this.bodyOffset = 0;
    this.listenToPopoverChangeEvent = async (event) => {
      const customEvent = event;
      const isNavPopoverOpen = customEvent.detail;
      if (isNavPopoverOpen) {
        this.bodyScrollBlocker.block();
      }
      else {
        this.bodyScrollBlocker.allow();
      }
      if (isNavPopoverOpen) {
        this.isMainBodyOpen = false;
      }
    };
    this.onBurgerButtonClick = async () => {
      this.dismissPopover();
      this.isMainBodyOpen = !this.isMainBodyOpen;
      if (this.isMainBodyOpen) {
        this.bodyScrollBlocker.block();
      }
      else {
        this.bodyScrollBlocker.allow();
      }
    };
    this.onAccordionClick = (event) => {
      formInput_helpers.stopEventBubbling(event);
      clearTimeout(this.closeOtherAccordionsTimer);
      const target = event.target;
      const isMainAccordionItem = !target.subAccordionItem;
      const closeOtherAccordions = (selector, element) => {
        const items = element.querySelectorAll(selector);
        items.forEach(item => {
          if (item !== target) {
            const accordionHeadEl = item.querySelector('bal-list-item-accordion-head');
            if (accordionHeadEl) {
              accordionHeadEl.accordionOpen = false;
            }
          }
        });
      };
      if (isMainAccordionItem) {
        closeOtherAccordions('bal-list-item.bal-nav__main-mobile__main-accordion', this.el);
        this.closeOtherAccordionsTimer = setTimeout(() => {
          closeOtherAccordions('bal-list-item.is-sub-accordion-item', this.el);
        }, 300);
      }
      else {
        const parent = target.closest('bal-list-item.bal-nav__main-mobile__main-accordion');
        if (parent) {
          closeOtherAccordions('bal-list-item.is-sub-accordion-item', parent);
        }
      }
    };
    this.onMainTabChange = (event) => {
      const isMainNavOpen = event.detail !== '';
      if (browser.isBrowser('touch')) {
        if (isMainNavOpen) {
          this.isMetaHidden = false;
          this.bodyScrollBlocker.block();
        }
        else {
          this.bodyScrollBlocker.allow();
        }
      }
    };
  }
  async clickOnOutside(event) {
    var _a, _b;
    if (platform.isPlatform('desktop')) {
      if (!((_a = this.mainNavElement) === null || _a === void 0 ? void 0 : _a.contains(event.target)) && this.isMainBodyOpen) {
        this.isMainBodyOpen = false;
        this.selectedMainValue = '';
      }
    }
    if (platform.isPlatform('touch')) {
      if ((_b = this.metaMobileActionsElement) === null || _b === void 0 ? void 0 : _b.contains(event.target)) {
        this.isMainBodyOpen = false;
      }
    }
  }
  get metaMobileActionsElement() {
    return this.el.querySelector('.bal-nav__metamobile__actions');
  }
  get metaDesktopEndElement() {
    return this.el.querySelector('bal-navigation-meta-end');
  }
  async resizeHandler() {
    this.isMetaHidden = false;
    this.mainMobileHeight = this.getMaxHeight();
    if (this.isTouch !== platform.isPlatform('touch')) {
      this.isMainBodyOpen = false;
      this.selectedMainValue = '';
      this.isTouch = platform.isPlatform('touch');
    }
  }
  async orientationHandler() {
    this.isMainBodyOpen = false;
    this.dismissPopover();
  }
  handleScroll(_event) {
    if (platform.isPlatform('desktop') && !this.bodyScrollBlocker.isBlocked()) {
      const maxScrollHeight = document.body.scrollHeight - document.body.clientHeight;
      const isOnTop = 0 >= window.scrollY;
      const isOverViewportTop = 0 > window.scrollY;
      const isOverViewportBottom = maxScrollHeight <= window.scrollY;
      const didMoveDownwards = window.scrollY > this.previousY;
      this.isMetaHidden = !isOnTop && (didMoveDownwards || isOverViewportBottom || isOverViewportTop);
      this.previousY = window.scrollY;
    }
  }
  async connectedCallback() {
    this.selectedMetaValue = this.metaValue;
    await this.readSubLevels();
    this.updateIndexes();
    this.mutationO = level_utils.observeLevels(this.el, 'bal-navigation-levels', () => this.readSubLevels());
  }
  disconnectedCallback() {
    var _a, _b;
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
    (_a = this.metaMobileActionsElement) === null || _a === void 0 ? void 0 : _a.removeEventListener('balChange', this.listenToPopoverChangeEvent);
    (_b = this.metaDesktopEndElement) === null || _b === void 0 ? void 0 : _b.removeEventListener('balChange', this.listenToPopoverChangeEvent);
  }
  componentDidLoad() {
    var _a, _b;
    this.previousY = window.scrollY;
    this.mainMobileHeight = this.getMaxHeight();
    (_a = this.metaMobileActionsElement) === null || _a === void 0 ? void 0 : _a.addEventListener('balChange', this.listenToPopoverChangeEvent);
    (_b = this.metaDesktopEndElement) === null || _b === void 0 ? void 0 : _b.addEventListener('balChange', this.listenToPopoverChangeEvent);
    this.isTouch = platform.isPlatform('touch');
  }
  componentDidUpdate() {
    this.updateIndexes();
  }
  updateIndexes() {
    var _a;
    if (((_a = this.levels) === null || _a === void 0 ? void 0 : _a.length) > 0) {
      const selectedMetaIndex = this.levels.findIndex(meta => meta.value === this.selectedMetaValue);
      this.selectedMetaIndex = selectedMetaIndex !== -1 ? selectedMetaIndex : 0;
    }
  }
  async readSubLevels() {
    const levelEl = this.el.querySelector('bal-navigation-levels');
    const levels = await (levelEl === null || levelEl === void 0 ? void 0 : levelEl.getLevelInfos());
    if (levels) {
      this.levels = levels;
    }
  }
  getMaxHeight() {
    return `${(window.innerHeight - 64) / 16}rem`;
  }
  dismissPopover() {
    const popoverElements = this.el.querySelectorAll('bal-popover');
    popoverElements === null || popoverElements === void 0 ? void 0 : popoverElements.forEach(popoverEl => {
      popoverEl.value = false;
    });
  }
  render() {
    var _a, _b;
    const navigationEl = bem.BEM.block('nav');
    const hasLevels = ((_a = this.levels) === null || _a === void 0 ? void 0 : _a.length) > 0;
    return (index.h(index.Host, { class: Object.assign(Object.assign({}, navigationEl.class()), { 'bal-nav--transformed': this.isMetaHidden }) }, index.h("bal-navigation-meta", { class: "is-hidden-touch", "aria-label-meta": this.ariaLabelMeta }, index.h("bal-navigation-meta-start", null, hasLevels && (index.h("bal-tabs", { interface: "meta", spaceless: true, inverted: true, value: this.selectedMetaValue }, this.levels.map((meta, index$1) => {
      return meta.isTabLink ? (index.h("bal-tab-item", { label: meta.label, value: meta.value, href: meta.link, target: meta.target })) : (index.h("bal-tab-item", { label: meta.label, value: meta.value, onBalNavigate: ev => {
          meta.onClick(ev.detail);
          this.selectedMetaValue = meta.value;
          this.selectedMetaIndex = index$1;
          this.isMainBodyOpen = false;
          this.selectedMainValue = '';
        } }));
    })))), index.h("bal-navigation-meta-end", null, this.levels && index.h("slot", { name: "meta-actions" }))), index.h("bal-navigation-main", { class: {
        'is-hidden-touch': true,
        'container': true,
        'bal-nav__main--expanded': this.isMainBodyOpen,
      }, ref: el => {
        this.mainNavElement = el;
      }, "aria-label-main": this.ariaLabelMain }, index.h("bal-navigation-main-head", { slot: "main-head", class: {
        'is-hidden-mobile': true,
        'bal-nav__main__head--active': this.isMainBodyOpen,
      } }, index.h("div", null, index.h("a", { href: this.logoPath, class: "bal-nav__main-head-logo", tabindex: -1 }, index.h("bal-logo", { color: "blue", animated: this.logoAnimated })), index.h("bal-tabs", { interface: "navigation", float: "right", fullwidth: true, spaceless: true, value: this.selectedMainValue, onBalChange: this.onMainTabChange }, hasLevels &&
      ((_b = this.levels[this.selectedMetaIndex].subLevels) === null || _b === void 0 ? void 0 : _b.map((main, index$1) => {
        return main.isTabLink ? (index.h("bal-tab-item", { label: main.label, value: main.value, href: main.link, target: main.target, onBalNavigate: ev => {
            main.onClick(ev.detail);
            this.selectedMainIndex = index$1;
            this.isMainBodyOpen = false;
            this.selectedMainValue = main.value;
          } })) : (index.h("bal-tab-item", { label: main.label, value: main.value, icon: "nav-go-down", onBalNavigate: ev => {
            main.onClick(ev.detail);
            this.selectedMainIndex = index$1;
            this.isMainBodyOpen = !(ev.target.value === this.selectedMainValue);
            this.selectedMainValue = ev.target.value === this.selectedMainValue ? '' : main.value;
          } }));
      }))))), this.isMainBodyOpen && (index.h("bal-navigation-main-body", { slot: "main-body" }, this.levels
      .filter((_, index) => index === this.selectedMetaIndex)
      .map(meta => {
      var _a;
      return (_a = meta.subLevels) === null || _a === void 0 ? void 0 : _a.filter((_, mainIndex) => this.selectedMainIndex === mainIndex).map(main => (index.h("bal-navigation-menu", { "link-href": main.link, "link-name": main.linkLabel, target: main.target, elements: main.subLevels })));
    })))), index.h("div", { class: "bal-nav__metamobile container" }, index.h("nav", { role: "navigation", "aria-label": this.ariaLabelMeta }, index.h("a", { href: this.logoPath, class: "bal-nav__main-mobile__logo", tabindex: -1 }, index.h("bal-logo", { color: "blue", animated: this.logoAnimated })), index.h("div", { class: "bal-nav__metamobile__actions" }, index.h("slot", { name: "meta-actions-mobile" })), index.h("bal-button", { slot: "burger", "data-testid": "navigation-burger", color: this.isMainBodyOpen ? 'primary' : 'light', square: true, icon: this.isMainBodyOpen ? 'close' : 'menu-bars', onClick: () => this.onBurgerButtonClick() }))), index.h("div", { class: "bal-nav__main-mobile container", style: {
        '--bal-nav-main-mobile-height': this.mainMobileHeight,
        'display': this.isMainBodyOpen && this.isTouch ? 'block' : 'none',
      } }, index.h("bal-list", { border: true, "in-main-nav": true, size: "small" }, this.levels.map(meta => {
      var _a;
      return (index.h("bal-list-item", { accordion: true, onBalNavigate: this.onAccordionClick, class: "bal-nav__main-mobile__main-accordion" }, index.h("bal-list-item-accordion-head", { icon: "nav-go-down" }, index.h("bal-list-item-content", null, index.h("bal-list-item-title", { level: "h4" }, meta.label))), index.h("bal-list-item-accordion-body", { class: "bal-list__item__accordion-body__parent" }, index.h("div", null, meta.link && (index.h("div", { class: "bal-nav__main-mobile__link" }, index.h("a", { href: meta.link }, meta.linkLabel))), index.h("bal-list", { border: true, "in-main-nav": true, class: "pt-4", size: "small" }, (_a = meta.subLevels) === null || _a === void 0 ? void 0 : _a.map(main => {
        return main.isTabLink ? (index.h("bal-list-item", { "sub-accordion-item": true, href: main.link, target: main.target }, index.h("bal-list-item-content", null, index.h("bal-list-item-title", { level: "h5" }, main.label)))) : (index.h("bal-list-item", { accordion: true, "sub-accordion-item": true }, index.h("bal-list-item-accordion-head", { icon: "nav-go-down" }, index.h("bal-list-item-content", null, index.h("bal-list-item-title", { level: "h5" }, main.label))), index.h("bal-list-item-accordion-body", null, index.h("bal-navigation-menu", { "link-href": main.link, "link-name": main.linkLabel, target: main.target, elements: main.subLevels }))));
      }))))));
    }))), index.h("div", { class: "bal-nav__foot-mobile", style: {
        display: this.isMainBodyOpen && this.isTouch ? 'block' : 'none',
      } }, index.h("slot", { name: "meta-mobile-foot" })), index.h("slot", null)));
  }
  get el() { return index.getElement(this); }
};

exports.bal_navigation = Navigation;
