'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const bem = require('./bem-5d122a5c.js');

const Pagination = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balChangeEventEmitter = index.createEvent(this, "balChange", 7);
    this._value = 1;
    /**
     * Defines the layout of the pagination
     */
    this.interface = '';
    /**
     * Disables component
     */
    this.disabled = false;
    /**
     * Current selected page
     */
    this.value = 1;
    /**
     * The total amount of pages
     */
    this.totalPages = 1;
    /**
     * Specify the max visible pages before and after the selected page
     */
    this.pageRange = 2;
    /**
     * List of tabs names for 'tabs' interface
     */
    this.tabsNames = [];
    /**
     * If 'true, the pagination will be sticky to the top
     */
    this.sticky = false;
    /**
     * If sticky, the top position will be determined by this value
     */
    this.top = 0;
  }
  valueChanged(newValue) {
    this._value = newValue;
  }
  topValueChanged(newValue) {
    if (this.sticky) {
      this.el.style.top = `${newValue}px`;
    }
  }
  componentWillLoad() {
    this._value = this.value;
    this.topValueChanged(this.top);
  }
  /**
   * Go to the next page
   */
  async next() {
    if (this._value < this.totalPages) {
      this._value = this._value + 1;
      this.balChangeEventEmitter.emit(this._value);
    }
  }
  /**
   * Go to the previous page
   */
  async previous() {
    if (this._value !== 1) {
      this._value = this._value - 1;
      this.balChangeEventEmitter.emit(this._value);
    }
  }
  selectPage(pageNumber) {
    this._value = pageNumber;
    this.balChangeEventEmitter.emit(this._value);
  }
  renderEllipsisElement() {
    return (index.h("li", null, index.h("div", { class: "pagination-more" }, index.h("bal-text", { bold: true, heading: true, inline: true, space: "none" }, "\u2026"))));
  }
  renderPageElement(pageNumber) {
    const isActive = this._value === pageNumber;
    const dot = bem.BEM.block('pagination').element('nav').element('pagination-list').element('dot');
    const tab = bem.BEM.block('pagination').element('nav').element('pagination-list').element('tab');
    if (this.interface === 'small') {
      return (index.h("li", null, index.h("span", { class: Object.assign(Object.assign(Object.assign({}, dot.class()), dot.modifier('active').class(isActive)), dot.modifier('inactive').class(!isActive)), onClick: () => this.selectPage(pageNumber) })));
    }
    if (this.interface === 'tabs') {
      return (index.h("bal-button", { expanded: true, class: Object.assign({}, tab.class()), color: "light", inverted: isActive, onClick: () => this.selectPage(pageNumber) }, this.tabsNames[pageNumber - 1] !== '' ? this.tabsNames[pageNumber - 1] : pageNumber));
    }
    return (index.h("li", null, index.h("bal-button", { square: true, color: isActive ? 'primary' : 'text', onClick: () => this.selectPage(pageNumber) }, pageNumber)));
  }
  getItems(pageRange = 1) {
    const items = [];
    let rangeStart = this._value - pageRange;
    let rangeEnd = this._value + pageRange;
    if (this.interface === 'small') {
      rangeStart = 1;
      rangeEnd = this.totalPages - 1;
    }
    else {
      if (rangeEnd > this.totalPages) {
        rangeEnd = this.totalPages;
        rangeStart = this.totalPages - pageRange * 2;
        rangeStart = rangeStart < 1 ? 1 : rangeStart;
      }
      if (rangeStart <= 1) {
        rangeStart = 1;
        rangeEnd = Math.min(pageRange * 2 + 1, this.totalPages);
      }
    }
    if (rangeStart > 1) {
      items.push(this.renderPageElement(1));
      if (this.interface !== 'small') {
        items.push(this.renderEllipsisElement());
      }
    }
    for (let i = rangeStart; i <= rangeEnd; i++) {
      items.push(this.renderPageElement(i));
    }
    if (rangeEnd < this.totalPages) {
      if (this.interface !== 'small') {
        items.push(this.renderEllipsisElement());
      }
      items.push(this.renderPageElement(this.totalPages));
    }
    return items;
  }
  render() {
    const mobileItems = this.getItems();
    const tabletItems = this.getItems(this.pageRange);
    const block = bem.BEM.block('pagination');
    const elNav = block.element('nav');
    const elPrevious = elNav.element('pagination-previous');
    const elNext = elNav.element('pagination-next');
    const elList = elNav.element('pagination-list');
    const isSmall = this.interface === 'small';
    const hasTabs = this.interface === 'tabs';
    const buttonColor = isSmall ? 'link' : 'text';
    const buttonSize = isSmall ? 'small' : '';
    const flat = isSmall;
    return (index.h(index.Host, { class: Object.assign(Object.assign({}, block.class()), block.modifier('is-sticky').class(this.sticky)) }, index.h("nav", { class: Object.assign(Object.assign({}, elNav.class()), elNav.modifier(`context-${this.interface}`).class()), role: "navigation", "aria-label": "pagination" }, !hasTabs && [
      index.h("bal-button", { square: true, color: buttonColor, size: buttonSize, flat: flat, class: Object.assign(Object.assign({}, elPrevious.class()), elPrevious.modifier(`context-${this.interface}`).class()), disabled: this._value < 2 || this.disabled, onClick: () => this.previous() }, index.h("bal-icon", { name: "nav-go-left", size: "small" })),
      index.h("bal-button", { square: true, color: buttonColor, size: buttonSize, flat: flat, class: Object.assign(Object.assign({}, elNext.class()), elNext.modifier(`context-${this.interface}`).class()), disabled: this._value === this.totalPages || this.disabled, onClick: () => this.next() }, index.h("bal-icon", { name: "nav-go-right", size: "small" })),
    ], this.interface === '' || (isSmall && this.totalPages <= 5) || hasTabs ? ([
      index.h("ul", { class: Object.assign(Object.assign(Object.assign({}, elList.class()), elList.modifier(`context-${this.interface}`).class()), { 'is-hidden-mobile': true, 'is-disabled': this.disabled }) }, tabletItems),
      index.h("ul", { class: Object.assign(Object.assign(Object.assign({}, elList.class()), elList.modifier(`context-${this.interface}`).class()), { 'is-hidden-tablet': true, 'is-disabled': this.disabled }) }, mobileItems),
    ]) : (index.h("bal-text", { space: "none", class: Object.assign(Object.assign(Object.assign({}, elList.class()), elList.modifier(`context-${this.interface}`).class()), { 'is-size-5': true }), color: "blue" }, index.h("span", { class: "has-text-weight-bold" }, this._value), ' / ' + this.totalPages)))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["valueChanged"],
    "top": ["topValueChanged"]
  }; }
};

exports.bal_pagination = Pagination;
