'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const formInput_helpers = require('./form-input.helpers-8ed22653.js');
const helpers = require('./helpers-c4f9304b.js');
const bem = require('./bem-5d122a5c.js');

const Radio = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balFocus = index.createEvent(this, "balFocus", 7);
    this.balBlur = index.createEvent(this, "balBlur", 7);
    this.balChange = index.createEvent(this, "balChange", 7);
    this.balClick = index.createEvent(this, "balClick", 7);
    this.inputId = `bal-rb-${radioIds++}`;
    this.inheritedAttributes = {};
    this.hasFocus = false;
    this.hasLabel = true;
    /**
     * @deprecated If `true` the radio has no label
     */
    this.isEmpty = false;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * If `true` the radio has no label
     */
    this.labelHidden = false;
    /**
     * If `true` the control is no padding
     */
    this.flat = false;
    /**
     * Defines the layout of the radio button
     */
    this.interface = 'radio';
    /**
     * Value of the radio item, if checked the whole group has this value.
     */
    this.value = '';
    /**
     * If `true`, the radio is selected.
     */
    this.checked = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true`, the value will not be send with a form submit
     */
    this.hidden = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    this.updateState = () => {
      if (this.group) {
        this.checked = this.group.value === this.value;
      }
    };
    this.onInputFocus = (ev) => formInput_helpers.inputHandleFocus(this, ev);
    this.onInputBlur = (ev) => formInput_helpers.inputHandleBlur(this, ev);
    this.onClick = (ev) => {
      const element = ev.target;
      if (element.href) {
        return;
      }
      if (element.nodeName !== 'INPUT' && !this.disabled && !this.readonly) {
        this.balChange.emit(this.checked);
        this.balClick.emit(ev);
        ev.preventDefault();
      }
      else {
        formInput_helpers.stopEventBubbling(ev);
      }
    };
  }
  isEmptyHandler() {
    this.labelHidden = this.isEmpty;
    console.warn('[DEPRECATED] - Use label-hidden instead');
  }
  listenOnClick(ev) {
    if ((this.disabled || this.readonly) &&
      ev.target &&
      (ev.target === this.el || helpers.isDescendant(this.el, ev.target))) {
      formInput_helpers.stopEventBubbling(ev);
    }
  }
  componentWillLoad() {
    this.inheritedAttributes = helpers.inheritAttributes(this.el, ['aria-label', 'tabindex', 'title']);
  }
  connectedCallback() {
    if (this.group) {
      this.updateState();
      this.group.addEventListener('balChange', () => this.updateState());
    }
  }
  disconnectedCallback() {
    if (this.group) {
      this.group.removeEventListener('balChange', () => this.updateState());
    }
  }
  /**
   * Sets the focus on the checkbox input element.
   */
  async setFocus() {
    formInput_helpers.inputSetFocus(this);
  }
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  async setBlur() {
    formInput_helpers.inputSetBlur(this);
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  get group() {
    return this.el.closest('bal-radio-group');
  }
  render() {
    const block = bem.BEM.block('radio-checkbox');
    const inputEl = block.element('input');
    const labelEl = block.element('label');
    const labelTextEl = labelEl.element('text');
    const value = typeof this.value === 'boolean' ? JSON.stringify(this.value) : this.value;
    return (index.h(index.Host, Object.assign({ role: "radio", "aria-checked": `${this.checked}`, "aria-disabled": this.disabled ? 'true' : null, "aria-hidden": this.disabled ? 'true' : null, "aria-focused": this.hasFocus ? 'true' : null, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('radio').class()), block.modifier('select-button').class(this.interface === 'select-button')), block.modifier('focused').class(this.hasFocus)), block.modifier('invalid').class(this.invalid)), block.modifier('checked').class(this.checked)), block.modifier('flat').class(this.flat)), block.modifier('disabled').class(this.disabled || this.readonly)), onClick: this.onClick, onFocus: this.onInputFocus, onBlur: this.onInputBlur }, this.inheritedAttributes), index.h("input", { class: Object.assign(Object.assign(Object.assign({}, inputEl.class()), inputEl.modifier('select-button').class(this.interface === 'select-button')), { 'data-test-radio-input': true }), type: "radio", id: this.inputId, name: this.name, value: value, checked: this.checked, "aria-checked": `${this.checked}`, disabled: this.disabled, readonly: this.readonly, required: this.required, onFocus: this.onInputFocus, onBlur: this.onInputBlur, ref: inputEl => (this.nativeInput = inputEl) }), index.h("label", { class: Object.assign(Object.assign(Object.assign(Object.assign({}, labelEl.class()), labelEl.modifier('checked').class(this.checked)), labelEl.modifier('radio').class()), { 'data-test-radio-label': true }), htmlFor: this.inputId }, index.h("span", { class: Object.assign(Object.assign({}, labelTextEl.class()), labelTextEl.modifier('hidden').class(this.labelHidden)) }, index.h("slot", null)))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "isEmpty": ["isEmptyHandler"]
  }; }
};
let radioIds = 0;

exports.bal_radio = Radio;
