'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const bem = require('./bem-5d122a5c.js');
const observer = require('./observer-6a0d113e.js');

const Slider = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xPosition = 0;
    this.slideIndex = 1;
    this.slidesLabels = [];
    /**
     * Set the slide to switch to
     * @param {number} slide :Set to switch to.
     */
    this.setSlide = (slide) => {
      const slideContainer = this.getSlideContainer();
      const slideWidth = this.slides[0].clientWidth;
      if (slideContainer && slide >= 0 && slide <= this.slides.length) {
        this.slideIndex = slide;
        slideContainer.style.transitionDuration = '1.2s';
        slideContainer.style.transitionTimingFunction = 'cubic-bezier(0.23, 0.93, 0.13, 1)';
        slideContainer.style.transform = `translate(-${(this.slideIndex - 1) * slideWidth}px)`;
      }
    };
  }
  async resizeHandler() {
    this.setSlide(this.slideIndex);
  }
  connectedCallback() {
    this.mutationO = observer.observeItems(this.el, 'bal-slider-item', () => this.updateSlides());
    this.updateSlides();
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  touchStart(event) {
    const container = this.getSliderContainer();
    if (container === null || container === void 0 ? void 0 : container.contains(event.target)) {
      this.xPosition = event.touches[0].pageX;
    }
  }
  touchEnd(event) {
    const container = this.getSliderContainer();
    if (container === null || container === void 0 ? void 0 : container.contains(event.target)) {
      if (event.changedTouches[0].pageX < this.xPosition) {
        this.setSlide(this.slideIndex + 1);
      }
      else {
        this.setSlide(this.slideIndex - 1);
      }
    }
  }
  getChildItems() {
    return Array.from(this.el.querySelectorAll('bal-slider-item'));
  }
  getSliderContainer() {
    return this.el.querySelector('.bal-slider__container');
  }
  getSlideContainer() {
    return this.el.querySelector('.bal-slider__container__slides');
  }
  updateSlides() {
    this.slides = this.getChildItems();
    this.slidesLabels = this.slides.map(slide => slide.label);
  }
  render() {
    const block = bem.BEM.block('slider');
    const container = block.element('container');
    const containerSlides = container.element('slides');
    return (index.h(index.Host, { class: Object.assign({}, block.class()) }, index.h("bal-pagination", { sticky: true, interface: "tabs", totalPages: this.slides.length, value: this.slideIndex, tabsNames: this.slidesLabels, onBalChange: ev => {
        this.setSlide(ev.detail);
      } }), index.h("div", { class: Object.assign({}, container.class()) }, index.h("div", { class: Object.assign({}, containerSlides.class()) }, index.h("slot", null)))));
  }
  get el() { return index.getElement(this); }
};

exports.bal_slider = Slider;
