'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');

const Snackbar = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balClose = index.createEvent(this, "balClose", 7);
    this.balAction = index.createEvent(this, "balAction", 7);
    this.snackbarId = `bal-snackbar-${snackbarIds++}`;
    this.animationClass = 'fadeInDown';
    /**
     * The theme type of the snackbar. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * The duration of the snackbar
     */
    this.duration = 0;
    /**
     * The subject of the snackbar header
     */
    this.subject = '';
    /**
     * The message of the snackbar as html content
     */
    this.message = '';
    /**
     * The icon of the snackbar header
     */
    this.icon = '';
    /**
     * Label text for the action button
     */
    this.action = '';
    /**
     * @internal Handler for on close event
     */
    this.closeHandler = () => void 0;
    /**
     * @internal Handler for on action button click event
     */
    this.actionHandler = () => void 0;
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    this.onActionHandler = () => {
      this.balAction.emit(this.snackbarId);
      this.actionHandler();
    };
  }
  async componentWillLoad() {
    if (this.duration > 0) {
      await this.closeIn(this.duration);
    }
  }
  /**
   * Closes the snackbar after the given duration in ms
   */
  async closeIn(duration) {
    this.timer = setTimeout(() => this.close(), duration);
  }
  /**
   * Closes this snackbar
   */
  async close() {
    clearTimeout(this.timer);
    this.balClose.emit(this.snackbarId);
    this.element.remove();
    this.closeHandler();
  }
  get colorType() {
    if (this.color === '') {
      return '';
    }
    return `bal-snackbar__inner--is-${this.color}`;
  }
  get buttonType() {
    if (this.color === '') {
      return 'info';
    }
    return this.color;
  }
  render() {
    const labelAttributes = {};
    if (this.message !== undefined && this.message !== '') {
      labelAttributes.innerHTML = this.message;
    }
    return (index.h(index.Host, { id: this.snackbarId, class: "bal-snackbar" }, index.h("div", { role: "alert", class: `bal-snackbar__inner ${this.animationClass} ${this.colorType} p-5` }, index.h("div", { class: "bal-snackbar__header" }, index.h("span", { class: "icon-text is-small" }, index.h("span", { class: "icon", style: { display: this.icon ? '' : 'none' } }, index.h("bal-icon", { name: this.icon, color: 'primary' })), index.h("bal-heading", { level: "h5", space: "none" }, this.subject))), index.h("span", Object.assign({ class: "bal-snackbar__label" }, labelAttributes), index.h("slot", null), index.h("span", { class: "hidden" })), index.h("bal-close", { class: "bal-snackbar__close", onClick: () => this.close() }), index.h("div", { class: "bal-snackbar__footer", style: { display: this.action === '' ? 'none' : 'inline-flex' } }, index.h("bal-button", { color: "info", href: this.href, target: this.target, onClick: () => this.onActionHandler() }, this.action)))));
  }
  get element() { return index.getElement(this); }
};
let snackbarIds = 0;

exports.bal_snackbar = Snackbar;
