'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const bem = require('./bem-5d122a5c.js');

const Stage = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Defines content width of the stage
     */
    this.containerSize = '';
    /**
     * Defines size of the stage
     */
    this.size = '';
    /**
     * Defines the background color of the stage section
     */
    this.color = 'purple';
    /**
     * If true the Baloise Shape is set
     */
    this.shape = false;
    /**
     * @deprecated If true the Baloise Shape is set
     */
    this.hasShape = false;
    /**
     * sets text color to white for images and dark backgrounds (optional)
     */
    this.inverted = false;
    this.getContainerWidth = () => {
      switch (this.containerSize) {
        case 'is-detail-page':
        case 'detail-page':
          return '680px';
        case 'is-compact':
        case 'compact':
          return '832px';
        case 'is-blog-page':
        case 'blog-page':
          return '920px';
        case 'is-fluid':
        case 'fluid':
          return '100vw';
        case 'is-wide':
        case 'wide':
        default:
          return '1400px';
      }
    };
  }
  hasShapeHandler() {
    console.warn('[DEPRECATED] - Please use the property shape instead');
  }
  migrateHasShape() {
    if (this.hasShape === true) {
      this.shape = this.hasShape;
    }
  }
  connectedCallback() {
    this.migrateHasShape();
  }
  get containerClass() {
    if (this.containerSize.includes('wide')) {
      return '';
    }
    if (this.containerSize.startsWith('is-')) {
      return this.containerSize;
    }
    return `is-${this.containerSize}`;
  }
  render() {
    const block = bem.BEM.block('stage');
    const element = bem.BEM.block('stage-content');
    return (index.h(index.Host, { class: Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(`is-${this.size === '' ? 'medium' : this.size}`).class()), block.modifier(`is-${this.color}`).class(!!this.color)), block.modifier('has-shape').class(!!this.shape)), style: { '--bal-stage-container-width': this.getContainerWidth() } }, index.h("section", { class: Object.assign(Object.assign(Object.assign({}, element.class()), element.modifier('is-inverted').class(this.inverted)), { container: true, [`${this.containerClass}`]: this.containerSize !== '' }) }, index.h("slot", null), this.shape && (index.h("div", { class: { container: true, [`${this.containerClass}`]: this.containerSize !== '' } }, index.h("bal-shape", { color: this.color, variation: this.shapeVariation, rotation: this.shapeRotation }))))));
  }
  static get watchers() { return {
    "hasShape": ["hasShapeHandler"]
  }; }
};

exports.bal_stage = Stage;
