'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a6a78ee3.js');
const helpers = require('./helpers-c4f9304b.js');
const bem = require('./bem-5d122a5c.js');

const Tag = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.balCloseClick = index.createEvent(this, "balCloseClick", 7);
    this.inheritedAttributes = {};
    this.inheritedAttributesClose = {};
    /**
     * The theme type of the tag. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * The size of the tag element
     */
    this.size = '';
    /**
     * The theme type of the tag. Given by bulma our css framework.
     */
    this.closable = false;
    /**
     * Overwrites the default color to invalid style
     */
    this.invalid = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * Choosing left or center the tag is aligned to that side in the bal-card.
     */
    this.position = 'left';
    /**
     * If `true` a light version of the color is displayed
     */
    this.light = false;
    /**
     * @deprecated
     * @internal
     * Sets background color to transparent
     */
    this.transparent = false;
  }
  componentWillLoad() {
    this.inheritedAttributes = helpers.inheritAttributes(this.el, ['aria-label', 'title']);
    this.inheritedAttributesClose = helpers.inheritAttributes(this.el, ['tabindex']);
  }
  render() {
    const block = bem.BEM.block('tag');
    const elLabel = block.element('label');
    const sizeClass = `is-${this.size}`;
    const hasSize = this.size !== undefined;
    const hasColor = this.color !== '';
    const colorClass = `is-${this.color}${this.light ? '-light' : ''}`;
    const disabledClass = 'is-disabled';
    const hasDisabled = this.disabled;
    const positionClass = `is-${this.position}`;
    const hasPosition = this.position !== undefined;
    return (index.h(index.Host, Object.assign({ "aria-disabled": this.disabled ? 'true' : null, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(sizeClass).class(hasSize)), block.modifier(colorClass).class(hasColor)), block.modifier(disabledClass).class(hasDisabled)), block.modifier(positionClass).class(hasPosition)), block.modifier('is-invalid').class(this.invalid)) }, this.inheritedAttributes), index.h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, elLabel.class()), elLabel.modifier(sizeClass).class(hasSize)), elLabel.modifier(colorClass).class(hasColor)), elLabel.modifier(disabledClass).class(hasDisabled)), elLabel.modifier('is-invalid').class(this.invalid)) }, index.h("slot", null)), index.h("bal-close", Object.assign({ class: Object.assign({}, block.element('close').class()), style: {
        display: this.closable && !this.disabled ? 'flex' : 'none',
      }, size: this.size === 'small' ? 'small' : '', inverted: (['blue', 'primary', 'info', 'success', 'warning', 'danger', 'red', 'purple', 'yellow', 'green'].includes(this.color) &&
        !this.light) ||
        this.invalid, onClick: (event) => this.balCloseClick.emit(event) }, this.inheritedAttributesClose))));
  }
  get el() { return index.getElement(this); }
};

exports.bal_tag = Tag;
