'use strict';

const stopEventBubbling = (event) => {
  event.preventDefault();
  event.stopPropagation();
};
const getInputTarget = (event) => {
  return event.target;
};
const getNativeInputValue = (component) => {
  var _a;
  return ((_a = component.nativeInput) === null || _a === void 0 ? void 0 : _a.value) || '';
};
const getUpcomingValue = (component, event) => {
  var _a, _b;
  const value = ((_a = component.nativeInput) === null || _a === void 0 ? void 0 : _a.value) || '';
  const idx = (_b = event.target) === null || _b === void 0 ? void 0 : _b.selectionStart;
  return value.slice(0, idx) + event.key + value.slice(idx + Math.abs(0));
};
const inputSetBlur = (component) => {
  if (component.nativeInput) {
    component.nativeInput.blur();
  }
};
const inputListenOnClick = (component, event) => {
  if ((component.disabled || component.readonly) && event.target && event.target === component.el) {
    stopEventBubbling(event);
  }
};
let inputSetFocusTimer;
const inputSetFocus = (component) => {
  clearTimeout(inputSetFocusTimer);
  inputSetFocusTimer = setTimeout(() => {
    if (component.nativeInput) {
      component.nativeInput.focus();
    }
  }, 0);
};
const inputHandleHostClick = (component, event) => {
  if (component.disabled || component.readonly) {
    stopEventBubbling(event);
  }
};
const inputHandleClick = (component, event) => {
  if (!component.disabled && !component.readonly && component.balClick) {
    component.balClick.emit(event);
  }
};
const inputHandleFocus = (component, event) => {
  component.hasFocus = true;
  component.inputValue = component.value;
  if (!component.disabled && component.balFocus) {
    component.balFocus.emit(event);
  }
};
const inputHandleReset = (component, defaultValue = undefined, timer) => {
  component.value = defaultValue;
  component.inputValue = component.value;
  clearTimeout(timer);
  timer = setTimeout(() => {
    if (component.nativeInput) {
      component.nativeInput.value = component.value;
    }
  });
};
const inputHandleBlur = (component, event) => {
  component.hasFocus = false;
  if (!component.disabled && component.balBlur) {
    component.balBlur.emit(event);
  }
};
const inputHandleChange = (component) => {
  if (component.value !== component.inputValue) {
    component.value = component.inputValue;
    component.balChange.emit(component.value);
  }
};

exports.getInputTarget = getInputTarget;
exports.getNativeInputValue = getNativeInputValue;
exports.getUpcomingValue = getUpcomingValue;
exports.inputHandleBlur = inputHandleBlur;
exports.inputHandleChange = inputHandleChange;
exports.inputHandleClick = inputHandleClick;
exports.inputHandleFocus = inputHandleFocus;
exports.inputHandleHostClick = inputHandleHostClick;
exports.inputHandleReset = inputHandleReset;
exports.inputListenOnClick = inputListenOnClick;
exports.inputSetBlur = inputSetBlur;
exports.inputSetFocus = inputSetFocus;
exports.stopEventBubbling = stopEventBubbling;
