'use strict';

const onBalConfigChange = (callback) => {
  attachToConfig({
    configChanged(state) {
      callback(state);
    },
  });
};
const useBalConfig = () => {
  if (typeof window === 'undefined') {
    return;
  }
  const win = window;
  return win && win.BaloiseDesignSystem && win.BaloiseDesignSystem.config;
};
const attachToConfig = (observer) => {
  const config = useBalConfig();
  if (config) {
    config.attach(observer);
  }
};
const attachComponentToConfig = (observer) => {
  const config = useBalConfig();
  if (config) {
    config.attachComponent(observer);
  }
};
const detachComponentToConfig = (observer) => {
  const config = useBalConfig();
  if (config) {
    config.detachComponent(observer);
  }
};
const updateBalLanguage = (language) => {
  const config = useBalConfig();
  if (config) {
    config.language = language;
  }
};
const updateBalRegion = (region) => {
  const config = useBalConfig();
  if (config) {
    config.region = region;
  }
};
const updateBalAllowedLanguages = (allowedLanguages) => {
  const config = useBalConfig();
  if (config) {
    config.allowedLanguages = allowedLanguages;
  }
};

exports.attachComponentToConfig = attachComponentToConfig;
exports.attachToConfig = attachToConfig;
exports.detachComponentToConfig = detachComponentToConfig;
exports.onBalConfigChange = onBalConfigChange;
exports.updateBalAllowedLanguages = updateBalAllowedLanguages;
exports.updateBalLanguage = updateBalLanguage;
exports.updateBalRegion = updateBalRegion;
exports.useBalConfig = useBalConfig;
