'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-e042d4b5.js');
const balFileUpload_type = require('./bal-file-upload.type-6182bc54.js');
const helpers = require('./helpers-c4f9304b.js');
const platform = require('./platform-14f86172.js');
const browser = require('./browser-5e81f6ec.js');
const form = require('./form-4296ccd3.js');
const toggleScrollingBody = require('./toggle-scrolling-body-5e1f7be7.js');
const balSnackbar_controller = require('./bal-snackbar.controller-aeab4a29.js');
const overlays = require('./overlays-33555855.js');
const initialize = require('./initialize-a2a400ed.js');

const NewBalOptionValue = (value, label, disabled = false, data) => {
  return {
    value,
    label,
    disabled,
    data,
  };
};
const NewBalSingleOptionValue = (valueAndLabel, disabled = false, data) => {
  return NewBalOptionValue(valueAndLabel, valueAndLabel, disabled, data);
};

class BalModalController {
  constructor() {
    this.tag = 'bal-modal';
  }
  create(options) {
    /* tslint:disable-next-line */
    if (typeof customElements !== 'undefined') {
      return customElements.whenDefined(this.tag).then(() => {
        const element = document.createElement(this.tag);
        // convert the passed in overlay options into props
        // that get passed down into the new overlay
        Object.assign(element, options);
        // append the overlay element to the document body
        helpers.getAppRoot(document).appendChild(element);
        return new Promise(resolve => helpers.componentOnReady(element, resolve));
      });
    }
    return Promise.resolve();
  }
  async dismissAll(data, role) {
    const overlays$1 = overlays.getOverlays(document, this.tag);
    await Promise.all(overlays$1.map(o => o.dismiss(data, role)));
  }
  dismiss(data, role, id) {
    const overlay = overlays.getOverlay(document, this.tag, id);
    if (!overlay) {
      return Promise.reject('overlay does not exist');
    }
    return overlay.dismiss(data, role);
  }
  async getTop() {
    return overlays.getOverlay(document, this.tag);
  }
}
const balModalController = new BalModalController();

exports.attachComponentToConfig = index.attachComponentToConfig;
exports.attachToConfig = index.attachToConfig;
exports.detachComponentToConfig = index.detachComponentToConfig;
exports.onBalConfigChange = index.onBalConfigChange;
exports.updateBalAllowedLanguages = index.updateBalAllowedLanguages;
exports.updateBalLanguage = index.updateBalLanguage;
exports.updateBalRegion = index.updateBalRegion;
exports.useBalConfig = index.useBalConfig;
Object.defineProperty(exports, 'FileUploadRejectionReason', {
  enumerable: true,
  get: function () {
    return balFileUpload_type.FileUploadRejectionReason;
  }
});
exports.componentOnReady = helpers.componentOnReady;
exports.deepReady = helpers.deepReady;
exports.getAppRoot = helpers.getAppRoot;
exports.isDescendant = helpers.isDescendant;
exports.shallowReady = helpers.shallowReady;
exports.wait = helpers.wait;
exports.getPlatforms = platform.getPlatforms;
exports.isPlatform = platform.isPlatform;
exports.isBrowser = browser.isBrowser;
exports.scrollToFirstInvalidField = form.scrollToFirstInvalidField;
exports.BodyScrollBlocker = toggleScrollingBody.BodyScrollBlocker;
exports.BalSnackbarController = balSnackbar_controller.BalSnackbarController;
exports.BalToastController = balSnackbar_controller.BalToastController;
exports.balSnackbarController = balSnackbar_controller.balSnackbarController;
exports.balToastController = balSnackbar_controller.balToastController;
exports.Config = initialize.Config;
exports.config = initialize.config;
exports.configFromSession = initialize.configFromSession;
exports.defaultConfig = initialize.defaultConfig;
exports.defaultLocale = initialize.defaultLocale;
exports.initialize = initialize.initialize;
exports.saveConfig = initialize.saveConfig;
exports.BalModalController = BalModalController;
exports.NewBalOptionValue = NewBalOptionValue;
exports.NewBalSingleOptionValue = NewBalSingleOptionValue;
exports.balModalController = balModalController;
