'use strict';

const observeItems = (target, tag, notify) => {
  /* tslint:disable-next-line */
  if (typeof MutationObserver === 'undefined') {
    return;
  }
  const mutation = new MutationObserver(mutationList => {
    if (tag) {
      mutationList = mutationList.filter(record => record.target.nodeName === tag.toLocaleUpperCase());
    }
    if (mutationList.length > 0) {
      notify();
    }
  });
  mutation.observe(target, {
    childList: true,
    attributes: true,
    characterData: true,
    subtree: false,
  });
  return mutation;
};
const observeHasClassActive = (target, notify) => {
  /* tslint:disable-next-line */
  if (typeof MutationObserver === 'undefined') {
    return;
  }
  const mutation = new MutationObserver(list => {
    let hasActiveClass = false;
    list.forEach((record) => {
      if (record.target.classList.value.includes('--active')) {
        hasActiveClass = true;
      }
    });
    if (hasActiveClass) {
      notify();
    }
  });
  mutation.observe(target, {
    attributes: true,
    childList: false,
    characterData: false,
    subtree: false,
  });
  return mutation;
};

exports.observeHasClassActive = observeHasClassActive;
exports.observeItems = observeItems;
