'use strict';

const getPlatforms = (win) => setupPlatforms(win);
const isPlatform = (winOrPlatform, platform) => {
  if (typeof winOrPlatform === 'string') {
    platform = winOrPlatform;
    winOrPlatform = undefined;
  }
  return getPlatforms(winOrPlatform).includes(platform);
};
const setupPlatforms = (win = {}) => {
  if (typeof window === 'undefined') {
    return [];
  }
  win = window;
  win.BaloiseDesignSystem = win.BaloiseDesignSystem || {};
  const platforms = (win.BaloiseDesignSystem.platforms = detectPlatforms(win));
  return platforms;
};
const detectPlatforms = (win) => Object.keys(PLATFORMS_MAP).filter(p => PLATFORMS_MAP[p](win));
const isMobile = (win) => {
  const width = win.innerWidth;
  return width <= 768;
};
const isTablet = (win) => {
  const width = win.innerWidth;
  return width > 768 && width < 1024;
};
const isTouch = (win) => isMobile(win) || isTablet(win);
const isDesktop = (win) => !isTouch(win);
const isHighDefinition = (win) => {
  const width = win.innerWidth;
  return width > 1280 && width < 1440;
};
const isWideScreen = (win) => {
  const width = win.innerWidth;
  return width > 1439 && width < 1920;
};
const isFullHD = (win) => {
  const width = win.innerWidth;
  return width > 1919;
};
const PLATFORMS_MAP = {
  mobile: isMobile,
  tablet: isTablet,
  touch: isTouch,
  desktop: isDesktop,
  highDefinition: isHighDefinition,
  widescreen: isWideScreen,
  fullhd: isFullHD,
};

exports.getPlatforms = getPlatforms;
exports.isPlatform = isPlatform;
exports.setupPlatforms = setupPlatforms;
