'use strict';

const getBodyTopOffset = () => {
  const doc = document.documentElement;
  return (window.pageYOffset || doc.scrollTop) - (doc.clientTop || 0);
};
const getBody = () => document.body;
const getHtml = () => { var _a; return (_a = document.firstChild) === null || _a === void 0 ? void 0 : _a.nextSibling; };
const getHtmlStyles = () => getComputedStyle(getHtml());
const hasScrollSmoothOnHtml = () => getHtmlStyles().scrollBehavior === 'smooth';
const disableSmoothScrolling = () => {
  const body = getBody();
  body.style.scrollBehavior = 'auto';
  if (hasScrollSmoothOnHtml()) {
    const html = getHtml();
    html.style.scrollBehavior = 'auto';
  }
};
const enableSmoothScrolling = () => {
  const body = getBody();
  body.style.scrollBehavior = 'smooth';
  if (hasScrollSmoothOnHtml()) {
    const html = getHtml();
    html.style.scrollBehavior = 'smooth';
  }
};
const BodyScrollBlocker = () => {
  const body = getBody();
  const html = getHtml();
  let timer = undefined;
  let isBlocked = false;
  let bodyTopOffset = getBodyTopOffset();
  return {
    isBlocked: () => isBlocked,
    block: () => {
      clearTimeout(timer);
      isBlocked = true;
      bodyTopOffset = getBodyTopOffset();
      body.style.scrollBehavior = 'auto';
      if (hasScrollSmoothOnHtml()) {
        html.style.scrollBehavior = 'auto';
      }
      body.style.position = 'fixed';
      body.style.width = '100%';
      body.style.top = `-${bodyTopOffset}px`;
    },
    allow: () => {
      clearTimeout(timer);
      body.style.position = 'static';
      body.style.width = 'inherit';
      body.style.top = `inherit`;
      document.documentElement.scrollTop = bodyTopOffset;
      timer = setTimeout(() => {
        isBlocked = false;
        body.style.scrollBehavior = 'smooth';
        if (hasScrollSmoothOnHtml()) {
          html.style.scrollBehavior = 'smooth';
        }
      }, 0);
    },
  };
};

exports.BodyScrollBlocker = BodyScrollBlocker;
exports.disableSmoothScrolling = disableSmoothScrolling;
exports.enableSmoothScrolling = enableSmoothScrolling;
