import { Component, h, Host, Element, Prop } from '@stencil/core';
export class Badge {
  constructor() {
    /**
     * Define the size of badge. Small is recommended for tabs.
     */
    this.size = '';
    /**
     * Define the alert color for the badge.
     */
    this.color = 'danger';
    /**
     * If `true` the badge is added to the top right corner of the card.
     */
    this.position = '';
  }
  render() {
    return (h(Host, { class: {
        'bal-badge': true,
        [`bal-badge--has-background-${this.color}`]: true,
        [`bal-badge--has-position-${this.position}`]: this.position !== '',
        [`bal-badge--has-size-${this.size}`]: this.size !== '',
      } },
      h("span", { class: {
          'bal-badge__label': true,
          'is-hidden': !!this.icon || this.size === 'small',
        } },
        h("slot", null)),
      h("bal-icon", { class: {
          'bal-badge__icon': true,
          'is-hidden': !this.icon || this.size === 'small',
        }, size: this.size === '' ? 'small' : '', name: this.icon, color: "white" })));
  }
  static get is() { return "bal-badge"; }
  static get properties() { return {
    "icon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Name of the icon to show. If a icon is present text should be hidden."
      },
      "attribute": "icon",
      "reflect": false
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalBadgeSize",
        "resolved": "\"\" | \"large\" | \"small\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the size of badge. Small is recommended for tabs."
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "''"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalBadgeColor",
        "resolved": "\"danger\" | \"success\" | \"warning\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the alert color for the badge."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "'danger'"
    },
    "position": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalBadgePosition",
        "resolved": "\"\" | \"button\" | \"card\" | \"tabs\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the badge is added to the top right corner of the card."
      },
      "attribute": "position",
      "reflect": false,
      "defaultValue": "''"
    }
  }; }
  static get elementRef() { return "el"; }
}
