import { Component, Host, h, Prop, Event, Element } from '@stencil/core';
import isNil from 'lodash.isnil';
import { BEM } from '../../../utils/bem';
export class DataValue {
  constructor() {
    /**
     * If `true` a small button with a edit icon will be shown on the right.
     */
    this.editable = false;
    /**
     * If `true` the button will get disabled.
     */
    this.disabled = false;
    /**
     * If `true` the text will break and the height of the item increases.
     */
    this.multiline = false;
  }
  onClickHandler(event) {
    this.balClick.emit(event);
    const input = this.el.querySelector('bal-input');
    if (!isNil(input)) {
      input.setFocus();
    }
  }
  render() {
    const element = BEM.block('data-value');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign({}, element.class()), element.modifier('is-editable').class(this.editable)), element.modifier('is-multiline').class(this.multiline)) },
      h("div", null,
        h("slot", null)),
      h("bal-button", { class: "bal-data-value-btn", square: true, outlined: true, color: "text", size: "small", icon: "edit", disabled: this.disabled, onBalBlur: _ => this.balBlur.emit(), onBalFocus: _ => this.balFocus.emit(), onClick: ev => this.onClickHandler(ev) })));
  }
  static get is() { return "bal-data-value"; }
  static get properties() { return {
    "editable": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` a small button with a edit icon will be shown on the right."
      },
      "attribute": "editable",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the button will get disabled."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "multiline": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the text will break and the height of the item increases."
      },
      "attribute": "multiline",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "balClick",
      "name": "balClick",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the edit button has focus."
      },
      "complexType": {
        "original": "MouseEvent",
        "resolved": "MouseEvent",
        "references": {
          "MouseEvent": {
            "location": "global"
          }
        }
      }
    }, {
      "method": "balFocus",
      "name": "balFocus",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the edit button has focus."
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "balBlur",
      "name": "balBlur",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the edit button loses focus."
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }]; }
  static get elementRef() { return "el"; }
}
