import { Language, loadFooterLinks } from '@baloise/web-app-utils';
import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { defaultConfig, detachComponentToConfig, attachComponentToConfig, updateBalLanguage, } from '../../config';
import { BEM } from '../../utils/bem';
export class Footer {
  constructor() {
    this.links = [];
    this.language = defaultConfig.language;
    this.region = defaultConfig.region;
    this.allowedLanguages = defaultConfig.allowedLanguages;
    /**
     * @deprecated The languages in which the links will appear.
     */
    this.locale = '';
    /**
     * If `true` the legal Baloise links will be hidden.
     */
    this.hideLinks = false;
    /**
     * If `true` the language selection will be hidden.
     */
    this.hideLanguageSelection = false;
  }
  disconnectedCallback() {
    detachComponentToConfig(this);
  }
  connectedCallback() {
    attachComponentToConfig(this);
    this.updateFooterLinks();
  }
  configChanged(config) {
    this.language = config.language;
    this.region = config.region;
    this.allowedLanguages = config.allowedLanguages;
    this.updateFooterLinks();
  }
  watchLocaleHandler() {
    if (this.locale !== '') {
      this.language = this.locale;
      this.updateFooterLinks();
    }
  }
  changeLanguage(language) {
    updateBalLanguage(language);
  }
  updateFooterLinks() {
    if (!this.hideLinks && this.region === 'CH') {
      // The following footer links only apply to swiss applications
      loadFooterLinks(new Language(this.language)).then(links => (this.links = links));
    }
  }
  render() {
    const block = BEM.block('footer');
    const elInner = block.element('inner');
    const elContainer = elInner.element('container');
    const elLinksContainer = elInner.element('links-container');
    const elLegalLinks = elLinksContainer.element('legal-links');
    const elLanguageLinks = elLinksContainer.element('language-links');
    return (h(Host, { class: Object.assign({}, block.class()) },
      h("footer", { class: Object.assign({}, elInner.class()) },
        h("slot", null),
        h("div", { class: Object.assign(Object.assign({ container: true }, elContainer.class()), elLinksContainer.class()) },
          h("div", { class: Object.assign(Object.assign({}, elLegalLinks.class()), { 'pt-4': true }), style: { display: this.hideLinks ? 'none' : 'flex' } }, this.links.map(link => (h("a", { class: {
              'is-link': true,
              'is-inverted': true,
              'pr-4': true,
            }, href: link.link, target: "_blank" }, link.label)))),
          h("div", { class: Object.assign(Object.assign({}, elLanguageLinks.class()), { 'pt-4': true }), style: {
              display: this.hideLanguageSelection || this.allowedLanguages.length <= 1 ? 'none' : 'flex',
            } }, this.allowedLanguages.map(lang => (h("a", { class: [
              'is-link',
              'is-inverted',
              'pr-4',
              this.language.toLowerCase() == lang.toLowerCase() ? 'is-current' : '',
            ].join(' '), onClick: () => this.changeLanguage(lang) }, lang.toUpperCase()))))))));
  }
  static get is() { return "bal-footer"; }
  static get properties() { return {
    "locale": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'en' | 'de' | 'fr' | 'it' | ''",
        "resolved": "\"\" | \"de\" | \"en\" | \"fr\" | \"it\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "The languages in which the links will appear."
          }],
        "text": ""
      },
      "attribute": "locale",
      "reflect": false,
      "defaultValue": "''"
    },
    "hideLinks": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the legal Baloise links will be hidden."
      },
      "attribute": "hide-links",
      "reflect": false,
      "defaultValue": "false"
    },
    "hideLanguageSelection": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the language selection will be hidden."
      },
      "attribute": "hide-language-selection",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "links": {},
    "language": {},
    "region": {},
    "allowedLanguages": {}
  }; }
  static get watchers() { return [{
      "propName": "locale",
      "methodName": "watchLocaleHandler"
    }]; }
}
