import { Component, h, Host, Prop } from '@stencil/core';
import * as balIcons from '@baloise/design-system-next-icons';
import upperFirst from 'lodash.upperfirst';
import camelCase from 'lodash.camelcase';
import { BEM } from '../../utils/bem';
export class Icon {
  constructor() {
    /**
     * Name of the baloise icon.
     */
    this.name = '';
    /**
     * Svg content.
     */
    this.svg = '';
    /**
     * Defines the size of the icon.
     */
    this.size = '';
    /**
     * The theme type of the button. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * If `true` the icon has display inline style
     */
    this.inline = false;
    /**
     * If `true` the icon is inverted
     */
    this.inverted = false;
    /**
     * If `true` the icon is rotated 180deg
     */
    this.turn = false;
    /**
     * If `true` adds a box shadow to improve readability on image background
     * */
    this.shadow = false;
  }
  get svgContent() {
    if (balIcons && this.name && this.name.length > 0) {
      // We are doing this to avoid breaking change.
      if (this.name.startsWith('alert')) {
        this.name = 'alert-triangle';
      }
      if (this.name.startsWith('info')) {
        this.name = 'info-circle';
      }
      const icon = balIcons[`balIcon${upperFirst(camelCase(this.name))}`];
      if (icon) {
        return icon;
      }
    }
    return this.svg || '';
  }
  render() {
    const color = ['white', 'blue', 'grey', 'danger', 'warning', 'success', 'grey-light'].includes(this.color)
      ? this.color
      : 'blue';
    const block = BEM.block('icon');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('is-inverted').class(this.inverted)), block.modifier('is-inline').class(this.inline)), block.modifier('shadow').class(this.shadow)), block.modifier(`is-${this.size}`).class(!!this.size)), block.modifier(`is-${color}`).class()) },
      h("div", { class: Object.assign(Object.assign(Object.assign({}, block.element('inner').class()), block.element('inner').modifier('turn').class(this.turn)), block.modifier(`is-${this.size}`).class(!!this.size)), innerHTML: this.svgContent })));
  }
  static get is() { return "bal-icon"; }
  static get properties() { return {
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Name of the baloise icon."
      },
      "attribute": "name",
      "reflect": true,
      "defaultValue": "''"
    },
    "svg": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Svg content."
      },
      "attribute": "svg",
      "reflect": false,
      "defaultValue": "''"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalIconSize",
        "resolved": "\"\" | \"large\" | \"medium\" | \"small\" | \"xsmall\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the size of the icon."
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "''"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalIconColor",
        "resolved": "string",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The theme type of the button. Given by bulma our css framework."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "''"
    },
    "inline": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the icon has display inline style"
      },
      "attribute": "inline",
      "reflect": false,
      "defaultValue": "false"
    },
    "inverted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the icon is inverted"
      },
      "attribute": "inverted",
      "reflect": false,
      "defaultValue": "false"
    },
    "turn": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the icon is rotated 180deg"
      },
      "attribute": "turn",
      "reflect": false,
      "defaultValue": "false"
    },
    "shadow": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` adds a box shadow to improve readability on image background"
      },
      "attribute": "shadow",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
}
