import { Component, h, Host, Element, State, Listen, Prop } from '@stencil/core';
import { BEM } from '../../utils/bem';
import { observeItems } from '../../utils/observer';
export class ImageSlider {
  constructor() {
    this.xPosition = 0;
    this.slideIndex = 1;
    /**
     * value to set the images aspect ratio
     */
    this.aspectRatio = '16by9';
    /**
     * Set the slide to switch to
     * @param {number} slide :Set to switch to.
     */
    this.setSlide = (slide) => {
      const container = this.getImageContainer();
      const slideWidth = this.images[0].clientWidth;
      if (container && slide >= 0 && slide <= this.images.length) {
        this.slideIndex = slide;
        container.style.transitionDuration = '1.2s';
        container.style.transitionTimingFunction = 'cubic-bezier(0.23, 0.93, 0.13, 1)';
        container.style.transform = `translate(-${(this.slideIndex - 1) * slideWidth}px)`;
      }
    };
  }
  async resizeHandler() {
    this.setSlide(this.slideIndex);
  }
  connectedCallback() {
    this.mutationO = observeItems(this.el, 'bal-image-slider-item', () => this.updateImages());
    this.updateImages();
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  touchStart(event) {
    const imageContainer = this.getSliderContainer();
    if (imageContainer === null || imageContainer === void 0 ? void 0 : imageContainer.contains(event.target)) {
      this.xPosition = event.touches[0].pageX;
    }
  }
  touchEnd(event) {
    const imageContainer = this.getSliderContainer();
    if (imageContainer === null || imageContainer === void 0 ? void 0 : imageContainer.contains(event.target)) {
      if (event.changedTouches[0].pageX < this.xPosition) {
        this.setSlide(this.slideIndex + 1);
      }
      else {
        this.setSlide(this.slideIndex - 1);
      }
    }
  }
  getChildItems() {
    return Array.from(this.el.querySelectorAll('bal-image-slider-item'));
  }
  getSliderContainer() {
    return this.el.querySelector('.bal-image-slider__container');
  }
  getImageContainer() {
    return this.el.querySelector('.bal-image-slider__container__images');
  }
  updateImages() {
    this.images = this.getChildItems();
  }
  render() {
    const block = BEM.block('image-slider');
    const container = block.element('container');
    const containerImages = container.element('images');
    return (h(Host, { class: Object.assign({}, block.class()) },
      h("div", { class: Object.assign(Object.assign({}, container.class()), container.modifier(`is-${this.aspectRatio}`).class()) },
        h("div", { class: Object.assign({}, containerImages.class()) },
          h("slot", null))),
      h("bal-pagination", { interface: "small", totalPages: this.images.length, value: this.slideIndex, onBalChange: ev => {
          this.setSlide(ev.detail);
        } })));
  }
  static get is() { return "bal-image-slider"; }
  static get properties() { return {
    "aspectRatio": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'1by1' | '3by2' | '4by3' | '16by9'",
        "resolved": "\"16by9\" | \"1by1\" | \"3by2\" | \"4by3\" | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "value to set the images aspect ratio"
      },
      "attribute": "aspect-ratio",
      "reflect": false,
      "defaultValue": "'16by9'"
    }
  }; }
  static get states() { return {
    "slideIndex": {},
    "images": {}
  }; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "resize",
      "method": "resizeHandler",
      "target": "window",
      "capture": false,
      "passive": true
    }, {
      "name": "touchstart",
      "method": "touchStart",
      "target": undefined,
      "capture": false,
      "passive": true
    }, {
      "name": "touchend",
      "method": "touchEnd",
      "target": undefined,
      "capture": false,
      "passive": true
    }]; }
}
