import { Component, Host, h, Prop, Element, State, Listen, Method } from '@stencil/core';
export class ListItemAccordionBody {
  constructor() {
    this.contentHeight = '0px';
    /**
     * If `true` the body will be open and visible
     */
    this.open = false;
    /**
     * Sets justify-content of the items to start, center, end, or space-between. Default is start.
     */
    this.contentAlignment = 'start';
  }
  async resizeHandler() {
    this.calcContentHeight();
  }
  componentDidRender() {
    setTimeout(() => {
      this.calcContentHeight();
    }, 10);
  }
  async getContentHeight() {
    const inner = this.el.querySelector('bal-list-item-content');
    if (inner) {
      return inner.scrollHeight;
    }
    return 0;
  }
  getAccordionGroupItems() {
    return Array.from(document.body.querySelectorAll('bal-list-item-accordion-body')).filter(accordionBody => accordionBody.accordionGroup === this.accordionGroup);
  }
  setContentHeight(height) {
    this.contentHeight = height + 'px';
    const parent = this.el.closest('.bal-list__item__accordion-body__parent');
    const parentHeight = parent ? parent.scrollHeight : 0;
    const parentIsThereAndIsOpen = parent && parentHeight > 0 && parent.open;
    if (parentIsThereAndIsOpen && this.open) {
      parent.style.maxHeight = parentHeight + height + 'px';
    }
  }
  get areWeInAGroup() {
    return this.accordionGroup !== '' && this.accordionGroup !== undefined;
  }
  async calcContentHeight() {
    let height = await this.getContentHeight();
    if (this.areWeInAGroup) {
      const items = this.getAccordionGroupItems();
      const heights = [];
      for (let index = 0; index < items.length; index++) {
        const element = items[index];
        heights.push(await element.getContentHeight());
      }
      const maxHeight = Math.max(...heights);
      height = maxHeight;
    }
    this.setContentHeight(height);
  }
  render() {
    return (h(Host, { class: {
        'bal-list__item': true,
        'bal-list__item__accordion-body': true,
        'bal-list__item__accordion-body--open': this.open,
      }, style: { maxHeight: this.open ? this.contentHeight : '0' } },
      h("bal-list-item-content", { style: {
          minHeight: this.areWeInAGroup ? this.contentHeight : 'inherit',
          height: this.areWeInAGroup ? this.contentHeight : 'inherit',
        }, contentAlignment: this.contentAlignment },
        h("slot", null))));
  }
  static get is() { return "bal-list-item-accordion-body"; }
  static get properties() { return {
    "open": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the body will be open and visible"
      },
      "attribute": "open",
      "reflect": false,
      "defaultValue": "false"
    },
    "accordionGroup": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Synchronizes the height of the accordion to max of all\nthe other grouped accordion bodies"
      },
      "attribute": "accordion-group",
      "reflect": false
    },
    "contentAlignment": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalListContentSpacing",
        "resolved": "\"center\" | \"end\" | \"space-between\" | \"start\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Sets justify-content of the items to start, center, end, or space-between. Default is start."
      },
      "attribute": "content-alignment",
      "reflect": false,
      "defaultValue": "'start'"
    }
  }; }
  static get states() { return {
    "contentHeight": {}
  }; }
  static get methods() { return {
    "getContentHeight": {
      "complexType": {
        "signature": "() => Promise<number>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<number>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "resize",
      "method": "resizeHandler",
      "target": "window",
      "capture": false,
      "passive": true
    }]; }
}
