import { Component, Host, h, Prop, Event, Element } from '@stencil/core';
import { BEM } from '../../../utils/bem';
export class ListItem {
  constructor() {
    /**
     * If `true` the list item can be hovered
     */
    this.disabled = false;
    /**
     * If `true` the list item shows that it is clickable
     */
    this.clickable = false;
    /**
     * If `true` the list item has a selected theme
     */
    this.selected = false;
    /**
     * If `true` the list item can be used as a accordion
     */
    this.accordion = false;
    /**
     * If `true` the list item can be used as an accordion inside another accordion
     */
    this.subAccordionItem = false;
    /**
     * Specifies the URL of the page the link goes to
     */
    this.href = '';
    /**
     * Specifies where to open the linked document
     */
    this.target = '_self';
  }
  connectedCallback() {
    const accordionHead = this.findAccordionHead();
    if (accordionHead) {
      accordionHead.addEventListener('balAccordionChange', (event) => this.updateState(event.detail));
    }
  }
  disconnectedCallback() {
    const accordionHead = this.findAccordionHead();
    if (accordionHead) {
      accordionHead.removeEventListener('balAccordionChange', (event) => this.updateState(event.detail));
    }
  }
  findAccordionHead() {
    return this.el.querySelector('bal-list-item-accordion-head');
  }
  findAccordionBody() {
    return this.el.querySelector('bal-list-item-accordion-body');
  }
  updateState(isAccordionOpen) {
    const accordionBody = this.findAccordionBody();
    if (accordionBody) {
      accordionBody.open = isAccordionOpen;
    }
  }
  render() {
    const itemEl = BEM.block('list').element('item');
    const triggerEl = itemEl.element('trigger');
    const basicClasses = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, itemEl.class()), itemEl.modifier('disabled').class(this.disabled)), itemEl.modifier('selected').class(this.selected)), itemEl.modifier('accordion').class(this.accordion)), itemEl.modifier('sub-accordion').class(this.subAccordionItem)), itemEl
      .modifier('clickable')
      .class(!this.disabled && (this.clickable || this.href.length > 0 || this.accordion)));
    if (this.href.length > 0 && !this.disabled) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) },
        h("a", { class: Object.assign({}, triggerEl.class()), href: this.href, target: this.target, onClick: (event) => {
            this.balNavigate.emit(event);
          } },
          h("slot", null))));
    }
    if (this.clickable) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) },
        h("button", { class: Object.assign({}, triggerEl.class()), disabled: this.disabled, onClick: (event) => {
            this.balNavigate.emit(event);
          } },
          h("slot", null))));
    }
    if (this.accordion) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses), onClick: (event) => {
          this.balNavigate.emit(event);
        } },
        h("div", { class: Object.assign({}, triggerEl.class()) },
          h("slot", null))));
    }
    return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) },
      h("div", { class: Object.assign({}, triggerEl.class()) },
        h("slot", null))));
  }
  static get is() { return "bal-list-item"; }
  static get properties() { return {
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list item can be hovered"
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "clickable": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list item shows that it is clickable"
      },
      "attribute": "clickable",
      "reflect": false,
      "defaultValue": "false"
    },
    "selected": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list item has a selected theme"
      },
      "attribute": "selected",
      "reflect": false,
      "defaultValue": "false"
    },
    "accordion": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list item can be used as a accordion"
      },
      "attribute": "accordion",
      "reflect": false,
      "defaultValue": "false"
    },
    "subAccordionItem": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list item can be used as an accordion inside another accordion"
      },
      "attribute": "sub-accordion-item",
      "reflect": false,
      "defaultValue": "false"
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies the URL of the page the link goes to"
      },
      "attribute": "href",
      "reflect": false,
      "defaultValue": "''"
    },
    "target": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalListItemTarget",
        "resolved": "\" _parent\" | \"_blank\" | \"_self\" | \"_top\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies where to open the linked document"
      },
      "attribute": "target",
      "reflect": false,
      "defaultValue": "'_self'"
    }
  }; }
  static get events() { return [{
      "method": "balNavigate",
      "name": "balNavigate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the link element has clicked"
      },
      "complexType": {
        "original": "MouseEvent",
        "resolved": "MouseEvent",
        "references": {
          "MouseEvent": {
            "location": "global"
          }
        }
      }
    }]; }
  static get elementRef() { return "el"; }
}
