import { Component, Host, h, Prop, Watch } from '@stencil/core';
import { BEM } from '../../utils/bem';
export class List {
  constructor() {
    /**
     * If `true` the list item can not be hovered
     */
    this.disabled = false;
    /**
     * @deprecated
     * If `true` the list can be used on a dark background
     */
    this.inverted = false;
    /**
     * If `true` the list can be used on a light, dark or colored backgrounds
     */
    this.background = 'light';
    /**
     * If `true` each list item has a bottom border
     */
    this.border = false;
    /**
     * Defines the min height of the list item
     */
    this.size = '';
    /**
     * If `true` the list can be used as an accordion in meta nav
     */
    this.inMainNav = false;
  }
  invertedHandler() {
    console.warn('[DEPRECATED] - Please use the property background="dark" instead');
    if (this.inverted === true) {
      this.background = 'dark';
    }
  }
  render() {
    const block = BEM.block('list');
    return (h(Host, { role: "list", class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('context-main-nav').class(this.inMainNav)), block.modifier('disabled').class(this.disabled)), block.modifier('border').class(this.border)), block.modifier(`size-${this.size}`).class(this.size !== '')), block.modifier(`background-${this.background}`).class()) },
      h("slot", null)));
  }
  static get is() { return "bal-list"; }
  static get properties() { return {
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list item can not be hovered"
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "inverted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "If `true` the list can be used on a dark background"
          }],
        "text": ""
      },
      "attribute": "inverted",
      "reflect": false,
      "defaultValue": "false"
    },
    "background": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalListBackground",
        "resolved": "\"color\" | \"dark\" | \"light\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list can be used on a light, dark or colored backgrounds"
      },
      "attribute": "background",
      "reflect": false,
      "defaultValue": "'light'"
    },
    "border": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` each list item has a bottom border"
      },
      "attribute": "border",
      "reflect": false,
      "defaultValue": "false"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalListSize",
        "resolved": "\"\" | \"large\" | \"small\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the min height of the list item"
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "''"
    },
    "inMainNav": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the list can be used as an accordion in meta nav"
      },
      "attribute": "in-main-nav",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get watchers() { return [{
      "propName": "inverted",
      "methodName": "invertedHandler"
    }]; }
}
