import { Component, h, Host, Method, State, Element, Prop } from '@stencil/core';
import { deepReady } from '../../../helpers/helpers';
import { BEM } from '../../../utils/bem';
export class NavbarMenu {
  constructor() {
    this.isMenuActive = false;
    /**
     * @internal
     * Defines the type of navbar. App is used for almost every web applications
     * like the portal app. For our sales funnel we recommend to use the simple navbar.
     * Meta and main are used for the website.
     */
    this.interface = 'app';
  }
  /**
   * @internal - If the menu is open it closes it and the other way around.
   */
  async toggle(isMenuActive) {
    this.isMenuActive = isMenuActive;
    const tabsElement = this.element.querySelector('bal-tabs');
    if (tabsElement) {
      await deepReady(tabsElement);
      tabsElement.renderLine();
    }
  }
  render() {
    const menuEl = BEM.block('navbar').element('menu');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign({}, menuEl.class()), menuEl.modifier('active').class(this.isMenuActive)), menuEl.modifier(`context-${this.interface}`).class()) },
      h("slot", null)));
  }
  static get is() { return "bal-navbar-menu"; }
  static get properties() { return {
    "interface": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalNavbarInterface",
        "resolved": "\"app\" | \"simple\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": "Defines the type of navbar. App is used for almost every web applications\nlike the portal app. For our sales funnel we recommend to use the simple navbar.\nMeta and main are used for the website."
          }],
        "text": ""
      },
      "attribute": "interface",
      "reflect": false,
      "defaultValue": "'app'"
    }
  }; }
  static get states() { return {
    "isMenuActive": {}
  }; }
  static get methods() { return {
    "toggle": {
      "complexType": {
        "signature": "(isMenuActive: boolean) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": [{
            "name": "internal",
            "text": "- If the menu is open it closes it and the other way around."
          }]
      }
    }
  }; }
  static get elementRef() { return "element"; }
}
