import { Component, h, Host, Listen, Prop, State } from '@stencil/core';
import { BEM } from '../../../utils/bem';
import { isPlatform } from '../../../utils/platform';
export class NavigationMenuList {
  constructor() {
    /**
     * Color of the menu list card background
     */
    this.color = 'white';
    /**
     * Target of the menu list card headline target as link
     */
    this.target = '_self';
    this.setHeadingLevel = () => {
      if (isPlatform('touch')) {
        this.headingLevel = 'h4';
        return;
      }
      this.headingLevel = 'h3';
    };
  }
  async resizeHandler() {
    this.setHeadingLevel();
  }
  connectedCallback() {
    this.setHeadingLevel();
  }
  render() {
    const navMenuListEl = BEM.block('nav').element('menu').element('list');
    return (h(Host, { class: Object.assign(Object.assign({}, navMenuListEl.class()), navMenuListEl.modifier(`context-${this.color}`).class()) },
      h("bal-card", { class: Object.assign({}, navMenuListEl.element('card').class()), flat: true, color: this.color === 'grey' ? this.color : '' },
        h("bal-card-content", null,
          this.href ? (h("a", { href: this.href, target: this.target },
            h("bal-heading", { class: Object.assign({}, navMenuListEl.element('card').element('heading').class()), level: this.headingLevel, space: "none" }, this.headline))) : (h("bal-heading", { class: Object.assign({}, navMenuListEl.element('card').element('heading').class()), level: this.headingLevel, space: "none" }, this.headline)),
          h("slot", { name: "links" })))));
  }
  static get is() { return "bal-navigation-menu-list"; }
  static get properties() { return {
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'white' | 'grey'",
        "resolved": "\"grey\" | \"white\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Color of the menu list card background"
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "'white'"
    },
    "headline": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Optional headline of the menu list card"
      },
      "attribute": "headline",
      "reflect": false
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Optional href of the menu list card headline as link"
      },
      "attribute": "href",
      "reflect": false
    },
    "target": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalButtonTarget",
        "resolved": "\" _parent\" | \"_blank\" | \"_self\" | \"_top\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Target of the menu list card headline target as link"
      },
      "attribute": "target",
      "reflect": false,
      "defaultValue": "'_self'"
    }
  }; }
  static get states() { return {
    "headingLevel": {}
  }; }
  static get listeners() { return [{
      "name": "resize",
      "method": "resizeHandler",
      "target": "window",
      "capture": false,
      "passive": true
    }]; }
}
