import { Component, h, Host, Prop, State } from '@stencil/core';
import { stopEventBubbling } from '../../../helpers/form-input.helpers';
import { BEM } from '../../../utils/bem';
import { disableSmoothScrolling, enableSmoothScrolling } from '../../../utils/toggle-scrolling-body';
export class NavigationPopover {
  constructor() {
    this.isActive = false;
    /**
     * Defines the label of the button
     */
    this.label = '';
    /**
     * Turns the trigger button to inverted style.
     */
    this.inverted = false;
    /**
     * If `true` a backdrop is added
     */
    this.backdrop = false;
    /**
     * Defines the size of the button
     */
    this.size = '';
    /**
     * Color style of the button when the popover is closed.
     */
    this.inactiveColor = 'light';
    /**
     * Color style of the button when the popover is open.
     */
    this.activeColor = 'primary';
    /**
     * If 'false', the closing button is not displayed
     */
    this.closable = true;
    /**
     * Defines border-radius of popover content.
     */
    this.contentRadius = 'normal';
    /**
     * Define the position of the popover content.
     */
    this.position = 'bottom-start';
    /**
     * Define the max width of the popover content.
     */
    this.contentWidth = 0;
    /**
     * Define the min width of the popover content.
     */
    this.contentMinWidth = 0;
    /**
     * Define the offset of the popover content.
     */
    this.offsetY = 0;
    /**
     * If `true` the width of the buttons is limited
     */
    this.square = false;
    /**
     * If `true` the popover does not have the shadow
     */
    this.contentNoShadow = false;
    /**
     * If `true` the content has a min width of 100%.
     */
    this.contentExpanded = false;
    /**
     * If `true` a little arrow is added, which points to the trigger element
     */
    this.arrow = false;
    /**
     * If `true` its content will have a divider line on top
     */
    this.mobileTop = false;
    this.toggle = (event) => {
      stopEventBubbling(event);
      this.clearTimeouts();
      if (!this.isActive) {
        disableSmoothScrolling();
        this.scrollToTopTimer = setTimeout(() => {
          window.scrollTo(0, 0);
        }, 0);
      }
      this.setActiveTimer = setTimeout(() => {
        enableSmoothScrolling();
        this.isActive = !this.isActive;
      }, 100);
    };
  }
  clearTimeouts() {
    if (this.scrollToTopTimer) {
      clearTimeout(this.scrollToTopTimer);
    }
    if (this.setActiveTimer) {
      clearTimeout(this.setActiveTimer);
    }
  }
  render() {
    const navPopoverEl = BEM.block('nav').element('popover');
    return (h(Host, { class: Object.assign(Object.assign({}, navPopoverEl.class()), { control: true }) },
      h("bal-popover", { value: this.isActive, onBalChange: event => (this.isActive = event.detail), arrow: this.arrow, backdrop: this.backdrop, position: this.position, offsetY: this.offsetY, "mobile-top": this.mobileTop },
        h("bal-button", { "bal-popover-trigger": true, icon: this.icon, size: this.size, inverted: this.inverted, color: this.isActive ? this.activeColor : this.inactiveColor, square: this.square, onClick: this.toggle, "aria-haspopup": "true", class: `bal-navigation-popover__button bal-navigation-popover__button-${this.isActive ? this.activeColor : this.inactiveColor}` }, this.label),
        h("bal-popover-content", { radius: this.contentRadius, "content-width": this.contentWidth, "content-min-width": this.contentMinWidth, "no-shadow": this.contentNoShadow, expanded: this.contentExpanded, "mobile-top": this.mobileTop },
          (this.closable || this.heading) && (h("div", { class: Object.assign({}, navPopoverEl.element('head').class()) },
            this.heading && (h("bal-heading", { space: "none", level: "h4" }, this.heading)),
            this.closable && h("bal-close", { onClick: () => (this.isActive = !this.isActive) }))),
          h("slot", null)))));
  }
  static get is() { return "bal-navigation-popover"; }
  static get properties() { return {
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the label of the button"
      },
      "attribute": "label",
      "reflect": false,
      "defaultValue": "''"
    },
    "inverted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Turns the trigger button to inverted style."
      },
      "attribute": "inverted",
      "reflect": false,
      "defaultValue": "false"
    },
    "icon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Defines the icon of the trigger button."
      },
      "attribute": "icon",
      "reflect": false
    },
    "backdrop": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` a backdrop is added"
      },
      "attribute": "backdrop",
      "reflect": false,
      "defaultValue": "false"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalButtonSize",
        "resolved": "\"\" | \"small\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the size of the button"
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "''"
    },
    "inactiveColor": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalButtonColor",
        "resolved": "\"danger\" | \"info\" | \"info-light\" | \"light\" | \"link\" | \"primary\" | \"primary-light\" | \"success\" | \"text\" | \"warning\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Color style of the button when the popover is closed."
      },
      "attribute": "inactive-color",
      "reflect": false,
      "defaultValue": "'light'"
    },
    "activeColor": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalButtonColor",
        "resolved": "\"danger\" | \"info\" | \"info-light\" | \"light\" | \"link\" | \"primary\" | \"primary-light\" | \"success\" | \"text\" | \"warning\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Color style of the button when the popover is open."
      },
      "attribute": "active-color",
      "reflect": false,
      "defaultValue": "'primary'"
    },
    "heading": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Defines the heading of the popover"
      },
      "attribute": "heading",
      "reflect": false
    },
    "closable": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If 'false', the closing button is not displayed"
      },
      "attribute": "closable",
      "reflect": false,
      "defaultValue": "true"
    },
    "contentRadius": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalPopoverContentRadius",
        "resolved": "\"large\" | \"large-bottom-none\" | \"large-top-none\" | \"none\" | \"normal\" | \"normal-bottom-none\" | \"normal-top-none\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines border-radius of popover content."
      },
      "attribute": "content-radius",
      "reflect": false,
      "defaultValue": "'normal'"
    },
    "position": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalPopoverPlacement",
        "resolved": "\"auto\" | \"auto-end\" | \"auto-start\" | \"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the position of the popover content."
      },
      "attribute": "position",
      "reflect": false,
      "defaultValue": "'bottom-start'"
    },
    "contentWidth": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the max width of the popover content."
      },
      "attribute": "content-width",
      "reflect": false,
      "defaultValue": "0"
    },
    "contentMinWidth": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the min width of the popover content."
      },
      "attribute": "content-min-width",
      "reflect": false,
      "defaultValue": "0"
    },
    "offsetY": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the offset of the popover content."
      },
      "attribute": "offset-y",
      "reflect": false,
      "defaultValue": "0"
    },
    "square": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the width of the buttons is limited"
      },
      "attribute": "square",
      "reflect": false,
      "defaultValue": "false"
    },
    "contentNoShadow": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the popover does not have the shadow"
      },
      "attribute": "content-no-shadow",
      "reflect": false,
      "defaultValue": "false"
    },
    "contentExpanded": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the content has a min width of 100%."
      },
      "attribute": "content-expanded",
      "reflect": false,
      "defaultValue": "false"
    },
    "arrow": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` a little arrow is added, which points to the trigger element"
      },
      "attribute": "arrow",
      "reflect": false,
      "defaultValue": "false"
    },
    "mobileTop": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` its content will have a divider line on top"
      },
      "attribute": "mobile-top",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "isActive": {}
  }; }
}
