import { Component, Host, h, Prop, State, Watch, Method, Event, Element } from '@stencil/core';
import { BEM } from '../../utils/bem';
export class Pagination {
  constructor() {
    this._value = 1;
    /**
     * Defines the layout of the pagination
     */
    this.interface = '';
    /**
     * Disables component
     */
    this.disabled = false;
    /**
     * Current selected page
     */
    this.value = 1;
    /**
     * The total amount of pages
     */
    this.totalPages = 1;
    /**
     * Specify the max visible pages before and after the selected page
     */
    this.pageRange = 2;
    /**
     * List of tabs names for 'tabs' interface
     */
    this.tabsNames = [];
    /**
     * If 'true, the pagination will be sticky to the top
     */
    this.sticky = false;
    /**
     * If sticky, the top position will be determined by this value
     */
    this.top = 0;
  }
  valueChanged(newValue) {
    this._value = newValue;
  }
  topValueChanged(newValue) {
    if (this.sticky) {
      this.el.style.top = `${newValue}px`;
    }
  }
  componentWillLoad() {
    this._value = this.value;
    this.topValueChanged(this.top);
  }
  /**
   * Go to the next page
   */
  async next() {
    if (this._value < this.totalPages) {
      this._value = this._value + 1;
      this.balChangeEventEmitter.emit(this._value);
    }
  }
  /**
   * Go to the previous page
   */
  async previous() {
    if (this._value !== 1) {
      this._value = this._value - 1;
      this.balChangeEventEmitter.emit(this._value);
    }
  }
  selectPage(pageNumber) {
    this._value = pageNumber;
    this.balChangeEventEmitter.emit(this._value);
  }
  renderEllipsisElement() {
    return (h("li", null,
      h("div", { class: "pagination-more" },
        h("bal-text", { bold: true, heading: true, inline: true, space: "none" }, "\u2026"))));
  }
  renderPageElement(pageNumber) {
    const isActive = this._value === pageNumber;
    const dot = BEM.block('pagination').element('nav').element('pagination-list').element('dot');
    const tab = BEM.block('pagination').element('nav').element('pagination-list').element('tab');
    if (this.interface === 'small') {
      return (h("li", null,
        h("span", { class: Object.assign(Object.assign(Object.assign({}, dot.class()), dot.modifier('active').class(isActive)), dot.modifier('inactive').class(!isActive)), onClick: () => this.selectPage(pageNumber) })));
    }
    if (this.interface === 'tabs') {
      return (h("bal-button", { expanded: true, class: Object.assign({}, tab.class()), color: "light", inverted: isActive, onClick: () => this.selectPage(pageNumber) }, this.tabsNames[pageNumber - 1] !== '' ? this.tabsNames[pageNumber - 1] : pageNumber));
    }
    return (h("li", null,
      h("bal-button", { square: true, color: isActive ? 'primary' : 'text', onClick: () => this.selectPage(pageNumber) }, pageNumber)));
  }
  getItems(pageRange = 1) {
    const items = [];
    let rangeStart = this._value - pageRange;
    let rangeEnd = this._value + pageRange;
    if (this.interface === 'small') {
      rangeStart = 1;
      rangeEnd = this.totalPages - 1;
    }
    else {
      if (rangeEnd > this.totalPages) {
        rangeEnd = this.totalPages;
        rangeStart = this.totalPages - pageRange * 2;
        rangeStart = rangeStart < 1 ? 1 : rangeStart;
      }
      if (rangeStart <= 1) {
        rangeStart = 1;
        rangeEnd = Math.min(pageRange * 2 + 1, this.totalPages);
      }
    }
    if (rangeStart > 1) {
      items.push(this.renderPageElement(1));
      if (this.interface !== 'small') {
        items.push(this.renderEllipsisElement());
      }
    }
    for (let i = rangeStart; i <= rangeEnd; i++) {
      items.push(this.renderPageElement(i));
    }
    if (rangeEnd < this.totalPages) {
      if (this.interface !== 'small') {
        items.push(this.renderEllipsisElement());
      }
      items.push(this.renderPageElement(this.totalPages));
    }
    return items;
  }
  render() {
    const mobileItems = this.getItems();
    const tabletItems = this.getItems(this.pageRange);
    const block = BEM.block('pagination');
    const elNav = block.element('nav');
    const elPrevious = elNav.element('pagination-previous');
    const elNext = elNav.element('pagination-next');
    const elList = elNav.element('pagination-list');
    const isSmall = this.interface === 'small';
    const hasTabs = this.interface === 'tabs';
    const buttonColor = isSmall ? 'link' : 'text';
    const buttonSize = isSmall ? 'small' : '';
    const flat = isSmall;
    return (h(Host, { class: Object.assign(Object.assign({}, block.class()), block.modifier('is-sticky').class(this.sticky)) },
      h("nav", { class: Object.assign(Object.assign({}, elNav.class()), elNav.modifier(`context-${this.interface}`).class()), role: "navigation", "aria-label": "pagination" },
        !hasTabs && [
          h("bal-button", { square: true, color: buttonColor, size: buttonSize, flat: flat, class: Object.assign(Object.assign({}, elPrevious.class()), elPrevious.modifier(`context-${this.interface}`).class()), disabled: this._value < 2 || this.disabled, onClick: () => this.previous() },
            h("bal-icon", { name: "nav-go-left", size: "small" })),
          h("bal-button", { square: true, color: buttonColor, size: buttonSize, flat: flat, class: Object.assign(Object.assign({}, elNext.class()), elNext.modifier(`context-${this.interface}`).class()), disabled: this._value === this.totalPages || this.disabled, onClick: () => this.next() },
            h("bal-icon", { name: "nav-go-right", size: "small" })),
        ],
        this.interface === '' || (isSmall && this.totalPages <= 5) || hasTabs ? ([
          h("ul", { class: Object.assign(Object.assign(Object.assign({}, elList.class()), elList.modifier(`context-${this.interface}`).class()), { 'is-hidden-mobile': true, 'is-disabled': this.disabled }) }, tabletItems),
          h("ul", { class: Object.assign(Object.assign(Object.assign({}, elList.class()), elList.modifier(`context-${this.interface}`).class()), { 'is-hidden-tablet': true, 'is-disabled': this.disabled }) }, mobileItems),
        ]) : (h("bal-text", { space: "none", class: Object.assign(Object.assign(Object.assign({}, elList.class()), elList.modifier(`context-${this.interface}`).class()), { 'is-size-5': true }), color: "blue" },
          h("span", { class: "has-text-weight-bold" }, this._value),
          ' / ' + this.totalPages)))));
  }
  static get is() { return "bal-pagination"; }
  static get properties() { return {
    "interface": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalPaginationInterface",
        "resolved": "\"\" | \"small\" | \"tabs\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the layout of the pagination"
      },
      "attribute": "interface",
      "reflect": false,
      "defaultValue": "''"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Disables component"
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "value": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Current selected page"
      },
      "attribute": "value",
      "reflect": false,
      "defaultValue": "1"
    },
    "totalPages": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The total amount of pages"
      },
      "attribute": "total-pages",
      "reflect": false,
      "defaultValue": "1"
    },
    "pageRange": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specify the max visible pages before and after the selected page"
      },
      "attribute": "page-range",
      "reflect": false,
      "defaultValue": "2"
    },
    "tabsNames": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "string[]",
        "resolved": "string[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "List of tabs names for 'tabs' interface"
      },
      "defaultValue": "[]"
    },
    "sticky": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If 'true, the pagination will be sticky to the top"
      },
      "attribute": "sticky",
      "reflect": false,
      "defaultValue": "false"
    },
    "top": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If sticky, the top position will be determined by this value"
      },
      "attribute": "top",
      "reflect": false,
      "defaultValue": "0"
    }
  }; }
  static get states() { return {
    "_value": {}
  }; }
  static get events() { return [{
      "method": "balChangeEventEmitter",
      "name": "balChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Triggers when a page change happens"
      },
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "next": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Go to the next page",
        "tags": []
      }
    },
    "previous": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Go to the previous page",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "value",
      "methodName": "valueChanged"
    }, {
      "propName": "top",
      "methodName": "topValueChanged"
    }]; }
}
