import { Component, h, Host, Element, Prop, State, Listen } from '@stencil/core';
import { BEM } from '../../../utils/bem';
export class PopoverContent {
  constructor() {
    /**
     * If `true` the popover has no padding space.
     */
    this.spaceless = false;
    /**
     * Limit the height of the popover content. Pass the amount of pixel.
     */
    this.scrollable = 0;
    /**
     * Define the max width of the popover content.
     */
    this.contentWidth = 0;
    /**
     * Define the min width of the popover content.
     */
    this.contentMinWidth = 0;
    /**
     * Defines background color of the content.
     */
    this.color = 'white';
    /**
     * If `true` the content has a min width of 100%.
     */
    this.expanded = false;
    /**
     * Defines border-radius of popover content.
     */
    this.radius = 'normal';
    /**
     * If `true` the popover does not have the shadow
     */
    this.noShadow = false;
    /**
     * If `true` the content will have a divider line on top
     */
    this.mobileTop = false;
    this.contentHeightOnTop = 0;
  }
  async resizeHandler() {
    this.contentHeightOnTop = window.innerHeight - 64;
  }
  get innerStyle() {
    let scrollable = {};
    if (this.scrollable > 0) {
      scrollable = {
        'max-height': `${this.scrollable}px`,
        'overflow': 'auto',
      };
    }
    return Object.assign({}, scrollable);
  }
  get contentStyle() {
    let contentWidth = {};
    let contentMinWidth = {};
    const contentHeightOnTopNav = {
      '--bal-popover-content-height-top-nav': `${this.contentHeightOnTop / 16}rem`,
    };
    if (this.contentWidth > 0) {
      contentWidth = { 'max-width': `${this.contentWidth}px` };
    }
    if (this.contentMinWidth > 0) {
      contentMinWidth = { 'min-width': `${this.contentMinWidth}px` };
    }
    return Object.assign(Object.assign(Object.assign({}, contentWidth), contentMinWidth), contentHeightOnTopNav);
  }
  componentDidLoad() {
    this.contentHeightOnTop = window.innerHeight - 64;
  }
  render() {
    const block = BEM.block('popover').element('content');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('expanded').class(this.expanded)), block.modifier('spaceless').class(this.spaceless)), block.modifier('no-shadow').class(this.noShadow)), block.modifier(`radius-${this.radius}`).class()), block.modifier(`color-${this.color}`).class()), block.modifier('on-top').class(this.mobileTop)), role: "tooltip", style: this.contentStyle },
      h("div", { class: Object.assign({}, block.element('inner').class()), style: this.innerStyle },
        h("slot", null)),
      h("div", { class: Object.assign({}, block.element('arrow').class()), "data-popper-arrow": true })));
  }
  static get is() { return "bal-popover-content"; }
  static get properties() { return {
    "spaceless": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the popover has no padding space."
      },
      "attribute": "spaceless",
      "reflect": false,
      "defaultValue": "false"
    },
    "scrollable": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Limit the height of the popover content. Pass the amount of pixel."
      },
      "attribute": "scrollable",
      "reflect": false,
      "defaultValue": "0"
    },
    "contentWidth": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the max width of the popover content."
      },
      "attribute": "content-width",
      "reflect": false,
      "defaultValue": "0"
    },
    "contentMinWidth": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Define the min width of the popover content."
      },
      "attribute": "content-min-width",
      "reflect": false,
      "defaultValue": "0"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalPopoverContentColor",
        "resolved": "\"grey\" | \"white\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines background color of the content."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "'white'"
    },
    "expanded": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the content has a min width of 100%."
      },
      "attribute": "expanded",
      "reflect": false,
      "defaultValue": "false"
    },
    "radius": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalPopoverContentRadius",
        "resolved": "\"large\" | \"large-bottom-none\" | \"large-top-none\" | \"none\" | \"normal\" | \"normal-bottom-none\" | \"normal-top-none\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines border-radius of popover content."
      },
      "attribute": "radius",
      "reflect": false,
      "defaultValue": "'normal'"
    },
    "noShadow": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the popover does not have the shadow"
      },
      "attribute": "no-shadow",
      "reflect": false,
      "defaultValue": "false"
    },
    "mobileTop": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the content will have a divider line on top"
      },
      "attribute": "mobile-top",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "contentHeightOnTop": {}
  }; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "resize",
      "method": "resizeHandler",
      "target": "window",
      "capture": false,
      "passive": true
    }]; }
}
