import { Component, h, Host, Prop, Element } from '@stencil/core';
import Lottie from 'lottie-web/build/player/lottie_light_html';
import { SpinnerAnimationData } from './bal-spinner.animation';
import { flatten } from 'lottie-colorify';
export class Spinner {
  constructor() {
    /**
     * If `true` the component can be used on dark background
     */
    this.inverted = false;
    /**
     * Defines the color of the spinner.
     */
    this.color = 'blue';
    /**
     * If `true` the component is smaller
     */
    this.small = false;
  }
  componentDidUpdate() {
    this.resetAnimation();
  }
  componentDidLoad() {
    this.resetAnimation();
  }
  getColor() {
    if (this.inverted || this.color === 'white') {
      return '#ffffff';
    }
    return '#151f6d';
  }
  resetAnimation() {
    if (this.animation) {
      this.animation.destroy();
    }
    this.animation = Lottie.loadAnimation({
      container: this.el,
      renderer: 'svg',
      loop: true,
      autoplay: true,
      animationData: flatten(this.getColor(), SpinnerAnimationData(this.getColor())),
    });
  }
  disconnectedCallback() {
    if (this.animation && this.animation.destroy) {
      this.animation.destroy();
    }
  }
  render() {
    return h(Host, { style: { width: this.small ? '32px' : '64px' } });
  }
  static get is() { return "bal-spinner"; }
  static get properties() { return {
    "inverted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the component can be used on dark background"
      },
      "attribute": "inverted",
      "reflect": false,
      "defaultValue": "false"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'blue' | 'white'",
        "resolved": "\"blue\" | \"white\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the color of the spinner."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "'blue'"
    },
    "small": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the component is smaller"
      },
      "attribute": "small",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get elementRef() { return "el"; }
}
