import { Component, Host, h, Prop, Method, State, Element, Event } from '@stencil/core';
export class TabItem {
  constructor() {
    this.isActive = false;
    /**
     * Tells if this route is active and overrides the bal-tabs value property.
     */
    this.active = false;
    /**
     * This is the key of the tab.
     */
    this.value = '';
    /**
     * Label for the tab.
     */
    this.label = '';
    /**
     * Link to path.
     */
    this.href = '';
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    /**
     * If `true` a small red bubble is added to the tab.
     */
    this.bubble = false;
    /**
     * If `true` the tab is disabled.
     */
    this.disabled = false;
    /**
     * If `true` the step is marked as done.
     */
    this.done = false;
    /**
     * If `true` the step is hidden.
     */
    this.hidden = false;
    /**
     * If `true` the step is marked as failed.
     */
    this.failed = false;
    /**
     * Tell's if the linking is done by a router.
     */
    this.prevent = false;
    /**
     * Tab icon not available for the steps.
     */
    this.icon = undefined;
  }
  /**
   * Options of the tab like label, value etc.
   */
  async getOptions() {
    return this.options;
  }
  /**
   * Sets the tab active.
   */
  async setActive(active) {
    this.isActive = active;
  }
  get options() {
    return {
      value: this.value,
      icon: this.icon,
      label: this.label,
      href: this.href,
      target: this.target,
      active: this.active,
      disabled: this.disabled,
      done: this.done,
      hidden: this.hidden,
      failed: this.failed,
      bubble: this.bubble,
      passed: false,
      prevent: this.prevent,
      navigate: this.balNavigate,
    };
  }
  render() {
    return (h(Host, { class: {
        'bal-tabs-item': true,
        'bal-tabs-item--active': this.isActive,
      } },
      h("slot", null)));
  }
  static get is() { return "bal-tab-item"; }
  static get properties() { return {
    "active": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Tells if this route is active and overrides the bal-tabs value property."
      },
      "attribute": "active",
      "reflect": true,
      "defaultValue": "false"
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "This is the key of the tab."
      },
      "attribute": "value",
      "reflect": true,
      "defaultValue": "''"
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label for the tab."
      },
      "attribute": "label",
      "reflect": true,
      "defaultValue": "''"
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Link to path."
      },
      "attribute": "href",
      "reflect": true,
      "defaultValue": "''"
    },
    "target": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalButtonTarget",
        "resolved": "\" _parent\" | \"_blank\" | \"_self\" | \"_top\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies where to display the linked URL.\nOnly applies when an `href` is provided."
      },
      "attribute": "target",
      "reflect": false,
      "defaultValue": "'_self'"
    },
    "bubble": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "boolean | string",
        "resolved": "boolean | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` a small red bubble is added to the tab."
      },
      "attribute": "bubble",
      "reflect": true,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the tab is disabled."
      },
      "attribute": "disabled",
      "reflect": true,
      "defaultValue": "false"
    },
    "done": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the step is marked as done."
      },
      "attribute": "done",
      "reflect": true,
      "defaultValue": "false"
    },
    "hidden": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the step is hidden."
      },
      "attribute": "hidden",
      "reflect": true,
      "defaultValue": "false"
    },
    "failed": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the step is marked as failed."
      },
      "attribute": "failed",
      "reflect": true,
      "defaultValue": "false"
    },
    "prevent": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Tell's if the linking is done by a router."
      },
      "attribute": "prevent",
      "reflect": false,
      "defaultValue": "false"
    },
    "icon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Tab icon not available for the steps."
      },
      "attribute": "icon",
      "reflect": true,
      "defaultValue": "undefined"
    }
  }; }
  static get states() { return {
    "isActive": {}
  }; }
  static get events() { return [{
      "method": "balNavigate",
      "name": "balNavigate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the link element has clicked"
      },
      "complexType": {
        "original": "MouseEvent",
        "resolved": "MouseEvent",
        "references": {
          "MouseEvent": {
            "location": "global"
          }
        }
      }
    }]; }
  static get methods() { return {
    "getOptions": {
      "complexType": {
        "signature": "() => Promise<BalTabOption>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          },
          "BalTabOption": {
            "location": "import",
            "path": "../bal-tab.type"
          }
        },
        "return": "Promise<BalTabOption>"
      },
      "docs": {
        "text": "Options of the tab like label, value etc.",
        "tags": []
      }
    },
    "setActive": {
      "complexType": {
        "signature": "(active: boolean) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Sets the tab active.",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}
