import { Component, h, Host, Prop } from '@stencil/core';
export class Text {
  constructor() {
    /**
     * Defines the size of the paragraph
     */
    this.size = '';
    /**
     * If `true` the text has heading font family
     */
    this.heading = false;
    /**
     * If `true` the text is bold
     */
    this.bold = false;
    /**
     * If `true` the text is shown as a display inline
     */
    this.inline = false;
    /**
     * Defines the color of the text.
     */
    this.color = '';
    /**
     * Defines at which position the heading has spacing.
     */
    this.space = '';
    /**
     * If `true` the color gets inverted for dark backgrounds
     */
    this.inverted = false;
    /**
     * If `true` adds a text shadow to improve readability on image background
     * */
    this.shadow = false;
  }
  get spacing() {
    switch (this.space) {
      case 'all':
        return 'my-4';
      case 'top':
        return 'mt-4';
      case 'bottom':
        return 'mb-4';
      case '':
        return !this.inline ? 'mb-4' : '';
      default:
        return '';
    }
  }
  render() {
    const Text = this.inline ? 'span' : 'p';
    return (h(Host, { style: { display: this.inline ? 'inline' : 'block' }, class: { [this.spacing]: true } },
      h(Text, { class: {
          [`has-text-${this.color === '' ? 'primary' : this.color}${this.inverted ? '-inverted' : ''}`]: this.color !== '' || this.inverted,
          'is-small': this.size === 'small',
          'is-lead': this.size === 'lead',
          'is-block': this.size === 'block',
          'is-bold': this.bold,
          'is-family-title': this.heading,
          'has-blur-shadow': this.shadow,
          'm-0': true,
        } },
        h("slot", null))));
  }
  static get is() { return "bal-text"; }
  static get properties() { return {
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalTextSize",
        "resolved": "\"\" | \"block\" | \"lead\" | \"small\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the size of the paragraph"
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "''"
    },
    "heading": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the text has heading font family"
      },
      "attribute": "heading",
      "reflect": false,
      "defaultValue": "false"
    },
    "bold": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the text is bold"
      },
      "attribute": "bold",
      "reflect": false,
      "defaultValue": "false"
    },
    "inline": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the text is shown as a display inline"
      },
      "attribute": "inline",
      "reflect": false,
      "defaultValue": "false"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalTextColor",
        "resolved": "\"\" | \"blue\" | \"danger\" | \"grey\" | \"hint\" | \"info\" | \"primary\" | \"success\" | \"warning\" | \"white\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines the color of the text."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "''"
    },
    "space": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalTextSpace",
        "resolved": "\"\" | \"all\" | \"bottom\" | \"none\" | \"top\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Defines at which position the heading has spacing."
      },
      "attribute": "space",
      "reflect": false,
      "defaultValue": "''"
    },
    "inverted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the color gets inverted for dark backgrounds"
      },
      "attribute": "inverted",
      "reflect": false,
      "defaultValue": "false"
    },
    "shadow": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` adds a text shadow to improve readability on image background"
      },
      "attribute": "shadow",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
}
