import { Component, h, Host, Prop, Element, State } from '@stencil/core';
import { attachComponentToConfig, defaultConfig, detachComponentToConfig, } from '../../../../config';
import { i18nFieldLabel } from './bal-field-label.i18n';
export class FieldLabel {
  constructor() {
    this.language = defaultConfig.language;
    this.region = defaultConfig.region;
    /**
     * If `true` the component gets a invalid red style.
     */
    this.invalid = false;
    /**
     * If `true` the form control needs to be filled. If it is set to
     * `false` an optional label is added to the label..
     */
    this.required = true;
    /**
     * If `true` the component gets a valid green style.
     */
    this.valid = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.weight = 'bold';
  }
  connectedCallback() {
    attachComponentToConfig(this);
  }
  componentDidLoad() {
    if (this.element) {
      this.parentBalFieldElement = this.element.closest('bal-field');
      if (this.parentBalFieldElement) {
        this.parentBalFieldElement.classList.add('has-label');
      }
    }
  }
  disconnectedCallback() {
    detachComponentToConfig(this);
    if (this.parentBalFieldElement) {
      this.parentBalFieldElement.classList.remove('has-label');
    }
  }
  configChanged(config) {
    this.language = config.language;
    this.region = config.region;
  }
  render() {
    const suffix = this.required === false ? i18nFieldLabel[this.language].optional || '' : '';
    return (h(Host, { class: "bal-field-label" },
      h("label", { class: {
          'label': true,
          'is-disabled': this.disabled || this.readonly,
          'is-success': this.valid,
          'is-danger': this.invalid,
          'is-regular': this.weight === 'regular',
        } },
        h("slot", null),
        suffix)));
  }
  static get is() { return "bal-field-label"; }
  static get encapsulation() { return "scoped"; }
  static get properties() { return {
    "invalid": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the component gets a invalid red style."
      },
      "attribute": "invalid",
      "reflect": false,
      "defaultValue": "false"
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the form control needs to be filled. If it is set to\n`false` an optional label is added to the label.."
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "true"
    },
    "valid": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the component gets a valid green style."
      },
      "attribute": "valid",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "readonly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the element can not mutated, meaning the user can not edit the control."
      },
      "attribute": "readonly",
      "reflect": false,
      "defaultValue": "false"
    },
    "weight": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalFieldLabelWeight",
        "resolved": "\"bold\" | \"regular\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the component gets a invalid style."
      },
      "attribute": "weight",
      "reflect": false,
      "defaultValue": "'bold'"
    }
  }; }
  static get states() { return {
    "language": {},
    "region": {}
  }; }
  static get elementRef() { return "element"; }
}
