import { Component, h, Host, Prop, Element, Watch } from '@stencil/core';
import { observeItems } from '../../../utils/observer';
export class Field {
  constructor() {
    this.formControlElement = ['bal-field-control'];
    this.inputElements = [
      'bal-input',
      'bal-number-input',
      'bal-textarea',
      'bal-select',
      'bal-datepicker',
      'bal-checkbox',
      'bal-radio',
      'bal-input-group',
      'bal-input-stepper',
      'bal-file-upload',
    ];
    this.formElements = [...this.formControlElement, 'bal-field-label', 'bal-field-message'];
    /**
     * If `true` the form control needs to be filled. If it is set to
     * `false` an optional label is added to the label..
     */
    this.required = undefined;
    /**
     * If `true` the component gets a invalid red style.
     */
    this.invalid = undefined;
    /**
     * If `true` the component gets a valid green style.
     */
    this.valid = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = undefined;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = undefined;
    /**
     * If `true` a loading spinner is visible at the end of the input
     */
    this.loading = undefined;
  }
  requiredHandler() {
    this.updateProps([...this.inputElements, 'bal-field-label'], 'required');
  }
  invalidHandler() {
    this.updateProps([...this.inputElements, ...this.formElements], 'invalid');
  }
  validHandler() {
    this.updateProps([...this.inputElements, ...this.formElements], 'valid');
  }
  disabledHandler() {
    this.updateProps([...this.inputElements, ...this.formElements], 'disabled');
  }
  readonlyHandler() {
    this.updateProps([...this.inputElements, ...this.formElements], 'readonly');
  }
  loadingHandler() {
    this.updateProps([...this.inputElements, ...this.formControlElement], 'loading');
  }
  connectedCallback() {
    this.mutationO = observeItems(this.el, undefined, () => this.triggerAllHandlers());
    this.triggerAllHandlers();
  }
  componentWillLoad() {
    this.triggerAllHandlers();
  }
  triggerAllHandlers() {
    this.requiredHandler();
    this.invalidHandler();
    this.validHandler();
    this.readonlyHandler();
    this.disabledHandler();
    this.loadingHandler();
  }
  updateProps(selectors, key) {
    const value = this[key];
    if (value !== undefined) {
      this.notifyComponents(selectors, input => (input[key] = value));
    }
  }
  notifyComponents(selectors, callback) {
    const components = this.el.querySelectorAll(selectors.join(', '));
    components.forEach(c => callback(c));
  }
  render() {
    return (h(Host, { class: {
        'bal-field': true,
        'field': true,
        'bal-field--invalid': this.invalid === true,
      } },
      h("slot", null),
      h("span", { class: "hidden" })));
  }
  static get is() { return "bal-field"; }
  static get properties() { return {
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "If `true` the form control needs to be filled. If it is set to\n`false` an optional label is added to the label.."
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "undefined"
    },
    "invalid": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "If `true` the component gets a invalid red style."
      },
      "attribute": "invalid",
      "reflect": false,
      "defaultValue": "undefined"
    },
    "valid": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If `true` the component gets a valid green style."
      },
      "attribute": "valid",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "undefined"
    },
    "readonly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "If `true` the element can not mutated, meaning the user can not edit the control."
      },
      "attribute": "readonly",
      "reflect": false,
      "defaultValue": "undefined"
    },
    "loading": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "If `true` a loading spinner is visible at the end of the input"
      },
      "attribute": "loading",
      "reflect": false,
      "defaultValue": "undefined"
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "required",
      "methodName": "requiredHandler"
    }, {
      "propName": "invalid",
      "methodName": "invalidHandler"
    }, {
      "propName": "valid",
      "methodName": "validHandler"
    }, {
      "propName": "disabled",
      "methodName": "disabledHandler"
    }, {
      "propName": "readonly",
      "methodName": "readonlyHandler"
    }, {
      "propName": "loading",
      "methodName": "loadingHandler"
    }]; }
}
