import { Component, Host, h, Prop, Method, Element, State, Event } from '@stencil/core';
export class Snackbar {
  constructor() {
    this.snackbarId = `bal-snackbar-${snackbarIds++}`;
    this.animationClass = 'fadeInDown';
    /**
     * The theme type of the snackbar. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * The duration of the snackbar
     */
    this.duration = 0;
    /**
     * The subject of the snackbar header
     */
    this.subject = '';
    /**
     * The message of the snackbar as html content
     */
    this.message = '';
    /**
     * The icon of the snackbar header
     */
    this.icon = '';
    /**
     * Label text for the action button
     */
    this.action = '';
    /**
     * @internal Handler for on close event
     */
    this.closeHandler = () => void 0;
    /**
     * @internal Handler for on action button click event
     */
    this.actionHandler = () => void 0;
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    this.onActionHandler = () => {
      this.balAction.emit(this.snackbarId);
      this.actionHandler();
    };
  }
  async componentWillLoad() {
    if (this.duration > 0) {
      await this.closeIn(this.duration);
    }
  }
  /**
   * Closes the snackbar after the given duration in ms
   */
  async closeIn(duration) {
    this.timer = setTimeout(() => this.close(), duration);
  }
  /**
   * Closes this snackbar
   */
  async close() {
    clearTimeout(this.timer);
    this.balClose.emit(this.snackbarId);
    this.element.remove();
    this.closeHandler();
  }
  get colorType() {
    if (this.color === '') {
      return '';
    }
    return `bal-snackbar__inner--is-${this.color}`;
  }
  get buttonType() {
    if (this.color === '') {
      return 'info';
    }
    return this.color;
  }
  render() {
    const labelAttributes = {};
    if (this.message !== undefined && this.message !== '') {
      labelAttributes.innerHTML = this.message;
    }
    return (h(Host, { id: this.snackbarId, class: "bal-snackbar" },
      h("div", { role: "alert", class: `bal-snackbar__inner ${this.animationClass} ${this.colorType} p-5` },
        h("div", { class: "bal-snackbar__header" },
          h("span", { class: "icon-text is-small" },
            h("span", { class: "icon", style: { display: this.icon ? '' : 'none' } },
              h("bal-icon", { name: this.icon, color: 'primary' })),
            h("bal-heading", { level: "h5", space: "none" }, this.subject))),
        h("span", Object.assign({ class: "bal-snackbar__label" }, labelAttributes),
          h("slot", null),
          h("span", { class: "hidden" })),
        h("bal-close", { class: "bal-snackbar__close", onClick: () => this.close() }),
        h("div", { class: "bal-snackbar__footer", style: { display: this.action === '' ? 'none' : 'inline-flex' } },
          h("bal-button", { color: "info", href: this.href, target: this.target, onClick: () => this.onActionHandler() }, this.action)))));
  }
  static get is() { return "bal-snackbar"; }
  static get properties() { return {
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalSnackbarColor",
        "resolved": "\"\" | \"danger\" | \"info\" | \"primary\" | \"success\" | \"warning\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The theme type of the snackbar. Given by bulma our css framework."
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "''"
    },
    "duration": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The duration of the snackbar"
      },
      "attribute": "duration",
      "reflect": false,
      "defaultValue": "0"
    },
    "subject": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The subject of the snackbar header"
      },
      "attribute": "subject",
      "reflect": false,
      "defaultValue": "''"
    },
    "message": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The message of the snackbar as html content"
      },
      "attribute": "message",
      "reflect": false,
      "defaultValue": "''"
    },
    "icon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The icon of the snackbar header"
      },
      "attribute": "icon",
      "reflect": false,
      "defaultValue": "''"
    },
    "action": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label text for the action button"
      },
      "attribute": "action",
      "reflect": false,
      "defaultValue": "''"
    },
    "closeHandler": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "() => void",
        "resolved": "() => void",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": "Handler for on close event"
          }],
        "text": ""
      },
      "defaultValue": "() => void 0"
    },
    "actionHandler": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "() => void",
        "resolved": "() => void",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "internal",
            "text": "Handler for on action button click event"
          }],
        "text": ""
      },
      "defaultValue": "() => void 0"
    },
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string | undefined",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Specifies the URL of the page the link goes to"
      },
      "attribute": "href",
      "reflect": false
    },
    "target": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Props.BalButtonTarget",
        "resolved": "\" _parent\" | \"_blank\" | \"_self\" | \"_top\"",
        "references": {
          "Props": {
            "location": "import",
            "path": "../../../types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies where to display the linked URL.\nOnly applies when an `href` is provided."
      },
      "attribute": "target",
      "reflect": false,
      "defaultValue": "'_self'"
    }
  }; }
  static get states() { return {
    "animationClass": {}
  }; }
  static get events() { return [{
      "method": "balClose",
      "name": "balClose",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when snackbar is closed"
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "balAction",
      "name": "balAction",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the action button is clicked"
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "closeIn": {
      "complexType": {
        "signature": "(duration: number) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Closes the snackbar after the given duration in ms",
        "tags": []
      }
    },
    "close": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Closes this snackbar",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "element"; }
}
let snackbarIds = 0;
