import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { b as debounceEvent } from './helpers.js';
import { d as defineCustomElement$4 } from './bal-button2.js';
import { d as defineCustomElement$3 } from './bal-icon2.js';
import { d as defineCustomElement$2 } from './bal-spinner2.js';

const Accordion = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balChange = createEvent(this, "balChange", 7);
    this.didInit = false;
    /**
     * If `true` the accordion is open.
     */
    this.value = false;
    /**
     * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
     */
    this.debounce = 0;
    /**
     * Label of the open trigger button
     */
    this.openLabel = '';
    /**
     * BalIcon of the open trigger button
     */
    this.openIcon = 'plus';
    /**
     * Label of the close trigger button
     */
    this.closeLabel = '';
    /**
     * BalIcon of the close trigger button
     */
    this.closeIcon = 'close';
    /**
     * If `true` the accordion is used on the bottom of a card
     */
    this.card = false;
  }
  async valueChanged(newValue, oldValue) {
    if (this.didInit && newValue !== oldValue) {
      this.balChange.emit(newValue);
    }
  }
  debounceChanged() {
    this.balChange = debounceEvent(this.balChange, this.debounce);
  }
  connectedCallback() {
    this.debounceChanged();
  }
  componentDidLoad() {
    this.didInit = true;
    if (this.value !== undefined) {
      this.valueChanged(this.value, false);
    }
  }
  /**
   * Opens the accordion
   */
  async present() {
    this.value = true;
  }
  /**
   * Closes the accordion
   */
  async dismiss() {
    this.value = false;
  }
  /**
   * Triggers the accordion
   */
  async toggle() {
    this.value = !this.value;
  }
  get label() {
    return this.value ? this.closeLabel : this.openLabel;
  }
  get icon() {
    return this.value ? this.closeIcon : this.openIcon;
  }
  render() {
    const label = this.value ? this.closeLabel : this.openLabel;
    const icon = this.value ? this.closeIcon : this.openIcon;
    return (h(Host, { class: {
        'accordion': true,
        'mt-5': this.card,
      }, "aria-presented": this.value ? 'true' : null }, h("div", { class: {
        'is-flex is-flex-direction-column-reverse': true,
      } }, h("div", { class: {
        'accordion-trigger': true,
        'px-5': this.card,
        'pb-5': this.card,
      } }, h("bal-button", { class: {
        'data-test-accordion-trigger': true,
      }, expanded: true, color: 'info', icon: icon, onClick: () => this.toggle() }, label)), h("div", { class: {
        'accordion-content': true,
      }, style: {
        display: this.value ? 'block' : 'none',
      } }, h("slot", null)))));
  }
  static get watchers() { return {
    "value": ["valueChanged"],
    "debounce": ["debounceChanged"]
  }; }
}, [4, "bal-accordion", {
    "value": [1540],
    "debounce": [2],
    "openLabel": [1, "open-label"],
    "openIcon": [1, "open-icon"],
    "closeLabel": [1, "close-label"],
    "closeIcon": [1, "close-icon"],
    "card": [4],
    "present": [64],
    "dismiss": [64],
    "toggle": [64]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-accordion", "bal-button", "bal-icon", "bal-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-accordion":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Accordion);
      }
      break;
    case "bal-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalAccordion = Accordion;
const defineCustomElement = defineCustomElement$1;

export { BalAccordion, defineCustomElement };
