import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$2 } from './bal-icon2.js';
import { d as defineCustomElement$1 } from './bal-spinner2.js';

const Button = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balNavigate = createEvent(this, "balNavigate", 7);
    this.balFocus = createEvent(this, "balFocus", 7);
    this.balBlur = createEvent(this, "balBlur", 7);
    this.balDidRender = createEvent(this, "balDidRender", 7);
    /**
     * The color to use from your application's color palette.
     */
    this.color = 'primary';
    /**
     * The type of button.
     */
    this.elementType = 'button';
    /**
     * If `true`, the user cannot interact with the button.
     */
    this.disabled = false;
    /**
     * Size of the button
     */
    this.size = '';
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    /**
     * If `true` adds a box shadow to improve readability on image background
     * */
    this.shadow = false;
    /**
     * If `true` the width of the buttons is limited
     */
    this.square = false;
    /**
     * If `true` the button has a active theme
     */
    this.isActive = false;
    /**
     * If `true` the button has a full width
     */
    this.expanded = false;
    /**
     * If `true` the button has no padding and a reduced height
     */
    this.flat = false;
    /**
     * If `true` the button is outlined
     */
    this.outlined = false;
    /**
     * If `true` the button is inverted
     */
    this.inverted = false;
    /**
     * If `true` the label is hidden and a loading spinner is shown instead.
     */
    this.loading = false;
    /**
     * If `true` the button is rounded.
     */
    this.rounded = false;
    /**
     * If `true` the top corners get rounded
     */
    this.topRounded = undefined;
    /**
     * If `true` the bottom corners get rounded
     */
    this.bottomRounded = undefined;
    /**
     * Name of the left button icon
     */
    this.icon = '';
    /**
     * Name of the right button icon
     */
    this.iconRight = '';
    /**
     * The name of the button, which is submitted with the form data.
     */
    this.name = '';
    /**
     * The value of the button, which is submitted with the form data.
     */
    this.value = '';
    this.onFocus = () => {
      this.balFocus.emit();
    };
    this.onBlur = () => {
      this.balBlur.emit();
    };
    this.onClick = (event) => {
      if (this.href !== undefined) {
        this.balNavigate.emit(event);
      }
    };
  }
  listenOnClick(ev) {
    if (this.disabled && ev.target && ev.target === this.el) {
      ev.preventDefault();
      ev.stopPropagation();
    }
  }
  componentDidRender() {
    this.balDidRender.emit();
  }
  get isIconInverted() {
    return this.inverted;
  }
  get buttonCssClass() {
    return {
      'button': true,
      [`is-${this.color}`]: true,
      'is-flat': this.flat,
      'is-square': this.square,
      'is-small': this.size === 'small',
      'is-inverted': this.inverted,
      'is-active': this.isActive,
      'is-outlined': this.outlined,
      'is-fullwidth': this.expanded,
      'is-disabled': this.disabled,
      'is-loading': this.loading,
      'has-blur-shadow': this.shadow === true,
      'has-radius-rounded': this.rounded === true,
      'has-round-top-corners': this.topRounded === true,
      'has-round-bottom-corners': this.bottomRounded === true,
      'has-no-round-top-corners': this.topRounded === false,
      'has-no-round-bottom-corners': this.bottomRounded === false,
    };
  }
  get leftIconAttrs() {
    if (!this.icon || this.loading) {
      return {
        style: { display: 'none' },
      };
    }
    return {};
  }
  get leftRightAttrs() {
    if (!this.iconRight || this.loading) {
      return {
        style: { display: 'none' },
      };
    }
    return {};
  }
  get loadingAttrs() {
    if (!this.loading) {
      return {
        style: { display: 'none' },
      };
    }
    return {
      style: { position: 'absolute' },
    };
  }
  handleClick(event) {
    if (this.disabled) {
      event.preventDefault();
      event.stopPropagation();
    }
  }
  render() {
    const { elementType, download, href, rel, target, name, value } = this;
    const TagType = this.href === undefined ? 'button' : 'a';
    const attrs = TagType === 'button'
      ? { type: elementType, name, value }
      : {
        download,
        href,
        rel,
        target,
      };
    const spinnerColor = () => {
      if (this.disabled) {
        return 'blue';
      }
      switch (this.color) {
        case 'primary':
        case 'success':
        case 'warning':
        case 'danger':
          return this.inverted ? 'blue' : 'white';
        default:
          return this.inverted ? 'white' : 'blue';
      }
    };
    return (h(Host, { onClick: this.handleClick, "aria-disabled": this.disabled ? 'true' : null, class: {
        'bal-button': true,
        'control': true,
        'is-fullwidth': this.expanded,
        'is-disabled': this.disabled,
      } }, h(TagType, Object.assign({}, attrs, { type: this.elementType, class: this.buttonCssClass, part: "native", disabled: this.disabled, onFocus: this.onFocus, onBlur: this.onBlur, onClick: this.onClick }), h("bal-spinner", Object.assign({ color: spinnerColor(), small: true }, this.loadingAttrs)), h("bal-icon", Object.assign({}, this.leftIconAttrs, { class: "icon-left", name: this.icon, size: this.square ? this.size : 'small', inverted: this.isIconInverted })), h("span", { class: {
        'data-test-button-label button-label': true,
        'is-small': this.size === 'small',
      }, style: { opacity: this.loading || (this.square && this.icon !== '') ? '0' : '1' } }, h("slot", null)), h("bal-icon", Object.assign({}, this.leftRightAttrs, { class: "icon-right", name: this.iconRight, size: 'small', inverted: this.isIconInverted })))));
  }
  get el() { return this; }
}, [4, "bal-button", {
    "color": [1],
    "elementType": [1, "element-type"],
    "disabled": [516],
    "size": [513],
    "href": [1],
    "target": [1],
    "rel": [1],
    "download": [1],
    "shadow": [4],
    "square": [4],
    "isActive": [4, "is-active"],
    "expanded": [4],
    "flat": [4],
    "outlined": [4],
    "inverted": [4],
    "loading": [4],
    "rounded": [4],
    "topRounded": [4, "top-rounded"],
    "bottomRounded": [4, "bottom-rounded"],
    "icon": [1],
    "iconRight": [1, "icon-right"],
    "name": [1],
    "value": [8]
  }, [[6, "click", "listenOnClick"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-button", "bal-icon", "bal-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-button":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Button);
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { Button as B, defineCustomElement as d };
