import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { b as attachComponentToConfig, d as detachComponentToConfig } from './index2.js';
import { d as defaultConfig } from './initialize.js';

const i18nFieldLabel = {
  de: {
    optional: ' (optional)',
  },
  en: {
    optional: ' (optional)',
  },
  fr: {
    optional: ' (optionnel)',
  },
  it: {
    optional: ' (opzionale)',
  },
  nl: {
    optional: ' (optioneel)',
  },
};

const FieldLabel = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.language = defaultConfig.language;
    this.region = defaultConfig.region;
    /**
     * If `true` the component gets a invalid red style.
     */
    this.invalid = false;
    /**
     * If `true` the form control needs to be filled. If it is set to
     * `false` an optional label is added to the label..
     */
    this.required = true;
    /**
     * If `true` the component gets a valid green style.
     */
    this.valid = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.weight = 'bold';
  }
  connectedCallback() {
    attachComponentToConfig(this);
  }
  componentDidLoad() {
    if (this.element) {
      this.parentBalFieldElement = this.element.closest('bal-field');
      if (this.parentBalFieldElement) {
        this.parentBalFieldElement.classList.add('has-label');
      }
    }
  }
  disconnectedCallback() {
    detachComponentToConfig(this);
    if (this.parentBalFieldElement) {
      this.parentBalFieldElement.classList.remove('has-label');
    }
  }
  configChanged(config) {
    this.language = config.language;
    this.region = config.region;
  }
  render() {
    const suffix = this.required === false ? i18nFieldLabel[this.language].optional || '' : '';
    return (h(Host, { class: "bal-field-label" }, h("label", { class: {
        'label': true,
        'is-disabled': this.disabled || this.readonly,
        'is-success': this.valid,
        'is-danger': this.invalid,
        'is-regular': this.weight === 'regular',
      } }, h("slot", null), suffix)));
  }
  get element() { return this; }
}, [6, "bal-field-label", {
    "invalid": [4],
    "required": [4],
    "valid": [4],
    "disabled": [4],
    "readonly": [4],
    "weight": [1],
    "language": [32],
    "region": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-field-label"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-field-label":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FieldLabel);
      }
      break;
  } });
}

const BalFieldLabel = FieldLabel;
const defineCustomElement = defineCustomElement$1;

export { BalFieldLabel, defineCustomElement };
