import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { a as createCommonjsModule, g as getDefaultExportFromCjs } from './_commonjsHelpers.js';
import { a as areArraysEqual } from './index.esm.js';
import { F as FileUploadRejectionReason } from './bal-file-upload.type.js';
import { i as inputHandleFocus, a as inputHandleBlur, d as inputHandleHostClick, s as stopEventBubbling, b as inputSetFocus, c as inputSetBlur } from './form-input.helpers.js';
import { d as defineCustomElement$c } from './bal-card2.js';
import { d as defineCustomElement$b } from './bal-heading2.js';
import { d as defineCustomElement$a } from './bal-icon2.js';
import { d as defineCustomElement$9 } from './bal-list2.js';
import { d as defineCustomElement$8 } from './bal-list-item2.js';
import { d as defineCustomElement$7 } from './bal-list-item-content2.js';
import { d as defineCustomElement$6 } from './bal-list-item-icon2.js';
import { d as defineCustomElement$5 } from './bal-list-item-subtitle2.js';
import { d as defineCustomElement$4 } from './bal-list-item-title2.js';
import { d as defineCustomElement$3 } from './bal-spinner2.js';
import { d as defineCustomElement$2 } from './bal-text2.js';

var spec = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });
var si = { radix: 1e3, unit: ['b', 'kb', 'Mb', 'Gb', 'Tb', 'Pb', 'Eb', 'Zb', 'Yb'] };
var iec = { radix: 1024, unit: ['b', 'Kib', 'Mib', 'Gib', 'Tib', 'Pib', 'Eib', 'Zib', 'Yib'] };
var jedec = { radix: 1024, unit: ['b', 'Kb', 'Mb', 'Gb', 'Tb', 'Pb', 'Eb', 'Zb', 'Yb'] };
exports.SPECS = {
    si: si,
    iec: iec,
    jedec: jedec,
};
//# sourceMappingURL=spec.js.map
});

var lib = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", { value: true });

/**
 * file size
 * @param bytes
 * @param fixed
 * @param spec
 */
function default_1(bytes, fixed, spec$1) {
    if (fixed === void 0) { fixed = 1; }
    bytes = Math.abs(bytes);
    var _a = spec.SPECS[spec$1] || spec.SPECS['jedec'], radix = _a.radix, unit = _a.unit;
    var loop = 0;
    // calculate
    while (bytes >= radix) {
        bytes /= radix;
        ++loop;
    }
    return bytes.toFixed(fixed) + " " + unit[loop];
}
exports.default = default_1;
//# sourceMappingURL=index.js.map
});

const fileSize = /*@__PURE__*/getDefaultExportFromCjs(lib);

const FileUpload = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balChange = createEvent(this, "balChange", 7);
    this.balFilesAddedEmitter = createEvent(this, "balFilesAdded", 7);
    this.balFilesRemovedEmitter = createEvent(this, "balFilesRemoved", 7);
    this.balClick = createEvent(this, "balClick", 7);
    this.balBlur = createEvent(this, "balBlur", 7);
    this.balFocus = createEvent(this, "balFocus", 7);
    this.balRejectedFileEventEmitter = createEvent(this, "balRejectedFile", 7);
    this.uploadId = `bal-upload-${UploadIds++}`;
    this.bundleSize = 0;
    this.isOver = false;
    this.files = [];
    this.hasFocus = false;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.uploadId;
    /**
     * Label of the drop area.
     */
    this.label = 'Choose or drop a file...';
    /**
     * If `true` multiple file upload is possible.
     */
    this.multiple = true;
    /**
     * If `true` below the drop-down area it generates a file list.
     */
    this.hasFileList = true;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * Accepted MIME-Types like `image/png,image/jpeg`.
     */
    this.accept = '';
    /**
     * Input value.
     */
    this.value = [];
    /**
     * If `true` the file upload is disabled and shows a spinner
     */
    this.loading = false;
    this.handleFiles = (files) => {
      if (!this.disabled) {
        const list = [...this.files];
        const filesAdded = [];
        for (let index = 0; index < files.length; index++) {
          const file = files.item(index);
          if (file) {
            const rejectReasons = [];
            if (this.accept && this.accept.split(' ').join('').split(',').indexOf(file.type) === -1) {
              rejectReasons.push(FileUploadRejectionReason.BAD_EXTENSION);
            }
            if (this.maxFileSize && file.size > this.maxFileSize) {
              rejectReasons.push(FileUploadRejectionReason.FILE_TOO_BIG);
            }
            const transactionFileSizeSum = this.files.map(f => f.size).reduce((a, b) => a + b, 0);
            const bundleSize = file.size + transactionFileSizeSum;
            if (this.maxBundleSize && bundleSize > this.maxBundleSize) {
              rejectReasons.push(FileUploadRejectionReason.FILE_SIZE_SUM_TOO_BIG);
            }
            if (this.maxFiles && list.length + 1 > this.maxFiles) {
              rejectReasons.push(FileUploadRejectionReason.TOO_MANY_FILES);
            }
            const duplicatedFiles = list.filter(f => f.size === file.size && f.name === file.name && f.type === file.type);
            if (duplicatedFiles.length > 0) {
              rejectReasons.push(FileUploadRejectionReason.DUPLICATED_FILE);
            }
            if (rejectReasons.length > 0) {
              this.balRejectedFileEventEmitter.emit({
                file: file,
                reasons: rejectReasons,
              });
            }
            else {
              list.push(file);
              filesAdded.push(file);
            }
          }
        }
        if (this.files.length !== list.length) {
          this.files = [...list];
          this.balChange.emit(this.files);
        }
        if (filesAdded.length > 0) {
          this.balFilesAddedEmitter.emit(filesAdded);
        }
        this.setFileList();
      }
    };
    this.onInputChange = () => {
      var _a;
      if ((_a = this.nativeInput) === null || _a === void 0 ? void 0 : _a.files) {
        const files = this.nativeInput.files;
        this.handleFiles(files);
      }
    };
    this.setFileList = () => {
      const fileList = new DataTransfer();
      this.files.forEach(el => fileList.items.add(el));
      this.nativeInput.files = fileList.files;
    };
    this.onInputFocus = (event) => inputHandleFocus(this, event);
    this.onInputBlur = (event) => inputHandleBlur(this, event);
    this.handleClick = (event) => inputHandleHostClick(this, event);
    this.onInputClick = (event) => {
      this.balClick.emit(event);
    };
  }
  onValueChange() {
    if (!areArraysEqual(this.files, this.value)) {
      this.files = this.value;
    }
  }
  dragenterHandler() {
    if (!this.disabled && !this.readonly) {
      this.isOver = true;
    }
  }
  dragoverHandler() {
    if (!this.disabled && !this.readonly) {
      this.isOver = true;
    }
  }
  dragleaveHandler() {
    if (!this.disabled && !this.readonly) {
      this.isOver = false;
    }
  }
  dropHandler(event) {
    if (!this.disabled && !this.readonly) {
      this.isOver = false;
      const dataTransfer = event.dataTransfer;
      if (dataTransfer) {
        this.handleFiles(dataTransfer.files);
      }
    }
  }
  componentWillLoad() {
    this.onValueChange();
  }
  componentDidLoad() {
    ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
      this.el.addEventListener(eventName, stopEventBubbling, {
        passive: false,
      });
      document.body.addEventListener(eventName, stopEventBubbling, {
        passive: false,
      });
    });
  }
  disconnectedCallback() {
    ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
      this.el.removeEventListener(eventName, stopEventBubbling, false);
      document.body.removeEventListener(eventName, stopEventBubbling, false);
    });
  }
  /**
   * Sets the file list to an empty list
   */
  async clear() {
    this.files = [];
  }
  /**
   * Sets focus on the native `input`. Use this method instead of the global
   * `input.focus()`.
   */
  async setFocus() {
    inputSetFocus(this);
  }
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  async setBlur() {
    inputSetBlur(this);
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  removeFile(indexToRemove) {
    if (!this.disabled && !this.readonly) {
      const list = [];
      const removedFiles = [];
      for (let index = 0; index < this.files.length; index++) {
        if (index !== indexToRemove) {
          list.push(this.files[index]);
        }
        else {
          removedFiles.push(this.files[index]);
        }
      }
      this.files = [...list];
      this.balChange.emit(this.files);
      this.balFilesRemovedEmitter.emit(removedFiles);
      this.setFileList();
    }
  }
  render() {
    const FileList = () => (h("bal-card", { flat: true, class: "mt-4", style: { display: this.files.length ? 'block' : 'none' } }, h("bal-list", { disabled: this.disabled || this.loading || this.readonly, border: true, size: "large", class: "p-0" }, this.files.map((file, index) => (h("bal-list-item", { disabled: this.disabled || this.loading || this.readonly }, h("bal-list-item-icon", null, h("bal-icon", { name: "document" })), h("bal-list-item-content", null, h("bal-list-item-title", null, file.name), h("bal-list-item-subtitle", null, this.subTitle ? this.subTitle(file) : fileSize(file.size))), h("bal-list-item-icon", { right: true, class: {
        'file-remove': true,
        'is-clickable': !this.disabled && !this.readonly,
      }, onClick: () => this.removeFile(index) }, h("bal-icon", { name: "trash", color: this.disabled || this.loading || this.readonly ? 'grey' : 'danger' }))))))));
    return (h(Host, { onClick: this.handleClick, class: {
        'bal-file-upload': true,
      } }, h("div", { class: {
        'file': true,
        'is-disabled': this.disabled || this.readonly || this.loading,
        'is-danger': this.invalid,
      } }, h("label", { class: ['file-label', this.disabled || this.loading || this.readonly ? 'is-disabled' : ''].join(' ') }, h("input", { class: "file-input", type: "file", name: this.name, multiple: this.multiple, disabled: this.disabled || this.loading, readonly: this.readonly, required: this.required, accept: this.accept, onClick: this.onInputClick, onChange: this.onInputChange, onFocus: this.onInputFocus, onBlur: this.onInputBlur, ref: el => (this.nativeInput = el) }), this.loading ? (h("span", { class: "file-cta" }, h("bal-spinner", null))) : (h("span", { class: "file-cta" }, h("span", { class: "file-icon" }, h("bal-icon", { name: "upload", size: "medium", color: this.disabled || this.loading || this.readonly ? 'grey-light' : this.invalid ? 'danger' : 'blue' })), h("span", { class: "file-label" }, this.label))))), this.hasFileList ? h(FileList, null) : ''));
  }
  get el() { return this; }
  static get watchers() { return {
    "value": ["onValueChange"]
  }; }
}, [0, "bal-file-upload", {
    "name": [1],
    "label": [1],
    "multiple": [4],
    "hasFileList": [4, "has-file-list"],
    "disabled": [4],
    "required": [4],
    "invalid": [4],
    "readonly": [4],
    "accept": [1],
    "maxFiles": [2, "max-files"],
    "maxFileSize": [2, "max-file-size"],
    "maxBundleSize": [2, "max-bundle-size"],
    "value": [16],
    "loading": [4],
    "subTitle": [16],
    "isOver": [32],
    "files": [32],
    "hasFocus": [32],
    "clear": [64],
    "setFocus": [64],
    "setBlur": [64],
    "getInputElement": [64]
  }, [[0, "dragenter", "dragenterHandler"], [0, "dragover", "dragoverHandler"], [0, "dragleave", "dragleaveHandler"], [0, "drop", "dropHandler"]]]);
let UploadIds = 0;
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-file-upload", "bal-card", "bal-heading", "bal-icon", "bal-list", "bal-list-item", "bal-list-item-content", "bal-list-item-icon", "bal-list-item-subtitle", "bal-list-item-title", "bal-spinner", "bal-text"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-file-upload":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FileUpload);
      }
      break;
    case "bal-card":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "bal-heading":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "bal-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "bal-list-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "bal-list-item-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "bal-list-item-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-list-item-subtitle":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-list-item-title":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-text":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalFileUpload = FileUpload;
const defineCustomElement = defineCustomElement$1;

export { BalFileUpload, defineCustomElement };
