import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { b as attachComponentToConfig, d as detachComponentToConfig } from './index2.js';
import { i as isPlatform } from './platform.js';
import { B as BEM } from './bem.js';
import { p as preventDefault } from './utils.js';
import { B as BodyScrollBlocker } from './toggle-scrolling-body.js';
import { d as defineCustomElement$6 } from './bal-button2.js';
import { d as defineCustomElement$5 } from './bal-button-group2.js';
import { d as defineCustomElement$4 } from './bal-icon2.js';
import { d as defineCustomElement$3 } from './bal-popover2.js';
import { d as defineCustomElement$2 } from './bal-popover-content2.js';
import { d as defineCustomElement$1 } from './bal-spinner2.js';

const Hint = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.bodyScrollBlocker = BodyScrollBlocker();
    this.isActive = false;
    this.innerCloseLabel = 'Close';
    this.isMobile = isPlatform('mobile');
    /**
     * Disables the close button for tablet and desktop
     */
    this.small = false;
    this.onPopoverChange = (event) => {
      this.isActive = event.detail;
      preventDefault(event);
    };
  }
  async resizeHandler() {
    const isCurrentMobile = isPlatform('mobile');
    if (isCurrentMobile !== this.isMobile) {
      this.isActive = false;
    }
    this.isMobile = isCurrentMobile;
  }
  connectedCallback() {
    attachComponentToConfig(this);
  }
  disconnectedCallback() {
    detachComponentToConfig(this);
  }
  componentDidRender() {
    this.updateContent();
  }
  configChanged(state) {
    if (!this.closeLabel) {
      switch (state.language) {
        case 'de':
          this.innerCloseLabel = 'Schliessen';
          break;
        case 'fr':
          this.innerCloseLabel = 'Fermer';
          break;
        case 'it':
          this.innerCloseLabel = 'Chiudere';
          break;
        case 'nl':
          this.innerCloseLabel = 'Sluiten';
          break;
        default:
          this.innerCloseLabel = 'Close';
          break;
      }
    }
  }
  /**
   * Toggles the hint box.
   */
  async toggle() {
    if (this.isActive) {
      this.dismiss();
    }
    else {
      this.present();
    }
  }
  /**
   * Opens the hint box.
   */
  async present() {
    if (this.popoverElement) {
      this.popoverElement.present();
    }
    if (this.isMobile) {
      this.bodyScrollBlocker.block();
    }
    this.isActive = true;
  }
  /**
   * Closes the hint box.
   */
  async dismiss() {
    if (this.popoverElement) {
      this.popoverElement.dismiss();
    }
    if (this.isMobile) {
      this.bodyScrollBlocker.allow();
    }
    this.isActive = false;
  }
  updateContent() {
    if (this.hintContentEl && this.slotWrapperEl) {
      this.hintContentEl.innerHTML = this.slotWrapperEl.innerHTML;
    }
  }
  render() {
    const block = BEM.block('hint');
    const elIcon = block.element('icon');
    const elContent = block.element('content');
    const elButtons = elContent.element('buttons');
    const padding = this.isMobile ? 0 : 8;
    const offsetY = this.isMobile ? 0 : 16;
    const TriggerIcon = () => {
      return (h("bal-icon", { class: Object.assign(Object.assign({}, elIcon.class()), { 'data-test-hint-trigger': true }), "bal-popover-trigger": true, "aria-haspopup": "true", role: "button", name: "info-circle", onClick: () => this.toggle() }));
    };
    const HintContent = () => {
      return (h("div", { class: Object.assign(Object.assign({}, elContent.class()), { 'data-test-hint-content': true }) }, h("div", { ref: el => (this.hintContentEl = el) }), h("bal-button-group", { class: Object.assign(Object.assign({}, elButtons.class()), elButtons.modifier('is-hidden-desktop').class(this.small)) }, h("bal-button", { class: "data-test-hint-close", color: "info", onClick: () => this.dismiss() }, this.closeLabel ? this.closeLabel : this.innerCloseLabel))));
    };
    const MobileOverlay = () => {
      const elOverlay = block.element('overlay');
      return (h("div", { class: Object.assign({}, elOverlay.class()) }, h(TriggerIcon, null), h("div", { class: Object.assign(Object.assign({}, elOverlay.element('content').class()), elOverlay.element('content').modifier('active').class(this.isActive)) }, h(HintContent, null))));
    };
    const Popover = () => {
      return (h("div", { class: Object.assign({}, block.element('popover').class()) }, h("bal-popover", { hint: true, position: "right", offsetX: 0, offsetY: offsetY, padding: padding, ref: el => (this.popoverElement = el), onBalChange: this.onPopoverChange }, h(TriggerIcon, null), h("bal-popover-content", { color: "grey" }, h(HintContent, null)))));
    };
    const HintElement = this.isMobile ? MobileOverlay : Popover;
    return (h(Host, { class: Object.assign({}, block.class()) }, h(HintElement, null), h("div", { ref: el => (this.slotWrapperEl = el), style: { display: 'none' } }, h("slot", null))));
  }
  get element() { return this; }
}, [4, "bal-hint", {
    "closeLabel": [1, "close-label"],
    "small": [4],
    "isActive": [32],
    "innerCloseLabel": [32],
    "isMobile": [32],
    "toggle": [64],
    "present": [64],
    "dismiss": [64]
  }, [[9, "resize", "resizeHandler"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-hint", "bal-button", "bal-button-group", "bal-icon", "bal-popover", "bal-popover-content", "bal-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-hint":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Hint);
      }
      break;
    case "bal-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-button-group":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-popover":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-popover-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { Hint as H, defineCustomElement as d };
