import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { B as BEM } from './bem.js';
import { o as observeItems } from './observer.js';
import { d as defineCustomElement$6 } from './bal-button2.js';
import { d as defineCustomElement$5 } from './bal-icon2.js';
import { d as defineCustomElement$4 } from './bal-pagination2.js';
import { d as defineCustomElement$3 } from './bal-spinner2.js';
import { d as defineCustomElement$2 } from './bal-text2.js';

const ImageSlider = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.xPosition = 0;
    this.slideIndex = 1;
    /**
     * value to set the images aspect ratio
     */
    this.aspectRatio = '16by9';
    /**
     * Set the slide to switch to
     * @param {number} slide :Set to switch to.
     */
    this.setSlide = (slide) => {
      const container = this.getImageContainer();
      const slideWidth = this.images[0].clientWidth;
      if (container && slide >= 0 && slide <= this.images.length) {
        this.slideIndex = slide;
        container.style.transitionDuration = '1.2s';
        container.style.transitionTimingFunction = 'cubic-bezier(0.23, 0.93, 0.13, 1)';
        container.style.transform = `translate(-${(this.slideIndex - 1) * slideWidth}px)`;
      }
    };
  }
  async resizeHandler() {
    this.setSlide(this.slideIndex);
  }
  connectedCallback() {
    this.mutationO = observeItems(this.el, 'bal-image-slider-item', () => this.updateImages());
    this.updateImages();
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  touchStart(event) {
    const imageContainer = this.getSliderContainer();
    if (imageContainer === null || imageContainer === void 0 ? void 0 : imageContainer.contains(event.target)) {
      this.xPosition = event.touches[0].pageX;
    }
  }
  touchEnd(event) {
    const imageContainer = this.getSliderContainer();
    if (imageContainer === null || imageContainer === void 0 ? void 0 : imageContainer.contains(event.target)) {
      if (event.changedTouches[0].pageX < this.xPosition) {
        this.setSlide(this.slideIndex + 1);
      }
      else {
        this.setSlide(this.slideIndex - 1);
      }
    }
  }
  getChildItems() {
    return Array.from(this.el.querySelectorAll('bal-image-slider-item'));
  }
  getSliderContainer() {
    return this.el.querySelector('.bal-image-slider__container');
  }
  getImageContainer() {
    return this.el.querySelector('.bal-image-slider__container__images');
  }
  updateImages() {
    this.images = this.getChildItems();
  }
  render() {
    const block = BEM.block('image-slider');
    const container = block.element('container');
    const containerImages = container.element('images');
    return (h(Host, { class: Object.assign({}, block.class()) }, h("div", { class: Object.assign(Object.assign({}, container.class()), container.modifier(`is-${this.aspectRatio}`).class()) }, h("div", { class: Object.assign({}, containerImages.class()) }, h("slot", null))), h("bal-pagination", { interface: "small", totalPages: this.images.length, value: this.slideIndex, onBalChange: ev => {
        this.setSlide(ev.detail);
      } })));
  }
  get el() { return this; }
}, [4, "bal-image-slider", {
    "aspectRatio": [1, "aspect-ratio"],
    "slideIndex": [32],
    "images": [32]
  }, [[9, "resize", "resizeHandler"], [1, "touchstart", "touchStart"], [1, "touchend", "touchEnd"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-image-slider", "bal-button", "bal-icon", "bal-pagination", "bal-spinner", "bal-text"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-image-slider":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ImageSlider);
      }
      break;
    case "bal-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-pagination":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-text":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalImageSlider = ImageSlider;
const defineCustomElement = defineCustomElement$1;

export { BalImageSlider, defineCustomElement };
