import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$1 } from './bal-list-item-content2.js';

const ListItemAccordionBody = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.contentHeight = '0px';
    /**
     * If `true` the body will be open and visible
     */
    this.open = false;
    /**
     * Sets justify-content of the items to start, center, end, or space-between. Default is start.
     */
    this.contentAlignment = 'start';
  }
  async resizeHandler() {
    this.calcContentHeight();
  }
  componentDidRender() {
    setTimeout(() => {
      this.calcContentHeight();
    }, 10);
  }
  async getContentHeight() {
    const inner = this.el.querySelector('bal-list-item-content');
    if (inner) {
      return inner.scrollHeight;
    }
    return 0;
  }
  getAccordionGroupItems() {
    return Array.from(document.body.querySelectorAll('bal-list-item-accordion-body')).filter(accordionBody => accordionBody.accordionGroup === this.accordionGroup);
  }
  setContentHeight(height) {
    this.contentHeight = height + 'px';
    const parent = this.el.closest('.bal-list__item__accordion-body__parent');
    const parentHeight = parent ? parent.scrollHeight : 0;
    const parentIsThereAndIsOpen = parent && parentHeight > 0 && parent.open;
    if (parentIsThereAndIsOpen && this.open) {
      parent.style.maxHeight = parentHeight + height + 'px';
    }
  }
  get areWeInAGroup() {
    return this.accordionGroup !== '' && this.accordionGroup !== undefined;
  }
  async calcContentHeight() {
    let height = await this.getContentHeight();
    if (this.areWeInAGroup) {
      const items = this.getAccordionGroupItems();
      const heights = [];
      for (let index = 0; index < items.length; index++) {
        const element = items[index];
        heights.push(await element.getContentHeight());
      }
      const maxHeight = Math.max(...heights);
      height = maxHeight;
    }
    this.setContentHeight(height);
  }
  render() {
    return (h(Host, { class: {
        'bal-list__item': true,
        'bal-list__item__accordion-body': true,
        'bal-list__item__accordion-body--open': this.open,
      }, style: { maxHeight: this.open ? this.contentHeight : '0' } }, h("bal-list-item-content", { style: {
        minHeight: this.areWeInAGroup ? this.contentHeight : 'inherit',
        height: this.areWeInAGroup ? this.contentHeight : 'inherit',
      }, contentAlignment: this.contentAlignment }, h("slot", null))));
  }
  get el() { return this; }
}, [4, "bal-list-item-accordion-body", {
    "open": [4],
    "accordionGroup": [1, "accordion-group"],
    "contentAlignment": [1, "content-alignment"],
    "contentHeight": [32],
    "getContentHeight": [64]
  }, [[9, "resize", "resizeHandler"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-list-item-accordion-body", "bal-list-item-content"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-list-item-accordion-body":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ListItemAccordionBody);
      }
      break;
    case "bal-list-item-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ListItemAccordionBody as L, defineCustomElement as d };
