import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { B as BEM } from './bem.js';

const ListItem = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balNavigate = createEvent(this, "balNavigate", 7);
    /**
     * If `true` the list item can be hovered
     */
    this.disabled = false;
    /**
     * If `true` the list item shows that it is clickable
     */
    this.clickable = false;
    /**
     * If `true` the list item has a selected theme
     */
    this.selected = false;
    /**
     * If `true` the list item can be used as a accordion
     */
    this.accordion = false;
    /**
     * If `true` the list item can be used as an accordion inside another accordion
     */
    this.subAccordionItem = false;
    /**
     * Specifies the URL of the page the link goes to
     */
    this.href = '';
    /**
     * Specifies where to open the linked document
     */
    this.target = '_self';
  }
  connectedCallback() {
    const accordionHead = this.findAccordionHead();
    if (accordionHead) {
      accordionHead.addEventListener('balAccordionChange', (event) => this.updateState(event.detail));
    }
  }
  disconnectedCallback() {
    const accordionHead = this.findAccordionHead();
    if (accordionHead) {
      accordionHead.removeEventListener('balAccordionChange', (event) => this.updateState(event.detail));
    }
  }
  findAccordionHead() {
    return this.el.querySelector('bal-list-item-accordion-head');
  }
  findAccordionBody() {
    return this.el.querySelector('bal-list-item-accordion-body');
  }
  updateState(isAccordionOpen) {
    const accordionBody = this.findAccordionBody();
    if (accordionBody) {
      accordionBody.open = isAccordionOpen;
    }
  }
  render() {
    const itemEl = BEM.block('list').element('item');
    const triggerEl = itemEl.element('trigger');
    const basicClasses = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, itemEl.class()), itemEl.modifier('disabled').class(this.disabled)), itemEl.modifier('selected').class(this.selected)), itemEl.modifier('accordion').class(this.accordion)), itemEl.modifier('sub-accordion').class(this.subAccordionItem)), itemEl
      .modifier('clickable')
      .class(!this.disabled && (this.clickable || this.href.length > 0 || this.accordion)));
    if (this.href.length > 0 && !this.disabled) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) }, h("a", { class: Object.assign({}, triggerEl.class()), href: this.href, target: this.target, onClick: (event) => {
          this.balNavigate.emit(event);
        } }, h("slot", null))));
    }
    if (this.clickable) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) }, h("button", { class: Object.assign({}, triggerEl.class()), disabled: this.disabled, onClick: (event) => {
          this.balNavigate.emit(event);
        } }, h("slot", null))));
    }
    if (this.accordion) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses), onClick: (event) => {
          this.balNavigate.emit(event);
        } }, h("div", { class: Object.assign({}, triggerEl.class()) }, h("slot", null))));
    }
    return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) }, h("div", { class: Object.assign({}, triggerEl.class()) }, h("slot", null))));
  }
  get el() { return this; }
}, [4, "bal-list-item", {
    "disabled": [4],
    "clickable": [4],
    "selected": [4],
    "accordion": [4],
    "subAccordionItem": [4, "sub-accordion-item"],
    "href": [1],
    "target": [1]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-list-item"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-list-item":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ListItem);
      }
      break;
  } });
}

export { ListItem as L, defineCustomElement as d };
