import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as deepReady } from './helpers.js';
import { B as BEM } from './bem.js';

const NavbarMenu = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.isMenuActive = false;
    /**
     * @internal
     * Defines the type of navbar. App is used for almost every web applications
     * like the portal app. For our sales funnel we recommend to use the simple navbar.
     * Meta and main are used for the website.
     */
    this.interface = 'app';
  }
  /**
   * @internal - If the menu is open it closes it and the other way around.
   */
  async toggle(isMenuActive) {
    this.isMenuActive = isMenuActive;
    const tabsElement = this.element.querySelector('bal-tabs');
    if (tabsElement) {
      await deepReady(tabsElement);
      tabsElement.renderLine();
    }
  }
  render() {
    const menuEl = BEM.block('navbar').element('menu');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign({}, menuEl.class()), menuEl.modifier('active').class(this.isMenuActive)), menuEl.modifier(`context-${this.interface}`).class()) }, h("slot", null)));
  }
  get element() { return this; }
}, [4, "bal-navbar-menu", {
    "interface": [1],
    "isMenuActive": [32],
    "toggle": [64]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-navbar-menu"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-navbar-menu":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, NavbarMenu);
      }
      break;
  } });
}

const BalNavbarMenu = NavbarMenu;
const defineCustomElement = defineCustomElement$1;

export { BalNavbarMenu, defineCustomElement };
