import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { B as BEM } from './bem.js';

const Navbar = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * It `true` the navbar has a white background. Always use the blue header.
     */
    this.light = false;
    /**
     * Defines the type of navbar. App is used for almost every web applications
     * like the portal app. For our sales funnel we recommend to use the simple navbar.
     * Meta and main are used for the website.
     */
    this.interface = 'app';
    /**
     * Sets the content content width with the regular container classes
     */
    this.container = '';
  }
  interfaceHandler() {
    this.updateProps(['bal-navbar-brand', 'bal-navbar-menu', 'bal-navbar-menu-start', 'bal-navbar-menu-end'], 'interface');
  }
  componentWillLoad() {
    this.interfaceHandler();
  }
  updateProps(selectors, key) {
    const value = this[key];
    if (value !== undefined) {
      this.notifyComponents(selectors, input => (input[key] = value));
    }
  }
  notifyComponents(selectors, callback) {
    const components = this.element.querySelectorAll(selectors.join(', '));
    components.forEach(c => callback(c));
  }
  render() {
    const navbarEl = BEM.block('navbar');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign({}, navbarEl.class()), navbarEl.modifier(`context-${this.interface}`).class()), navbarEl.modifier(`is-light`).class(this.light)) }, h("nav", { role: "navigation", "aria-label": "main navigation", class: {
        container: true,
        [`is-${this.container}`]: this.container !== '',
      } }, h("slot", null))));
  }
  get element() { return this; }
  static get watchers() { return {
    "interface": ["interfaceHandler"]
  }; }
}, [4, "bal-navbar", {
    "light": [4],
    "interface": [1],
    "container": [1]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-navbar"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-navbar":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Navbar);
      }
      break;
  } });
}

const BalNavbar = Navbar;
const defineCustomElement = defineCustomElement$1;

export { BalNavbar, defineCustomElement };
