import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { o as observeLevels } from './level.utils.js';
import { B as BEM } from './bem.js';
import { i as isPlatform } from './platform.js';
import { i as isBrowser } from './browser.js';
import { B as BodyScrollBlocker } from './toggle-scrolling-body.js';
import { s as stopEventBubbling } from './form-input.helpers.js';
import { d as defineCustomElement$y } from './bal-badge2.js';
import { d as defineCustomElement$x } from './bal-button2.js';
import { d as defineCustomElement$w } from './bal-card2.js';
import { d as defineCustomElement$v } from './bal-card-content2.js';
import { d as defineCustomElement$u } from './bal-checkbox2.js';
import { d as defineCustomElement$t } from './bal-close2.js';
import { d as defineCustomElement$s } from './bal-heading2.js';
import { d as defineCustomElement$r } from './bal-icon2.js';
import { d as defineCustomElement$q } from './bal-list2.js';
import { d as defineCustomElement$p } from './bal-list-item2.js';
import { d as defineCustomElement$o } from './bal-list-item-accordion-body2.js';
import { d as defineCustomElement$n } from './bal-list-item-accordion-head2.js';
import { d as defineCustomElement$m } from './bal-list-item-content2.js';
import { d as defineCustomElement$l } from './bal-list-item-icon2.js';
import { d as defineCustomElement$k } from './bal-list-item-title2.js';
import { d as defineCustomElement$j } from './bal-logo2.js';
import { d as defineCustomElement$i } from './bal-navigation-main2.js';
import { d as defineCustomElement$h } from './bal-navigation-main-body2.js';
import { d as defineCustomElement$g } from './bal-navigation-main-head2.js';
import { d as defineCustomElement$f } from './bal-navigation-menu2.js';
import { d as defineCustomElement$e } from './bal-navigation-menu-list2.js';
import { d as defineCustomElement$d } from './bal-navigation-menu-list-item2.js';
import { d as defineCustomElement$c } from './bal-navigation-meta2.js';
import { d as defineCustomElement$b } from './bal-navigation-meta-end2.js';
import { d as defineCustomElement$a } from './bal-navigation-meta-start2.js';
import { d as defineCustomElement$9 } from './bal-popover2.js';
import { d as defineCustomElement$8 } from './bal-popover-content2.js';
import { d as defineCustomElement$7 } from './bal-select2.js';
import { d as defineCustomElement$6 } from './bal-select-option2.js';
import { d as defineCustomElement$5 } from './bal-spinner2.js';
import { d as defineCustomElement$4 } from './bal-tab-item2.js';
import { d as defineCustomElement$3 } from './bal-tabs2.js';
import { d as defineCustomElement$2 } from './bal-tag2.js';

const Navigation = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.previousY = 0;
    this.bodyScrollBlocker = BodyScrollBlocker();
    this.mainMobileHeight = '';
    this.isMetaHidden = false;
    this.levels = [];
    this.selectedMetaIndex = 0;
    this.selectedMainIndex = 0;
    this.isMainBodyOpen = false;
    this.selectedMetaValue = '';
    this.selectedMainValue = '';
    this.isTouch = isPlatform('touch');
    /**
     * Defines if the animation should be active
     */
    this.logoAnimated = true;
    /**
     * Path to the logo-image
     */
    this.logoPath = '/';
    /**
     * Aria label for the meta-navigation-wrapper
     */
    this.ariaLabelMeta = '';
    /**
     * Aria label for the main-navigation-wrapper
     */
    this.ariaLabelMain = '';
    this.bodyOffset = 0;
    this.listenToPopoverChangeEvent = async (event) => {
      const customEvent = event;
      const isNavPopoverOpen = customEvent.detail;
      if (isNavPopoverOpen) {
        this.bodyScrollBlocker.block();
      }
      else {
        this.bodyScrollBlocker.allow();
      }
      if (isNavPopoverOpen) {
        this.isMainBodyOpen = false;
      }
    };
    this.onBurgerButtonClick = async () => {
      this.dismissPopover();
      this.isMainBodyOpen = !this.isMainBodyOpen;
      if (this.isMainBodyOpen) {
        this.bodyScrollBlocker.block();
      }
      else {
        this.bodyScrollBlocker.allow();
      }
    };
    this.onAccordionClick = (event) => {
      stopEventBubbling(event);
      clearTimeout(this.closeOtherAccordionsTimer);
      const target = event.target;
      const isMainAccordionItem = !target.subAccordionItem;
      const closeOtherAccordions = (selector, element) => {
        const items = element.querySelectorAll(selector);
        items.forEach(item => {
          if (item !== target) {
            const accordionHeadEl = item.querySelector('bal-list-item-accordion-head');
            if (accordionHeadEl) {
              accordionHeadEl.accordionOpen = false;
            }
          }
        });
      };
      if (isMainAccordionItem) {
        closeOtherAccordions('bal-list-item.bal-nav__main-mobile__main-accordion', this.el);
        this.closeOtherAccordionsTimer = setTimeout(() => {
          closeOtherAccordions('bal-list-item.is-sub-accordion-item', this.el);
        }, 300);
      }
      else {
        const parent = target.closest('bal-list-item.bal-nav__main-mobile__main-accordion');
        if (parent) {
          closeOtherAccordions('bal-list-item.is-sub-accordion-item', parent);
        }
      }
    };
    this.onMainTabChange = (event) => {
      const isMainNavOpen = event.detail !== '';
      if (isBrowser('touch')) {
        if (isMainNavOpen) {
          this.isMetaHidden = false;
          this.bodyScrollBlocker.block();
        }
        else {
          this.bodyScrollBlocker.allow();
        }
      }
    };
  }
  async clickOnOutside(event) {
    var _a, _b;
    if (isPlatform('desktop')) {
      if (!((_a = this.mainNavElement) === null || _a === void 0 ? void 0 : _a.contains(event.target)) && this.isMainBodyOpen) {
        this.isMainBodyOpen = false;
        this.selectedMainValue = '';
      }
    }
    if (isPlatform('touch')) {
      if ((_b = this.metaMobileActionsElement) === null || _b === void 0 ? void 0 : _b.contains(event.target)) {
        this.isMainBodyOpen = false;
      }
    }
  }
  get metaMobileActionsElement() {
    return this.el.querySelector('.bal-nav__metamobile__actions');
  }
  get metaDesktopEndElement() {
    return this.el.querySelector('bal-navigation-meta-end');
  }
  async resizeHandler() {
    this.isMetaHidden = false;
    this.mainMobileHeight = this.getMaxHeight();
    if (this.isTouch !== isPlatform('touch')) {
      this.isMainBodyOpen = false;
      this.selectedMainValue = '';
      this.isTouch = isPlatform('touch');
    }
  }
  async orientationHandler() {
    this.isMainBodyOpen = false;
    this.dismissPopover();
  }
  handleScroll(_event) {
    if (isPlatform('desktop') && !this.bodyScrollBlocker.isBlocked()) {
      const maxScrollHeight = document.body.scrollHeight - document.body.clientHeight;
      const isOnTop = 0 >= window.scrollY;
      const isOverViewportTop = 0 > window.scrollY;
      const isOverViewportBottom = maxScrollHeight <= window.scrollY;
      const didMoveDownwards = window.scrollY > this.previousY;
      this.isMetaHidden = !isOnTop && (didMoveDownwards || isOverViewportBottom || isOverViewportTop);
      this.previousY = window.scrollY;
    }
  }
  async connectedCallback() {
    this.selectedMetaValue = this.metaValue;
    await this.readSubLevels();
    this.updateIndexes();
    this.mutationO = observeLevels(this.el, 'bal-navigation-levels', () => this.readSubLevels());
  }
  disconnectedCallback() {
    var _a, _b;
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
    (_a = this.metaMobileActionsElement) === null || _a === void 0 ? void 0 : _a.removeEventListener('balChange', this.listenToPopoverChangeEvent);
    (_b = this.metaDesktopEndElement) === null || _b === void 0 ? void 0 : _b.removeEventListener('balChange', this.listenToPopoverChangeEvent);
  }
  componentDidLoad() {
    var _a, _b;
    this.previousY = window.scrollY;
    this.mainMobileHeight = this.getMaxHeight();
    (_a = this.metaMobileActionsElement) === null || _a === void 0 ? void 0 : _a.addEventListener('balChange', this.listenToPopoverChangeEvent);
    (_b = this.metaDesktopEndElement) === null || _b === void 0 ? void 0 : _b.addEventListener('balChange', this.listenToPopoverChangeEvent);
    this.isTouch = isPlatform('touch');
  }
  componentDidUpdate() {
    this.updateIndexes();
  }
  updateIndexes() {
    var _a;
    if (((_a = this.levels) === null || _a === void 0 ? void 0 : _a.length) > 0) {
      const selectedMetaIndex = this.levels.findIndex(meta => meta.value === this.selectedMetaValue);
      this.selectedMetaIndex = selectedMetaIndex !== -1 ? selectedMetaIndex : 0;
    }
  }
  async readSubLevels() {
    const levelEl = this.el.querySelector('bal-navigation-levels');
    const levels = await (levelEl === null || levelEl === void 0 ? void 0 : levelEl.getLevelInfos());
    if (levels) {
      this.levels = levels;
    }
  }
  getMaxHeight() {
    return `${(window.innerHeight - 64) / 16}rem`;
  }
  dismissPopover() {
    const popoverElements = this.el.querySelectorAll('bal-popover');
    popoverElements === null || popoverElements === void 0 ? void 0 : popoverElements.forEach(popoverEl => {
      popoverEl.value = false;
    });
  }
  render() {
    var _a, _b;
    const navigationEl = BEM.block('nav');
    const hasLevels = ((_a = this.levels) === null || _a === void 0 ? void 0 : _a.length) > 0;
    return (h(Host, { class: Object.assign(Object.assign({}, navigationEl.class()), { 'bal-nav--transformed': this.isMetaHidden }) }, h("bal-navigation-meta", { class: "is-hidden-touch", "aria-label-meta": this.ariaLabelMeta }, h("bal-navigation-meta-start", null, hasLevels && (h("bal-tabs", { interface: "meta", spaceless: true, inverted: true, value: this.selectedMetaValue }, this.levels.map((meta, index) => {
      return meta.isTabLink ? (h("bal-tab-item", { label: meta.label, value: meta.value, href: meta.link, target: meta.target })) : (h("bal-tab-item", { label: meta.label, value: meta.value, onBalNavigate: ev => {
          meta.onClick(ev.detail);
          this.selectedMetaValue = meta.value;
          this.selectedMetaIndex = index;
          this.isMainBodyOpen = false;
          this.selectedMainValue = '';
        } }));
    })))), h("bal-navigation-meta-end", null, this.levels && h("slot", { name: "meta-actions" }))), h("bal-navigation-main", { class: {
        'is-hidden-touch': true,
        'container': true,
        'bal-nav__main--expanded': this.isMainBodyOpen,
      }, ref: el => {
        this.mainNavElement = el;
      }, "aria-label-main": this.ariaLabelMain }, h("bal-navigation-main-head", { slot: "main-head", class: {
        'is-hidden-mobile': true,
        'bal-nav__main__head--active': this.isMainBodyOpen,
      } }, h("div", null, h("a", { href: this.logoPath, class: "bal-nav__main-head-logo", tabindex: -1 }, h("bal-logo", { color: "blue", animated: this.logoAnimated })), h("bal-tabs", { interface: "navigation", float: "right", fullwidth: true, spaceless: true, value: this.selectedMainValue, onBalChange: this.onMainTabChange }, hasLevels &&
      ((_b = this.levels[this.selectedMetaIndex].subLevels) === null || _b === void 0 ? void 0 : _b.map((main, index) => {
        return main.isTabLink ? (h("bal-tab-item", { label: main.label, value: main.value, href: main.link, target: main.target, onBalNavigate: ev => {
            main.onClick(ev.detail);
            this.selectedMainIndex = index;
            this.isMainBodyOpen = false;
            this.selectedMainValue = main.value;
          } })) : (h("bal-tab-item", { label: main.label, value: main.value, icon: "nav-go-down", onBalNavigate: ev => {
            main.onClick(ev.detail);
            this.selectedMainIndex = index;
            this.isMainBodyOpen = !(ev.target.value === this.selectedMainValue);
            this.selectedMainValue = ev.target.value === this.selectedMainValue ? '' : main.value;
          } }));
      }))))), this.isMainBodyOpen && (h("bal-navigation-main-body", { slot: "main-body" }, this.levels
      .filter((_, index) => index === this.selectedMetaIndex)
      .map(meta => {
      var _a;
      return (_a = meta.subLevels) === null || _a === void 0 ? void 0 : _a.filter((_, mainIndex) => this.selectedMainIndex === mainIndex).map(main => (h("bal-navigation-menu", { "link-href": main.link, "link-name": main.linkLabel, target: main.target, elements: main.subLevels })));
    })))), h("div", { class: "bal-nav__metamobile container" }, h("nav", { role: "navigation", "aria-label": this.ariaLabelMeta }, h("a", { href: this.logoPath, class: "bal-nav__main-mobile__logo", tabindex: -1 }, h("bal-logo", { color: "blue", animated: this.logoAnimated })), h("div", { class: "bal-nav__metamobile__actions" }, h("slot", { name: "meta-actions-mobile" })), h("bal-button", { slot: "burger", "data-testid": "navigation-burger", color: this.isMainBodyOpen ? 'primary' : 'light', square: true, icon: this.isMainBodyOpen ? 'close' : 'menu-bars', onClick: () => this.onBurgerButtonClick() }))), h("div", { class: "bal-nav__main-mobile container", style: {
        '--bal-nav-main-mobile-height': this.mainMobileHeight,
        'display': this.isMainBodyOpen && this.isTouch ? 'block' : 'none',
      } }, h("bal-list", { border: true, "in-main-nav": true, size: "small" }, this.levels.map(meta => {
      var _a;
      return (h("bal-list-item", { accordion: true, onBalNavigate: this.onAccordionClick, class: "bal-nav__main-mobile__main-accordion" }, h("bal-list-item-accordion-head", { icon: "nav-go-down" }, h("bal-list-item-content", null, h("bal-list-item-title", { level: "h4" }, meta.label))), h("bal-list-item-accordion-body", { class: "bal-list__item__accordion-body__parent" }, h("div", null, meta.link && (h("div", { class: "bal-nav__main-mobile__link" }, h("a", { href: meta.link }, meta.linkLabel))), h("bal-list", { border: true, "in-main-nav": true, class: "pt-4", size: "small" }, (_a = meta.subLevels) === null || _a === void 0 ? void 0 : _a.map(main => {
        return main.isTabLink ? (h("bal-list-item", { "sub-accordion-item": true, href: main.link, target: main.target }, h("bal-list-item-content", null, h("bal-list-item-title", { level: "h5" }, main.label)))) : (h("bal-list-item", { accordion: true, "sub-accordion-item": true }, h("bal-list-item-accordion-head", { icon: "nav-go-down" }, h("bal-list-item-content", null, h("bal-list-item-title", { level: "h5" }, main.label))), h("bal-list-item-accordion-body", null, h("bal-navigation-menu", { "link-href": main.link, "link-name": main.linkLabel, target: main.target, elements: main.subLevels }))));
      }))))));
    }))), h("div", { class: "bal-nav__foot-mobile", style: {
        display: this.isMainBodyOpen && this.isTouch ? 'block' : 'none',
      } }, h("slot", { name: "meta-mobile-foot" })), h("slot", null)));
  }
  get el() { return this; }
}, [4, "bal-navigation", {
    "logoAnimated": [4, "logo-animated"],
    "logoPath": [1, "logo-path"],
    "ariaLabelMeta": [1, "aria-label-meta"],
    "ariaLabelMain": [1, "aria-label-main"],
    "metaValue": [1, "meta-value"],
    "mainMobileHeight": [32],
    "isMetaHidden": [32],
    "levels": [32],
    "selectedMetaIndex": [32],
    "selectedMainIndex": [32],
    "isMainBodyOpen": [32],
    "selectedMetaValue": [32],
    "selectedMainValue": [32],
    "isTouch": [32]
  }, [[4, "click", "clickOnOutside"], [9, "resize", "resizeHandler"], [8, "orientationchange", "orientationHandler"], [8, "scroll", "handleScroll"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-navigation", "bal-badge", "bal-button", "bal-card", "bal-card-content", "bal-checkbox", "bal-close", "bal-heading", "bal-icon", "bal-list", "bal-list-item", "bal-list-item-accordion-body", "bal-list-item-accordion-head", "bal-list-item-content", "bal-list-item-icon", "bal-list-item-title", "bal-logo", "bal-navigation-main", "bal-navigation-main-body", "bal-navigation-main-head", "bal-navigation-menu", "bal-navigation-menu-list", "bal-navigation-menu-list-item", "bal-navigation-meta", "bal-navigation-meta-end", "bal-navigation-meta-start", "bal-popover", "bal-popover-content", "bal-select", "bal-select-option", "bal-spinner", "bal-tab-item", "bal-tabs", "bal-tag"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-navigation":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Navigation);
      }
      break;
    case "bal-badge":
      if (!customElements.get(tagName)) {
        defineCustomElement$y();
      }
      break;
    case "bal-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$x();
      }
      break;
    case "bal-card":
      if (!customElements.get(tagName)) {
        defineCustomElement$w();
      }
      break;
    case "bal-card-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$v();
      }
      break;
    case "bal-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$u();
      }
      break;
    case "bal-close":
      if (!customElements.get(tagName)) {
        defineCustomElement$t();
      }
      break;
    case "bal-heading":
      if (!customElements.get(tagName)) {
        defineCustomElement$s();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$r();
      }
      break;
    case "bal-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$q();
      }
      break;
    case "bal-list-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$p();
      }
      break;
    case "bal-list-item-accordion-body":
      if (!customElements.get(tagName)) {
        defineCustomElement$o();
      }
      break;
    case "bal-list-item-accordion-head":
      if (!customElements.get(tagName)) {
        defineCustomElement$n();
      }
      break;
    case "bal-list-item-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$m();
      }
      break;
    case "bal-list-item-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$l();
      }
      break;
    case "bal-list-item-title":
      if (!customElements.get(tagName)) {
        defineCustomElement$k();
      }
      break;
    case "bal-logo":
      if (!customElements.get(tagName)) {
        defineCustomElement$j();
      }
      break;
    case "bal-navigation-main":
      if (!customElements.get(tagName)) {
        defineCustomElement$i();
      }
      break;
    case "bal-navigation-main-body":
      if (!customElements.get(tagName)) {
        defineCustomElement$h();
      }
      break;
    case "bal-navigation-main-head":
      if (!customElements.get(tagName)) {
        defineCustomElement$g();
      }
      break;
    case "bal-navigation-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$f();
      }
      break;
    case "bal-navigation-menu-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$e();
      }
      break;
    case "bal-navigation-menu-list-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "bal-navigation-meta":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "bal-navigation-meta-end":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "bal-navigation-meta-start":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "bal-popover":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "bal-popover-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "bal-select":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "bal-select-option":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-tab-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-tabs":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalNavigation = Navigation;
const defineCustomElement = defineCustomElement$1;

export { BalNavigation, defineCustomElement };
