import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { B as BEM } from './bem.js';

const PopoverContent = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * If `true` the popover has no padding space.
     */
    this.spaceless = false;
    /**
     * Limit the height of the popover content. Pass the amount of pixel.
     */
    this.scrollable = 0;
    /**
     * Define the max width of the popover content.
     */
    this.contentWidth = 0;
    /**
     * Define the min width of the popover content.
     */
    this.contentMinWidth = 0;
    /**
     * Defines background color of the content.
     */
    this.color = 'white';
    /**
     * If `true` the content has a min width of 100%.
     */
    this.expanded = false;
    /**
     * Defines border-radius of popover content.
     */
    this.radius = 'normal';
    /**
     * If `true` the popover does not have the shadow
     */
    this.noShadow = false;
    /**
     * If `true` the content will have a divider line on top
     */
    this.mobileTop = false;
    this.contentHeightOnTop = 0;
  }
  async resizeHandler() {
    this.contentHeightOnTop = window.innerHeight - 64;
  }
  get innerStyle() {
    let scrollable = {};
    if (this.scrollable > 0) {
      scrollable = {
        'max-height': `${this.scrollable}px`,
        'overflow': 'auto',
      };
    }
    return Object.assign({}, scrollable);
  }
  get contentStyle() {
    let contentWidth = {};
    let contentMinWidth = {};
    const contentHeightOnTopNav = {
      '--bal-popover-content-height-top-nav': `${this.contentHeightOnTop / 16}rem`,
    };
    if (this.contentWidth > 0) {
      contentWidth = { 'max-width': `${this.contentWidth}px` };
    }
    if (this.contentMinWidth > 0) {
      contentMinWidth = { 'min-width': `${this.contentMinWidth}px` };
    }
    return Object.assign(Object.assign(Object.assign({}, contentWidth), contentMinWidth), contentHeightOnTopNav);
  }
  componentDidLoad() {
    this.contentHeightOnTop = window.innerHeight - 64;
  }
  render() {
    const block = BEM.block('popover').element('content');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('expanded').class(this.expanded)), block.modifier('spaceless').class(this.spaceless)), block.modifier('no-shadow').class(this.noShadow)), block.modifier(`radius-${this.radius}`).class()), block.modifier(`color-${this.color}`).class()), block.modifier('on-top').class(this.mobileTop)), role: "tooltip", style: this.contentStyle }, h("div", { class: Object.assign({}, block.element('inner').class()), style: this.innerStyle }, h("slot", null)), h("div", { class: Object.assign({}, block.element('arrow').class()), "data-popper-arrow": true })));
  }
  get el() { return this; }
}, [4, "bal-popover-content", {
    "spaceless": [4],
    "scrollable": [2],
    "contentWidth": [2, "content-width"],
    "contentMinWidth": [2, "content-min-width"],
    "color": [1],
    "expanded": [4],
    "radius": [1],
    "noShadow": [4, "no-shadow"],
    "mobileTop": [4, "mobile-top"],
    "contentHeightOnTop": [32]
  }, [[9, "resize", "resizeHandler"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-popover-content"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-popover-content":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PopoverContent);
      }
      break;
  } });
}

export { PopoverContent as P, defineCustomElement as d };
