import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { i as inputHandleFocus, a as inputHandleBlur, s as stopEventBubbling, b as inputSetFocus, c as inputSetBlur } from './form-input.helpers.js';
import { i as isDescendant, e as inheritAttributes } from './helpers.js';
import { B as BEM } from './bem.js';

const Radio = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balFocus = createEvent(this, "balFocus", 7);
    this.balBlur = createEvent(this, "balBlur", 7);
    this.balChange = createEvent(this, "balChange", 7);
    this.balClick = createEvent(this, "balClick", 7);
    this.inputId = `bal-rb-${radioIds++}`;
    this.inheritedAttributes = {};
    this.hasFocus = false;
    this.hasLabel = true;
    /**
     * @deprecated If `true` the radio has no label
     */
    this.isEmpty = false;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * If `true` the radio has no label
     */
    this.labelHidden = false;
    /**
     * If `true` the control is no padding
     */
    this.flat = false;
    /**
     * Defines the layout of the radio button
     */
    this.interface = 'radio';
    /**
     * Value of the radio item, if checked the whole group has this value.
     */
    this.value = '';
    /**
     * If `true`, the radio is selected.
     */
    this.checked = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * If `true`, the value will not be send with a form submit
     */
    this.hidden = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    this.updateState = () => {
      if (this.group) {
        this.checked = this.group.value === this.value;
      }
    };
    this.onInputFocus = (ev) => inputHandleFocus(this, ev);
    this.onInputBlur = (ev) => inputHandleBlur(this, ev);
    this.onClick = (ev) => {
      const element = ev.target;
      if (element.href) {
        return;
      }
      if (element.nodeName !== 'INPUT' && !this.disabled && !this.readonly) {
        this.balChange.emit(this.checked);
        this.balClick.emit(ev);
        ev.preventDefault();
      }
      else {
        stopEventBubbling(ev);
      }
    };
  }
  isEmptyHandler() {
    this.labelHidden = this.isEmpty;
    console.warn('[DEPRECATED] - Use label-hidden instead');
  }
  listenOnClick(ev) {
    if ((this.disabled || this.readonly) &&
      ev.target &&
      (ev.target === this.el || isDescendant(this.el, ev.target))) {
      stopEventBubbling(ev);
    }
  }
  componentWillLoad() {
    this.inheritedAttributes = inheritAttributes(this.el, ['aria-label', 'tabindex', 'title']);
  }
  connectedCallback() {
    if (this.group) {
      this.updateState();
      this.group.addEventListener('balChange', () => this.updateState());
    }
  }
  disconnectedCallback() {
    if (this.group) {
      this.group.removeEventListener('balChange', () => this.updateState());
    }
  }
  /**
   * Sets the focus on the checkbox input element.
   */
  async setFocus() {
    inputSetFocus(this);
  }
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  async setBlur() {
    inputSetBlur(this);
  }
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement() {
    return Promise.resolve(this.nativeInput);
  }
  get group() {
    return this.el.closest('bal-radio-group');
  }
  render() {
    const block = BEM.block('radio-checkbox');
    const inputEl = block.element('input');
    const labelEl = block.element('label');
    const labelTextEl = labelEl.element('text');
    const value = typeof this.value === 'boolean' ? JSON.stringify(this.value) : this.value;
    return (h(Host, Object.assign({ role: "radio", "aria-checked": `${this.checked}`, "aria-disabled": this.disabled ? 'true' : null, "aria-hidden": this.disabled ? 'true' : null, "aria-focused": this.hasFocus ? 'true' : null, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('radio').class()), block.modifier('select-button').class(this.interface === 'select-button')), block.modifier('focused').class(this.hasFocus)), block.modifier('invalid').class(this.invalid)), block.modifier('checked').class(this.checked)), block.modifier('flat').class(this.flat)), block.modifier('disabled').class(this.disabled || this.readonly)), onClick: this.onClick, onFocus: this.onInputFocus, onBlur: this.onInputBlur }, this.inheritedAttributes), h("input", { class: Object.assign(Object.assign(Object.assign({}, inputEl.class()), inputEl.modifier('select-button').class(this.interface === 'select-button')), { 'data-test-radio-input': true }), type: "radio", id: this.inputId, name: this.name, value: value, checked: this.checked, "aria-checked": `${this.checked}`, disabled: this.disabled, readonly: this.readonly, required: this.required, onFocus: this.onInputFocus, onBlur: this.onInputBlur, ref: inputEl => (this.nativeInput = inputEl) }), h("label", { class: Object.assign(Object.assign(Object.assign(Object.assign({}, labelEl.class()), labelEl.modifier('checked').class(this.checked)), labelEl.modifier('radio').class()), { 'data-test-radio-label': true }), htmlFor: this.inputId }, h("span", { class: Object.assign(Object.assign({}, labelTextEl.class()), labelTextEl.modifier('hidden').class(this.labelHidden)) }, h("slot", null)))));
  }
  get el() { return this; }
  static get watchers() { return {
    "isEmpty": ["isEmptyHandler"]
  }; }
}, [4, "bal-radio", {
    "isEmpty": [4, "is-empty"],
    "name": [1],
    "labelHidden": [4, "label-hidden"],
    "flat": [4],
    "interface": [1],
    "value": [8],
    "checked": [1540],
    "disabled": [4],
    "readonly": [4],
    "required": [4],
    "hidden": [4],
    "invalid": [4],
    "hasFocus": [32],
    "hasLabel": [32],
    "setFocus": [64],
    "setBlur": [64],
    "getInputElement": [64]
  }, [[6, "click", "listenOnClick"]]]);
let radioIds = 0;
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-radio"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-radio":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Radio);
      }
      break;
  } });
}

const BalRadio = Radio;
const defineCustomElement = defineCustomElement$1;

export { BalRadio, defineCustomElement };
