import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { l as lodash_isnil } from './index3.js';
import { d as deepReady, i as isDescendant, f as findItemLabel, h as debounce } from './helpers.js';
import { j as isSpaceKey, a as areArraysEqual, u as isArrowDownKey, v as isArrowUpKey, k as isEnterKey, w as isEscapeKey, x as isBackspaceKey } from './index.esm.js';
import { r as removeValue, p as preventDefault, l as length, g as getValues, i as includes, s as startsWith, a as addValue, f as findLabelByValue, b as findOptionByLabel, v as validateAfterBlur } from './utils.js';
import { s as stopEventBubbling } from './form-input.helpers.js';
import { B as BEM } from './bem.js';
import { d as defineCustomElement$6 } from './bal-checkbox2.js';
import { d as defineCustomElement$5 } from './bal-close2.js';
import { d as defineCustomElement$4 } from './bal-icon2.js';
import { d as defineCustomElement$3 } from './bal-popover2.js';
import { d as defineCustomElement$2 } from './bal-popover-content2.js';
import { d as defineCustomElement$1 } from './bal-tag2.js';

/**
 * lodash 4.0.0 (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright 2012-2016 The Dojo Foundation <http://dojofoundation.org/>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright 2009-2016 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 * Available under MIT license <https://lodash.com/license>
 */

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @type Function
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is correctly classified, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray = Array.isArray;

var lodash_isarray = isArray;

const watchForOptions = (containerEl, tagName, onChange) => {
  /* tslint:disable-next-line */
  if (typeof MutationObserver === 'undefined') {
    return;
  }
  const mutation = new MutationObserver(mutationList => {
    mutationList = mutationList.filter(record => record.target.nodeName === tagName.toUpperCase() || record.target.nodeName === 'bal-select'.toUpperCase());
    if (mutationList.length > 0) {
      onChange(undefined);
    }
  });
  mutation.observe(containerEl, {
    childList: true,
    subtree: true,
    attributes: true,
    characterData: true,
  });
  return mutation;
};

const Select = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balChange = createEvent(this, "balChange", 7);
    this.balClick = createEvent(this, "balClick", 7);
    this.balInput = createEvent(this, "balInput", 7);
    this.balBlur = createEvent(this, "balBlur", 7);
    this.balFocus = createEvent(this, "balFocus", 7);
    this.balCancel = createEvent(this, "balCancel", 7);
    this.balKeyPress = createEvent(this, "balKeyPress", 7);
    this.didInit = false;
    this.inputId = `bal-select-${selectIds++}`;
    this.initialValue = [];
    this.hasFocus = false;
    this.inputValue = '';
    this.focusIndex = 0;
    this.isPopoverOpen = false;
    this.options = new Map();
    this.labelToScrollTo = '';
    this.labelToSelectTo = '';
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * If `true` the component gets a invalid style.
     */
    this.invalid = false;
    /**
     * If `true` the component gets a invalid style.
     */
    this.filter = 'includes';
    /**
     * The tabindex of the control.
     */
    this.balTabindex = 0;
    /**
     * If `true` multiple option can be selected
     */
    this.multiple = false;
    /**
     * @deprecated  Removes the border of the input.
     */
    this.noBorder = false;
    /**
     * Indicates whether the value of the control can be automatically completed by the browser.
     */
    this.autocomplete = 'off';
    /**
     * @deprecated Enables the slide in animation for the option items.
     */
    this.hasMovement = false;
    /**
     * If `true` the user can search by typing into the input field.
     */
    this.typeahead = false;
    /**
     * If `true` the options are a proposal and the user can also create his
     * own value. Can only be used with the typeahead property.
     */
    this.selectionOptional = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = false;
    /**
     * If `true`, the user must fill in a value before submitting a form.
     */
    this.required = false;
    /**
     * @deprecated  Set this to `true` when the component is placed on a dark background.
     * Set this to `true` when the component is placed on a dark background.
     */
    this.inverted = false;
    /**
     * Defines the height of the popover list.
     */
    this.scrollable = 250;
    /**
     * Defines if the select is in a loading state.
     */
    this.loading = false;
    /**
     * If `true` the filtering is done outside the component.
     */
    this.remote = false;
    /**
     * Selected option values. Could also be passed as a string, which gets transformed.
     */
    this.value = [];
    this.rawValue = [];
    this.removeValue = (value) => {
      if (!this.disabled) {
        this.rawValue = removeValue(this.rawValue, value);
        if (this.multiple && this.typeahead) {
          this.setFocus();
        }
      }
    };
    /********************************************************
     * EVENT HANDLERS
     ********************************************************/
    this.handleClick = (event) => {
      if (this.disabled || this.readonly) {
        preventDefault(event);
      }
    };
    this.handlePopoverChange = (event) => {
      this.isPopoverOpen = event.detail;
      if (this.isPopoverOpen) {
        this.updateFocus();
      }
      else {
        this.focusIndex = 0;
        if (this.multiple && this.typeahead) {
          this.updateInputValue('');
        }
        this.balBlur.emit();
      }
      event.stopPropagation();
    };
    this.handleInputBlur = (event) => {
      preventDefault(event);
      this.validateAfterBlur();
      this.hasFocus = false;
    };
    this.handleInputFocus = (event) => {
      this.balFocus.emit(event);
      this.hasFocus = true;
    };
    this.handleInputClick = async (event) => {
      var _a, _b, _c;
      stopEventBubbling(event);
      if (this.isChipClicked(event)) {
        return;
      }
      if (this.disabled || this.readonly) {
        preventDefault(event);
      }
      else {
        this.focusIndex = 0;
        this.balClick.emit(event);
        if (this.typeahead) {
          await ((_a = this.popoverElement) === null || _a === void 0 ? void 0 : _a.present());
        }
        else {
          if (this.isPopoverOpen) {
            await ((_b = this.popoverElement) === null || _b === void 0 ? void 0 : _b.dismiss());
          }
          else {
            await ((_c = this.popoverElement) === null || _c === void 0 ? void 0 : _c.present());
          }
        }
      }
    };
    this.handleKeyPress = async (event) => {
      if (!this.isPopoverOpen && isSpaceKey(event)) {
        preventDefault(event);
        await this.open();
      }
      this.balKeyPress.emit(event);
    };
    this.handleInputChange = (event) => {
      if (!this.disabled && !this.readonly) {
        this.inputValue = event.target.value;
      }
    };
    this.handleInput = async (event) => {
      if (!this.disabled && !this.readonly) {
        this.inputValue = event.target.value;
        if (!this.isPopoverOpen) {
          this.popoverElement.present();
        }
        this.focusIndex = 0;
        this.updateFocus();
        preventDefault(event);
        this.balInput.emit(this.inputValue);
      }
    };
    this.handleOptionMouseEnter = (index) => {
      this.focusIndex = index;
    };
  }
  valueWatcher() {
    this.updateRawValue(false);
  }
  rawValueWatcher(newValue, oldValue, isHuman = true) {
    if (!areArraysEqual(newValue, oldValue || [])) {
      this.rawValue = newValue;
      this.syncNativeInput();
      if (this.didInit && isHuman) {
        if (this.multiple) {
          if (lodash_isnil(this.rawValue)) {
            this.balChange.emit([]);
          }
          else {
            this.balChange.emit([...this.rawValue]);
          }
        }
        else {
          if (lodash_isnil(this.rawValue) || length(this.rawValue) === 0) {
            this.balChange.emit(undefined);
          }
          else {
            this.balChange.emit(this.rawValue[0]);
          }
        }
      }
    }
  }
  listenOnClick(event) {
    if (this.disabled && event.target && event.target === this.el) {
      preventDefault(event);
    }
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      if (this.resetHandlerTimer) {
        clearTimeout(this.resetHandlerTimer);
      }
      this.resetHandlerTimer = setTimeout(() => {
        this.value = this.initialValue;
        this.updateRawValue(false);
        this.syncNativeInput();
        if (this.nativeSelectEl) {
          const options = Array.from(this.nativeSelectEl.options);
          options.forEach(o => (o.selected = true));
        }
      }, 0);
    }
  }
  async handleKeyDown(event) {
    if (this.isPopoverOpen) {
      if (isArrowDownKey(event) || isArrowUpKey(event)) {
        preventDefault(event);
        this.navigateWithArrowKey(event);
        this.updateFocus();
      }
      if (isEnterKey(event)) {
        preventDefault(event);
        this.selectedFocusedOption();
      }
      if (isEscapeKey(event)) {
        this.cancel();
      }
      if (isBackspaceKey(event) && this.typeahead && this.multiple) {
        if (this.inputElement.value === '' && length(this.rawValue) > 0) {
          const valuesArray = getValues(this.rawValue);
          this.removeValue(valuesArray[length(this.rawValue) - 1]);
        }
      }
      if (!this.typeahead && event.key.length === 1) {
        this.focusOptionByLabel(event.key);
      }
      if (isSpaceKey(event) && !this.typeahead) {
        preventDefault(event);
      }
    }
    else {
      if (this.hasFocus) {
        if (isArrowDownKey(event) || isArrowUpKey(event)) {
          preventDefault(event);
          await this.open();
        }
        if (!this.typeahead && event.key.length === 1) {
          this.selectOptionByLabel(event.key);
        }
      }
    }
  }
  connectedCallback() {
    const debounceUpdateOptions = debounce(() => this.updateOptions(), 0);
    this.initialValue = this.value;
    debounceUpdateOptions();
    this.mutationO = watchForOptions(this.el, 'bal-select-option', () => {
      debounceUpdateOptions();
    });
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  async waitForOptionsAndThenUpdateRawValues() {
    clearTimeout(this.waitForOptionsAndThenUpdateRawValuesTimer);
    await deepReady(this.el);
    const hasOptions = this.options.size > 0;
    if (hasOptions) {
      this.updateRawValue(false);
    }
    else {
      this.waitForOptionsAndThenUpdateRawValuesTimer = setTimeout(() => this.waitForOptionsAndThenUpdateRawValues(), 10);
    }
  }
  componentWillLoad() {
    this.waitForOptionsAndThenUpdateRawValues();
    if (!lodash_isnil(this.rawValue) && this.options.size > 0 && length(this.rawValue) === 1) {
      const firstOption = this.options.get(this.rawValue[0]);
      if (!lodash_isnil(firstOption)) {
        this.inputValue = firstOption.label;
      }
    }
  }
  componentDidLoad() {
    this.updateRawValue(false);
    if (!this.multiple) {
      this.inputElement.value = this.inputValue;
    }
    this.didInit = true;
  }
  updateOptions() {
    const optionElements = this.getChildOpts();
    const options = new Map();
    for (let index = 0; index < optionElements.length; index++) {
      const element = optionElements[index];
      options.set(element.value, {
        value: element.value,
        label: element.label,
        disabled: element.disabled,
        id: element.for,
        textContent: element.textContent,
        innerHTML: element.innerHTML,
      });
    }
    if (!this.selectionOptional && Array.isArray(this.rawValue)) {
      for (let index = 0; index < this.rawValue.length; index++) {
        const val = this.rawValue[index];
        if (!options.has(val)) {
          this.rawValue = removeValue(this.rawValue, val);
        }
      }
    }
    this.options = new Map(options);
    if (!this.remote) {
      this.syncNativeInput();
      if (this.didInit) {
        this.validateAfterBlur();
      }
    }
  }
  /**
   * Sets the focus on the input element
   */
  async setFocus() {
    clearTimeout(this.setFocusTimer);
    this.setFocusTimer = setTimeout(() => {
      if (this.inputElement && !this.disabled) {
        this.inputElement.focus();
      }
    });
  }
  /**
   * Sets the focus on the input element
   */
  async getValue() {
    return this.rawValue;
  }
  /**
   * Sets the value to `[]`, the input value to ´''´ and the focus index to ´0´.
   */
  async clear() {
    this.focusIndex = 0;
    if (this.inputElement) {
      this.updateInputValue('');
      this.rawValue = [];
      this.value = this.multiple ? [] : '';
    }
  }
  /**
   * Opens the popover
   */
  async open() {
    if (!this.disabled && !this.readonly && !lodash_isnil(this.popoverElement)) {
      await this.popoverElement.present();
    }
  }
  /**
   * Closes the popover
   */
  async close() {
    if (!this.disabled && !this.readonly && !lodash_isnil(this.popoverElement)) {
      this.blurSelect();
    }
  }
  /**
   * Cancel the popover
   */
  async cancel() {
    this.labelToScrollTo = '';
    this.close();
    this.scrollTo(0);
    this.balCancel.emit();
  }
  /**
   * Select option by passed value
   */
  async select(value) {
    const option = this.options.get(value);
    if (!lodash_isnil(option)) {
      this.optionSelected(option);
    }
  }
  /********************************************************
   * GETTERS
   ********************************************************/
  get optionArray() {
    const options = Array.from(this.options, ([_, value]) => value);
    if (!this.typeahead || this.remote) {
      return options;
    }
    return options.filter(option => this.filter === 'includes'
      ? includes(option.textContent, this.inputValue)
      : startsWith(option.textContent, this.inputValue));
  }
  hasOptions() {
    return this.optionArray.length > 0;
  }
  get inputPlaceholder() {
    if (this.multiple) {
      if (length(this.rawValue) < 1) {
        return this.placeholder;
      }
      return undefined;
    }
    else {
      if (!lodash_isnil(this.rawValue) && length(this.rawValue) > 0) {
        return undefined;
      }
    }
    return this.placeholder;
  }
  getChildOpts() {
    return Array.from(this.el.querySelectorAll('bal-select-option'));
  }
  getPopoverContent() {
    return this.popoverElement.querySelector('.bal-popover__content__inner');
  }
  updateFocus() {
    if (this.focusIndex < 0) {
      this.focusIndex = 0;
    }
    const visibleOptions = this.optionArray;
    if (visibleOptions.length > 0) {
      if (visibleOptions.length <= this.focusIndex) {
        this.focusIndex = visibleOptions.length - 1;
      }
      const option = visibleOptions[this.focusIndex];
      if (option && option.id) {
        const focusedElement = this.el.querySelector(`button#${option.id}`);
        if (focusedElement) {
          clearTimeout(this.updateFocusTimer);
          this.updateFocusTimer = setTimeout(() => {
            this.scrollToFocusedOption(focusedElement);
          }, 0);
        }
      }
    }
    else {
      this.focusIndex = 0;
    }
  }
  scrollToFocusedOption(focusedElement) {
    if (focusedElement && this.popoverElement) {
      const popoverContentElement = this.getPopoverContent();
      if (popoverContentElement) {
        // up
        const topOfOption = focusedElement.offsetTop;
        const topOfPopoverContent = popoverContentElement.scrollTop;
        if (topOfOption < topOfPopoverContent) {
          popoverContentElement.scrollTop = topOfOption;
        }
        // down
        const bottomOfOption = focusedElement.offsetTop + focusedElement.clientHeight;
        const bottomOfPopoverContent = popoverContentElement.scrollTop + popoverContentElement.clientHeight;
        if (bottomOfOption > bottomOfPopoverContent) {
          popoverContentElement.scrollTop = popoverContentElement.scrollTop + focusedElement.clientHeight;
        }
      }
    }
  }
  scrollTo(scrollTop) {
    const popoverContentElement = this.getPopoverContent();
    if (popoverContentElement) {
      popoverContentElement.scrollTop = scrollTop;
    }
  }
  selectedFocusedOption() {
    const visibleOptions = this.optionArray;
    if (visibleOptions.length > this.focusIndex) {
      const focusedOption = visibleOptions[this.focusIndex];
      this.optionSelected(focusedOption);
    }
  }
  navigateWithArrowKey(event) {
    if (isArrowDownKey(event)) {
      this.focusIndex = this.focusIndex + 1;
    }
    else {
      if (isArrowUpKey(event)) {
        this.focusIndex = this.focusIndex - 1;
      }
    }
  }
  focusOptionByLabel(key) {
    this.labelToScrollTo = this.labelToScrollTo + key;
    clearTimeout(this.clearScrollToValue);
    this.clearScrollToValue = setTimeout(() => {
      this.scrollToLabel(this.labelToScrollTo);
    }, 600);
  }
  selectOptionByLabel(key) {
    this.labelToSelectTo = this.labelToSelectTo + key;
    clearTimeout(this.clearSelectValue);
    this.clearSelectValue = setTimeout(() => {
      this.selectLabel(this.labelToSelectTo);
      this.labelToSelectTo = '';
    }, 600);
  }
  async selectLabel(label) {
    if (label !== ' ') {
      const option = this.optionArray.find(o => startsWith(o.label || '', label));
      if (!lodash_isnil(option) && option.id) {
        const optionElement = this.el.querySelector(`button#${option.id}`);
        if (!lodash_isnil(optionElement)) {
          const index = this.optionArray.indexOf(option);
          this.focusIndex = index;
          this.select(option.value);
        }
      }
      this.labelToScrollTo = '';
    }
  }
  async scrollToLabel(label) {
    if (label !== ' ') {
      const option = this.optionArray.find(o => startsWith(o.label || '', label));
      if (!lodash_isnil(option) && option.id) {
        const optionElement = this.el.querySelector(`button#${option.id}`);
        if (!lodash_isnil(optionElement)) {
          const index = this.optionArray.indexOf(option);
          this.focusIndex = index;
          this.scrollTo(optionElement.offsetTop);
        }
      }
      this.labelToScrollTo = '';
    }
  }
  /********************************************************
   * VALUE & FILTER & SELECTION
   ********************************************************/
  updateRawValue(isHuman = true) {
    const oldValue = [...(this.rawValue || [])];
    let newValue = [];
    if (!lodash_isnil(this.value)) {
      if (lodash_isarray(this.value)) {
        newValue = [...this.value.filter(v => !lodash_isnil(v))];
      }
      else {
        if (this.value.split('').includes(',')) {
          newValue = [...this.value.split(',').map(v => v.trim())];
        }
        else {
          newValue = [this.value];
        }
      }
    }
    // trigger the raw value change
    this.rawValueWatcher(newValue, oldValue, isHuman);
  }
  blurSelect() {
    this.popoverElement.dismiss();
  }
  optionSelected(selectedOption) {
    const valuesArray = getValues(this.rawValue);
    const isAlreadySelected = valuesArray.some(v => v === selectedOption.value);
    this.updateValue(selectedOption.value, !isAlreadySelected);
    if (!this.multiple) {
      this.blurSelect();
    }
    else {
      if (this.typeahead) {
        this.setFocus();
      }
    }
  }
  updateValue(newValue, isSelected = true) {
    if (this.multiple) {
      if (isSelected) {
        this.rawValue = addValue(this.rawValue, newValue, this.multiple);
      }
      else {
        this.rawValue = removeValue(this.rawValue, newValue);
      }
    }
    else {
      this.rawValue = addValue(this.rawValue, newValue, this.multiple);
      this.updateInputValue(findLabelByValue(this.options, this.rawValue[0]));
    }
  }
  validateAfterBlur() {
    if (this.didInit && !this.multiple) {
      if (this.selectionOptional && this.typeahead) {
        const typedOption = findOptionByLabel(this.options, this.inputElement.value);
        if (typedOption) {
          this.rawValue = [typedOption.value];
        }
        else {
          this.rawValue = [this.inputElement.value];
        }
      }
      else {
        this.rawValue = validateAfterBlur(this.rawValue, this.options, this.inputElement.value);
      }
    }
  }
  updateInputValue(value) {
    if (this.updateInputValueTimer) {
      clearTimeout(this.updateInputValueTimer);
    }
    this.updateInputValueTimer = setTimeout(() => {
      if (!lodash_isnil(this.inputElement)) {
        this.inputElement.value = value;
        this.inputValue = value;
      }
    }, 0);
  }
  syncNativeInput() {
    if (!this.multiple && !this.remote) {
      if (length(this.rawValue) > 0) {
        const valuesArray = getValues(this.rawValue);
        let label = findLabelByValue(this.options, valuesArray[0]);
        if (!this.multiple && this.typeahead && this.selectionOptional && label === '') {
          label = valuesArray.join(', ');
        }
        this.updateInputValue(label);
      }
    }
  }
  isChipClicked(event) {
    let isChipClicked = false;
    if (this.multiple) {
      const chips = this.selectionEl.querySelectorAll('bal-tag');
      const target = event.target;
      chips.forEach(chip => {
        const isChip = isDescendant(chip, target) || chip === target;
        if (isChip) {
          isChipClicked = isChip;
        }
      });
    }
    return isChipClicked;
  }
  render() {
    var _a;
    const labelId = this.inputId + '-lbl';
    const label = findItemLabel(this.el);
    if (label) {
      label.id = labelId;
      label.htmlFor = this.inputId;
    }
    const Chip = (props) => (h("bal-tag", { size: "", closable: !this.disabled, disabled: this.disabled, invalid: this.invalid, tabindex: -1, onBalCloseClick: _ => this.removeValue(props.value) }, findLabelByValue(this.options, props.value) || props.value));
    const valuesArray = getValues(this.rawValue);
    const block = BEM.block('select');
    const nativeEl = block.element('native');
    const controlEl = block.element('control');
    const controlIconEl = controlEl.element('icon');
    const controlSelectionsEl = controlEl.element('selections');
    const controlInputEl = controlEl.element('input');
    const popoverContentEl = block.element('popover');
    const popoverContentEmptyEl = popoverContentEl.element('empty');
    const optionEl = block.element('option');
    const optionContentEl = optionEl.element('content');
    const optionContentCheckboxEl = optionContentEl.element('checkbox');
    const optionContentLabelEl = optionContentEl.element('label');
    return (h(Host, { role: "listbox", onClick: this.handleClick, "aria-disabled": this.disabled ? 'true' : null, "data-value": (_a = this.rawValue) === null || _a === void 0 ? void 0 : _a.map(v => findLabelByValue(this.options, v)).join(','), class: Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('disabled').class(this.disabled || this.readonly)), block.modifier('inverted').class(this.inverted)) }, h("select", { class: Object.assign({}, nativeEl.class()), name: this.name, multiple: this.multiple, required: this.required, tabindex: -1, ref: el => (this.nativeSelectEl = el) }, valuesArray.map((value) => (h("option", { value: value, selected: true }, value)))), h("bal-popover", { onBalChange: this.handlePopoverChange, ref: el => (this.popoverElement = el) }, h("div", { "bal-popover-trigger": true, class: Object.assign(Object.assign(Object.assign(Object.assign({}, controlEl.class()), controlEl.modifier('invalid').class(this.invalid)), controlEl.modifier('disabled').class(this.disabled || this.readonly)), controlEl.modifier('focused').class(this.isPopoverOpen)) }, h("div", { class: Object.assign(Object.assign({}, controlSelectionsEl.class()), controlSelectionsEl
        .modifier('clickable')
        .class(!this.isPopoverOpen && !this.disabled && !this.readonly)), onClick: this.handleInputClick, ref: el => (this.selectionEl = el) }, valuesArray
      .filter(_ => this.multiple)
      .map((value) => (h(Chip, { value: value }))), h("input", { type: "text", class: Object.assign(Object.assign({}, controlInputEl.class()), { 'input': true, 'is-inverted': this.inverted, 'is-danger': this.invalid, 'is-disabled': this.disabled || this.readonly, 'is-clickable': !this.isPopoverOpen && !this.disabled && !this.readonly, 'data-test-select-input': true }), autocomplete: this.autocomplete, placeholder: this.inputPlaceholder, readonly: !this.typeahead || this.disabled || this.readonly, contentEditable: this.typeahead, disabled: this.disabled, maxLength: this.maxLength, tabindex: this.balTabindex, onInput: this.handleInput, onClick: this.handleInputClick, onChange: this.handleInputChange, onFocus: this.handleInputFocus, onBlur: this.handleInputBlur, onKeyPress: this.handleKeyPress, ref: el => (this.inputElement = el) })), h("bal-icon", { class: Object.assign(Object.assign(Object.assign({}, controlIconEl.class()), controlIconEl.modifier('loading').class(this.loading)), controlIconEl.modifier('clickable').class(!this.disabled && !this.readonly)), name: "caret-down", color: this.disabled || this.readonly ? 'grey-light' : this.invalid ? 'danger' : 'primary', turn: this.isPopoverOpen, onClick: this.handleInputClick })), h("bal-popover-content", { class: Object.assign({}, popoverContentEl.class()), scrollable: this.scrollable, spaceless: true, expanded: true }, this.optionArray.map((option, index) => (h("button", { type: "button", role: "option", id: option.id, "data-value": option.value, "data-label": option.label, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, optionEl.class()), optionEl.modifier('selected').class(valuesArray.includes(option.value))), optionEl.modifier('focused').class(this.focusIndex === index)), optionEl.modifier('checkbox').class(this.multiple)), optionEl.modifier('disabled').class(option.disabled === true)), disabled: option.disabled, tabIndex: -1, onMouseEnter: () => this.handleOptionMouseEnter(index), onClick: () => this.optionSelected(option) }, h("div", { class: Object.assign({}, optionContentEl.class()) }, h("span", { class: Object.assign({}, optionContentCheckboxEl.class()), style: { display: this.multiple ? 'flex' : 'none' } }, h("bal-checkbox", { checked: valuesArray.includes(option.value), tabindex: -1, hidden: true, flat: true, onBalChange: preventDefault })), h("span", { class: Object.assign({}, optionContentLabelEl.class()), innerHTML: option.innerHTML }))))), h("div", { class: Object.assign(Object.assign({}, popoverContentEmptyEl.class()), popoverContentEmptyEl
        .modifier('hidden')
        .class(this.noDataLabel === undefined || this.hasOptions() || !this.typeahead || this.selectionOptional)) }, this.noDataLabel)))));
  }
  get el() { return this; }
  static get watchers() { return {
    "value": ["valueWatcher"],
    "rawValue": ["rawValueWatcher"]
  }; }
}, [0, "bal-select", {
    "name": [1],
    "invalid": [4],
    "filter": [1],
    "balTabindex": [2, "bal-tabindex"],
    "multiple": [4],
    "maxLength": [2, "max-length"],
    "noDataLabel": [1, "no-data-label"],
    "noBorder": [4, "no-border"],
    "autocomplete": [1],
    "hasMovement": [4, "has-movement"],
    "typeahead": [4],
    "selectionOptional": [4, "selection-optional"],
    "disabled": [4],
    "readonly": [4],
    "required": [4],
    "inverted": [4],
    "placeholder": [1],
    "scrollable": [2],
    "loading": [4],
    "remote": [4],
    "value": [1025],
    "hasFocus": [32],
    "inputValue": [32],
    "focusIndex": [32],
    "isPopoverOpen": [32],
    "options": [32],
    "labelToScrollTo": [32],
    "labelToSelectTo": [32],
    "rawValue": [32],
    "setFocus": [64],
    "getValue": [64],
    "clear": [64],
    "open": [64],
    "close": [64],
    "cancel": [64],
    "select": [64]
  }, [[6, "click", "listenOnClick"], [6, "reset", "resetHandler"], [8, "keydown", "handleKeyDown"]]]);
let selectIds = 0;
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-select", "bal-checkbox", "bal-close", "bal-icon", "bal-popover", "bal-popover-content", "bal-tag"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-select":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Select);
      }
      break;
    case "bal-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-close":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-popover":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-popover-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "bal-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { Select as S, defineCustomElement as d };
