import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { B as BEM } from './bem.js';
import { o as observeItems } from './observer.js';
import { d as defineCustomElement$6 } from './bal-button2.js';
import { d as defineCustomElement$5 } from './bal-icon2.js';
import { d as defineCustomElement$4 } from './bal-pagination2.js';
import { d as defineCustomElement$3 } from './bal-spinner2.js';
import { d as defineCustomElement$2 } from './bal-text2.js';

const Slider = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.xPosition = 0;
    this.slideIndex = 1;
    this.slidesLabels = [];
    /**
     * Set the slide to switch to
     * @param {number} slide :Set to switch to.
     */
    this.setSlide = (slide) => {
      const slideContainer = this.getSlideContainer();
      const slideWidth = this.slides[0].clientWidth;
      if (slideContainer && slide >= 0 && slide <= this.slides.length) {
        this.slideIndex = slide;
        slideContainer.style.transitionDuration = '1.2s';
        slideContainer.style.transitionTimingFunction = 'cubic-bezier(0.23, 0.93, 0.13, 1)';
        slideContainer.style.transform = `translate(-${(this.slideIndex - 1) * slideWidth}px)`;
      }
    };
  }
  async resizeHandler() {
    this.setSlide(this.slideIndex);
  }
  connectedCallback() {
    this.mutationO = observeItems(this.el, 'bal-slider-item', () => this.updateSlides());
    this.updateSlides();
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  touchStart(event) {
    const container = this.getSliderContainer();
    if (container === null || container === void 0 ? void 0 : container.contains(event.target)) {
      this.xPosition = event.touches[0].pageX;
    }
  }
  touchEnd(event) {
    const container = this.getSliderContainer();
    if (container === null || container === void 0 ? void 0 : container.contains(event.target)) {
      if (event.changedTouches[0].pageX < this.xPosition) {
        this.setSlide(this.slideIndex + 1);
      }
      else {
        this.setSlide(this.slideIndex - 1);
      }
    }
  }
  getChildItems() {
    return Array.from(this.el.querySelectorAll('bal-slider-item'));
  }
  getSliderContainer() {
    return this.el.querySelector('.bal-slider__container');
  }
  getSlideContainer() {
    return this.el.querySelector('.bal-slider__container__slides');
  }
  updateSlides() {
    this.slides = this.getChildItems();
    this.slidesLabels = this.slides.map(slide => slide.label);
  }
  render() {
    const block = BEM.block('slider');
    const container = block.element('container');
    const containerSlides = container.element('slides');
    return (h(Host, { class: Object.assign({}, block.class()) }, h("bal-pagination", { sticky: true, interface: "tabs", totalPages: this.slides.length, value: this.slideIndex, tabsNames: this.slidesLabels, onBalChange: ev => {
        this.setSlide(ev.detail);
      } }), h("div", { class: Object.assign({}, container.class()) }, h("div", { class: Object.assign({}, containerSlides.class()) }, h("slot", null)))));
  }
  get el() { return this; }
}, [4, "bal-slider", {
    "slideIndex": [32],
    "slides": [32],
    "slidesLabels": [32]
  }, [[9, "resize", "resizeHandler"], [1, "touchstart", "touchStart"], [1, "touchend", "touchEnd"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-slider", "bal-button", "bal-icon", "bal-pagination", "bal-spinner", "bal-text"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-slider":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Slider);
      }
      break;
    case "bal-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-pagination":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-text":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalSlider = Slider;
const defineCustomElement = defineCustomElement$1;

export { BalSlider, defineCustomElement };
