class BalNoticeController {
  constructor(options) {
    this.options = options;
    this.container = null;
    this.queue = [];
    this.preQueue = [];
    this.queueLimit = 5;
  }
  create(options) {
    this.setupContainer();
    const clone = this.findClone(options);
    if (clone === undefined) {
      const el = document.createElement(this.options.tag);
      Object.assign(el, options);
      el.addEventListener('balClose', event => {
        this.removeFromQueue(event.detail);
      });
      this.preQueue.push(el);
      this.updateQueue();
      return el;
    }
    return clone;
  }
  setQueue(queueLimit) {
    this.queueLimit = queueLimit;
  }
  async dismissAll() {
    var _a;
    const elements = (_a = this.container) === null || _a === void 0 ? void 0 : _a.querySelectorAll(this.options.tag);
    if (elements) {
      const closingQueue = [];
      for (let index = 0; index < elements.length; index++) {
        const el = elements[index];
        if (el.close) {
          closingQueue.push(el.close());
        }
      }
      await Promise.all(closingQueue);
    }
  }
  /**
   * @deprecated use dismissAll instead
   */
  async clearAll() {
    console.warn('[DEPRECATED] - use dismissAll() instead');
    return this.dismissAll();
  }
  findClone(options) {
    for (let index = 0; index < this.queue.length; index++) {
      const el = this.queue[index];
      if (el.message === options.message && el.color === options.color) {
        return el;
      }
    }
    return undefined;
  }
  setupContainer() {
    const containerId = `${this.options.tag}-container`;
    this.container = document.getElementById(containerId);
    if (this.container)
      return;
    if (!this.container) {
      this.container = document.createElement('bal-notices');
      this.container.setAttribute('interface', this.options.tag.replace('bal-', ''));
      // this.container.className = `bal-notices bal-notices--${this.options.tag.replace('bal-', '')}`
      this.container.id = containerId;
    }
    document.body.appendChild(this.container);
  }
  updateQueue() {
    if (this.queue.length < this.queueLimit) {
      const el = this.preQueue.shift();
      if (el && this.container) {
        this.queue.push(el);
        this.container.insertAdjacentElement('beforeend', el);
      }
    }
  }
  removeFromQueue(toastId) {
    this.queue = this.queue.filter(el => el.id !== toastId);
    setTimeout(() => this.updateQueue(), 0);
  }
}

class BalToastController extends BalNoticeController {
  constructor() {
    super({
      tag: 'bal-toast',
    });
  }
  create(options) {
    return super.create(options);
  }
}
const balToastController = new BalToastController();

class BalSnackbarController extends BalNoticeController {
  constructor() {
    super({
      tag: 'bal-snackbar',
    });
  }
  create(options) {
    return super.create(options);
  }
}
const balSnackbarController = new BalSnackbarController();

export { BalToastController as B, BalSnackbarController as a, balToastController as b, balSnackbarController as c };
