import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$6 } from './bal-button2.js';
import { d as defineCustomElement$5 } from './bal-close2.js';
import { d as defineCustomElement$4 } from './bal-heading2.js';
import { d as defineCustomElement$3 } from './bal-icon2.js';
import { d as defineCustomElement$2 } from './bal-spinner2.js';

const Snackbar = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balClose = createEvent(this, "balClose", 7);
    this.balAction = createEvent(this, "balAction", 7);
    this.snackbarId = `bal-snackbar-${snackbarIds++}`;
    this.animationClass = 'fadeInDown';
    /**
     * The theme type of the snackbar. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * The duration of the snackbar
     */
    this.duration = 0;
    /**
     * The subject of the snackbar header
     */
    this.subject = '';
    /**
     * The message of the snackbar as html content
     */
    this.message = '';
    /**
     * The icon of the snackbar header
     */
    this.icon = '';
    /**
     * Label text for the action button
     */
    this.action = '';
    /**
     * @internal Handler for on close event
     */
    this.closeHandler = () => void 0;
    /**
     * @internal Handler for on action button click event
     */
    this.actionHandler = () => void 0;
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    this.onActionHandler = () => {
      this.balAction.emit(this.snackbarId);
      this.actionHandler();
    };
  }
  async componentWillLoad() {
    if (this.duration > 0) {
      await this.closeIn(this.duration);
    }
  }
  /**
   * Closes the snackbar after the given duration in ms
   */
  async closeIn(duration) {
    this.timer = setTimeout(() => this.close(), duration);
  }
  /**
   * Closes this snackbar
   */
  async close() {
    clearTimeout(this.timer);
    this.balClose.emit(this.snackbarId);
    this.element.remove();
    this.closeHandler();
  }
  get colorType() {
    if (this.color === '') {
      return '';
    }
    return `bal-snackbar__inner--is-${this.color}`;
  }
  get buttonType() {
    if (this.color === '') {
      return 'info';
    }
    return this.color;
  }
  render() {
    const labelAttributes = {};
    if (this.message !== undefined && this.message !== '') {
      labelAttributes.innerHTML = this.message;
    }
    return (h(Host, { id: this.snackbarId, class: "bal-snackbar" }, h("div", { role: "alert", class: `bal-snackbar__inner ${this.animationClass} ${this.colorType} p-5` }, h("div", { class: "bal-snackbar__header" }, h("span", { class: "icon-text is-small" }, h("span", { class: "icon", style: { display: this.icon ? '' : 'none' } }, h("bal-icon", { name: this.icon, color: 'primary' })), h("bal-heading", { level: "h5", space: "none" }, this.subject))), h("span", Object.assign({ class: "bal-snackbar__label" }, labelAttributes), h("slot", null), h("span", { class: "hidden" })), h("bal-close", { class: "bal-snackbar__close", onClick: () => this.close() }), h("div", { class: "bal-snackbar__footer", style: { display: this.action === '' ? 'none' : 'inline-flex' } }, h("bal-button", { color: "info", href: this.href, target: this.target, onClick: () => this.onActionHandler() }, this.action)))));
  }
  get element() { return this; }
}, [4, "bal-snackbar", {
    "color": [1],
    "duration": [2],
    "subject": [1],
    "message": [1],
    "icon": [1],
    "action": [1],
    "closeHandler": [16],
    "actionHandler": [16],
    "href": [1],
    "target": [1],
    "animationClass": [32],
    "closeIn": [64],
    "close": [64]
  }]);
let snackbarIds = 0;
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-snackbar", "bal-button", "bal-close", "bal-heading", "bal-icon", "bal-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-snackbar":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Snackbar);
      }
      break;
    case "bal-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-close":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-heading":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalSnackbar = Snackbar;
const defineCustomElement = defineCustomElement$1;

export { BalSnackbar, defineCustomElement };
