import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { B as BEM } from './bem.js';
import { d as defineCustomElement$2 } from './bal-shape2.js';

const Stage = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * Defines content width of the stage
     */
    this.containerSize = '';
    /**
     * Defines size of the stage
     */
    this.size = '';
    /**
     * Defines the background color of the stage section
     */
    this.color = 'purple';
    /**
     * If true the Baloise Shape is set
     */
    this.shape = false;
    /**
     * @deprecated If true the Baloise Shape is set
     */
    this.hasShape = false;
    /**
     * sets text color to white for images and dark backgrounds (optional)
     */
    this.inverted = false;
    this.getContainerWidth = () => {
      switch (this.containerSize) {
        case 'is-detail-page':
        case 'detail-page':
          return '680px';
        case 'is-compact':
        case 'compact':
          return '832px';
        case 'is-blog-page':
        case 'blog-page':
          return '920px';
        case 'is-fluid':
        case 'fluid':
          return '100vw';
        case 'is-wide':
        case 'wide':
        default:
          return '1400px';
      }
    };
  }
  hasShapeHandler() {
    console.warn('[DEPRECATED] - Please use the property shape instead');
  }
  migrateHasShape() {
    if (this.hasShape === true) {
      this.shape = this.hasShape;
    }
  }
  connectedCallback() {
    this.migrateHasShape();
  }
  get containerClass() {
    if (this.containerSize.includes('wide')) {
      return '';
    }
    if (this.containerSize.startsWith('is-')) {
      return this.containerSize;
    }
    return `is-${this.containerSize}`;
  }
  render() {
    const block = BEM.block('stage');
    const element = BEM.block('stage-content');
    return (h(Host, { class: Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(`is-${this.size === '' ? 'medium' : this.size}`).class()), block.modifier(`is-${this.color}`).class(!!this.color)), block.modifier('has-shape').class(!!this.shape)), style: { '--bal-stage-container-width': this.getContainerWidth() } }, h("section", { class: Object.assign(Object.assign(Object.assign({}, element.class()), element.modifier('is-inverted').class(this.inverted)), { container: true, [`${this.containerClass}`]: this.containerSize !== '' }) }, h("slot", null), this.shape && (h("div", { class: { container: true, [`${this.containerClass}`]: this.containerSize !== '' } }, h("bal-shape", { color: this.color, variation: this.shapeVariation, rotation: this.shapeRotation }))))));
  }
  static get watchers() { return {
    "hasShape": ["hasShapeHandler"]
  }; }
}, [4, "bal-stage", {
    "containerSize": [1, "container-size"],
    "size": [1],
    "color": [1],
    "shape": [4],
    "hasShape": [4, "has-shape"],
    "shapeVariation": [1, "shape-variation"],
    "shapeRotation": [1, "shape-rotation"],
    "inverted": [4]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-stage", "bal-shape"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-stage":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Stage);
      }
      break;
    case "bal-shape":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalStage = Stage;
const defineCustomElement = defineCustomElement$1;

export { BalStage, defineCustomElement };
