import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';

const TabItem = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balNavigate = createEvent(this, "balNavigate", 7);
    this.isActive = false;
    /**
     * Tells if this route is active and overrides the bal-tabs value property.
     */
    this.active = false;
    /**
     * This is the key of the tab.
     */
    this.value = '';
    /**
     * Label for the tab.
     */
    this.label = '';
    /**
     * Link to path.
     */
    this.href = '';
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    /**
     * If `true` a small red bubble is added to the tab.
     */
    this.bubble = false;
    /**
     * If `true` the tab is disabled.
     */
    this.disabled = false;
    /**
     * If `true` the step is marked as done.
     */
    this.done = false;
    /**
     * If `true` the step is hidden.
     */
    this.hidden = false;
    /**
     * If `true` the step is marked as failed.
     */
    this.failed = false;
    /**
     * Tell's if the linking is done by a router.
     */
    this.prevent = false;
    /**
     * Tab icon not available for the steps.
     */
    this.icon = undefined;
  }
  /**
   * Options of the tab like label, value etc.
   */
  async getOptions() {
    return this.options;
  }
  /**
   * Sets the tab active.
   */
  async setActive(active) {
    this.isActive = active;
  }
  get options() {
    return {
      value: this.value,
      icon: this.icon,
      label: this.label,
      href: this.href,
      target: this.target,
      active: this.active,
      disabled: this.disabled,
      done: this.done,
      hidden: this.hidden,
      failed: this.failed,
      bubble: this.bubble,
      passed: false,
      prevent: this.prevent,
      navigate: this.balNavigate,
    };
  }
  render() {
    return (h(Host, { class: {
        'bal-tabs-item': true,
        'bal-tabs-item--active': this.isActive,
      } }, h("slot", null)));
  }
  get el() { return this; }
}, [4, "bal-tab-item", {
    "active": [516],
    "value": [513],
    "label": [513],
    "href": [513],
    "target": [1],
    "bubble": [520],
    "disabled": [516],
    "done": [516],
    "hidden": [516],
    "failed": [516],
    "prevent": [4],
    "icon": [513],
    "isActive": [32],
    "getOptions": [64],
    "setActive": [64]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-tab-item"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-tab-item":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, TabItem);
      }
      break;
  } });
}

export { TabItem as T, defineCustomElement as d };
