import { h, proxyCustomElement, HTMLElement, createEvent, Host } from '@stencil/core/internal/client';
import { b as debounceEvent } from './helpers.js';
import { i as isPlatform, g as getPlatforms } from './platform.js';
import { B as BEM } from './bem.js';
import './bal-file-upload.type.js';
import './browser.js';
import './bal-snackbar.controller.js';
import { s as stopEventBubbling } from './form-input.helpers.js';
import { d as defineCustomElement$9 } from './bal-badge2.js';
import { d as defineCustomElement$8 } from './bal-checkbox2.js';
import { d as defineCustomElement$7 } from './bal-close2.js';
import { d as defineCustomElement$6 } from './bal-icon2.js';
import { d as defineCustomElement$5 } from './bal-popover2.js';
import { d as defineCustomElement$4 } from './bal-popover-content2.js';
import { d as defineCustomElement$3 } from './bal-select2.js';
import { d as defineCustomElement$2 } from './bal-select-option2.js';
import { d as defineCustomElement$1 } from './bal-tag2.js';

const watchForTabs = (containerEl, tagName, onChange) => {
  /* tslint:disable-next-line */
  if (typeof MutationObserver === 'undefined') {
    return;
  }
  const mutation = new MutationObserver(mutationList => {
    mutationList = mutationList.filter(record => record.target.nodeName === tagName.toUpperCase() || record.target.nodeName === 'bal-tabs'.toUpperCase());
    if (mutationList.length > 0) {
      onChange(undefined);
    }
  });
  mutation.observe(containerEl, {
    childList: true,
    subtree: true,
    attributes: true,
    characterData: true,
  });
  return mutation;
};

const buttonEl = BEM.block('tabs').element('tabs').element('item').element('button');
const TabItem = ({ icon, expanded, disabled, href, target, label, vertical, iconPosition, bubble, active, context, inverted, onSelectTab, }) => {
  const cssClasses = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, buttonEl.class()), buttonEl.modifier(`context-${context}`).class()), buttonEl.modifier('vertical').class(vertical == true)), buttonEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), buttonEl.modifier('vertical-on-tablet').class(vertical === 'tablet')), buttonEl.modifier('fullwidth').class(expanded)), buttonEl.modifier('disabled').class(disabled)), buttonEl.modifier('inverted').class(inverted)), buttonEl.modifier('active').class(active)), buttonEl.modifier(`icon-${iconPosition}`).class(true)), buttonEl.modifier('icon').class(icon !== undefined));
  let hrefAttribute = {
    href: 'javascript:;',
  };
  if (href) {
    hrefAttribute = {
      href,
      target,
    };
  }
  const bubbleString = bubble === true || bubble === false ? '' : bubble;
  const labelString = label;
  return (h("a", Object.assign({ class: cssClasses }, hrefAttribute, { "aria-disabled": `${disabled}`, "aria-current": "page", onClick: e => onSelectTab(e) }),
    h("bal-icon", { class: Object.assign({}, buttonEl.element('icon').class()), name: icon, size: "small", turn: active, style: { display: icon ? 'flex' : 'none' } }),
    h("span", null,
      labelString,
      h("bal-badge", { position: "tabs", size: bubbleString === '' ? 'small' : '', style: { display: bubble ? 'flex' : 'none' } }, bubbleString))));
};

const tabsEl = BEM.block('tabs').element('tabs');
const tabItemEl = tabsEl.element('item');
const TabList = ({ value, expanded, border, float, tabs, spaceless, onSelectTab, isReady, iconPosition, lineWidth, lineOffsetLeft, lineHeight, lineOffsetTop, vertical, selectOnMobile, context, inverted, }) => {
  if (isPlatform('mobile') && selectOnMobile) {
    const onChange = (event) => {
      const selectedTabs = tabs.filter(tab => tab.value === event.detail);
      if (selectedTabs.length > 0) {
        onSelectTab(event, selectedTabs[0]);
      }
    };
    return (h("bal-select", { value: value, onBalChange: event => onChange(event) }, tabs.map(tab => (h("bal-select-option", { label: tab.label, value: tab.value }, tab.label)))));
  }
  return (h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, tabsEl.class()), tabsEl.modifier(`float-${float}`).class()), tabsEl.modifier('vertical').class(vertical === true)), tabsEl.modifier('spaceless').class(spaceless && !vertical)), tabsEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), tabsEl.modifier('vertical-on-tablet').class(vertical === 'tablet')) },
    h("ul", null, tabs.map((tab, index) => (h("li", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, tabItemEl.class()), tabItemEl.modifier('active').class(tab.value === value)), tabItemEl.modifier('disabled').class(tab.disabled)), tabItemEl.modifier('hidden').class(tab.hidden)), tabItemEl.modifier('fullwidth').class(expanded)), tabItemEl.modifier('spaceless').class(spaceless && !vertical)), tabItemEl.modifier('vertical').class(vertical === true)), tabItemEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), tabItemEl.modifier('vertical-on-tablet').class(vertical === 'tablet')), { 'data-test-tab-item': true }), "data-label": tab.label, "data-value": tab.value, "data-index": index },
      h(TabItem, { icon: tab.icon, active: tab.value === value, inverted: inverted, context: context, vertical: vertical, expanded: expanded, iconPosition: iconPosition, disabled: tab.disabled, href: tab.href, target: tab.target, label: tab.label, bubble: tab.bubble, onSelectTab: e => onSelectTab(e, tab) }))))),
    h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign({}, tabsEl.element('border').class()), tabsEl
        .element('border')
        .modifier('vertical')
        .class(vertical === true)), tabsEl
        .element('border')
        .modifier('vertical-on-mobile')
        .class(vertical === 'mobile')), tabsEl
        .element('border')
        .modifier('vertical-on-tablet')
        .class(vertical === 'tablet')), style: { display: border ? 'block' : 'none' } }),
    h(TabLine, { context: context, vertical: vertical, lineOffsetLeft: lineOffsetLeft, lineWidth: lineWidth, lineOffsetTop: lineOffsetTop, lineHeight: lineHeight, inverted: inverted, isReady: isReady })));
};
const TabLine = ({ vertical, isReady, lineWidth, lineOffsetLeft, lineHeight, lineOffsetTop, inverted, context, }) => {
  const tabLineEl = tabsEl.element('line');
  let style = {};
  const isMobile = isPlatform('mobile');
  const isTablet = isPlatform('tablet');
  const isNavbarTablet = context === 'navbar' && (isMobile || isTablet);
  const isVertical = vertical === true;
  const isVerticalMobile = isMobile && (vertical === 'mobile' || vertical === 'tablet');
  const isVerticalTablet = (isMobile || isTablet) && vertical === 'tablet';
  if (isVertical || isVerticalMobile || isVerticalTablet || isNavbarTablet) {
    style = {
      top: `${lineOffsetTop || 0}px`,
      height: `${lineHeight || 0}px`,
    };
  }
  else {
    style = {
      left: `${lineOffsetLeft || 0}px`,
      width: `${lineWidth || 0}px`,
    };
  }
  return (h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, tabLineEl.class()), tabLineEl.modifier('ready').class(isReady)), tabLineEl.modifier(`context-${context}`).class()), tabLineEl.modifier('inverted').class(inverted)), tabLineEl.modifier('vertical').class(vertical === true)), tabLineEl.modifier('vertical-on-mobile').class(vertical === 'mobile')), tabLineEl.modifier('vertical-on-tablet').class(vertical === 'tablet')), style: style }));
};

const stepsEl = BEM.block('tabs').element('steps');
const stepItemEl = stepsEl.element('item');
const stepItemButtonEl = stepItemEl.element('button');
const stepItemButtonIndexEl = stepItemButtonEl.element('index');
const stepItemButtonIndexLabelEl = stepItemButtonIndexEl.element('label');
const stepItemButtonLabelEl = stepItemButtonEl.element('label');
const StepList = ({ value, float, clickable, tabs, onSelectTab }) => {
  let hasPassed = true;
  let index = 0;
  tabs = tabs
    .map(tab => (Object.assign(Object.assign({}, tab), { active: tab.value === value })))
    .map(tab => {
    if (tab.active) {
      hasPassed = false;
    }
    if (!tab.hidden) {
      index = index + 1;
    }
    return Object.assign(Object.assign({}, tab), { passed: hasPassed, index });
  });
  return (h("ul", { class: Object.assign(Object.assign({}, stepsEl.class()), stepsEl.modifier(`float-${float}`).class()) }, tabs.map(tab => (h("li", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemEl.class()), stepItemEl.modifier('hidden').class(tab.hidden)), stepItemEl.modifier('active').class(tab.active)), stepItemEl.modifier('passed').class(tab.passed)), stepItemEl.modifier('disabled').class(tab.disabled)), stepItemEl.modifier('done').class(tab.done)), stepItemEl.modifier('failed').class(tab.failed)), stepItemEl.modifier('clickable').class(clickable && !tab.disabled)), { 'data-test-tab-item': true }), "data-label": tab.label, "data-value": tab.value, "data-index": index },
    h("a", { class: Object.assign(Object.assign(Object.assign({}, stepItemButtonEl.class()), stepItemButtonEl.modifier('disabled').class(tab.disabled)), stepItemButtonEl.modifier('clickable').class(clickable && !tab.disabled)), onClick: (event) => onSelectTab(event, tab) },
      h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemButtonIndexEl.class()), stepItemButtonIndexEl.modifier('done').class(tab.done)), stepItemButtonIndexEl.modifier('active').class(tab.active)), stepItemButtonIndexEl.modifier('failed').class(tab.failed)), stepItemButtonIndexEl.modifier('disabled').class(tab.disabled)) },
        h("bal-icon", { class: Object.assign({}, stepItemButtonIndexEl.element('icon').class()), style: { display: tab.done ? 'block' : 'none' }, size: isPlatform('mobile') ? 'small' : '', color: "white", name: "check" }),
        h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemButtonIndexLabelEl.class()), stepItemButtonIndexLabelEl.modifier('failed').class(tab.failed)), stepItemButtonIndexLabelEl.modifier('active').class(tab.active)), stepItemButtonIndexLabelEl.modifier('disabled').class(tab.disabled)), style: { display: !tab.done ? 'block' : 'none' } }, tab.failed ? '!' : tab.index)),
      h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, stepItemButtonLabelEl.class()), stepItemButtonLabelEl.modifier('done').class(tab.done)), stepItemButtonLabelEl.modifier('active').class(tab.active)), stepItemButtonLabelEl.modifier('failed').class(tab.failed)), stepItemButtonLabelEl.modifier('disabled').class(tab.disabled)) }, tab.label)))))));
};

const Tabs = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balChange = createEvent(this, "balChange", 7);
    this.didInit = false;
    this.tabsOptions = [];
    this.lineWidth = 0;
    this.lineOffsetLeft = 0;
    this.lineHeight = 0;
    this.lineOffsetTop = 0;
    this.isReady = false;
    this.platform = ['mobile'];
    /**
     * Defines the layout of the tabs.
     */
    this.interface = 'tabs';
    /**
     * Defines the layout of the tabs.
     */
    this.iconPosition = 'horizontal';
    /**
     * Defines the layout of the tabs. Right only works from the breakpoint
     * high-definition and beyond.
     */
    this.float = 'left';
    /**
     * If `true` the field expands over the whole width.
     */
    this.expanded = false;
    /**
     * If `true` the tabs container does not have a padding left or right.
     */
    this.spaceless = false;
    /**
     * If `true` the field expands over the whole width.
     */
    this.inverted = false;
    /**
     * If `true` the tabs is a block element and uses 100% of the width
     */
    this.fullwidth = false;
    /**
     * If `true` the tabs or steps can be clicked.
     */
    this.clickable = true;
    /**
     * If `true` a light border is shown for the tabs.
     */
    this.border = false;
    /**
     * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
     */
    this.debounce = 0;
    /**
     * If `true` tabs are align vertically.
     */
    this.vertical = false;
    /**
     * The col size of the tabs on vertical mode.
     */
    this.verticalColSize = 'one-third';
    /**
     * If `true` the tabs are shown as a select component on mobile
     */
    this.selectOnMobile = false;
    this.value = undefined;
  }
  debounceChanged() {
    this.balChange = debounceEvent(this.balChange, this.debounce);
  }
  async valueChanged(newValue, oldValue) {
    this.tabs.forEach(t => t.setActive(t.value === this.value));
    if (this.didInit && newValue !== oldValue) {
      this.isReady = true;
    }
  }
  async resizeHandler() {
    this.platform = getPlatforms();
    this.moveLine(this.getTargetElement(this.value));
  }
  async popoverHandler() {
    this.platform = getPlatforms();
    this.moveLine(this.getTargetElement(this.value));
  }
  connectedCallback() {
    this.platform = getPlatforms();
    this.debounceChanged();
    this.updateTabs();
    this.mutationO = watchForTabs(this.el, 'bal-tab-item', () => {
      this.updateTabs();
    });
  }
  disconnectedCallback() {
    if (this.mutationO) {
      this.mutationO.disconnect();
      this.mutationO = undefined;
    }
  }
  componentDidLoad() {
    this.didInit = true;
    let value = this.value;
    if ((value === undefined || value === '') && this.interface !== 'navigation') {
      const availableTabs = this.tabsOptions.filter(t => !t.disabled);
      if (availableTabs.length > 0) {
        value = availableTabs[0].value;
      }
    }
    this.value = value;
    this.valueChanged(value, this.value);
  }
  componentDidRender() {
    this.moveLine(this.getTargetElement(this.value));
  }
  /**
   * Go to tab with the given value
   */
  async select(tab) {
    this.value = tab.value;
  }
  /**
   * @internal
   * Rerenders the line to mark the active tab.
   */
  async renderLine() {
    this.moveLine(this.getTargetElement(this.value), 100);
  }
  get tabs() {
    return Array.from(this.el.querySelectorAll('bal-tab-item'));
  }
  async updateTabs() {
    try {
      await Promise.all(this.tabs.map(value => value.getOptions())).then(tabsOptions => {
        this.tabsOptions = tabsOptions;
      });
      const activeTabs = this.tabsOptions.filter(t => t.active);
      if (activeTabs.length > 0) {
        const firstActiveTab = activeTabs[0];
        this.value = firstActiveTab.value;
      }
    }
    catch (e) {
      console.warn('[WARN] - Could not read tab options');
    }
  }
  async onSelectTab(event, tab) {
    if (tab.prevent || tab.disabled || !this.clickable) {
      stopEventBubbling(event);
    }
    if (!tab.disabled) {
      tab.navigate.emit(event);
      if (this.clickable) {
        let value = tab.value;
        if (this.interface === 'navigation' && value === this.value) {
          value = '';
        }
        if (value !== this.value) {
          this.balChange.emit(value);
          await this.select(tab);
        }
      }
    }
  }
  parseVertical() {
    if (this.vertical === 'true' || this.vertical === '') {
      return true;
    }
    if (this.vertical === 'false' || this.vertical === undefined) {
      return false;
    }
    return this.vertical;
  }
  moveLine(element, timeout = 0) {
    if (this.timeoutTimer) {
      clearTimeout(this.timeoutTimer);
    }
    this.timeoutTimer = setTimeout(() => {
      if (this.interface !== 'steps' && this.interface !== 'o-steps') {
        if (element) {
          let paddingLeft = 0;
          let paddingRight = 0;
          const listElement = element.closest('li');
          if (listElement) {
            paddingLeft = parseInt(window
              .getComputedStyle(listElement.firstChild)
              .getPropertyValue('padding-left')
              .slice(0, -2), 10);
            paddingRight = parseInt(window
              .getComputedStyle(listElement.firstChild)
              .getPropertyValue('padding-right')
              .slice(0, -2), 10);
          }
          const isMobile = isPlatform('mobile');
          const isTablet = isPlatform('tablet');
          const isVertical = this.parseVertical() === true;
          const isNavbarTablet = this.interface === 'navbar' && (isMobile || isTablet);
          const isVerticalMobile = isMobile && (this.vertical === 'mobile' || this.vertical === 'tablet');
          const isVerticalTablet = (isMobile || isTablet) && this.vertical === 'tablet';
          if (isVertical || isVerticalMobile || isVerticalTablet || isNavbarTablet) {
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.clientHeight) !== undefined) {
              this.lineHeight = listElement.clientHeight - 8;
            }
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.offsetTop) !== undefined) {
              this.lineOffsetTop = listElement.offsetTop + 4;
            }
          }
          else {
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.clientWidth) !== undefined) {
              this.lineWidth = listElement.clientWidth - (this.expanded ? 0 : paddingLeft + paddingRight);
            }
            if ((listElement === null || listElement === void 0 ? void 0 : listElement.offsetLeft) !== undefined) {
              this.lineOffsetLeft = listElement.offsetLeft + (this.expanded ? 0 : paddingLeft);
            }
          }
        }
        else {
          this.lineWidth = 0;
        }
      }
    }, timeout);
  }
  getTargetElement(value) {
    const elements = Array.from(this.el.querySelectorAll('.data-test-tab-item'));
    return elements.filter(element => element.getAttribute('data-value') == value)[0];
  }
  isTabActive(tab) {
    return tab.value === this.value;
  }
  render() {
    const block = BEM.block('tabs');
    const isSteps = this.interface === 'steps' || this.interface === 'o-steps';
    const Tabs = isSteps ? StepList : TabList;
    const isMobile = isPlatform('mobile');
    const isTablet = isPlatform('tablet');
    const isPropVertical = this.parseVertical() === true;
    const isVerticalMobile = isMobile && (this.vertical === 'mobile' || this.vertical === 'tablet');
    const isVerticalTablet = (isMobile || isTablet) && this.vertical === 'tablet';
    const isVertical = isPropVertical || isVerticalMobile || isVerticalTablet;
    return (h(Host, { class: Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(`context-${this.interface}`).class()), block.modifier('vertical').class(this.parseVertical() === true)), block.modifier('fullwidth').class(this.expanded || this.fullwidth || isSteps)), "data-value": this.tabsOptions
        .filter(t => this.isTabActive(t))
        .map(t => t.value)
        .join(','), "data-label": this.tabsOptions
        .filter(t => this.isTabActive(t))
        .map(t => t.label)
        .join(',') }, h("div", { class: {
        'columns is-multiline': this.interface !== 'meta' && this.interface !== 'navigation',
      } }, h("div", { class: {
        'column': this.interface !== 'meta' && this.interface !== 'navigation',
        'is-full': !isVertical,
        [`is-${this.verticalColSize}`]: isVertical,
        'bal-tabs__col-items': true,
        'bal-tabs__col-items--vertical': isVertical,
      } }, h(Tabs, { value: this.value, context: this.interface, inverted: this.inverted, spaceless: this.spaceless, tabs: this.tabsOptions, border: this.border, float: this.float, expanded: this.expanded, clickable: this.clickable, isReady: this.isReady, iconPosition: this.iconPosition, onSelectTab: (e, t) => this.onSelectTab(e, t), lineWidth: this.lineWidth, lineOffsetLeft: this.lineOffsetLeft, lineHeight: this.lineHeight, lineOffsetTop: this.lineOffsetTop, vertical: this.interface === 'navbar' ? 'tablet' : this.parseVertical(), selectOnMobile: this.selectOnMobile })), h("div", { class: {
        'column': this.interface !== 'meta' && this.interface !== 'navigation',
        'is-full': !isVertical,
        'bal-tabs__col-content': true,
        'bal-tabs__col-content--vertical': isVertical,
        'bal-tabs__col-content--full': this.verticalColSize === 'full',
      } }, h("slot", null)))));
  }
  get el() { return this; }
  static get watchers() { return {
    "debounce": ["debounceChanged"],
    "value": ["valueChanged"]
  }; }
}, [4, "bal-tabs", {
    "interface": [1],
    "iconPosition": [1, "icon-position"],
    "float": [1],
    "expanded": [4],
    "spaceless": [4],
    "inverted": [4],
    "fullwidth": [4],
    "clickable": [4],
    "border": [4],
    "debounce": [2],
    "vertical": [8],
    "verticalColSize": [1, "vertical-col-size"],
    "selectOnMobile": [4, "select-on-mobile"],
    "value": [1025],
    "tabsOptions": [32],
    "lineWidth": [32],
    "lineOffsetLeft": [32],
    "lineHeight": [32],
    "lineOffsetTop": [32],
    "isReady": [32],
    "platform": [32],
    "select": [64],
    "renderLine": [64]
  }, [[9, "resize", "resizeHandler"], [8, "balPopoverPrepare", "popoverHandler"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-tabs", "bal-badge", "bal-checkbox", "bal-close", "bal-icon", "bal-popover", "bal-popover-content", "bal-select", "bal-select-option", "bal-tag"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-tabs":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Tabs);
      }
      break;
    case "bal-badge":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "bal-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "bal-close":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "bal-popover":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "bal-popover-content":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "bal-select":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-select-option":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "bal-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { Tabs as T, defineCustomElement as d };
