import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { e as inheritAttributes } from './helpers.js';
import { B as BEM } from './bem.js';
import { d as defineCustomElement$2 } from './bal-close2.js';
import { d as defineCustomElement$1 } from './bal-icon2.js';

const Tag = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balCloseClick = createEvent(this, "balCloseClick", 7);
    this.inheritedAttributes = {};
    this.inheritedAttributesClose = {};
    /**
     * The theme type of the tag. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * The size of the tag element
     */
    this.size = '';
    /**
     * The theme type of the tag. Given by bulma our css framework.
     */
    this.closable = false;
    /**
     * Overwrites the default color to invalid style
     */
    this.invalid = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * Choosing left or center the tag is aligned to that side in the bal-card.
     */
    this.position = 'left';
    /**
     * If `true` a light version of the color is displayed
     */
    this.light = false;
    /**
     * @deprecated
     * @internal
     * Sets background color to transparent
     */
    this.transparent = false;
  }
  componentWillLoad() {
    this.inheritedAttributes = inheritAttributes(this.el, ['aria-label', 'title']);
    this.inheritedAttributesClose = inheritAttributes(this.el, ['tabindex']);
  }
  render() {
    const block = BEM.block('tag');
    const elLabel = block.element('label');
    const sizeClass = `is-${this.size}`;
    const hasSize = this.size !== undefined;
    const hasColor = this.color !== '';
    const colorClass = `is-${this.color}${this.light ? '-light' : ''}`;
    const disabledClass = 'is-disabled';
    const hasDisabled = this.disabled;
    const positionClass = `is-${this.position}`;
    const hasPosition = this.position !== undefined;
    return (h(Host, Object.assign({ "aria-disabled": this.disabled ? 'true' : null, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(sizeClass).class(hasSize)), block.modifier(colorClass).class(hasColor)), block.modifier(disabledClass).class(hasDisabled)), block.modifier(positionClass).class(hasPosition)), block.modifier('is-invalid').class(this.invalid)) }, this.inheritedAttributes), h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, elLabel.class()), elLabel.modifier(sizeClass).class(hasSize)), elLabel.modifier(colorClass).class(hasColor)), elLabel.modifier(disabledClass).class(hasDisabled)), elLabel.modifier('is-invalid').class(this.invalid)) }, h("slot", null)), h("bal-close", Object.assign({ class: Object.assign({}, block.element('close').class()), style: {
        display: this.closable && !this.disabled ? 'flex' : 'none',
      }, size: this.size === 'small' ? 'small' : '', inverted: (['blue', 'primary', 'info', 'success', 'warning', 'danger', 'red', 'purple', 'yellow', 'green'].includes(this.color) &&
        !this.light) ||
        this.invalid, onClick: (event) => this.balCloseClick.emit(event) }, this.inheritedAttributesClose))));
  }
  get el() { return this; }
}, [4, "bal-tag", {
    "color": [1],
    "size": [1],
    "closable": [4],
    "invalid": [4],
    "disabled": [4],
    "position": [1],
    "light": [4],
    "transparent": [4]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-tag", "bal-close", "bal-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-tag":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Tag);
      }
      break;
    case "bal-close":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { Tag as T, defineCustomElement as d };
