import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const Text = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * Defines the size of the paragraph
     */
    this.size = '';
    /**
     * If `true` the text has heading font family
     */
    this.heading = false;
    /**
     * If `true` the text is bold
     */
    this.bold = false;
    /**
     * If `true` the text is shown as a display inline
     */
    this.inline = false;
    /**
     * Defines the color of the text.
     */
    this.color = '';
    /**
     * Defines at which position the heading has spacing.
     */
    this.space = '';
    /**
     * If `true` the color gets inverted for dark backgrounds
     */
    this.inverted = false;
    /**
     * If `true` adds a text shadow to improve readability on image background
     * */
    this.shadow = false;
  }
  get spacing() {
    switch (this.space) {
      case 'all':
        return 'my-4';
      case 'top':
        return 'mt-4';
      case 'bottom':
        return 'mb-4';
      case '':
        return !this.inline ? 'mb-4' : '';
      default:
        return '';
    }
  }
  render() {
    const Text = this.inline ? 'span' : 'p';
    return (h(Host, { style: { display: this.inline ? 'inline' : 'block' }, class: { [this.spacing]: true } }, h(Text, { class: {
        [`has-text-${this.color === '' ? 'primary' : this.color}${this.inverted ? '-inverted' : ''}`]: this.color !== '' || this.inverted,
        'is-small': this.size === 'small',
        'is-lead': this.size === 'lead',
        'is-block': this.size === 'block',
        'is-bold': this.bold,
        'is-family-title': this.heading,
        'has-blur-shadow': this.shadow,
        'm-0': true,
      } }, h("slot", null))));
  }
}, [4, "bal-text", {
    "size": [1],
    "heading": [4],
    "bold": [4],
    "inline": [4],
    "color": [1],
    "space": [1],
    "inverted": [4],
    "shadow": [4]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-text"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-text":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Text);
      }
      break;
  } });
}

export { Text as T, defineCustomElement as d };
