import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$3 } from './bal-close2.js';
import { d as defineCustomElement$2 } from './bal-icon2.js';

const Toast = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.balClose = createEvent(this, "balClose", 7);
    this.toastId = `bal-toast-${toastIds++}`;
    /**
     * The theme type of the toast. Given by bulma our css framework.
     * Color type primary is deprecated, please use info instead.
     */
    this.color = '';
    /**
     * The duration of the toast in milliseconds.
     */
    this.duration = 0;
    /**
     * Content message
     */
    this.message = '';
    /**
     * @internal Handler for on close event
     */
    this.closeHandler = () => void 0;
  }
  async componentWillLoad() {
    if (this.duration > 0) {
      await this.closeIn(this.duration);
    }
  }
  /**
   * Closes the toast after the given duration in ms
   */
  async closeIn(duration) {
    this.timer = setTimeout(() => this.close(), duration);
  }
  /**
   * Closes this toast
   */
  async close() {
    this.element.remove();
    clearTimeout(this.timer);
    this.balClose.emit(this.toastId);
    this.closeHandler();
  }
  get colorType() {
    if (this.color === '') {
      return '';
    }
    return `bal-toast__inner--is-${this.color}`;
  }
  render() {
    return (h(Host, { id: this.toastId, class: "bal-toast" }, h("div", { role: "alert", onClick: () => this.close(), class: `bal-toast__inner ${this.colorType}` }, h("span", { class: "bal-toast__label", innerHTML: this.message }, h("slot", null)), h("bal-close", { class: "bal-toast__close", inverted: false }))));
  }
  get element() { return this; }
}, [4, "bal-toast", {
    "color": [1],
    "duration": [2],
    "message": [1],
    "closeHandler": [16],
    "closeIn": [64],
    "close": [64]
  }]);
let toastIds = 0;
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bal-toast", "bal-close", "bal-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "bal-toast":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, Toast);
      }
      break;
    case "bal-close":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "bal-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const BalToast = Toast;
const defineCustomElement = defineCustomElement$1;

export { BalToast, defineCustomElement };
