export { setAssetPath, setPlatformOptions } from '@stencil/core/internal/client';
export { b as attachComponentToConfig, a as attachToConfig, d as detachComponentToConfig, o as onBalConfigChange, f as updateBalAllowedLanguages, c as updateBalLanguage, e as updateBalRegion, u as useBalConfig } from './index2.js';
export { F as FileUploadRejectionReason } from './bal-file-upload.type.js';
import { g as getAppRoot, c as componentOnReady } from './helpers.js';
export { c as componentOnReady, d as deepReady, g as getAppRoot, i as isDescendant, s as shallowReady, w as wait } from './helpers.js';
export { g as getPlatforms, i as isPlatform } from './platform.js';
export { i as isBrowser } from './browser.js';
export { s as scrollToFirstInvalidField } from './form.js';
export { B as BodyScrollBlocker } from './toggle-scrolling-body.js';
export { a as BalSnackbarController, B as BalToastController, c as balSnackbarController, b as balToastController } from './bal-snackbar.controller.js';
import { g as getOverlays, a as getOverlay } from './overlays.js';
import { g as globalScript } from './global.js';
export { C as Config, c as config, b as configFromSession, d as defaultConfig, a as defaultLocale, i as initialize, s as saveConfig } from './initialize.js';

const NewBalOptionValue = (value, label, disabled = false, data) => {
  return {
    value,
    label,
    disabled,
    data,
  };
};
const NewBalSingleOptionValue = (valueAndLabel, disabled = false, data) => {
  return NewBalOptionValue(valueAndLabel, valueAndLabel, disabled, data);
};

class BalModalController {
  constructor() {
    this.tag = 'bal-modal';
  }
  create(options) {
    /* tslint:disable-next-line */
    if (typeof customElements !== 'undefined') {
      return customElements.whenDefined(this.tag).then(() => {
        const element = document.createElement(this.tag);
        // convert the passed in overlay options into props
        // that get passed down into the new overlay
        Object.assign(element, options);
        // append the overlay element to the document body
        getAppRoot(document).appendChild(element);
        return new Promise(resolve => componentOnReady(element, resolve));
      });
    }
    return Promise.resolve();
  }
  async dismissAll(data, role) {
    const overlays = getOverlays(document, this.tag);
    await Promise.all(overlays.map(o => o.dismiss(data, role)));
  }
  dismiss(data, role, id) {
    const overlay = getOverlay(document, this.tag, id);
    if (!overlay) {
      return Promise.reject('overlay does not exist');
    }
    return overlay.dismiss(data, role);
  }
  async getTop() {
    return getOverlay(document, this.tag);
  }
}
const balModalController = new BalModalController();

const globalScripts = globalScript;

globalScripts();

export { BalModalController, NewBalOptionValue, NewBalSingleOptionValue, balModalController };
