import { r as registerInstance, c as createEvent, h, a as Host } from './index-1d35ece0.js';
import { b as debounceEvent } from './helpers-cb457e64.js';

const Accordion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balChange = createEvent(this, "balChange", 7);
    this.didInit = false;
    /**
     * If `true` the accordion is open.
     */
    this.value = false;
    /**
     * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
     */
    this.debounce = 0;
    /**
     * Label of the open trigger button
     */
    this.openLabel = '';
    /**
     * BalIcon of the open trigger button
     */
    this.openIcon = 'plus';
    /**
     * Label of the close trigger button
     */
    this.closeLabel = '';
    /**
     * BalIcon of the close trigger button
     */
    this.closeIcon = 'close';
    /**
     * If `true` the accordion is used on the bottom of a card
     */
    this.card = false;
  }
  async valueChanged(newValue, oldValue) {
    if (this.didInit && newValue !== oldValue) {
      this.balChange.emit(newValue);
    }
  }
  debounceChanged() {
    this.balChange = debounceEvent(this.balChange, this.debounce);
  }
  connectedCallback() {
    this.debounceChanged();
  }
  componentDidLoad() {
    this.didInit = true;
    if (this.value !== undefined) {
      this.valueChanged(this.value, false);
    }
  }
  /**
   * Opens the accordion
   */
  async present() {
    this.value = true;
  }
  /**
   * Closes the accordion
   */
  async dismiss() {
    this.value = false;
  }
  /**
   * Triggers the accordion
   */
  async toggle() {
    this.value = !this.value;
  }
  get label() {
    return this.value ? this.closeLabel : this.openLabel;
  }
  get icon() {
    return this.value ? this.closeIcon : this.openIcon;
  }
  render() {
    const label = this.value ? this.closeLabel : this.openLabel;
    const icon = this.value ? this.closeIcon : this.openIcon;
    return (h(Host, { class: {
        'accordion': true,
        'mt-5': this.card,
      }, "aria-presented": this.value ? 'true' : null }, h("div", { class: {
        'is-flex is-flex-direction-column-reverse': true,
      } }, h("div", { class: {
        'accordion-trigger': true,
        'px-5': this.card,
        'pb-5': this.card,
      } }, h("bal-button", { class: {
        'data-test-accordion-trigger': true,
      }, expanded: true, color: 'info', icon: icon, onClick: () => this.toggle() }, label)), h("div", { class: {
        'accordion-content': true,
      }, style: {
        display: this.value ? 'block' : 'none',
      } }, h("slot", null)))));
  }
  static get watchers() { return {
    "value": ["valueChanged"],
    "debounce": ["debounceChanged"]
  }; }
};

export { Accordion as bal_accordion };
