import { r as registerInstance, c as createEvent, h, a as Host, g as getElement } from './index-1d35ece0.js';
import { a as areArraysEqual } from './index.esm-bc66903e.js';
import { s as stopEventBubbling } from './form-input.helpers-c50d4159.js';
import { i as isDescendant, e as inheritAttributes, f as findItemLabel } from './helpers-cb457e64.js';
import { B as BEM } from './bem-1b28532d.js';
import './index-e3bc1663.js';
import './_commonjsHelpers-ba3f0406.js';

const CheckboxGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balChange = createEvent(this, "balChange", 7);
    this.inputId = `bal-cg-${checkboxGroupIds++}`;
    this.inheritedAttributes = {};
    /**
     * Defines the layout of the checkbox button
     */
    this.interface = undefined;
    /**
     * If `true` it acts as the main form control
     */
    this.control = false;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * Displays the checkboxes vertically
     */
    this.vertical = false;
    /**
     * If `true`, the controls will be vertically on mobile devices.
     */
    this.verticalOnMobile = false;
    /**
     * Uses the whole width
     */
    this.expanded = false;
    /**
     * If `true`, the user cannot interact with the checkboxes.
     */
    this.disabled = undefined;
    /**
     * If `true`, the user cannot interact with the checkboxes.
     */
    this.readonly = undefined;
    /**
     * The value of the control.
     */
    this.value = [];
    this.onClick = (ev) => {
      if (!this.control) {
        return;
      }
      const element = ev.target;
      if (element.href) {
        return;
      }
      ev.preventDefault();
      // toggle clicked checkbox
      const selectedCheckbox = ev.target && ev.target.closest('bal-checkbox');
      if (selectedCheckbox) {
        if (selectedCheckbox.disabled || selectedCheckbox.readonly) {
          ev.stopPropagation();
          return;
        }
      }
      // generate new value array out of the checked checkboxes
      const newValue = [];
      this.children.forEach(cb => {
        if (cb.checked) {
          newValue.push(cb.value);
        }
      });
      if (!areArraysEqual(this.value, newValue)) {
        this.value = [...newValue];
        this.balChange.emit(this.value);
      }
    };
  }
  disabledChanged(value) {
    if (this.control) {
      if (value !== undefined) {
        this.children.forEach(child => {
          child.disabled = value;
        });
      }
    }
  }
  readonlyChanged(value) {
    if (this.control) {
      if (value !== undefined) {
        this.children.forEach(child => {
          child.readonly = value;
        });
      }
    }
  }
  valueChanged(_value, oldValue) {
    if (this.control) {
      if (!areArraysEqual(this.value, oldValue)) {
        this.sync();
      }
    }
    else {
      this.sync();
    }
  }
  listenOnClick(ev) {
    if (this.control) {
      if (isDescendant(this.el, ev.target)) {
        stopEventBubbling(ev);
      }
    }
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      if (this.control) {
        this.value = [];
      }
      this.sync();
    }
  }
  componentWillLoad() {
    if (this.control) {
      this.inheritedAttributes = inheritAttributes(this.el, ['aria-label', 'tabindex', 'title']);
      this.disabledChanged(this.disabled);
      this.readonlyChanged(this.readonly);
    }
    this.sync();
  }
  get children() {
    return Array.from(this.el.querySelectorAll('bal-checkbox'));
  }
  /** @internal */
  async setValue(value) {
    if (this.control) {
      this.value = value;
    }
  }
  sync() {
    if (this.control) {
      const isChecked = (checkbox) => {
        for (let index = 0; index < this.value.length; index++) {
          const item = this.value[index];
          if (item.toString() === checkbox.value.toString()) {
            return true;
          }
        }
        return false;
      };
      this.children.forEach((checkbox) => {
        checkbox.checked = isChecked(checkbox);
      });
    }
    this.children.forEach((checkbox) => {
      if (this.interface) {
        checkbox.interface = this.interface;
      }
    });
  }
  render() {
    const label = findItemLabel(this.el);
    const block = BEM.block('radio-checkbox-group');
    const innerEl = block.element('inner');
    return (h(Host, Object.assign({ class: Object.assign({}, block.class()), role: "group", "aria-labelledby": label === null || label === void 0 ? void 0 : label.id, "aria-disabled": this.disabled ? 'true' : null, onClick: this.onClick }, this.inheritedAttributes), h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, innerEl.class()), innerEl.modifier('vertical-mobile').class(this.verticalOnMobile)), innerEl.modifier('vertical').class(this.vertical)), innerEl.modifier('expanded').class(this.expanded)), innerEl.modifier('select-button').class(this.interface === 'select-button')) }, h("slot", null))));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "disabled": ["disabledChanged"],
    "readonly": ["readonlyChanged"],
    "value": ["valueChanged"]
  }; }
};
let checkboxGroupIds = 0;

export { CheckboxGroup as bal_checkbox_group };
