import { r as registerInstance, h, a as Host } from './index-1d35ece0.js';
import { m as loadFooterLinks, L as Language } from './index.esm-bc66903e.js';
import { d as detachComponentToConfig, b as attachComponentToConfig, c as updateBalLanguage } from './index-40fb1d53.js';
import { B as BEM } from './bem-1b28532d.js';
import { d as defaultConfig } from './initialize-88364056.js';
import './index-e3bc1663.js';
import './_commonjsHelpers-ba3f0406.js';

const Footer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.links = [];
    this.language = defaultConfig.language;
    this.region = defaultConfig.region;
    this.allowedLanguages = defaultConfig.allowedLanguages;
    /**
     * @deprecated The languages in which the links will appear.
     */
    this.locale = '';
    /**
     * If `true` the legal Baloise links will be hidden.
     */
    this.hideLinks = false;
    /**
     * If `true` the language selection will be hidden.
     */
    this.hideLanguageSelection = false;
  }
  disconnectedCallback() {
    detachComponentToConfig(this);
  }
  connectedCallback() {
    attachComponentToConfig(this);
    this.updateFooterLinks();
  }
  configChanged(config) {
    this.language = config.language;
    this.region = config.region;
    this.allowedLanguages = config.allowedLanguages;
    this.updateFooterLinks();
  }
  watchLocaleHandler() {
    if (this.locale !== '') {
      this.language = this.locale;
      this.updateFooterLinks();
    }
  }
  changeLanguage(language) {
    updateBalLanguage(language);
  }
  updateFooterLinks() {
    if (!this.hideLinks && this.region === 'CH') {
      // The following footer links only apply to swiss applications
      loadFooterLinks(new Language(this.language)).then(links => (this.links = links));
    }
  }
  render() {
    const block = BEM.block('footer');
    const elInner = block.element('inner');
    const elContainer = elInner.element('container');
    const elLinksContainer = elInner.element('links-container');
    const elLegalLinks = elLinksContainer.element('legal-links');
    const elLanguageLinks = elLinksContainer.element('language-links');
    return (h(Host, { class: Object.assign({}, block.class()) }, h("footer", { class: Object.assign({}, elInner.class()) }, h("slot", null), h("div", { class: Object.assign(Object.assign({ container: true }, elContainer.class()), elLinksContainer.class()) }, h("div", { class: Object.assign(Object.assign({}, elLegalLinks.class()), { 'pt-4': true }), style: { display: this.hideLinks ? 'none' : 'flex' } }, this.links.map(link => (h("a", { class: {
        'is-link': true,
        'is-inverted': true,
        'pr-4': true,
      }, href: link.link, target: "_blank" }, link.label)))), h("div", { class: Object.assign(Object.assign({}, elLanguageLinks.class()), { 'pt-4': true }), style: {
        display: this.hideLanguageSelection || this.allowedLanguages.length <= 1 ? 'none' : 'flex',
      } }, this.allowedLanguages.map(lang => (h("a", { class: [
        'is-link',
        'is-inverted',
        'pr-4',
        this.language.toLowerCase() == lang.toLowerCase() ? 'is-current' : '',
      ].join(' '), onClick: () => this.changeLanguage(lang) }, lang.toUpperCase()))))))));
  }
  static get watchers() { return {
    "locale": ["watchLocaleHandler"]
  }; }
};

export { Footer as bal_footer };
