import { r as registerInstance, h, a as Host } from './index-1d35ece0.js';

const Heading = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * The actual heading level used in the HTML markup.
     */
    this.level = 'h1';
    /**
     * If `true` the heading gets displayed slimmer.
     */
    this.subtitle = false;
    /**
     * Defines at which position the heading has spacing.
     */
    this.space = 'bottom';
    /**
     * The theme type of the toast. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * If `true` the color gets inverted for dark backgrounds
     */
    this.inverted = false;
    /**
     * If `true` adds a text shadow to improve readability on image background
     * */
    this.shadow = false;
  }
  get fontSize() {
    const isHeading = (size) => size.startsWith('h');
    const parseDisplay = (size) => (size.startsWith('display') ? size : size);
    const parseSize = (size) => (isHeading(size) ? size.replace('h', '') : parseDisplay(size));
    const formatSize = (size) => `is-size-${parseSize(size)}`;
    return formatSize(this.visualLevel ? this.visualLevel : this.level);
  }
  get fontColor() {
    const parseColor = (color) => (color !== '' ? `has-text-${color}` : '');
    return parseColor(this.inverted ? 'white' : this.color);
  }
  margins(spacingLevel) {
    const spacing = [];
    if (this.space === 'top' || this.space === 'all') {
      spacing.push(`mt-${spacingLevel}`);
    }
    if (this.space === 'bottom' || this.space === 'all') {
      spacing.push(`mb-${spacingLevel}`);
    }
    return spacing.join(' ');
  }
  get spacing() {
    switch (this.level) {
      case 'display':
      case 'display-2':
        return this.margins(4);
      case 'h1':
        return this.margins(3);
      case 'h2':
      case 'h3':
      case 'h4':
      case 'h5':
        return this.margins(2);
      default:
        return '';
    }
  }
  render() {
    const Heading = this.level.startsWith('display') ? 'h1' : this.level;
    return (h(Host, { class: { [this.spacing]: true } }, h(Heading, { class: {
        'data-test-heading': true,
        'title': this.subtitle === false,
        'subtitle': this.subtitle === true,
        'has-blur-shadow': this.shadow,
        [this.fontSize]: true,
        [this.fontColor]: true,
      } }, h("slot", null))));
  }
};

export { Heading as bal_heading };
