import { r as registerInstance, h, a as Host, g as getElement } from './index-1d35ece0.js';
import { b as attachComponentToConfig, d as detachComponentToConfig } from './index-40fb1d53.js';
import { i as isPlatform } from './platform-5ceddd42.js';
import { B as BEM } from './bem-1b28532d.js';
import { p as preventDefault } from './utils-0d36ce94.js';
import { B as BodyScrollBlocker } from './toggle-scrolling-body-aa9a6dd4.js';
import './index-e3bc1663.js';

const Hint = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.bodyScrollBlocker = BodyScrollBlocker();
    this.isActive = false;
    this.innerCloseLabel = 'Close';
    this.isMobile = isPlatform('mobile');
    /**
     * Disables the close button for tablet and desktop
     */
    this.small = false;
    this.onPopoverChange = (event) => {
      this.isActive = event.detail;
      preventDefault(event);
    };
  }
  async resizeHandler() {
    const isCurrentMobile = isPlatform('mobile');
    if (isCurrentMobile !== this.isMobile) {
      this.isActive = false;
    }
    this.isMobile = isCurrentMobile;
  }
  connectedCallback() {
    attachComponentToConfig(this);
  }
  disconnectedCallback() {
    detachComponentToConfig(this);
  }
  componentDidRender() {
    this.updateContent();
  }
  configChanged(state) {
    if (!this.closeLabel) {
      switch (state.language) {
        case 'de':
          this.innerCloseLabel = 'Schliessen';
          break;
        case 'fr':
          this.innerCloseLabel = 'Fermer';
          break;
        case 'it':
          this.innerCloseLabel = 'Chiudere';
          break;
        case 'nl':
          this.innerCloseLabel = 'Sluiten';
          break;
        default:
          this.innerCloseLabel = 'Close';
          break;
      }
    }
  }
  /**
   * Toggles the hint box.
   */
  async toggle() {
    if (this.isActive) {
      this.dismiss();
    }
    else {
      this.present();
    }
  }
  /**
   * Opens the hint box.
   */
  async present() {
    if (this.popoverElement) {
      this.popoverElement.present();
    }
    if (this.isMobile) {
      this.bodyScrollBlocker.block();
    }
    this.isActive = true;
  }
  /**
   * Closes the hint box.
   */
  async dismiss() {
    if (this.popoverElement) {
      this.popoverElement.dismiss();
    }
    if (this.isMobile) {
      this.bodyScrollBlocker.allow();
    }
    this.isActive = false;
  }
  updateContent() {
    if (this.hintContentEl && this.slotWrapperEl) {
      this.hintContentEl.innerHTML = this.slotWrapperEl.innerHTML;
    }
  }
  render() {
    const block = BEM.block('hint');
    const elIcon = block.element('icon');
    const elContent = block.element('content');
    const elButtons = elContent.element('buttons');
    const padding = this.isMobile ? 0 : 8;
    const offsetY = this.isMobile ? 0 : 16;
    const TriggerIcon = () => {
      return (h("bal-icon", { class: Object.assign(Object.assign({}, elIcon.class()), { 'data-test-hint-trigger': true }), "bal-popover-trigger": true, "aria-haspopup": "true", role: "button", name: "info-circle", onClick: () => this.toggle() }));
    };
    const HintContent = () => {
      return (h("div", { class: Object.assign(Object.assign({}, elContent.class()), { 'data-test-hint-content': true }) }, h("div", { ref: el => (this.hintContentEl = el) }), h("bal-button-group", { class: Object.assign(Object.assign({}, elButtons.class()), elButtons.modifier('is-hidden-desktop').class(this.small)) }, h("bal-button", { class: "data-test-hint-close", color: "info", onClick: () => this.dismiss() }, this.closeLabel ? this.closeLabel : this.innerCloseLabel))));
    };
    const MobileOverlay = () => {
      const elOverlay = block.element('overlay');
      return (h("div", { class: Object.assign({}, elOverlay.class()) }, h(TriggerIcon, null), h("div", { class: Object.assign(Object.assign({}, elOverlay.element('content').class()), elOverlay.element('content').modifier('active').class(this.isActive)) }, h(HintContent, null))));
    };
    const Popover = () => {
      return (h("div", { class: Object.assign({}, block.element('popover').class()) }, h("bal-popover", { hint: true, position: "right", offsetX: 0, offsetY: offsetY, padding: padding, ref: el => (this.popoverElement = el), onBalChange: this.onPopoverChange }, h(TriggerIcon, null), h("bal-popover-content", { color: "grey" }, h(HintContent, null)))));
    };
    const HintElement = this.isMobile ? MobileOverlay : Popover;
    return (h(Host, { class: Object.assign({}, block.class()) }, h(HintElement, null), h("div", { ref: el => (this.slotWrapperEl = el), style: { display: 'none' } }, h("slot", null))));
  }
  get element() { return getElement(this); }
};

const HintText = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    const block = BEM.block('hint');
    const elContent = block.element('content');
    const elText = elContent.element('text');
    const elTextField = elText.element('field');
    return (h(Host, { class: Object.assign({}, elText.class()) }, h("p", { class: Object.assign({}, elTextField.class()) }, h("slot", null))));
  }
};

const HintTitle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    const block = BEM.block('hint');
    const elContent = block.element('content');
    const elTitle = elContent.element('title');
    const elHeading = elTitle.element('heading');
    return (h(Host, { class: Object.assign({}, elTitle.class()) }, h("h3", { class: Object.assign(Object.assign({}, elHeading.class()), { 'title': true, 'is-3': true }) }, h("span", null, h("slot", null)))));
  }
};

export { Hint as bal_hint, HintText as bal_hint_text, HintTitle as bal_hint_title };
