import { r as registerInstance, h, a as Host, c as createEvent, g as getElement } from './index-1d35ece0.js';
import { B as BEM } from './bem-1b28532d.js';

const List = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * If `true` the list item can not be hovered
     */
    this.disabled = false;
    /**
     * @deprecated
     * If `true` the list can be used on a dark background
     */
    this.inverted = false;
    /**
     * If `true` the list can be used on a light, dark or colored backgrounds
     */
    this.background = 'light';
    /**
     * If `true` each list item has a bottom border
     */
    this.border = false;
    /**
     * Defines the min height of the list item
     */
    this.size = '';
    /**
     * If `true` the list can be used as an accordion in meta nav
     */
    this.inMainNav = false;
  }
  invertedHandler() {
    console.warn('[DEPRECATED] - Please use the property background="dark" instead');
    if (this.inverted === true) {
      this.background = 'dark';
    }
  }
  render() {
    const block = BEM.block('list');
    return (h(Host, { role: "list", class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier('context-main-nav').class(this.inMainNav)), block.modifier('disabled').class(this.disabled)), block.modifier('border').class(this.border)), block.modifier(`size-${this.size}`).class(this.size !== '')), block.modifier(`background-${this.background}`).class()) }, h("slot", null)));
  }
  static get watchers() { return {
    "inverted": ["invertedHandler"]
  }; }
};

const ListItem = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balNavigate = createEvent(this, "balNavigate", 7);
    /**
     * If `true` the list item can be hovered
     */
    this.disabled = false;
    /**
     * If `true` the list item shows that it is clickable
     */
    this.clickable = false;
    /**
     * If `true` the list item has a selected theme
     */
    this.selected = false;
    /**
     * If `true` the list item can be used as a accordion
     */
    this.accordion = false;
    /**
     * If `true` the list item can be used as an accordion inside another accordion
     */
    this.subAccordionItem = false;
    /**
     * Specifies the URL of the page the link goes to
     */
    this.href = '';
    /**
     * Specifies where to open the linked document
     */
    this.target = '_self';
  }
  connectedCallback() {
    const accordionHead = this.findAccordionHead();
    if (accordionHead) {
      accordionHead.addEventListener('balAccordionChange', (event) => this.updateState(event.detail));
    }
  }
  disconnectedCallback() {
    const accordionHead = this.findAccordionHead();
    if (accordionHead) {
      accordionHead.removeEventListener('balAccordionChange', (event) => this.updateState(event.detail));
    }
  }
  findAccordionHead() {
    return this.el.querySelector('bal-list-item-accordion-head');
  }
  findAccordionBody() {
    return this.el.querySelector('bal-list-item-accordion-body');
  }
  updateState(isAccordionOpen) {
    const accordionBody = this.findAccordionBody();
    if (accordionBody) {
      accordionBody.open = isAccordionOpen;
    }
  }
  render() {
    const itemEl = BEM.block('list').element('item');
    const triggerEl = itemEl.element('trigger');
    const basicClasses = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, itemEl.class()), itemEl.modifier('disabled').class(this.disabled)), itemEl.modifier('selected').class(this.selected)), itemEl.modifier('accordion').class(this.accordion)), itemEl.modifier('sub-accordion').class(this.subAccordionItem)), itemEl
      .modifier('clickable')
      .class(!this.disabled && (this.clickable || this.href.length > 0 || this.accordion)));
    if (this.href.length > 0 && !this.disabled) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) }, h("a", { class: Object.assign({}, triggerEl.class()), href: this.href, target: this.target, onClick: (event) => {
          this.balNavigate.emit(event);
        } }, h("slot", null))));
    }
    if (this.clickable) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) }, h("button", { class: Object.assign({}, triggerEl.class()), disabled: this.disabled, onClick: (event) => {
          this.balNavigate.emit(event);
        } }, h("slot", null))));
    }
    if (this.accordion) {
      return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses), onClick: (event) => {
          this.balNavigate.emit(event);
        } }, h("div", { class: Object.assign({}, triggerEl.class()) }, h("slot", null))));
    }
    return (h(Host, { role: "listitem", class: Object.assign({}, basicClasses) }, h("div", { class: Object.assign({}, triggerEl.class()) }, h("slot", null))));
  }
  get el() { return getElement(this); }
};

const ListItemSubtitle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, { class: "bal-list__item__subtitle" }, h("bal-text", { size: "small", space: "none" }, h("slot", null))));
  }
};

const ListItemTitle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Heading level with value 'h4' on default
     */
    this.level = 'h5';
  }
  render() {
    return (h(Host, { class: "bal-list__item__title" }, h("bal-heading", { level: this.level, space: "none" }, h("slot", null))));
  }
};

export { List as bal_list, ListItem as bal_list_item, ListItemSubtitle as bal_list_item_subtitle, ListItemTitle as bal_list_item_title };
