import { r as registerInstance, h, a as Host } from './index-1d35ece0.js';
import { s as stopEventBubbling } from './form-input.helpers-c50d4159.js';
import { B as BEM } from './bem-1b28532d.js';
import { d as disableSmoothScrolling, e as enableSmoothScrolling } from './toggle-scrolling-body-aa9a6dd4.js';

const NavigationPopover = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.isActive = false;
    /**
     * Defines the label of the button
     */
    this.label = '';
    /**
     * Turns the trigger button to inverted style.
     */
    this.inverted = false;
    /**
     * If `true` a backdrop is added
     */
    this.backdrop = false;
    /**
     * Defines the size of the button
     */
    this.size = '';
    /**
     * Color style of the button when the popover is closed.
     */
    this.inactiveColor = 'light';
    /**
     * Color style of the button when the popover is open.
     */
    this.activeColor = 'primary';
    /**
     * If 'false', the closing button is not displayed
     */
    this.closable = true;
    /**
     * Defines border-radius of popover content.
     */
    this.contentRadius = 'normal';
    /**
     * Define the position of the popover content.
     */
    this.position = 'bottom-start';
    /**
     * Define the max width of the popover content.
     */
    this.contentWidth = 0;
    /**
     * Define the min width of the popover content.
     */
    this.contentMinWidth = 0;
    /**
     * Define the offset of the popover content.
     */
    this.offsetY = 0;
    /**
     * If `true` the width of the buttons is limited
     */
    this.square = false;
    /**
     * If `true` the popover does not have the shadow
     */
    this.contentNoShadow = false;
    /**
     * If `true` the content has a min width of 100%.
     */
    this.contentExpanded = false;
    /**
     * If `true` a little arrow is added, which points to the trigger element
     */
    this.arrow = false;
    /**
     * If `true` its content will have a divider line on top
     */
    this.mobileTop = false;
    this.toggle = (event) => {
      stopEventBubbling(event);
      this.clearTimeouts();
      if (!this.isActive) {
        disableSmoothScrolling();
        this.scrollToTopTimer = setTimeout(() => {
          window.scrollTo(0, 0);
        }, 0);
      }
      this.setActiveTimer = setTimeout(() => {
        enableSmoothScrolling();
        this.isActive = !this.isActive;
      }, 100);
    };
  }
  clearTimeouts() {
    if (this.scrollToTopTimer) {
      clearTimeout(this.scrollToTopTimer);
    }
    if (this.setActiveTimer) {
      clearTimeout(this.setActiveTimer);
    }
  }
  render() {
    const navPopoverEl = BEM.block('nav').element('popover');
    return (h(Host, { class: Object.assign(Object.assign({}, navPopoverEl.class()), { control: true }) }, h("bal-popover", { value: this.isActive, onBalChange: event => (this.isActive = event.detail), arrow: this.arrow, backdrop: this.backdrop, position: this.position, offsetY: this.offsetY, "mobile-top": this.mobileTop }, h("bal-button", { "bal-popover-trigger": true, icon: this.icon, size: this.size, inverted: this.inverted, color: this.isActive ? this.activeColor : this.inactiveColor, square: this.square, onClick: this.toggle, "aria-haspopup": "true", class: `bal-navigation-popover__button bal-navigation-popover__button-${this.isActive ? this.activeColor : this.inactiveColor}` }, this.label), h("bal-popover-content", { radius: this.contentRadius, "content-width": this.contentWidth, "content-min-width": this.contentMinWidth, "no-shadow": this.contentNoShadow, expanded: this.contentExpanded, "mobile-top": this.mobileTop }, (this.closable || this.heading) && (h("div", { class: Object.assign({}, navPopoverEl.element('head').class()) }, this.heading && (h("bal-heading", { space: "none", level: "h4" }, this.heading)), this.closable && h("bal-close", { onClick: () => (this.isActive = !this.isActive) }))), h("slot", null)))));
  }
};

export { NavigationPopover as bal_navigation_popover };
