import { r as registerInstance, c as createEvent, h, a as Host } from './index-1d35ece0.js';
import { B as BEM } from './bem-1b28532d.js';

const ProductSliderItem = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balNavigate = createEvent(this, "balNavigate", 7);
    this.balFocus = createEvent(this, "balFocus", 7);
    this.balBlur = createEvent(this, "balBlur", 7);
    this.inputId = `bal-product-slider-item-${productSliderItemId++}`;
    /**
     * The type of button.
     */
    this.elementType = 'button';
    /**
     * The name of the button, which is submitted with the form data.
     */
    this.name = '';
    /**
     * The value of the button, which is submitted with the form data.
     */
    this.value = '';
    /**
     * Specifies where to display the linked URL.
     * Only applies when an `href` is provided.
     */
    this.target = '_self';
    this.onClick = (event) => {
      if (this.href !== undefined) {
        this.balNavigate.emit(event);
      }
    };
    this.onFocus = () => {
      this.balFocus.emit();
    };
    this.onBlur = () => {
      this.balBlur.emit();
    };
  }
  render() {
    const { elementType, download, href, rel, target, name, value } = this;
    const TagType = this.href === undefined ? 'button' : 'a';
    const attrs = TagType === 'button'
      ? { type: elementType, name, value }
      : {
        download,
        href,
        rel,
        target,
      };
    const block = BEM.block('product-slider-item');
    const button = block.element('button');
    const image = button.element('image');
    const label = button.element('label');
    return (h(Host, { "aria-id": this.inputId, class: Object.assign({}, block.class()) }, h(TagType, Object.assign({}, attrs, { class: Object.assign(Object.assign({}, button.class()), button.modifier(`color-${this.color}`).class()), part: "native", onFocus: this.onFocus, onBlur: this.onBlur, onClick: this.onClick }), this.src !== undefined ? h("img", { class: Object.assign({}, image.class()), src: this.src }) : '', this.label !== undefined ? h("span", { class: Object.assign(Object.assign({}, label.class()), { 'is-bold': true }) }, this.label) : '', h("slot", null))));
  }
};
let productSliderItemId = 0;

export { ProductSliderItem as bal_product_slider_item };
