import { r as registerInstance, c as createEvent, h, a as Host, g as getElement } from './index-1d35ece0.js';
import { s as stopEventBubbling } from './form-input.helpers-c50d4159.js';
import { i as isDescendant, e as inheritAttributes, f as findItemLabel } from './helpers-cb457e64.js';
import { B as BEM } from './bem-1b28532d.js';

const RadioGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balChange = createEvent(this, "balChange", 7);
    this.inputId = `bal-rg-${radioGroupIds++}`;
    this.inheritedAttributes = {};
    this.initialValue = '';
    /**
     * Defines the layout of the radio button
     */
    this.interface = undefined;
    /**
     * The name of the control, which is submitted with the form data.
     */
    this.name = this.inputId;
    /**
     * Displays the checkboxes vertically
     */
    this.vertical = false;
    /**
     * If `true`, the controls will be vertically on mobile devices.
     */
    this.verticalOnMobile = false;
    /**
     * Uses the whole width
     */
    this.expanded = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = undefined;
    /**
     * If `true` the element can not mutated, meaning the user can not edit the control.
     */
    this.readonly = undefined;
    /**
     * The value of the control.
     */
    this.value = '';
    this.onClick = (ev) => {
      const element = ev.target;
      if (element.href) {
        return;
      }
      ev.preventDefault();
      const selectedRadio = ev.target && ev.target.closest('bal-radio');
      if (selectedRadio) {
        if (selectedRadio.disabled || selectedRadio.readonly) {
          ev.stopPropagation();
          return;
        }
        const currentValue = this.value;
        const newValue = selectedRadio.value;
        if (newValue !== currentValue) {
          this.value = newValue;
          this.balChange.emit(this.value);
        }
      }
    };
  }
  disabledChanged(value) {
    if (value !== undefined) {
      this.children.forEach(child => {
        child.disabled = value;
      });
    }
  }
  readonlyChanged(value) {
    if (value !== undefined) {
      this.children.forEach(child => {
        child.readonly = value;
      });
    }
  }
  valueChanged(value, oldValue) {
    if (value !== oldValue) {
      this.sync();
    }
  }
  listenOnClick(ev) {
    if (isDescendant(this.el, ev.target)) {
      stopEventBubbling(ev);
    }
  }
  resetHandler(event) {
    const formElement = event.target;
    if (formElement === null || formElement === void 0 ? void 0 : formElement.contains(this.el)) {
      this.value = this.initialValue;
      this.sync();
    }
  }
  connectedCallback() {
    this.initialValue = this.value;
  }
  componentWillLoad() {
    this.inheritedAttributes = inheritAttributes(this.el, ['aria-label', 'tabindex', 'title']);
    this.sync();
    this.disabledChanged(this.disabled);
    this.readonlyChanged(this.readonly);
  }
  get children() {
    return Array.from(this.el.querySelectorAll('bal-radio'));
  }
  /** @internal */
  async setValue(value) {
    this.value = value;
  }
  sync() {
    this.children.forEach((radio) => {
      if (this.interface) {
        radio.interface = this.interface;
      }
      radio.checked = radio.value === this.value;
    });
  }
  render() {
    const label = findItemLabel(this.el);
    const block = BEM.block('radio-checkbox-group');
    const innerEl = block.element('inner');
    return (h(Host, Object.assign({ class: Object.assign({}, block.class()), role: "radiogroup", "aria-labelledby": label === null || label === void 0 ? void 0 : label.id, "aria-disabled": this.disabled ? 'true' : null, onClick: this.onClick }, this.inheritedAttributes), h("div", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, innerEl.class()), innerEl.modifier('vertical-mobile').class(this.verticalOnMobile)), innerEl.modifier('vertical').class(this.vertical)), innerEl.modifier('expanded').class(this.expanded)), innerEl.modifier('select-button').class(this.interface === 'select-button')) }, h("slot", null))));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "disabled": ["disabledChanged"],
    "readonly": ["readonlyChanged"],
    "value": ["valueChanged"]
  }; }
};
let radioGroupIds = 0;

export { RadioGroup as bal_radio_group };
