import { r as registerInstance, c as createEvent, h, a as Host, g as getElement } from './index-1d35ece0.js';
import { e as inheritAttributes } from './helpers-cb457e64.js';
import { B as BEM } from './bem-1b28532d.js';

const Tag = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balCloseClick = createEvent(this, "balCloseClick", 7);
    this.inheritedAttributes = {};
    this.inheritedAttributesClose = {};
    /**
     * The theme type of the tag. Given by bulma our css framework.
     */
    this.color = '';
    /**
     * The size of the tag element
     */
    this.size = '';
    /**
     * The theme type of the tag. Given by bulma our css framework.
     */
    this.closable = false;
    /**
     * Overwrites the default color to invalid style
     */
    this.invalid = false;
    /**
     * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
     */
    this.disabled = false;
    /**
     * Choosing left or center the tag is aligned to that side in the bal-card.
     */
    this.position = 'left';
    /**
     * If `true` a light version of the color is displayed
     */
    this.light = false;
    /**
     * @deprecated
     * @internal
     * Sets background color to transparent
     */
    this.transparent = false;
  }
  componentWillLoad() {
    this.inheritedAttributes = inheritAttributes(this.el, ['aria-label', 'title']);
    this.inheritedAttributesClose = inheritAttributes(this.el, ['tabindex']);
  }
  render() {
    const block = BEM.block('tag');
    const elLabel = block.element('label');
    const sizeClass = `is-${this.size}`;
    const hasSize = this.size !== undefined;
    const hasColor = this.color !== '';
    const colorClass = `is-${this.color}${this.light ? '-light' : ''}`;
    const disabledClass = 'is-disabled';
    const hasDisabled = this.disabled;
    const positionClass = `is-${this.position}`;
    const hasPosition = this.position !== undefined;
    return (h(Host, Object.assign({ "aria-disabled": this.disabled ? 'true' : null, class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, block.class()), block.modifier(sizeClass).class(hasSize)), block.modifier(colorClass).class(hasColor)), block.modifier(disabledClass).class(hasDisabled)), block.modifier(positionClass).class(hasPosition)), block.modifier('is-invalid').class(this.invalid)) }, this.inheritedAttributes), h("span", { class: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, elLabel.class()), elLabel.modifier(sizeClass).class(hasSize)), elLabel.modifier(colorClass).class(hasColor)), elLabel.modifier(disabledClass).class(hasDisabled)), elLabel.modifier('is-invalid').class(this.invalid)) }, h("slot", null)), h("bal-close", Object.assign({ class: Object.assign({}, block.element('close').class()), style: {
        display: this.closable && !this.disabled ? 'flex' : 'none',
      }, size: this.size === 'small' ? 'small' : '', inverted: (['blue', 'primary', 'info', 'success', 'warning', 'danger', 'red', 'purple', 'yellow', 'green'].includes(this.color) &&
        !this.light) ||
        this.invalid, onClick: (event) => this.balCloseClick.emit(event) }, this.inheritedAttributesClose))));
  }
  get el() { return getElement(this); }
};

export { Tag as bal_tag };
