import { r as registerInstance, h, a as Host } from './index-1d35ece0.js';

const Text = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Defines the size of the paragraph
     */
    this.size = '';
    /**
     * If `true` the text has heading font family
     */
    this.heading = false;
    /**
     * If `true` the text is bold
     */
    this.bold = false;
    /**
     * If `true` the text is shown as a display inline
     */
    this.inline = false;
    /**
     * Defines the color of the text.
     */
    this.color = '';
    /**
     * Defines at which position the heading has spacing.
     */
    this.space = '';
    /**
     * If `true` the color gets inverted for dark backgrounds
     */
    this.inverted = false;
    /**
     * If `true` adds a text shadow to improve readability on image background
     * */
    this.shadow = false;
  }
  get spacing() {
    switch (this.space) {
      case 'all':
        return 'my-4';
      case 'top':
        return 'mt-4';
      case 'bottom':
        return 'mb-4';
      case '':
        return !this.inline ? 'mb-4' : '';
      default:
        return '';
    }
  }
  render() {
    const Text = this.inline ? 'span' : 'p';
    return (h(Host, { style: { display: this.inline ? 'inline' : 'block' }, class: { [this.spacing]: true } }, h(Text, { class: {
        [`has-text-${this.color === '' ? 'primary' : this.color}${this.inverted ? '-inverted' : ''}`]: this.color !== '' || this.inverted,
        'is-small': this.size === 'small',
        'is-lead': this.size === 'lead',
        'is-block': this.size === 'block',
        'is-bold': this.bold,
        'is-family-title': this.heading,
        'has-blur-shadow': this.shadow,
        'm-0': true,
      } }, h("slot", null))));
  }
};

export { Text as bal_text };
