import { r as registerInstance, c as createEvent, h, a as Host, g as getElement } from './index-1d35ece0.js';

const Toast = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.balClose = createEvent(this, "balClose", 7);
    this.toastId = `bal-toast-${toastIds++}`;
    /**
     * The theme type of the toast. Given by bulma our css framework.
     * Color type primary is deprecated, please use info instead.
     */
    this.color = '';
    /**
     * The duration of the toast in milliseconds.
     */
    this.duration = 0;
    /**
     * Content message
     */
    this.message = '';
    /**
     * @internal Handler for on close event
     */
    this.closeHandler = () => void 0;
  }
  async componentWillLoad() {
    if (this.duration > 0) {
      await this.closeIn(this.duration);
    }
  }
  /**
   * Closes the toast after the given duration in ms
   */
  async closeIn(duration) {
    this.timer = setTimeout(() => this.close(), duration);
  }
  /**
   * Closes this toast
   */
  async close() {
    this.element.remove();
    clearTimeout(this.timer);
    this.balClose.emit(this.toastId);
    this.closeHandler();
  }
  get colorType() {
    if (this.color === '') {
      return '';
    }
    return `bal-toast__inner--is-${this.color}`;
  }
  render() {
    return (h(Host, { id: this.toastId, class: "bal-toast" }, h("div", { role: "alert", onClick: () => this.close(), class: `bal-toast__inner ${this.colorType}` }, h("span", { class: "bal-toast__label", innerHTML: this.message }, h("slot", null)), h("bal-close", { class: "bal-toast__close", inverted: false }))));
  }
  get element() { return getElement(this); }
};
let toastIds = 0;

export { Toast as bal_toast };
