import { EventEmitter, ComponentInterface } from '../../stencil-public-runtime';
import { Props } from '../../types';
export declare class Button implements ComponentInterface {
  el: HTMLElement;
  /**
   * The color to use from your application's color palette.
   */
  color: Props.BalButtonColor;
  /**
   * The type of button.
   */
  elementType: Props.BalButtonElementType;
  /**
   * If `true`, the user cannot interact with the button.
   */
  disabled: boolean;
  /**
   * Size of the button
   */
  size: Props.BalButtonSize;
  /**
   * Specifies the URL of the page the link goes to
   */
  href?: string;
  /**
   * Specifies where to display the linked URL.
   * Only applies when an `href` is provided.
   */
  target: Props.BalButtonTarget;
  /**
   * Specifies the relationship of the target object to the link object.
   * The value is a space-separated list of [link types](https://developer.mozilla.org/en-US/docs/Web/HTML/Link_types).
   */
  rel?: string;
  /**
   * This attribute instructs browsers to download a URL instead of navigating to
   * it, so the user will be prompted to save it as a local file. If the attribute
   * has a value, it is used as the pre-filled file name in the Save prompt
   * (the user can still change the file name if they want).
   */
  download?: string;
  /**
   * If `true` adds a box shadow to improve readability on image background
   * */
  shadow: boolean;
  /**
   * If `true` the width of the buttons is limited
   */
  square: boolean;
  /**
   * If `true` the button has a active theme
   */
  isActive: boolean;
  /**
   * If `true` the button has a full width
   */
  expanded: boolean;
  /**
   * If `true` the button has no padding and a reduced height
   */
  flat: boolean;
  /**
   * If `true` the button is outlined
   */
  outlined: boolean;
  /**
   * If `true` the button is inverted
   */
  inverted: boolean;
  /**
   * If `true` the label is hidden and a loading spinner is shown instead.
   */
  loading: boolean;
  /**
   * If `true` the button is rounded.
   */
  rounded: boolean;
  /**
   * If `true` the top corners get rounded
   */
  topRounded: undefined | boolean;
  /**
   * If `true` the bottom corners get rounded
   */
  bottomRounded: undefined | boolean;
  /**
   * Name of the left button icon
   */
  icon: string;
  /**
   * Name of the right button icon
   */
  iconRight: string;
  /**
   * The name of the button, which is submitted with the form data.
   */
  name?: string;
  /**
   * The value of the button, which is submitted with the form data.
   */
  value?: string | number;
  /**
   * Emitted when the link element has clicked.
   */
  balNavigate: EventEmitter<MouseEvent>;
  /**
   * Emitted when the button has focus.
   */
  balFocus: EventEmitter<void>;
  /**
   * Emitted when the button loses focus.
   */
  balBlur: EventEmitter<void>;
  /**
   * Emitted when the button has been  rendered.
   */
  balDidRender: EventEmitter<void>;
  listenOnClick(ev: UIEvent): void;
  componentDidRender(): void;
  private get isIconInverted();
  private get buttonCssClass();
  private get leftIconAttrs();
  private get leftRightAttrs();
  private get loadingAttrs();
  private handleClick;
  private onFocus;
  private onBlur;
  private onClick;
  render(): any;
}
