/// <reference types="node" />
import { EventEmitter } from '../../stencil-public-runtime';
import { Props } from '../../types';
import { Events } from '../../types';
export interface PopoverPresentOptions {
  force: boolean;
}
export declare class Popover {
  private popoverId;
  private popperInstance;
  private backdropElement?;
  element: HTMLElement;
  isTouch: boolean;
  isInMainNav: boolean;
  backdropHeight: number;
  /**
   * If `true` the popover has max-width on tablet and desktop. On mobile it uses the whole viewport.
   */
  hint: boolean;
  /**
   * If `true` the popover shows on hover
   */
  hover: boolean;
  /**
   * If `true` a little arrow is added, which points to the trigger element
   */
  arrow: boolean;
  /**
   * If `true` a backdrop is added
   */
  backdrop: boolean;
  /**
   * If `true` the popover is shown as a tooltip
   */
  tooltip: boolean;
  /**
   * Define the offset of the popover content.
   */
  offsetX: number;
  /**
   * Define the offset of the popover content.
   */
  offsetY: number;
  /**
   * Define padding of the overflow
   */
  padding: number;
  /**
   * Define the position of the popover content.
   */
  position: Props.BalPopoverPlacement;
  /**
   * If `true` the popover content is open.
   */
  value: boolean;
  /**
   * If `true` there will be no backdrop
   */
  mobileTop: boolean;
  /**
   * Update the native input element when the value changes
   */
  protected valueChanged(newValue: boolean, oldValue: boolean): Promise<void>;
  /**
   * Listen when the popover opens or closes. Returns the current value.
   */
  balChange: EventEmitter<Events.BalPopoverChangeDetail>;
  /**
   * @internal - Use this to close unused popovers.
   */
  balPopoverPrepare: EventEmitter<string>;
  handlePopoverPrepare(event: CustomEvent<string>): void;
  clickOnOutside(event: UIEvent): Promise<void>;
  handleKeyUp(event: KeyboardEvent): void;
  tabOutside(event: KeyboardEvent): Promise<void>;
  resizeHandler(): Promise<void>;
  componentDidRenderTimer?: NodeJS.Timer;
  componentDidRender(): void;
  private get footMobileNav();
  componentDidLoad(): void;
  /**
   * Open the popover
   */
  present(options?: PopoverPresentOptions): Promise<void>;
  /**
   * Closes the popover
   */
  dismiss(options?: PopoverPresentOptions): Promise<void>;
  /**
   * Open or closes the popover
   */
  toggle(options?: PopoverPresentOptions): Promise<void>;
  private updatePopper;
  private get modifierOffset();
  private get modifierPreventOverflow();
  private get triggerElement();
  private get menuElement();
  private get menuInnerElement();
  private getBackdropHeight;
  render(): any;
}
