import { ComponentInterface, EventEmitter } from '../../../stencil-public-runtime';
import { Props } from '../../../types';
export declare class ProductSliderItem implements ComponentInterface {
  private inputId;
  /**
   * Src path to the image
   */
  src?: string;
  /**
   * Label or title of the product
   */
  label?: string;
  /**
   * The type of button.
   */
  elementType: Props.BalButtonElementType;
  /**
   * The name of the button, which is submitted with the form data.
   */
  name?: string;
  /**
   * The value of the button, which is submitted with the form data.
   */
  value?: string | number;
  /**
   * Specifies the URL of the page the link goes to
   */
  href?: string;
  /**
   * Specifies where to display the linked URL.
   * Only applies when an `href` is provided.
   */
  target: Props.BalButtonTarget;
  /**
   * Specifies the relationship of the target object to the link object.
   * The value is a space-separated list of [link types](https://developer.mozilla.org/en-US/docs/Web/HTML/Link_types).
   */
  rel?: string;
  /**
   * This attribute instructs browsers to download a URL instead of navigating to
   * it, so the user will be prompted to save it as a local file. If the attribute
   * has a value, it is used as the pre-filled file name in the Save prompt
   * (the user can still change the file name if they want).
   */
  download?: string;
  /**
   * Color of the background
   */
  color?: Props.BalProductSliderItemColor;
  /**
   * Emitted when the link element has clicked.
   */
  balNavigate: EventEmitter<MouseEvent>;
  /**
   * Emitted when the button has focus.
   */
  balFocus: EventEmitter<void>;
  /**
   * Emitted when the button loses focus.
   */
  balBlur: EventEmitter<void>;
  private onClick;
  private onFocus;
  private onBlur;
  render(): any;
}
