import { EventEmitter } from '../../../stencil-public-runtime';
import { Props } from '../../../types';
import { BalTabOption } from '../bal-tab.type';
export declare class TabItem {
  el: HTMLElement;
  isActive: boolean;
  /**
   * Tells if this route is active and overrides the bal-tabs value property.
   */
  active: boolean;
  /**
   * This is the key of the tab.
   */
  value: string;
  /**
   * Label for the tab.
   */
  label: string;
  /**
   * Link to path.
   */
  href: string;
  /**
   * Specifies where to display the linked URL.
   * Only applies when an `href` is provided.
   */
  target: Props.BalButtonTarget;
  /**
   * If `true` a small red bubble is added to the tab.
   */
  bubble: boolean | string;
  /**
   * If `true` the tab is disabled.
   */
  disabled: boolean;
  /**
   * If `true` the step is marked as done.
   */
  done: boolean;
  /**
   * If `true` the step is hidden.
   */
  hidden: boolean;
  /**
   * If `true` the step is marked as failed.
   */
  failed: boolean;
  /**
   * Tell's if the linking is done by a router.
   */
  prevent: boolean;
  /**
   * Tab icon not available for the steps.
   */
  icon?: string;
  /**
   * Emitted when the link element has clicked
   */
  balNavigate: EventEmitter<MouseEvent>;
  /**
   * Options of the tab like label, value etc.
   */
  getOptions(): Promise<BalTabOption>;
  /**
   * Sets the tab active.
   */
  setActive(active: boolean): Promise<void>;
  get options(): {
    value: string;
    icon: string | undefined;
    label: string;
    href: string;
    target: Props.BalButtonTarget;
    active: boolean;
    disabled: boolean;
    done: boolean;
    hidden: boolean;
    failed: boolean;
    bubble: string | boolean;
    passed: boolean;
    prevent: boolean;
    navigate: EventEmitter<MouseEvent>;
  };
  render(): any;
}
