import { EventEmitter } from '../../stencil-public-runtime';
import { BalTabOption } from './bal-tab.type';
import { Props, Platforms, Events } from '../../types';
export declare class Tabs {
  el: HTMLElement;
  private didInit;
  private mutationO?;
  private timeoutTimer?;
  tabsOptions: BalTabOption[];
  lineWidth: number;
  lineOffsetLeft: number;
  lineHeight: number;
  lineOffsetTop: number;
  isReady: boolean;
  platform: Platforms[];
  /**
   * Defines the layout of the tabs.
   */
  interface: Props.BalTabsInterface;
  /**
   * Defines the layout of the tabs.
   */
  iconPosition: Props.BalTabsIconPosition;
  /**
   * Defines the layout of the tabs. Right only works from the breakpoint
   * high-definition and beyond.
   */
  float: Props.BalTabsFloat;
  /**
   * If `true` the field expands over the whole width.
   */
  expanded: boolean;
  /**
   * If `true` the tabs container does not have a padding left or right.
   */
  spaceless: boolean;
  /**
   * If `true` the field expands over the whole width.
   */
  inverted: boolean;
  /**
   * If `true` the tabs is a block element and uses 100% of the width
   */
  fullwidth: boolean;
  /**
   * If `true` the tabs or steps can be clicked.
   */
  clickable: boolean;
  /**
   * If `true` a light border is shown for the tabs.
   */
  border: boolean;
  /**
   * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
   */
  debounce: number;
  /**
   * If `true` tabs are align vertically.
   */
  vertical: Props.BalTabsVertical;
  /**
   * The col size of the tabs on vertical mode.
   */
  verticalColSize: Props.BalTabsColSize;
  /**
   * If `true` the tabs are shown as a select component on mobile
   */
  selectOnMobile: boolean;
  protected debounceChanged(): void;
  value?: string;
  protected valueChanged(newValue?: string, oldValue?: string): Promise<void>;
  /**
   * Emitted when the changes has finished.
   */
  balChange: EventEmitter<Events.BalTabsChangeDetail>;
  resizeHandler(): Promise<void>;
  popoverHandler(): Promise<void>;
  connectedCallback(): void;
  disconnectedCallback(): void;
  componentDidLoad(): void;
  componentDidRender(): void;
  /**
   * Go to tab with the given value
   */
  select(tab: BalTabOption): Promise<void>;
  /**
   * @internal
   * Rerenders the line to mark the active tab.
   */
  renderLine(): Promise<void>;
  private get tabs();
  private updateTabs;
  private onSelectTab;
  private parseVertical;
  private moveLine;
  private getTargetElement;
  private isTabActive;
  render(): any;
}
