import { EventEmitter, ComponentInterface } from '../../../stencil-public-runtime';
import { BalCalendarCell, BalPointerDate } from './bal-datepicker.type';
import { BalLanguage, BalConfigState, BalRegion } from '../../../config/config.types';
import { BalConfigObserver } from '../../../config';
import { FormInput } from '../../../helpers/form-input.helpers';
import { Props, Events } from '../../../types';
export declare class Datepicker implements ComponentInterface, BalConfigObserver, FormInput<string | undefined> {
  private inputId;
  private inheritedAttributes;
  private popoverElement;
  nativeInput: HTMLInputElement;
  inputValue: string | undefined;
  initialValue?: string;
  el: HTMLElement;
  language: BalLanguage;
  region: BalRegion;
  isMobile: boolean;
  hasFocus: boolean;
  isPopoverOpen: boolean;
  selectedDate?: string;
  pointerDate: BalPointerDate;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * If `true` the component gets a invalid style.
   */
  invalid: boolean;
  /**
   * @deprecated Define the locale of month and day names.
   */
  locale: 'en' | 'de' | 'fr' | 'it' | '';
  watchLocaleHandler(): void;
  private migrateLocale;
  /**
   * Set this to `true` when the component is placed on a dark background.
   */
  inverted: boolean;
  /**
   * If `true` the attribute required is added to the native input.
   */
  required: boolean;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * The text to display when the select is empty.
   */
  placeholder?: string;
  /**
   * The minimum datetime allowed. Value must be a date string
   * following the
   * [ISO 8601 datetime format standard](https://www.w3.org/TR/NOTE-datetime),
   * such as `1996-12-19`. The format does not have to be specific to an exact
   * datetime. For example, the minimum could just be the year, such as `1994`.
   * Defaults to the beginning of the year, 100 years ago from today.
   */
  min?: string;
  /**
   * The maximum datetime allowed. Value must be a date string
   * following the
   * [ISO 8601 datetime format standard](https://www.w3.org/TR/NOTE-datetime),
   * `1996-12-19`. The format does not have to be specific to an exact
   * datetime. For example, the maximum could just be the year, such as `1994`.
   * Defaults to the end of this year.
   */
  max?: string;
  /**
   * Closes the datepicker popover after selection
   */
  closeOnSelect: boolean;
  /**
   * If `true` the datepicker only open on click of the icon
   */
  triggerIcon: boolean;
  /**
   * Earliest year available for selection
   */
  minYearProp?: number;
  /**
   * Latest year available for selection
   */
  maxYearProp?: number;
  /**
   * Set the amount of time, in milliseconds, to wait to trigger the `ionChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
   */
  debounce: number;
  protected debounceChanged(): void;
  /**
   * The date to defines where the datepicker popup starts. The prop accepts ISO 8601 date strings (YYYY-MM-DD).
   */
  defaultDate?: string;
  /**
   * The value of the form field, which accepts ISO 8601 date strings (YYYY-MM-DD).
   */
  value?: string;
  /**
   * Update the native input element when the value changes
   */
  protected valueChanged(): void;
  /**
   * Callback to determine which date in the datepicker should be selectable.
   */
  allowedDates: Props.BalDatepickerCallback | undefined;
  /**
   * Emitted when a option got selected.
   */
  balChange: EventEmitter<Events.BalDatepickerChangeDetail>;
  /**
   * Emitted when a keyboard input occurred.
   */
  balInput: EventEmitter<Events.BalDatepickerInputDetail>;
  /**
   * Emitted when the input loses focus.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  listenOnClick(event: UIEvent): void;
  private resetHandlerTimer?;
  resetHandler(event: UIEvent): void;
  resizeHandler(): Promise<void>;
  connectedCallback(): void;
  componentDidLoad(): void;
  componentWillLoad(): void;
  disconnectedCallback(): void;
  configChanged(config: BalConfigState): void;
  /**
   * Opens the popover
   */
  open(): Promise<void>;
  /**
   * Closes the popover
   */
  close(): Promise<void>;
  /**
   * Selects an option
   */
  select(dateString: string): Promise<void>;
  /**
   * Sets focus on the native `input`. Use this method instead of the global
   * `input.focus()`.
   */
  setFocus(): Promise<void>;
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  setBlur(): Promise<void>;
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement(): Promise<HTMLInputElement>;
  private updatePointerDates;
  private updateValue;
  get minYear(): number;
  get maxYear(): number;
  get years(): number[];
  get months(): {
    name: string;
    index: number;
  }[];
  get weekDays(): string[];
  get firstDateOfBox(): Date;
  getLocale(): string;
  get calendarGrid(): BalCalendarCell[][];
  private getAllowedDates;
  private onIconClick;
  private onInputClick;
  private onPopoverChange;
  private onInput;
  private onInputChange;
  private onClickDateCell;
  private onInputKeyUp;
  private onInputKeyDown;
  private onMonthSelect;
  private onYearSelect;
  private onInputFocus;
  private onInputBlur;
  private handleClick;
  render(): any;
  renderInput(): any;
  renderGrid(): any;
  renderWeekDayHeader(): any;
  renderHeader(): any;
  private previousMonth;
  private nextMonth;
  private calcPreviousMonth;
  private calcNextMonth;
  private lastDayOfMonth;
  private get isPreviousMonthDisabled();
  private get isNextMonthDisabled();
  private isDateInRange;
}
