import { EventEmitter } from '../../../stencil-public-runtime';
import { FileUploadRejectedFile } from './bal-file-upload.type';
import { FormInput } from '../../../helpers/form-input.helpers';
export declare class FileUpload implements FormInput<File[]> {
  el: HTMLElement;
  private uploadId;
  nativeInput: HTMLInputElement;
  bundleSize: number;
  inputValue?: File[] | undefined;
  isOver: boolean;
  files: File[];
  hasFocus: boolean;
  onValueChange(): void;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * Label of the drop area.
   */
  label: string;
  /**
   * If `true` multiple file upload is possible.
   */
  multiple: boolean;
  /**
   * If `true` below the drop-down area it generates a file list.
   */
  hasFileList: boolean;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true`, the user must fill in a value before submitting a form.
   */
  required: boolean;
  /**
   * If `true` the component gets a invalid style.
   */
  invalid: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * Accepted MIME-Types like `image/png,image/jpeg`.
   */
  accept: string;
  /**
   * Allowed number of files in the bundle.
   */
  maxFiles?: number;
  /**
   * Allowed max file size in bytes.
   */
  maxFileSize?: number;
  /**
   * Allowed max bundle size in bytes.
   */
  maxBundleSize?: number;
  /**
   * Input value.
   */
  value: File[];
  /**
   * If `true` the file upload is disabled and shows a spinner
   */
  loading: boolean;
  /**
   * Overrides the default subtitle file size
   */
  subTitle?: (file: File) => string;
  /**
   * Triggers when a file is added or removed.
   */
  balChange: EventEmitter<File[]>;
  /**
   * Triggers when a file is added.
   */
  balFilesAddedEmitter: EventEmitter<File[]>;
  /**
   * Triggers when a file is removed.
   */
  balFilesRemovedEmitter: EventEmitter<File[]>;
  /**
   * Emitted when the input has clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  /**
   * Emitted when the input loses focus.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  /**
   * Triggers when a file is rejected due to not allowed MIME-Type and so on.
   */
  balRejectedFileEventEmitter: EventEmitter<FileUploadRejectedFile>;
  dragenterHandler(): void;
  dragoverHandler(): void;
  dragleaveHandler(): void;
  dropHandler(event: DragEvent): void;
  handleFiles: (files: FileList) => void;
  componentWillLoad(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  /**
   * Sets the file list to an empty list
   */
  clear(): Promise<void>;
  /**
   * Sets focus on the native `input`. Use this method instead of the global
   * `input.focus()`.
   */
  setFocus(): Promise<void>;
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  setBlur(): Promise<void>;
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement(): Promise<HTMLInputElement>;
  private removeFile;
  private onInputChange;
  private setFileList;
  private onInputFocus;
  private onInputBlur;
  private handleClick;
  private onInputClick;
  render(): any;
}
