import { EventEmitter } from '../../../stencil-public-runtime';
import { Events } from '../../../types';
export declare class InputSlider {
  el: HTMLElement;
  private inputId;
  private nativeInput?;
  private didInit;
  private hasFocus;
  private initialValue?;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * The step size. 0 means no steps.
   */
  step: number;
  /**
   * Min value of the model.
   */
  min: number;
  /**
   * Max value of the model.
   */
  max: number;
  /**
   * The tabindex of the control.
   */
  balTabindex: number;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * If `true`, the user must fill in a value before submitting a form.
   */
  required: boolean;
  /**
   * If `true`, small ticks for the steps are shown.
   */
  hasTicks: boolean;
  /**
   * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
   */
  debounce: number;
  protected debounceChanged(): void;
  /**
   * The value of the input.
   */
  value?: string | number;
  /**
   * Emitted when a keyboard input occurred.
   */
  balInput: EventEmitter<string | number | null>;
  /**
   * Emitted when a keyboard input occurred.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  /**
   * Emitted when a keyboard key has pressed.
   */
  balKeyPress: EventEmitter<KeyboardEvent>;
  /**
   * Emitted when the input has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input value has changed.
   */
  balChange: EventEmitter<Events.BalInputSliderChangeDetail>;
  listenOnClick(ev: UIEvent): void;
  private resetHandlerTimer?;
  resetHandler(event: UIEvent): void;
  /**
   * Update the native input element when the value changes
   */
  protected valueChanged(newValue: string | number | undefined, oldValue: string | number | undefined): void;
  connectedCallback(): void;
  componentDidLoad(): void;
  private setFocusTimer?;
  /**
   * Sets focus on the native `input` in `bal-input`. Use this method instead of the global
   * `input.focus()`.
   */
  setFocus(): Promise<void>;
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement(): Promise<HTMLInputElement | undefined>;
  get numberOfSteps(): number;
  private cssWidth;
  private onInput;
  private handleClick;
  private onFocus;
  private onBlur;
  private onClick;
  private getNumberOfSteps;
  render(): any;
}
