import { ComponentInterface, EventEmitter } from '../../../stencil-public-runtime';
import { FormInput } from '../../../helpers/form-input.helpers';
import { BalConfigObserver, BalConfigState, BalLanguage, BalRegion } from '../../../config';
import { Events } from '../../../types';
export declare class InputStepper implements ComponentInterface, BalConfigObserver, FormInput<number | undefined> {
  private inputId;
  private inheritedAttributes;
  nativeInput?: HTMLInputElement;
  el: HTMLElement;
  hasFocus: boolean;
  language: BalLanguage;
  region: BalRegion;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * The min value the input can have
   */
  min: number;
  /**
   * The max value the input can have
   */
  max: number;
  /**
   * The steps in which the input increases or decreases
   */
  steps: number;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * If `true` the input is shown as invalid
   */
  invalid: boolean;
  /**
   * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
   */
  debounce: number;
  protected debounceChanged(): void;
  /**
   * The value of the input. Only allows values in the range of the min max attribute.
   */
  value: number;
  private initialValue;
  /**
   * Emitted when the input value has changed.
   */
  balChange: EventEmitter<Events.BalInputStepperChangeDetail>;
  /**
   * Emitted when the input value has changed.
   */
  balInput: EventEmitter<Events.BalInputStepperInputDetail>;
  /**
   * Emitted when the input value has increased.
   */
  balIncrease: EventEmitter<Events.BalInputStepperChangeDetail>;
  /**
   * Emitted when the input value has decreased.
   */
  balDecrease: EventEmitter<Events.BalInputStepperChangeDetail>;
  listenOnClick(event: UIEvent): void;
  resetHandler(event: UIEvent): void;
  connectedCallback(): void;
  componentWillLoad(): void;
  disconnectedCallback(): void;
  configChanged(state: BalConfigState): void;
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement(): Promise<HTMLInputElement | undefined>;
  increase(): void;
  decrease(): void;
  render(): any;
}
