import { ComponentInterface, EventEmitter } from '../../../stencil-public-runtime';
import { BalConfigObserver, BalConfigState, BalLanguage, BalRegion } from '../../../config';
import { Events } from '../../../types';
import { FormInput } from '../../../helpers/form-input.helpers';
export declare class NumberInput implements ComponentInterface, BalConfigObserver, FormInput<number | undefined> {
  private inputId;
  private inheritedAttributes;
  nativeInput?: HTMLInputElement;
  inputValue: number | undefined;
  initialValue: number;
  el: HTMLElement;
  hasFocus: boolean;
  language: BalLanguage;
  region: BalRegion;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * If `true` the component gets a invalid style.
   */
  invalid: boolean;
  /**
   * Defines the allowed decimal points for the `number-input`.
   */
  decimal: number;
  /**
   * Adds a suffix the the input-value after blur.
   */
  suffix?: string;
  /**
   * Instructional text that shows before the input has a value.
   */
  placeholder?: string;
  /**
   * If `true`, the user must fill in a value before submitting a form.
   */
  required: boolean;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * If `true` the input value has 0 as default value
   */
  exactNumber: boolean;
  /**
   * Set the amount of time, in milliseconds, to wait to trigger the `balChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
   */
  debounce: number;
  protected debounceChanged(): void;
  /**
   * The value of the input.
   */
  value?: number;
  /**
   * Emitted when a keyboard input occurred.
   */
  balInput: EventEmitter<Events.BalInputNumberInputDetail>;
  /**
   * Emitted when the value has changed.
   */
  balChange: EventEmitter<Events.BalInputNumberChangeDetail>;
  /**
   * Emitted when the input loses focus.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  /**
   * Emitted when a keyboard key has pressed.
   */
  balKeyPress: EventEmitter<KeyboardEvent>;
  /**
   * Emitted when the input has clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  listenOnClick(event: UIEvent): void;
  private resetHandlerTimer?;
  resetHandler(event: UIEvent): void;
  connectedCallback(): void;
  componentDidLoad(): void;
  componentWillLoad(): void;
  disconnectedCallback(): void;
  configChanged(state: BalConfigState): void;
  /**
   * Sets focus on the native `input`. Use this method instead of the global
   * `input.focus()`.
   */
  setFocus(): Promise<void>;
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  setBlur(): Promise<void>;
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement(): Promise<HTMLInputElement>;
  private getAllowedKeys;
  private getRawValue;
  private getFormattedValue;
  private onInput;
  private onBlur;
  private onKeydown;
  private onFocus;
  private onClick;
  private handleClick;
  get pattern(): string;
  render(): any;
}
