import { EventEmitter, ComponentInterface } from '../../../stencil-public-runtime';
import { FormInput } from '../../../helpers/form-input.helpers';
import { Props, Events } from '../../../types';
export declare class Radio implements ComponentInterface, FormInput<any> {
  private inputId;
  private inheritedAttributes;
  nativeInput?: HTMLInputElement;
  el: HTMLElement;
  hasFocus: boolean;
  hasLabel: boolean;
  /**
   * @deprecated If `true` the radio has no label
   */
  isEmpty: boolean;
  isEmptyHandler(): void;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * If `true` the radio has no label
   */
  labelHidden: boolean;
  /**
   * If `true` the control is no padding
   */
  flat: boolean;
  /**
   * Defines the layout of the radio button
   */
  interface: Props.BalRadioInterface;
  /**
   * Value of the radio item, if checked the whole group has this value.
   */
  value: number | string | boolean;
  /**
   * If `true`, the radio is selected.
   */
  checked: boolean;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * If `true`, the user must fill in a value before submitting a form.
   */
  required: boolean;
  /**
   * If `true`, the value will not be send with a form submit
   */
  hidden: boolean;
  /**
   * If `true` the component gets a invalid style.
   */
  invalid: boolean;
  /**
   * Emitted when the toggle has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  /**
   * Emitted when the toggle loses focus.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the checked property has changed.
   */
  balChange: EventEmitter<Events.BalRadioChangeDetail>;
  /**
   * Emitted when the input has clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  listenOnClick(ev: UIEvent): void;
  componentWillLoad(): void;
  connectedCallback(): void;
  disconnectedCallback(): void;
  /**
   * Sets the focus on the checkbox input element.
   */
  setFocus(): Promise<void>;
  /**
   * Sets blur on the native `input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  setBlur(): Promise<void>;
  /**
   * Returns the native `<input>` element used under the hood.
   */
  getInputElement(): Promise<HTMLInputElement | undefined>;
  get group(): HTMLBalRadioGroupElement | null;
  private updateState;
  private onInputFocus;
  private onInputBlur;
  private onClick;
  render(): any;
}
