/// <reference types="node" />
import { EventEmitter } from '../../../stencil-public-runtime';
import { BalOptionValue } from './utils/bal-option.type';
import { Props, Events } from '../../../types';
export interface BalOptionController extends BalOptionValue {
  id: string;
  textContent: string;
  innerHTML: string;
}
export declare class Select {
  private el;
  private inputElement;
  private nativeSelectEl;
  private popoverElement;
  private selectionEl;
  private didInit;
  private inputId;
  private clearScrollToValue;
  private clearSelectValue;
  private mutationO?;
  private initialValue?;
  hasFocus: boolean;
  inputValue: string;
  focusIndex: number;
  isPopoverOpen: boolean;
  options: Map<string, BalOptionController>;
  labelToScrollTo: string;
  labelToSelectTo: string;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * If `true` the component gets a invalid style.
   */
  invalid: boolean;
  /**
   * If `true` the component gets a invalid style.
   */
  filter: Props.BalSelectFilter;
  /**
   * The tabindex of the control.
   */
  balTabindex: number;
  /**
   * If `true` multiple option can be selected
   */
  multiple: boolean;
  /**
   * Defines the max length of the value.
   */
  maxLength?: number;
  /**
   * This label is shown if typeahead is active and all the options are filtered out.
   */
  noDataLabel?: string;
  /**
   * @deprecated  Removes the border of the input.
   */
  noBorder: boolean;
  /**
   * Indicates whether the value of the control can be automatically completed by the browser.
   */
  autocomplete: Props.BalInputAutocomplete;
  /**
   * @deprecated Enables the slide in animation for the option items.
   */
  hasMovement: boolean;
  /**
   * If `true` the user can search by typing into the input field.
   */
  typeahead: boolean;
  /**
   * If `true` the options are a proposal and the user can also create his
   * own value. Can only be used with the typeahead property.
   */
  selectionOptional: boolean;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * If `true`, the user must fill in a value before submitting a form.
   */
  required: boolean;
  /**
   * @deprecated  Set this to `true` when the component is placed on a dark background.
   * Set this to `true` when the component is placed on a dark background.
   */
  inverted: boolean;
  /**
   * The text to display when the select is empty.
   */
  placeholder?: string;
  /**
   * Defines the height of the popover list.
   */
  scrollable: number;
  /**
   * Defines if the select is in a loading state.
   */
  loading: boolean;
  /**
   * If `true` the filtering is done outside the component.
   */
  remote: boolean;
  /**
   * Selected option values. Could also be passed as a string, which gets transformed.
   */
  value?: string | string[];
  rawValue: string[] | undefined;
  valueWatcher(): void;
  rawValueWatcher(newValue: string[], oldValue: string[] | undefined, isHuman?: boolean): void;
  /**
   * Emitted when a option got selected.
   */
  balChange: EventEmitter<Events.BalSelectChangeDetail>;
  /**
   * Emitted when the input got clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  /**
   * Emitted when a keyboard input occurred.
   */
  balInput: EventEmitter<string>;
  /**
   * Emitted when the input loses focus.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  /**
   * Emitted when the user cancels the input.
   */
  balCancel: EventEmitter<KeyboardEvent>;
  /**
   * Emitted when the input has focus and key from the keyboard go hit.
   */
  balKeyPress: EventEmitter<KeyboardEvent>;
  listenOnClick(event: UIEvent): void;
  private resetHandlerTimer?;
  resetHandler(event: UIEvent): void;
  handleKeyDown(event: KeyboardEvent): Promise<void>;
  connectedCallback(): void;
  disconnectedCallback(): void;
  waitForOptionsAndThenUpdateRawValuesTimer?: NodeJS.Timer;
  waitForOptionsAndThenUpdateRawValues(): Promise<void>;
  componentWillLoad(): void;
  componentDidLoad(): void;
  private updateOptions;
  private setFocusTimer?;
  /**
   * Sets the focus on the input element
   */
  setFocus(): Promise<void>;
  /**
   * Sets the focus on the input element
   */
  getValue(): Promise<string[] | undefined>;
  /**
   * Sets the value to `[]`, the input value to ´''´ and the focus index to ´0´.
   */
  clear(): Promise<void>;
  /**
   * Opens the popover
   */
  open(): Promise<void>;
  /**
   * Closes the popover
   */
  close(): Promise<void>;
  /**
   * Cancel the popover
   */
  cancel(): Promise<void>;
  /**
   * Select option by passed value
   */
  select(value: string): Promise<void>;
  /********************************************************
   * GETTERS
   ********************************************************/
  private get optionArray();
  private hasOptions;
  private get inputPlaceholder();
  private getChildOpts;
  private getPopoverContent;
  /********************************************************
   * FOCUS
   ********************************************************/
  private updateFocusTimer?;
  private updateFocus;
  private scrollToFocusedOption;
  private scrollTo;
  private selectedFocusedOption;
  private navigateWithArrowKey;
  private focusOptionByLabel;
  private selectOptionByLabel;
  private selectLabel;
  private scrollToLabel;
  /********************************************************
   * VALUE & FILTER & SELECTION
   ********************************************************/
  private updateRawValue;
  private blurSelect;
  private optionSelected;
  private updateValue;
  private removeValue;
  private validateAfterBlur;
  private updateInputValueTimer?;
  private updateInputValue;
  private syncNativeInput;
  /********************************************************
   * EVENT HANDLERS
   ********************************************************/
  private handleClick;
  private handlePopoverChange;
  private handleInputBlur;
  private handleInputFocus;
  private isChipClicked;
  private handleInputClick;
  private handleKeyPress;
  private handleInputChange;
  private handleInput;
  private handleOptionMouseEnter;
  render(): any;
}
