import { EventEmitter, ComponentInterface } from '../../../stencil-public-runtime';
import { FormInput } from '../../../helpers/form-input.helpers';
import { Props, Events } from '../../../types';
export declare class Textarea implements ComponentInterface, FormInput<string | undefined> {
  private inputId;
  private inheritedAttributes;
  nativeInput?: HTMLTextAreaElement;
  inputValue: string | undefined;
  initialValue: string;
  el: HTMLElement;
  hasFocus: boolean;
  /**
   * The name of the control, which is submitted with the form data.
   */
  name: string;
  /**
   * If `true` the component gets a invalid style.
   */
  invalid: boolean;
  /**
   * Indicates whether and how the text value should be automatically capitalized as it is entered/edited by the user.
   */
  autocapitalize: string;
  /**
   * This Boolean attribute lets you specify that a form control should have input focus when the page loads.
   */
  autofocus: boolean;
  /**
   * Set the amount of time, in milliseconds, to wait to trigger the `ionChange` event after each keystroke. This also impacts form bindings such as `ngModel` or `v-model`.
   */
  debounce: number;
  protected debounceChanged(): void;
  /**
   * Instructional text that shows before the input has a value.
   */
  placeholder?: string;
  /**
   * If the value of the type attribute is `text`, `email`, `search`, `password`, `tel`, or `url`, this attribute specifies the maximum number of characters that the user can enter.
   */
  maxLength?: number;
  /**
   * If the value of the type attribute is `text`, `email`, `search`, `password`, `tel`, or `url`, this attribute specifies the minimum number of characters that the user can enter.
   */
  minLength?: number;
  /**
   * If `true` this component can be placed on dark background
   */
  inverted: boolean;
  /**
   * If `true`, the element is not mutable, focusable, or even submitted with the form. The user can neither edit nor focus on the control, nor its form control descendants.
   */
  disabled: boolean;
  /**
   * If `true` the element can not mutated, meaning the user can not edit the control.
   */
  readonly: boolean;
  /**
   * The visible width of the text control, in average character widths. If it is specified, it must be a positive integer.
   */
  cols?: number;
  /**
   * The number of visible text lines for the control.
   */
  rows?: number;
  /**
   * Indicates how the control wraps text.
   */
  wrap?: Props.BalTextareaWrap;
  /**
   * If `true`, the user must fill in a value before submitting a form.
   */
  required: boolean;
  /**
   * If `true` the input gets a clickable cursor style
   */
  clickable: boolean;
  /**
   * A hint to the browser for which keyboard to display.
   * Possible values: `"none"`, `"text"`, `"tel"`, `"url"`,
   * `"email"`, `"numeric"`, `"decimal"`, and `"search"`.
   */
  inputmode?: Props.BalTextareaInputMode;
  /**
   * The value of the textarea.
   */
  value?: string;
  /**
   * Emitted when the input value has changed..
   */
  balChange: EventEmitter<Events.BalTextareaChangeDetail>;
  /**
   * Emitted when a keyboard input occurred.
   */
  balInput: EventEmitter<Events.BalTextareaInputDetail>;
  /**
   * Emitted when a keyboard input occurred.
   */
  balBlur: EventEmitter<FocusEvent>;
  /**
   * Emitted when the input has clicked.
   */
  balClick: EventEmitter<MouseEvent>;
  /**
   * Emitted when a keyboard key has pressed.
   */
  balKeyPress: EventEmitter<KeyboardEvent>;
  /**
   * Emitted when the input has focus.
   */
  balFocus: EventEmitter<FocusEvent>;
  listenOnClick(event: UIEvent): void;
  private resetHandlerTimer?;
  resetHandler(event: UIEvent): void;
  connectedCallback(): void;
  componentDidLoad(): void;
  componentWillLoad(): void;
  /**
   * Sets focus on the native `input` in `bal-input`. Use this method instead of the global
   * `input.focus()`.
   */
  setFocus(): Promise<void>;
  /**
   * Sets blur on the native `input` in `bal-input`. Use this method instead of the global
   * `input.blur()`.
   * @internal
   */
  setBlur(): Promise<void>;
  /**
   * Returns the native `<textarea>` element used under the hood.
   */
  getInputElement(): Promise<HTMLTextAreaElement | undefined>;
  private getValue;
  private onInput;
  private onFocus;
  private onBlur;
  private onClick;
  private handleClick;
  render(): any;
}
