import { EventEmitter } from '../../../stencil-public-runtime';
import { OverlayEventDetail, OverlayInterface } from './bal-modal.type';
import { Props } from '../../../types';
export declare class Modal implements OverlayInterface {
  private usersElement?;
  private modalContentElement?;
  private modalContainerElement?;
  private modalBackgroundElement?;
  private bodyScrollBlocker;
  presented: boolean;
  el: HTMLBalModalElement;
  /** @internal */
  overlayIndex: number;
  /** @internal */
  delegate?: Props.FrameworkDelegate;
  /** @internal */
  dataTestId?: string;
  /**
   * Defines the width of the modal body
   */
  modalWidth: number;
  /**
   * Defines the space/padding of the modal
   */
  space: Props.BalModalSpace;
  /**
   * If `true`, a backdrop will be displayed behind the modal.
   */
  hasBackdrop: boolean;
  /**
   * If `true`, the modal can be closed with the escape key or the little close button.
   */
  isClosable: boolean;
  /**
   * The component to display inside of the modal.
   */
  component: Props.ComponentRef;
  /**
   * The data to pass to the modal component.
   */
  componentProps?: Props.ComponentProps;
  /**
   * Additional classes to apply for custom CSS. If multiple classes are
   * provided they should be separated by spaces.
   */
  cssClass?: string | string[];
  /**
   * Emitted after the modal has presented.
   */
  didPresent: EventEmitter<void>;
  /**
   * Emitted before the modal has presented.
   */
  willPresent: EventEmitter<void>;
  /**
   * Emitted before the modal has dismissed.
   */
  willDismiss: EventEmitter<OverlayEventDetail>;
  /**
   * Emitted after the modal has dismissed.
   */
  didDismiss: EventEmitter<OverlayEventDetail>;
  connectedCallback(): void;
  /**
   * @internal Opens the modal.
   */
  open(): Promise<void>;
  /**
   * @internal Closes the modal.
   */
  close(): Promise<void>;
  /**
   * Presents the modal through the modal controller
   */
  present(): Promise<void>;
  /**
   * Closes the presented modal with the modal controller
   */
  dismiss(data?: any, role?: string): Promise<boolean>;
  /**
   * Returns a promise that resolves when the modal did dismiss.
   */
  onDidDismiss<T = any>(): Promise<OverlayEventDetail<T>>;
  /**
   * Returns a promise that resolves when the modal will dismiss.
   */
  onWillDismiss<T = any>(): Promise<OverlayEventDetail<T>>;
  onClickCloseButton(event: MouseEvent): Promise<void>;
  handleKeyUp(event: KeyboardEvent): Promise<void>;
  private setModalActiveOnBody;
  private unsetModalActiveOnBody;
  render(): any;
}
