import { EventEmitter } from '../../../stencil-public-runtime';
import { Props } from '../../../types';
export declare class Snackbar {
  element: HTMLElement;
  private timer;
  private snackbarId;
  animationClass: string;
  /**
   * The theme type of the snackbar. Given by bulma our css framework.
   */
  color: Props.BalSnackbarColor;
  /**
   * The duration of the snackbar
   */
  duration: number;
  /**
   * The subject of the snackbar header
   */
  subject: string;
  /**
   * The message of the snackbar as html content
   */
  message: string;
  /**
   * The icon of the snackbar header
   */
  icon: string;
  /**
   * Label text for the action button
   */
  action: string;
  /**
   * @internal Handler for on close event
   */
  closeHandler: () => void;
  /**
   * @internal Handler for on action button click event
   */
  actionHandler: () => void;
  /**
   * Specifies the URL of the page the link goes to
   */
  href?: string;
  /**
   * Specifies where to display the linked URL.
   * Only applies when an `href` is provided.
   */
  target: Props.BalButtonTarget;
  /**
   * Emitted when snackbar is closed
   */
  balClose: EventEmitter<string>;
  /**
   * Emitted when the action button is clicked
   */
  balAction: EventEmitter<string>;
  componentWillLoad(): Promise<void>;
  /**
   * Closes the snackbar after the given duration in ms
   */
  closeIn(duration: number): Promise<void>;
  /**
   * Closes this snackbar
   */
  close(): Promise<void>;
  onActionHandler: () => void;
  get colorType(): string;
  get buttonType(): Props.BalButtonColor;
  render(): any;
}
